/* Generated by Cython 0.20 on Wed Apr  2 22:44:20 2014 */

#define PY_SSIZE_T_CLEAN
#ifndef CYTHON_USE_PYLONG_INTERNALS
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 0
#else
#include "pyconfig.h"
#ifdef PYLONG_BITS_IN_DIGIT
#define CYTHON_USE_PYLONG_INTERNALS 1
#else
#define CYTHON_USE_PYLONG_INTERNALS 0
#endif
#endif
#endif
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02040000
    #error Cython requires Python 2.4+.
#else
#define CYTHON_ABI "0_20"
#include <stddef.h> /* For offsetof */
#ifndef offsetof
#define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
#define CYTHON_COMPILING_IN_PYPY 1
#define CYTHON_COMPILING_IN_CPYTHON 0
#else
#define CYTHON_COMPILING_IN_PYPY 0
#define CYTHON_COMPILING_IN_CPYTHON 1
#endif
#if CYTHON_COMPILING_IN_PYPY
#define Py_OptimizeFlag 0
#endif
#if PY_VERSION_HEX < 0x02050000
  typedef int Py_ssize_t;
  #define PY_SSIZE_T_MAX INT_MAX
  #define PY_SSIZE_T_MIN INT_MIN
  #define PY_FORMAT_SIZE_T ""
  #define CYTHON_FORMAT_SSIZE_T ""
  #define PyInt_FromSsize_t(z) PyInt_FromLong(z)
  #define PyInt_AsSsize_t(o)   __Pyx_PyInt_As_int(o)
  #define PyNumber_Index(o)    ((PyNumber_Check(o) && !PyFloat_Check(o)) ? PyNumber_Int(o) : \
                                (PyErr_Format(PyExc_TypeError, \
                                              "expected index value, got %.200s", Py_TYPE(o)->tp_name), \
                                 (PyObject*)0))
  #define __Pyx_PyIndex_Check(o) (PyNumber_Check(o) && !PyFloat_Check(o) && \
                                  !PyComplex_Check(o))
  #define PyIndex_Check __Pyx_PyIndex_Check
  #define PyErr_WarnEx(category, message, stacklevel) PyErr_Warn(category, message)
  #define __PYX_BUILD_PY_SSIZE_T "i"
#else
  #define __PYX_BUILD_PY_SSIZE_T "n"
  #define CYTHON_FORMAT_SSIZE_T "z"
  #define __Pyx_PyIndex_Check PyIndex_Check
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_REFCNT(ob) (((PyObject*)(ob))->ob_refcnt)
  #define Py_TYPE(ob)   (((PyObject*)(ob))->ob_type)
  #define Py_SIZE(ob)   (((PyVarObject*)(ob))->ob_size)
  #define PyVarObject_HEAD_INIT(type, size) \
          PyObject_HEAD_INIT(type) size,
  #define PyType_Modified(t)
  typedef struct {
     void *buf;
     PyObject *obj;
     Py_ssize_t len;
     Py_ssize_t itemsize;
     int readonly;
     int ndim;
     char *format;
     Py_ssize_t *shape;
     Py_ssize_t *strides;
     Py_ssize_t *suboffsets;
     void *internal;
  } Py_buffer;
  #define PyBUF_SIMPLE 0
  #define PyBUF_WRITABLE 0x0001
  #define PyBUF_FORMAT 0x0004
  #define PyBUF_ND 0x0008
  #define PyBUF_STRIDES (0x0010 | PyBUF_ND)
  #define PyBUF_C_CONTIGUOUS (0x0020 | PyBUF_STRIDES)
  #define PyBUF_F_CONTIGUOUS (0x0040 | PyBUF_STRIDES)
  #define PyBUF_ANY_CONTIGUOUS (0x0080 | PyBUF_STRIDES)
  #define PyBUF_INDIRECT (0x0100 | PyBUF_STRIDES)
  #define PyBUF_RECORDS (PyBUF_STRIDES | PyBUF_FORMAT | PyBUF_WRITABLE)
  #define PyBUF_FULL (PyBUF_INDIRECT | PyBUF_FORMAT | PyBUF_WRITABLE)
  typedef int (*getbufferproc)(PyObject *, Py_buffer *, int);
  typedef void (*releasebufferproc)(PyObject *, Py_buffer *);
#endif
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PyUnicode_FromString(s) PyUnicode_Decode(s, strlen(s), "UTF-8", "strict")
#endif
#if PY_MAJOR_VERSION >= 3
  #define Py_TPFLAGS_CHECKTYPES 0
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#if (PY_VERSION_HEX < 0x02060000) || (PY_MAJOR_VERSION >= 3)
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_TPFLAGS_HAVE_VERSION_TAG 0
#endif
#if PY_VERSION_HEX < 0x02060000 && !defined(Py_TPFLAGS_IS_ABSTRACT)
  #define Py_TPFLAGS_IS_ABSTRACT 0
#endif
#if PY_VERSION_HEX < 0x030400a1 && !defined(Py_TPFLAGS_HAVE_FINALIZE)
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ? \
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
#else
  #define CYTHON_PEP393_ENABLED 0
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
#endif
#define __Pyx_PyString_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#define __Pyx_PyUnicode_Concat(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ? \
    PyNumber_Add(a, b) : PyUnicode_Concat(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PyBytesObject                PyStringObject
  #define PyBytes_Type                 PyString_Type
  #define PyBytes_Check                PyString_Check
  #define PyBytes_CheckExact           PyString_CheckExact
  #define PyBytes_FromString           PyString_FromString
  #define PyBytes_FromStringAndSize    PyString_FromStringAndSize
  #define PyBytes_FromFormat           PyString_FromFormat
  #define PyBytes_DecodeEscape         PyString_DecodeEscape
  #define PyBytes_AsString             PyString_AsString
  #define PyBytes_AsStringAndSize      PyString_AsStringAndSize
  #define PyBytes_Size                 PyString_Size
  #define PyBytes_AS_STRING            PyString_AS_STRING
  #define PyBytes_GET_SIZE             PyString_GET_SIZE
  #define PyBytes_Repr                 PyString_Repr
  #define PyBytes_Concat               PyString_Concat
  #define PyBytes_ConcatAndDel         PyString_ConcatAndDel
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj) || \
                                         PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PySet_Check(obj)             PyObject_TypeCheck(obj, &PySet_Type)
  #define PyFrozenSet_Check(obj)       PyObject_TypeCheck(obj, &PyFrozenSet_Type)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_VERSION_HEX < 0x03020000
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if (PY_MAJOR_VERSION < 3) || (PY_VERSION_HEX >= 0x03010300)
  #define __Pyx_PySequence_GetSlice(obj, a, b) PySequence_GetSlice(obj, a, b)
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) PySequence_SetSlice(obj, a, b, value)
  #define __Pyx_PySequence_DelSlice(obj, a, b) PySequence_DelSlice(obj, a, b)
#else
  #define __Pyx_PySequence_GetSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), (PyObject*)0) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_GetSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object is unsliceable", (obj)->ob_type->tp_name), (PyObject*)0)))
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_SetSlice(obj, a, b, value)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice assignment", (obj)->ob_type->tp_name), -1)))
  #define __Pyx_PySequence_DelSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_DelSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice deletion", (obj)->ob_type->tp_name), -1)))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),((char *)(n)))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),((char *)(n)),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),((char *)(n)))
#else
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),(n))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),(n),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),(n))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_NAMESTR(n) ((char *)(n))
  #define __Pyx_DOCSTR(n)  ((char *)(n))
#else
  #define __Pyx_NAMESTR(n) (n)
  #define __Pyx_DOCSTR(n)  (n)
#endif
#ifndef CYTHON_INLINE
  #if defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  /* Initialize NaN. The sign is irrelevant, an exponent with all bits 1 and
   a nonzero mantissa means NaN. If the first bit in the mantissa is 1, it is
   a quiet NaN. */
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif


#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
#define _USE_MATH_DEFINES
#endif
#include <math.h>
#define __PYX_HAVE__fiona__ogrext
#define __PYX_HAVE_API__fiona__ogrext
#include "cpl_conv.h"
#include "cpl_string.h"
#include "ogr_core.h"
#include "ogr_srs_api.h"
#include "ogr_api.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
typedef struct {PyObject **p; char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry; /*proto*/

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (    \
    (sizeof(type) < sizeof(Py_ssize_t))  ||             \
    (sizeof(type) > sizeof(Py_ssize_t) &&               \
          likely(v < (type)PY_SSIZE_T_MAX ||            \
                 v == (type)PY_SSIZE_T_MAX)  &&         \
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||       \
                                v == (type)PY_SSIZE_T_MIN)))  ||  \
    (sizeof(type) == sizeof(Py_ssize_t) &&              \
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||        \
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyObject_AsSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromUString(s)  __Pyx_PyObject_FromString((char*)s)
#define __Pyx_PyBytes_FromUString(s)   __Pyx_PyBytes_FromString((char*)s)
#define __Pyx_PyByteArray_FromUString(s)   __Pyx_PyByteArray_FromString((char*)s)
#define __Pyx_PyStr_FromUString(s)     __Pyx_PyStr_FromString((char*)s)
#define __Pyx_PyUnicode_FromUString(s) __Pyx_PyUnicode_FromString((char*)s)
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return u_end - u - 1;
}
#else
#define __Pyx_Py_UNICODE_strlen Py_UNICODE_strlen
#endif
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_Owned_Py_None(b) (Py_INCREF(Py_None), Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? (Py_INCREF(Py_True), Py_True) : (Py_INCREF(Py_False), Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x);
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_COMPILING_IN_CPYTHON
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys = NULL;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    sys = PyImport_ImportModule("sys");
    if (sys == NULL) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    if (default_encoding == NULL) goto bad;
    if (strcmp(PyBytes_AsString(default_encoding), "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        const char* default_encoding_c = PyBytes_AS_STRING(default_encoding);
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (ascii_chars_u == NULL) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (ascii_chars_b == NULL || strncmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
    }
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return 0;
bad:
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys = NULL;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (sys == NULL) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    if (default_encoding == NULL) goto bad;
    default_encoding_c = PyBytes_AS_STRING(default_encoding);
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(sys);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(sys);
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


#ifdef __GNUC__
  /* Test for GCC > 2.95 */
  #if __GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95))
    #define likely(x)   __builtin_expect(!!(x), 1)
    #define unlikely(x) __builtin_expect(!!(x), 0)
  #else /* __GNUC__ > 2 ... */
    #define likely(x)   (x)
    #define unlikely(x) (x)
  #endif /* __GNUC__ > 2 ... */
#else /* __GNUC__ */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */

static PyObject *__pyx_m;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "ogrext.pyx",
};

/* "ograpi.pxd":14
 *     void    CSLDestroy (char **list)
 * 
 * ctypedef int OGRErr             # <<<<<<<<<<<<<<
 * ctypedef struct OGREnvelope:
 *     double MinX
 */
typedef int __pyx_t_5fiona_6ograpi_OGRErr;

/*--- Type declarations ---*/
struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode;
struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs;
struct __pyx_obj_5fiona_6ogrext_FeatureBuilder;
struct __pyx_obj_5fiona_6ogrext_OGRFeatureBuilder;
struct __pyx_obj_5fiona_6ogrext_Session;
struct __pyx_obj_5fiona_6ogrext_GeomBuilder;
struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder;
struct __pyx_obj_5fiona_6ogrext_Iterator;
struct __pyx_obj_5fiona_6ogrext_WritingSession;
struct __pyx_t_5fiona_6ograpi_OGREnvelope;
typedef struct __pyx_t_5fiona_6ograpi_OGREnvelope __pyx_t_5fiona_6ograpi_OGREnvelope;

/* "ograpi.pxd":15
 * 
 * ctypedef int OGRErr
 * ctypedef struct OGREnvelope:             # <<<<<<<<<<<<<<
 *     double MinX
 *     double MaxX
 */
struct __pyx_t_5fiona_6ograpi_OGREnvelope {
  double MinX;
  double MaxX;
  double MinY;
  double MaxY;
};
struct __pyx_opt_args_5fiona_6ogrext_14FeatureBuilder_build;

/* "fiona/ogrext.pyx":424
 *     """
 * 
 *     cdef build(self, void *feature, encoding='utf-8', bbox=False):             # <<<<<<<<<<<<<<
 *         # The only method anyone ever needs to call
 *         cdef void *fdefn
 */
struct __pyx_opt_args_5fiona_6ogrext_14FeatureBuilder_build {
  int __pyx_n;
  PyObject *encoding;
  PyObject *bbox;
};

/* "fiona/ogrext.pyx":393
 * 
 * 
 * def _explode(coords):             # <<<<<<<<<<<<<<
 *     """Explode a GeoJSON geometry's coordinates object and yield
 *     coordinate tuples. As long as the input is conforming, the type of
 */
struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode {
  PyObject_HEAD
  PyObject *__pyx_v_coords;
  PyObject *__pyx_v_e;
  PyObject *__pyx_v_f;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
  PyObject *__pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
};


/* "fiona/ogrext.pyx":1004
 *         log.debug("Writing started")
 * 
 *     def writerecs(self, records, collection):             # <<<<<<<<<<<<<<
 *         """Writes buffered records to OGR."""
 *         cdef void *cogr_driver
 */
struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs {
  PyObject_HEAD
  PyObject *__pyx_v_schema_geom_type;
};


/* "fiona/ogrext.pyx":417
 * # Feature extension classes and functions follow.
 * 
 * cdef class FeatureBuilder:             # <<<<<<<<<<<<<<
 *     """Build Fiona features from OGR feature pointers.
 * 
 */
struct __pyx_obj_5fiona_6ogrext_FeatureBuilder {
  PyObject_HEAD
  struct __pyx_vtabstruct_5fiona_6ogrext_FeatureBuilder *__pyx_vtab;
};


/* "fiona/ogrext.pyx":496
 * 
 * 
 * cdef class OGRFeatureBuilder:             # <<<<<<<<<<<<<<
 * 
 *     """Builds an OGR Feature from a Fiona feature mapping.
 */
struct __pyx_obj_5fiona_6ogrext_OGRFeatureBuilder {
  PyObject_HEAD
  struct __pyx_vtabstruct_5fiona_6ogrext_OGRFeatureBuilder *__pyx_vtab;
};


/* "fiona/ogrext.pyx":591
 * # Collection-related extension classes and functions
 * 
 * cdef class Session:             # <<<<<<<<<<<<<<
 * 
 *     cdef void *cogr_ds
 */
struct __pyx_obj_5fiona_6ogrext_Session {
  PyObject_HEAD
  void *cogr_ds;
  void *cogr_layer;
  PyObject *_fileencoding;
  PyObject *_encoding;
  PyObject *collection;
};


/* "fiona/ogrext.pyx":144
 * 
 * 
 * cdef class GeomBuilder:             # <<<<<<<<<<<<<<
 *     """Builds Fiona (GeoJSON) geometries from an OGR geometry handle.
 *     """
 */
struct __pyx_obj_5fiona_6ogrext_GeomBuilder {
  PyObject_HEAD
  struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *__pyx_vtab;
  void *geom;
  PyObject *code;
  PyObject *typename;
  PyObject *ndims;
};


/* "fiona/ogrext.pyx":227
 * 
 * 
 * cdef class OGRGeomBuilder:             # <<<<<<<<<<<<<<
 *     """Builds OGR geometries from Fiona geometries.
 *     """
 */
struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder {
  PyObject_HEAD
  struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *__pyx_vtab;
  PyObject *coordinates;
  PyObject *typename;
  PyObject *ndims;
};


/* "fiona/ogrext.pyx":1065
 * 
 * 
 * cdef class Iterator:             # <<<<<<<<<<<<<<
 * 
 *     """Provides iterated access to feature data.
 */
struct __pyx_obj_5fiona_6ogrext_Iterator {
  PyObject_HEAD
  PyObject *collection;
  PyObject *encoding;
};


/* "fiona/ogrext.pyx":797
 * 
 * 
 * cdef class WritingSession(Session):             # <<<<<<<<<<<<<<
 * 
 *     cdef object _schema_mapping
 */
struct __pyx_obj_5fiona_6ogrext_WritingSession {
  struct __pyx_obj_5fiona_6ogrext_Session __pyx_base;
  PyObject *_schema_mapping;
};



/* "fiona/ogrext.pyx":144
 * 
 * 
 * cdef class GeomBuilder:             # <<<<<<<<<<<<<<
 *     """Builds Fiona (GeoJSON) geometries from an OGR geometry handle.
 *     """
 */

struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder {
  PyObject *(*_buildCoords)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, void *);
  PyObject *(*_buildPoint)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch);
  PyObject *(*_buildLineString)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch);
  PyObject *(*_buildLinearRing)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch);
  PyObject *(*_buildParts)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, void *);
  PyObject *(*_buildPolygon)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch);
  PyObject *(*_buildMultiPoint)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch);
  PyObject *(*_buildMultiLineString)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch);
  PyObject *(*_buildMultiPolygon)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch);
  PyObject *(*_buildGeometryCollection)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch);
  PyObject *(*build)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, void *);
  PyObject *(*build_wkb)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, PyObject *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *__pyx_vtabptr_5fiona_6ogrext_GeomBuilder;


/* "fiona/ogrext.pyx":496
 * 
 * 
 * cdef class OGRFeatureBuilder:             # <<<<<<<<<<<<<<
 * 
 *     """Builds an OGR Feature from a Fiona feature mapping.
 */

struct __pyx_vtabstruct_5fiona_6ogrext_OGRFeatureBuilder {
  void *(*build)(struct __pyx_obj_5fiona_6ogrext_OGRFeatureBuilder *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_5fiona_6ogrext_OGRFeatureBuilder *__pyx_vtabptr_5fiona_6ogrext_OGRFeatureBuilder;


/* "fiona/ogrext.pyx":227
 * 
 * 
 * cdef class OGRGeomBuilder:             # <<<<<<<<<<<<<<
 *     """Builds OGR geometries from Fiona geometries.
 *     """
 */

struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder {
  void *(*_buildPoint)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *);
  void *(*_buildLineString)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *);
  void *(*_buildLinearRing)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *);
  void *(*_buildPolygon)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *);
  void *(*_buildMultiPoint)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *);
  void *(*_buildMultiLineString)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *);
  void *(*_buildMultiPolygon)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *);
  void *(*_buildGeometryCollection)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *);
  void *(*build)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *, PyObject *);
};
static struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *__pyx_vtabptr_5fiona_6ogrext_OGRGeomBuilder;


/* "fiona/ogrext.pyx":417
 * # Feature extension classes and functions follow.
 * 
 * cdef class FeatureBuilder:             # <<<<<<<<<<<<<<
 *     """Build Fiona features from OGR feature pointers.
 * 
 */

struct __pyx_vtabstruct_5fiona_6ogrext_FeatureBuilder {
  PyObject *(*build)(struct __pyx_obj_5fiona_6ogrext_FeatureBuilder *, void *, struct __pyx_opt_args_5fiona_6ogrext_14FeatureBuilder_build *__pyx_optional_args);
};
static struct __pyx_vtabstruct_5fiona_6ogrext_FeatureBuilder *__pyx_vtabptr_5fiona_6ogrext_FeatureBuilder;
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname); /*proto*/
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          if (acquire_gil) { \
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure(); \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
              PyGILState_Release(__pyx_gilstate_save); \
          } else { \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext() \
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif /* CYTHON_REFNANNY */
#define __Pyx_XDECREF_SET(r, v) do {                            \
        PyObject *tmp = (PyObject *) r;                         \
        r = v; __Pyx_XDECREF(tmp);                              \
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {                             \
        PyObject *tmp = (PyObject *) r;                         \
        r = v; __Pyx_DECREF(tmp);                               \
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

static PyObject *__Pyx_GetBuiltinName(PyObject *name); /*proto*/

static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found); /*proto*/

static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name); /*proto*/

static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[], \
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args, \
    const char* function_name); /*proto*/

#define __Pyx_GetItemInt_ByteArray(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck) \
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ? \
    __Pyx_GetItemInt_ByteArray_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) : \
    (PyErr_SetString(PyExc_IndexError, "bytearray index out of range"), -1))
static CYTHON_INLINE int __Pyx_GetItemInt_ByteArray_Fast(PyObject* string, Py_ssize_t i,
                                                         int wraparound, int boundscheck);

#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck) \
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ? \
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) : \
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) : \
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck) \
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ? \
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) : \
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck) \
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ? \
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) : \
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o,n,NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *); /*proto*/

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb); /*proto*/
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause); /*proto*/

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name); /*proto*/

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

static CYTHON_INLINE int __Pyx_IterFinish(void); /*proto*/

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected); /*proto*/

#include <string.h>

static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals); /*proto*/

static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals); /*proto*/

#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

static CYTHON_INLINE void __Pyx_ExceptionSave(PyObject **type, PyObject **value, PyObject **tb); /*proto*/
static void __Pyx_ExceptionReset(PyObject *type, PyObject *value, PyObject *tb); /*proto*/

static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors));

static CYTHON_INLINE int __Pyx_PySequence_Contains(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type); /*proto*/

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed); /*proto*/

static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback); /*proto*/

static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

static double __Pyx__PyObject_AsDouble(PyObject* obj); /* proto */
#if CYTHON_COMPILING_IN_PYPY
#define __Pyx_PyObject_AsDouble(obj) \
(likely(PyFloat_CheckExact(obj)) ? PyFloat_AS_DOUBLE(obj) : \
 likely(PyInt_CheckExact(obj)) ? \
 PyFloat_AsDouble(obj) : __Pyx__PyObject_AsDouble(obj))
#else
#define __Pyx_PyObject_AsDouble(obj) \
((likely(PyFloat_CheckExact(obj))) ? \
 PyFloat_AS_DOUBLE(obj) : __Pyx__PyObject_AsDouble(obj))
#endif

#if PY_MAJOR_VERSION < 3
#define __Pyx_PyString_Join __Pyx_PyBytes_Join
#define __Pyx_PyBaseString_Join(s, v) (PyUnicode_CheckExact(s) ? PyUnicode_Join(s, v) : __Pyx_PyBytes_Join(s, v))
#else
#define __Pyx_PyString_Join PyUnicode_Join
#define __Pyx_PyBaseString_Join PyUnicode_Join
#endif
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION < 3
    #define __Pyx_PyBytes_Join _PyString_Join
    #else
    #define __Pyx_PyBytes_Join _PyBytes_Join
    #endif
#else
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values); /*proto*/
#endif

static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname);

static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

#define __Pyx_CyFunction_USED 1
#include <structmember.h>
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f) \
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f) \
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f) \
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g) \
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
    int flags;
    PyObject *func_dict;
    PyObject *func_weakreflist;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj; /* No-args super() class cell */
    void *defaults;
    int defaults_pyobjects;
    PyObject *defaults_tuple;   /* Const defaults tuple */
    PyObject *defaults_kwdict;  /* Const kwonly defaults dict */
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations; /* function annotations dict */
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_NewEx(ml, flags, qualname, self, module, globals, code) \
    __Pyx_CyFunction_New(__pyx_CyFunctionType, ml, flags, qualname, self, module, globals, code)
static PyObject *__Pyx_CyFunction_New(PyTypeObject *, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __Pyx_CyFunction_init(void);

#if PY_VERSION_HEX < 0x02050000
#ifndef PyAnySet_CheckExact
#define PyAnySet_CheckExact(ob) \
    ((ob)->ob_type == &PySet_Type || \
     (ob)->ob_type == &PyFrozenSet_Type)
#define PySet_New(iterable) \
    PyObject_CallFunctionObjArgs((PyObject *)&PySet_Type, (iterable), NULL)
#define Pyx_PyFrozenSet_New(iterable) \
    PyObject_CallFunctionObjArgs((PyObject *)&PyFrozenSet_Type, (iterable), NULL)
#define PySet_Size(anyset) \
    PyObject_Size((anyset))
#define PySet_Contains(anyset, key) \
    PySequence_Contains((anyset), (key))
#define PySet_Pop(set) \
    PyObject_CallMethod((set), (char*)"pop", NULL)
static CYTHON_INLINE int PySet_Clear(PyObject *set) {
    PyObject *ret = PyObject_CallMethod(set, (char*)"clear", NULL);
    if (!ret) return -1;
    Py_DECREF(ret); return 0;
}
static CYTHON_INLINE int PySet_Discard(PyObject *set, PyObject *key) {
    PyObject *ret = PyObject_CallMethod(set, (char*)"discard", (char*)"(O)", key);
    if (!ret) return -1;
    Py_DECREF(ret); return 0;
}
static CYTHON_INLINE int PySet_Add(PyObject *set, PyObject *key) {
    PyObject *ret = PyObject_CallMethod(set, (char*)"add", (char*)"(O)", key);
    if (!ret) return -1;
    Py_DECREF(ret); return 0;
}
#endif /* PyAnySet_CheckExact (<= Py2.4) */
#endif /* < Py2.5  */

static int __Pyx_SetVtable(PyObject *dict, void *vtable); /*proto*/

static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name); /*proto*/

static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc); /*proto*/
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass); /*proto*/

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level); /*proto*/

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_int(unsigned int value);

static CYTHON_INLINE unsigned int __Pyx_PyInt_As_unsigned_int(PyObject *);

static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

static PyObject* __Pyx_PyObject_CallMethodTuple(PyObject* obj, PyObject* method_name, PyObject* args) {
    PyObject *method, *result = NULL;
    if (unlikely(!args)) return NULL;
    method = __Pyx_PyObject_GetAttrStr(obj, method_name);
    if (unlikely(!method)) goto bad;
    result = PyObject_Call(method, args, NULL);
    Py_DECREF(method);
bad:
    Py_DECREF(args);
    return result;
}
#define __Pyx_PyObject_CallMethod3(obj, name, arg1, arg2, arg3) \
    __Pyx_PyObject_CallMethodTuple(obj, name, PyTuple_Pack(3, arg1, arg2, arg3))
#define __Pyx_PyObject_CallMethod2(obj, name, arg1, arg2) \
    __Pyx_PyObject_CallMethodTuple(obj, name, PyTuple_Pack(2, arg1, arg2))
#define __Pyx_PyObject_CallMethod1(obj, name, arg1) \
    __Pyx_PyObject_CallMethodTuple(obj, name, PyTuple_Pack(1, arg1))
#define __Pyx_PyObject_CallMethod0(obj, name) \
    __Pyx_PyObject_CallMethodTuple(obj, name, (Py_INCREF(__pyx_empty_tuple), __pyx_empty_tuple))

static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

#define __Pyx_Generator_USED
#include <structmember.h>
#include <frameobject.h>
typedef PyObject *(*__pyx_generator_body_t)(PyObject *, PyObject *);
typedef struct {
    PyObject_HEAD
    __pyx_generator_body_t body;
    PyObject *closure;
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    int resume_label;
    char is_running;
} __pyx_GeneratorObject;
static __pyx_GeneratorObject *__Pyx_Generator_New(__pyx_generator_body_t body,
                                                  PyObject *closure);
static int __pyx_Generator_init(void);
static int __Pyx_Generator_clear(PyObject* self);
#if 1 || PY_VERSION_HEX < 0x030300B0
static int __Pyx_PyGen_FetchStopIterationValue(PyObject **pvalue);
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue) PyGen_FetchStopIterationValue(pvalue)
#endif

static int __Pyx_check_binary_version(void);

typedef struct {
    int code_line;
    PyCodeObject* code_object;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename); /*proto*/

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t); /*proto*/


/* Module declarations from 'fiona' */

/* Module declarations from 'fiona.ograpi' */

/* Module declarations from 'fiona.ogrext' */
static PyTypeObject *__pyx_ptype_5fiona_6ogrext___pyx_scope_struct___explode = 0;
static PyTypeObject *__pyx_ptype_5fiona_6ogrext___pyx_scope_struct_1_writerecs = 0;
static PyTypeObject *__pyx_ptype_5fiona_6ogrext_FeatureBuilder = 0;
static PyTypeObject *__pyx_ptype_5fiona_6ogrext_OGRFeatureBuilder = 0;
static PyTypeObject *__pyx_ptype_5fiona_6ogrext_Session = 0;
static PyTypeObject *__pyx_ptype_5fiona_6ogrext_GeomBuilder = 0;
static PyTypeObject *__pyx_ptype_5fiona_6ogrext_OGRGeomBuilder = 0;
static PyTypeObject *__pyx_ptype_5fiona_6ogrext_Iterator = 0;
static PyTypeObject *__pyx_ptype_5fiona_6ogrext_WritingSession = 0;
static void *__pyx_f_5fiona_6ogrext__createOgrGeomFromWKB(PyObject *); /*proto*/
static PyObject *__pyx_f_5fiona_6ogrext__deleteOgrGeom(void *); /*proto*/
static PyObject *__pyx_f_5fiona_6ogrext__deleteOgrFeature(void *); /*proto*/
#define __Pyx_MODULE_NAME "fiona.ogrext"
int __pyx_module_is_main_fiona__ogrext = 0;

/* Implementation of 'fiona.ogrext' */
static PyObject *__pyx_builtin_object;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_zip;
static PyObject *__pyx_builtin_min;
static PyObject *__pyx_builtin_max;
static PyObject *__pyx_builtin_KeyError;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_UnicodeDecodeError;
static PyObject *__pyx_builtin_RuntimeError;
static PyObject *__pyx_builtin_OSError;
static PyObject *__pyx_builtin_map;
static PyObject *__pyx_builtin_StopIteration;
static PyObject *__pyx_pf_5fiona_6ogrext_11NullHandler_emit(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_record); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_getNumDimsPoint(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_2getNumDimsLineString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_4getNumDimsLinearRing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_6getNumDimsPolygon(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_8getNumDimsMultiPoint(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_10getNumDimsMultiLineString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_12getNumDimsMultiPolygon(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_14getNumDimsGeometryCollection(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_16getNumDims(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_geom_type, PyObject *__pyx_v_coordinates); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder__buildPoint(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_2_buildLineString(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_4_buildLinearRing(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_6_buildPolygon(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_8_buildMultiPoint(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_10_buildMultiLineString(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_12_buildMultiPolygon(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_14_buildGeometryCollection(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_16build_wkb(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self, PyObject *__pyx_v_wkb); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_geometryRT(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_geometry); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_2_explode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_coords); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_5_bounds(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_geometry); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_7featureRT(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_feature, PyObject *__pyx_v_collection); /* proto */
static int __pyx_pf_5fiona_6ogrext_7Session___cinit__(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self); /* proto */
static void __pyx_pf_5fiona_6ogrext_7Session_2__dealloc__(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_7Session_4start(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self, PyObject *__pyx_v_collection); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_7Session_6stop(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_7Session_8get_fileencoding(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_7Session_10get_internalencoding(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_7Session_12get_length(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_7Session_14get_driver(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_7Session_16get_schema(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_7Session_18get_crs(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_7Session_20get_extent(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_7Session_22isactive(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_14WritingSession_start(struct __pyx_obj_5fiona_6ogrext_WritingSession *__pyx_v_self, PyObject *__pyx_v_collection); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_14WritingSession_9writerecs_validate_geometry_type(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_rec); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_14WritingSession_9writerecs_2validate_geometry_type(PyObject *__pyx_self, PyObject *__pyx_v_rec); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_14WritingSession_9writerecs_4validate_geometry_type(PyObject *__pyx_self, PyObject *__pyx_v_rec); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_14WritingSession_2writerecs(struct __pyx_obj_5fiona_6ogrext_WritingSession *__pyx_v_self, PyObject *__pyx_v_records, PyObject *__pyx_v_collection); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_14WritingSession_4sync(struct __pyx_obj_5fiona_6ogrext_WritingSession *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_collection); /* proto */
static int __pyx_pf_5fiona_6ogrext_8Iterator___init__(struct __pyx_obj_5fiona_6ogrext_Iterator *__pyx_v_self, PyObject *__pyx_v_collection, PyObject *__pyx_v_bbox); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_8Iterator_2__iter__(struct __pyx_obj_5fiona_6ogrext_Iterator *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_8Iterator_4__next__(struct __pyx_obj_5fiona_6ogrext_Iterator *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5fiona_6ogrext_9_listlayers(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_path); /* proto */
static PyObject *__pyx_tp_new_5fiona_6ogrext___pyx_scope_struct___explode(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_5fiona_6ogrext___pyx_scope_struct_1_writerecs(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_5fiona_6ogrext_FeatureBuilder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_5fiona_6ogrext_OGRFeatureBuilder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_5fiona_6ogrext_Session(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_5fiona_6ogrext_GeomBuilder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_5fiona_6ogrext_OGRGeomBuilder(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_5fiona_6ogrext_Iterator(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_5fiona_6ogrext_WritingSession(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static char __pyx_k_a[] = "a";
static char __pyx_k_d[] = ":%d";
static char __pyx_k_e[] = "e";
static char __pyx_k_f[] = "f";
static char __pyx_k_i[] = "i";
static char __pyx_k_s[] = "+%s";
static char __pyx_k_w[] = "w";
static char __pyx_k_x[] = "x";
static char __pyx_k_y[] = "y";
static char __pyx_k_3D[] = "3D ";
static char __pyx_k_id[] = "id";
static char __pyx_k_os[] = "os";
static char __pyx_k__20[] = "";
static char __pyx_k__29[] = "=";
static char __pyx_k__31[] = "+";
static char __pyx_k__40[] = " ";
static char __pyx_k__46[] = ":";
static char __pyx_k__48[] = ".";
static char __pyx_k_crs[] = "crs";
static char __pyx_k_d_2[] = ".%d";
static char __pyx_k_doc[] = "__doc__";
static char __pyx_k_get[] = "get";
static char __pyx_k_int[] = "int";
static char __pyx_k_log[] = "log";
static char __pyx_k_map[] = "map";
static char __pyx_k_max[] = "max";
static char __pyx_k_min[] = "min";
static char __pyx_k_rec[] = "rec";
static char __pyx_k_s_s[] = "+%s=%s";
static char __pyx_k_six[] = "six";
static char __pyx_k_str[] = "str";
static char __pyx_k_sys[] = "sys";
static char __pyx_k_zip[] = "zip";
static char __pyx_k_None[] = "None";
static char __pyx_k_args[] = "args";
static char __pyx_k_bbox[] = "bbox";
static char __pyx_k_date[] = "date";
static char __pyx_k_emit[] = "emit";
static char __pyx_k_join[] = "join";
static char __pyx_k_keys[] = "keys";
static char __pyx_k_long[] = "long";
static char __pyx_k_main[] = "__main__";
static char __pyx_k_mode[] = "mode";
static char __pyx_k_name[] = "name";
static char __pyx_k_path[] = "path";
static char __pyx_k_self[] = "self";
static char __pyx_k_send[] = "send";
static char __pyx_k_stop[] = "stop";
static char __pyx_k_test[] = "__test__";
static char __pyx_k_time[] = "time";
static char __pyx_k_type[] = "type";
static char __pyx_k_warn[] = "warn";
static char __pyx_k_Fiona[] = "Fiona";
static char __pyx_k_Multi[] = "Multi";
static char __pyx_k_Point[] = "Point";
static char __pyx_k_build[] = "_build";
static char __pyx_k_close[] = "close";
static char __pyx_k_debug[] = "debug";
static char __pyx_k_first[] = "first";
static char __pyx_k_float[] = "float";
static char __pyx_k_index[] = "index";
static char __pyx_k_items[] = "items";
static char __pyx_k_range[] = "range";
static char __pyx_k_split[] = "split";
static char __pyx_k_strip[] = "strip";
static char __pyx_k_throw[] = "throw";
static char __pyx_k_upper[] = "upper";
static char __pyx_k_utf_8[] = "utf-8";
static char __pyx_k_bounds[] = "_bounds";
static char __pyx_k_coords[] = "coords";
static char __pyx_k_decode[] = "decode";
static char __pyx_k_driver[] = "driver";
static char __pyx_k_encode[] = "encode";
static char __pyx_k_exists[] = "exists";
static char __pyx_k_import[] = "__import__";
static char __pyx_k_locale[] = "locale";
static char __pyx_k_lstrip[] = "lstrip";
static char __pyx_k_module[] = "__module__";
static char __pyx_k_name_b[] = "name_b";
static char __pyx_k_name_c[] = "name_c";
static char __pyx_k_object[] = "object";
static char __pyx_k_path_b[] = "path_b";
static char __pyx_k_path_c[] = "path_c";
static char __pyx_k_record[] = "record";
static char __pyx_k_result[] = "result";
static char __pyx_k_schema[] = "schema";
static char __pyx_k_Feature[] = "Feature";
static char __pyx_k_GeoJSON[] = "GeoJSON";
static char __pyx_k_Handler[] = "Handler";
static char __pyx_k_OSError[] = "OSError";
static char __pyx_k_Polygon[] = "Polygon";
static char __pyx_k_Unknown[] = "Unknown";
static char __pyx_k_cogr_ds[] = "cogr_ds";
static char __pyx_k_explode[] = "_explode";
static char __pyx_k_feature[] = "feature";
static char __pyx_k_logging[] = "logging";
static char __pyx_k_no_defs[] = "no_defs";
static char __pyx_k_prepare[] = "__prepare__";
static char __pyx_k_records[] = "records";
static char __pyx_k_session[] = "session";
static char __pyx_k_3D_Point[] = "3D Point";
static char __pyx_k_CRSError[] = "CRSError";
static char __pyx_k_ENCODING[] = "ENCODING";
static char __pyx_k_KeyError[] = "KeyError";
static char __pyx_k_Params_s[] = "Params: %s";
static char __pyx_k_datetime[] = "datetime";
static char __pyx_k_encoding[] = "encoding";
static char __pyx_k_geometry[] = "geometry";
static char __pyx_k_qualname[] = "__qualname__";
static char __pyx_k_Null_geom[] = "Null geom";
static char __pyx_k_TypeError[] = "TypeError";
static char __pyx_k_build_wkb[] = "build_wkb";
static char __pyx_k_featureRT[] = "featureRT";
static char __pyx_k_geom_type[] = "geom_type";
static char __pyx_k_getLogger[] = "getLogger";
static char __pyx_k_isoformat[] = "isoformat";
static char __pyx_k_metaclass[] = "__metaclass__";
static char __pyx_k_text_type[] = "text_type";
static char __pyx_k_3D_Polygon[] = "3D Polygon";
static char __pyx_k_Built_line[] = "Built line";
static char __pyx_k_Built_part[] = "Built part";
static char __pyx_k_Built_ring[] = "Built ring";
static char __pyx_k_Geometry_s[] = "Geometry: %s";
static char __pyx_k_ISO_8859_1[] = "ISO-8859-1";
static char __pyx_k_LineString[] = "LineString";
static char __pyx_k_LinearRing[] = "LinearRing";
static char __pyx_k_MultiPoint[] = "MultiPoint";
static char __pyx_k_Null_layer[] = "Null layer";
static char __pyx_k_ValueError[] = "ValueError";
static char __pyx_k_addHandler[] = "addHandler";
static char __pyx_k_buildPoint[] = "_buildPoint";
static char __pyx_k_cogr_layer[] = "cogr_layer";
static char __pyx_k_collection[] = "collection";
static char __pyx_k_geometries[] = "geometries";
static char __pyx_k_geometryRT[] = "geometryRT";
static char __pyx_k_getNumDims[] = "getNumDims";
static char __pyx_k_get_driver[] = "get_driver";
static char __pyx_k_get_schema[] = "get_schema";
static char __pyx_k_listlayers[] = "_listlayers";
static char __pyx_k_parse_date[] = "parse_date";
static char __pyx_k_parse_time[] = "parse_time";
static char __pyx_k_properties[] = "properties";
static char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static char __pyx_k_DriverError[] = "DriverError";
static char __pyx_k_FIELD_TYPES[] = "FIELD_TYPES";
static char __pyx_k_NullHandler[] = "NullHandler";
static char __pyx_k_Null_driver[] = "Null driver";
static char __pyx_k_OGRERR_NONE[] = "OGRERR_NONE";
static char __pyx_k_OrderedDict[] = "OrderedDict";
static char __pyx_k_SchemaError[] = "SchemaError";
static char __pyx_k_coordinates[] = "coordinates";
static char __pyx_k_fiona_odict[] = "fiona.odict";
static char __pyx_k_layer_count[] = "layer_count";
static char __pyx_k_layer_names[] = "layer_names";
static char __pyx_k_Added_line_s[] = "Added line %s";
static char __pyx_k_Added_part_s[] = "Added part %s";
static char __pyx_k_Added_ring_s[] = "Added ring %s";
static char __pyx_k_Closing_ring[] = "Closing ring";
static char __pyx_k_MultiPolygon[] = "MultiPolygon";
static char __pyx_k_Null_feature[] = "Null feature";
static char __pyx_k_Null_layer_2[] = "Null layer: ";
static char __pyx_k_RuntimeError[] = "RuntimeError";
static char __pyx_k_buildPolygon[] = "_buildPolygon";
static char __pyx_k_cogr_feature[] = "cogr_feature";
static char __pyx_k_fiona_errors[] = "fiona.errors";
static char __pyx_k_fiona_ogrext[] = "fiona.ogrext";
static char __pyx_k_string_types[] = "string_types";
static char __pyx_k_3D_LineString[] = "3D LineString";
static char __pyx_k_3D_MultiPoint[] = "3D MultiPoint";
static char __pyx_k_Added_point_s[] = "Added point %s";
static char __pyx_k_Adding_line_s[] = "Adding line %s";
static char __pyx_k_Adding_part_s[] = "Adding part %s";
static char __pyx_k_Adding_ring_s[] = "Adding ring %s";
static char __pyx_k_Built_polygon[] = "Built polygon";
static char __pyx_k_Created_layer[] = "Created layer";
static char __pyx_k_FionaDateType[] = "FionaDateType";
static char __pyx_k_FionaTimeType[] = "FionaTimeType";
static char __pyx_k_Null_geometry[] = "Null geometry";
static char __pyx_k_Set_field_s_s[] = "Set field %s: %s";
static char __pyx_k_StopIteration[] = "StopIteration";
static char __pyx_k_StringsAsUTF8[] = "StringsAsUTF8";
static char __pyx_k_cogr_geometry[] = "cogr_geometry";
static char __pyx_k_fiona_rfc3339[] = "fiona.rfc3339";
static char __pyx_k_integer_types[] = "integer_types";
static char __pyx_k_Adding_point_s[] = "Adding point %s";
static char __pyx_k_Created_fields[] = "Created fields";
static char __pyx_k_ESRI_Shapefile[] = "ESRI Shapefile";
static char __pyx_k_GEOMETRY_TYPES[] = "GEOMETRY_TYPES";
static char __pyx_k_OGRERR_FAILURE[] = "OGRERR_FAILURE";
static char __pyx_k_SHAPE_ENCODING[] = "SHAPE_ENCODING";
static char __pyx_k_parse_datetime[] = "parse_datetime";
static char __pyx_k_3D_MultiPolygon[] = "3D MultiPolygon";
static char __pyx_k_Added_polygon_s[] = "Added polygon %s";
static char __pyx_k_FIELD_TYPES_MAP[] = "FIELD_TYPES_MAP";
static char __pyx_k_MultiLineString[] = "MultiLineString";
static char __pyx_k_Null_projection[] = "Null projection";
static char __pyx_k_Writing_started[] = "Writing started";
static char __pyx_k_buildLineString[] = "_buildLineString";
static char __pyx_k_buildLinearRing[] = "_buildLinearRing";
static char __pyx_k_buildMultiPoint[] = "_buildMultiPoint";
static char __pyx_k_getNumDimsPoint[] = "getNumDimsPoint";
static char __pyx_k_Adding_polygon_s[] = "Adding polygon %s";
static char __pyx_k_Failed_to_open_s[] = "Failed to open %s";
static char __pyx_k_NullHandler_emit[] = "NullHandler.emit";
static char __pyx_k_Null_data_source[] = "Null data source";
static char __pyx_k_get_fileencoding[] = "get_fileencoding";
static char __pyx_k_Adding_values_f_f[] = "Adding values %f, %f";
static char __pyx_k_DimensionsHandler[] = "DimensionsHandler";
static char __pyx_k_FionaDateTimeType[] = "FionaDateTimeType";
static char __pyx_k_Looking_up_s_in_s[] = "Looking up %s in %s";
static char __pyx_k_buildMultiPolygon[] = "_buildMultiPolygon";
static char __pyx_k_getNumDimsPolygon[] = "getNumDimsPolygon";
static char __pyx_k_3D_MultiLineString[] = "3D MultiLineString";
static char __pyx_k_Creating_field_s_s[] = "Creating field: %s %s";
static char __pyx_k_GeometryCollection[] = "GeometryCollection";
static char __pyx_k_UnicodeDecodeError[] = "UnicodeDecodeError";
static char __pyx_k_OGRERR_CORRUPT_DATA[] = "OGRERR_CORRUPT_DATA";
static char __pyx_k_Syncing_OGR_to_disk[] = "Syncing OGR to disk";
static char __pyx_k_Invalid_field_type_s[] = "Invalid field type %s";
static char __pyx_k_buildMultiLineString[] = "_buildMultiLineString";
static char __pyx_k_getNumDimsLineString[] = "getNumDimsLineString";
static char __pyx_k_getNumDimsLinearRing[] = "getNumDimsLinearRing";
static char __pyx_k_getNumDimsMultiPoint[] = "getNumDimsMultiPoint";
static char __pyx_k_get_internalencoding[] = "get_internalencoding";
static char __pyx_k_getpreferredencoding[] = "getpreferredencoding";
static char __pyx_k_s_None_fieldtype_r_r[] = "%s: None, fieldtype: %r, %r";
static char __pyx_k_3D_GeometryCollection[] = "3D GeometryCollection";
static char __pyx_k_Failed_to_get_layer_s[] = "Failed to get layer %s";
static char __pyx_k_Got_coordinate_system[] = "Got coordinate system";
static char __pyx_k_Null_field_definition[] = "Null field definition";
static char __pyx_k_OGRERR_INVALID_HANDLE[] = "OGRERR_INVALID_HANDLE";
static char __pyx_k_OGR_DETECTED_ENCODING[] = "OGR_DETECTED_ENCODING";
static char __pyx_k_ogr_detected_encoding[] = "-ogr-detected-encoding";
static char __pyx_k_Failed_to_sync_to_disk[] = "Failed to sync to disk";
static char __pyx_k_Null_spatial_reference[] = "Null spatial reference";
static char __pyx_k_OGRERR_NOT_ENOUGH_DATA[] = "OGRERR_NOT_ENOUGH_DATA";
static char __pyx_k_OGRERR_UNSUPPORTED_SRS[] = "OGRERR_UNSUPPORTED_SRS";
static char __pyx_k_getNumDimsMultiPolygon[] = "getNumDimsMultiPolygon";
static char __pyx_k_validate_geometry_type[] = "validate_geometry_type";
static char __pyx_k_Null_feature_definition[] = "Null feature definition";
static char __pyx_k_buildGeometryCollection[] = "_buildGeometryCollection";
static char __pyx_k_Failed_to_write_record_s[] = "Failed to write record: %s";
static char __pyx_k_Invalid_field_name_ref_s[] = "Invalid field name ref: %s";
static char __pyx_k_OGRERR_NOT_ENOUGH_MEMORY[] = "OGRERR_NOT_ENOUGH_MEMORY";
static char __pyx_k_Null_field_name_reference[] = "Null field name reference";
static char __pyx_k_getNumDimsMultiLineString[] = "getNumDimsMultiLineString";
static char __pyx_k_Creating_feature_in_layer_s[] = "Creating feature in layer: %s";
static char __pyx_k_No_data_available_at_path_s[] = "No data available at path '%s'";
static char __pyx_k_No_such_file_or_directory_s[] = "No such file or directory %s";
static char __pyx_k_Unexpected_proj_parameter_s[] = "Unexpected proj parameter %s";
static char __pyx_k_Unsupported_geometry_type_s[] = "Unsupported geometry type %s";
static char __pyx_k_DimensionsHandler_getNumDims[] = "DimensionsHandler.getNumDims";
static char __pyx_k_OGRERR_UNSUPPORTED_OPERATION[] = "OGRERR_UNSUPPORTED_OPERATION";
static char __pyx_k_getNumDimsGeometryCollection[] = "getNumDimsGeometryCollection";
static char __pyx_k_Deleted_pre_existing_data_at_s[] = "Deleted pre-existing data at %s";
static char __pyx_k_Deleted_pre_existing_layer_at_s[] = "Deleted pre-existing layer at %s";
static char __pyx_k_Record_s_geometry_type_does_not[] = "Record's geometry type does not match collection schema's geometry type: %r != %r";
static char __pyx_k_Skipping_field_s_invalid_type_s[] = "Skipping field %s: invalid type %s";
static char __pyx_k_Users_seang_code_Fiona_src_fion[] = "/Users/seang/code/Fiona/src/fiona/ogrext.pyx";
static char __pyx_k_Determines_the_number_of_dimensi[] = "Determines the number of dimensions of a Fiona geometry.\n    ";
static char __pyx_k_DimensionsHandler_getNumDimsGeom[] = "DimensionsHandler.getNumDimsGeometryCollection";
static char __pyx_k_DimensionsHandler_getNumDimsLine[] = "DimensionsHandler.getNumDimsLineString";
static char __pyx_k_DimensionsHandler_getNumDimsMult[] = "DimensionsHandler.getNumDimsMultiPoint";
static char __pyx_k_DimensionsHandler_getNumDimsPoin[] = "DimensionsHandler.getNumDimsPoint";
static char __pyx_k_DimensionsHandler_getNumDimsPoly[] = "DimensionsHandler.getNumDimsPolygon";
static char __pyx_k_Failed_to_decode_s_using_s_codec[] = "Failed to decode %s using %s codec";
static char __pyx_k_Failed_to_encode_s_using_s_codec[] = "Failed to encode %s using %s codec";
static char __pyx_k_I_O_operation_on_closed_collecti[] = "I/O operation on closed collection";
static char __pyx_k_OGRERR_UNSUPPORTED_GEOMETRY_TYPE[] = "OGRERR_UNSUPPORTED_GEOMETRY_TYPE";
static char __pyx_k_Projection_not_found_cogr_crs_wa[] = "Projection not found (cogr_crs was NULL)";
static char __pyx_k_Record_does_not_match_collection[] = "Record does not match collection schema: %r != %r";
static char __pyx_k_writerecs_locals_validate_geomet[] = "writerecs.<locals>.validate_geometry_type";
static char __pyx_k_DimensionsHandler_getNumDimsLine_2[] = "DimensionsHandler.getNumDimsLinearRing";
static char __pyx_k_DimensionsHandler_getNumDimsMult_2[] = "DimensionsHandler.getNumDimsMultiLineString";
static char __pyx_k_DimensionsHandler_getNumDimsMult_3[] = "DimensionsHandler.getNumDimsMultiPolygon";
static PyObject *__pyx_kp_s_3D;
static PyObject *__pyx_kp_s_3D_GeometryCollection;
static PyObject *__pyx_kp_s_3D_LineString;
static PyObject *__pyx_kp_s_3D_MultiLineString;
static PyObject *__pyx_kp_s_3D_MultiPoint;
static PyObject *__pyx_kp_s_3D_MultiPolygon;
static PyObject *__pyx_kp_s_3D_Point;
static PyObject *__pyx_kp_s_3D_Polygon;
static PyObject *__pyx_kp_s_Added_line_s;
static PyObject *__pyx_kp_s_Added_part_s;
static PyObject *__pyx_kp_s_Added_point_s;
static PyObject *__pyx_kp_s_Added_polygon_s;
static PyObject *__pyx_kp_s_Added_ring_s;
static PyObject *__pyx_kp_s_Adding_line_s;
static PyObject *__pyx_kp_s_Adding_part_s;
static PyObject *__pyx_kp_s_Adding_point_s;
static PyObject *__pyx_kp_s_Adding_polygon_s;
static PyObject *__pyx_kp_s_Adding_ring_s;
static PyObject *__pyx_kp_s_Adding_values_f_f;
static PyObject *__pyx_kp_s_Built_line;
static PyObject *__pyx_kp_s_Built_part;
static PyObject *__pyx_kp_s_Built_polygon;
static PyObject *__pyx_kp_s_Built_ring;
static PyObject *__pyx_n_s_CRSError;
static PyObject *__pyx_kp_s_Closing_ring;
static PyObject *__pyx_kp_s_Created_fields;
static PyObject *__pyx_kp_s_Created_layer;
static PyObject *__pyx_kp_s_Creating_feature_in_layer_s;
static PyObject *__pyx_kp_s_Creating_field_s_s;
static PyObject *__pyx_kp_s_Deleted_pre_existing_data_at_s;
static PyObject *__pyx_kp_s_Deleted_pre_existing_layer_at_s;
static PyObject *__pyx_kp_s_Determines_the_number_of_dimensi;
static PyObject *__pyx_n_s_DimensionsHandler;
static PyObject *__pyx_n_s_DimensionsHandler_getNumDims;
static PyObject *__pyx_n_s_DimensionsHandler_getNumDimsGeom;
static PyObject *__pyx_n_s_DimensionsHandler_getNumDimsLine;
static PyObject *__pyx_n_s_DimensionsHandler_getNumDimsLine_2;
static PyObject *__pyx_n_s_DimensionsHandler_getNumDimsMult;
static PyObject *__pyx_n_s_DimensionsHandler_getNumDimsMult_2;
static PyObject *__pyx_n_s_DimensionsHandler_getNumDimsMult_3;
static PyObject *__pyx_n_s_DimensionsHandler_getNumDimsPoin;
static PyObject *__pyx_n_s_DimensionsHandler_getNumDimsPoly;
static PyObject *__pyx_n_s_DriverError;
static PyObject *__pyx_kp_b_ESRI_Shapefile;
static PyObject *__pyx_kp_s_ESRI_Shapefile;
static PyObject *__pyx_n_s_FIELD_TYPES;
static PyObject *__pyx_n_s_FIELD_TYPES_MAP;
static PyObject *__pyx_kp_s_Failed_to_decode_s_using_s_codec;
static PyObject *__pyx_kp_s_Failed_to_encode_s_using_s_codec;
static PyObject *__pyx_kp_s_Failed_to_get_layer_s;
static PyObject *__pyx_kp_s_Failed_to_open_s;
static PyObject *__pyx_kp_s_Failed_to_sync_to_disk;
static PyObject *__pyx_kp_s_Failed_to_write_record_s;
static PyObject *__pyx_n_s_Feature;
static PyObject *__pyx_n_s_Fiona;
static PyObject *__pyx_n_s_FionaDateTimeType;
static PyObject *__pyx_n_s_FionaDateType;
static PyObject *__pyx_n_s_FionaTimeType;
static PyObject *__pyx_n_s_GEOMETRY_TYPES;
static PyObject *__pyx_n_b_GeoJSON;
static PyObject *__pyx_n_s_GeometryCollection;
static PyObject *__pyx_kp_s_Geometry_s;
static PyObject *__pyx_kp_s_Got_coordinate_system;
static PyObject *__pyx_n_s_Handler;
static PyObject *__pyx_kp_s_ISO_8859_1;
static PyObject *__pyx_kp_s_I_O_operation_on_closed_collecti;
static PyObject *__pyx_kp_s_Invalid_field_name_ref_s;
static PyObject *__pyx_kp_s_Invalid_field_type_s;
static PyObject *__pyx_n_s_KeyError;
static PyObject *__pyx_n_s_LineString;
static PyObject *__pyx_n_s_LinearRing;
static PyObject *__pyx_kp_s_Looking_up_s_in_s;
static PyObject *__pyx_n_s_Multi;
static PyObject *__pyx_n_s_MultiLineString;
static PyObject *__pyx_n_s_MultiPoint;
static PyObject *__pyx_n_s_MultiPolygon;
static PyObject *__pyx_kp_s_No_data_available_at_path_s;
static PyObject *__pyx_kp_s_No_such_file_or_directory_s;
static PyObject *__pyx_n_s_None;
static PyObject *__pyx_n_s_NullHandler;
static PyObject *__pyx_n_s_NullHandler_emit;
static PyObject *__pyx_kp_s_Null_data_source;
static PyObject *__pyx_kp_s_Null_driver;
static PyObject *__pyx_kp_s_Null_feature;
static PyObject *__pyx_kp_s_Null_feature_definition;
static PyObject *__pyx_kp_s_Null_field_definition;
static PyObject *__pyx_kp_s_Null_field_name_reference;
static PyObject *__pyx_kp_s_Null_geom;
static PyObject *__pyx_kp_s_Null_geometry;
static PyObject *__pyx_kp_s_Null_layer;
static PyObject *__pyx_kp_s_Null_layer_2;
static PyObject *__pyx_kp_s_Null_projection;
static PyObject *__pyx_kp_s_Null_spatial_reference;
static PyObject *__pyx_n_s_OGRERR_CORRUPT_DATA;
static PyObject *__pyx_n_s_OGRERR_FAILURE;
static PyObject *__pyx_n_s_OGRERR_INVALID_HANDLE;
static PyObject *__pyx_n_s_OGRERR_NONE;
static PyObject *__pyx_n_s_OGRERR_NOT_ENOUGH_DATA;
static PyObject *__pyx_n_s_OGRERR_NOT_ENOUGH_MEMORY;
static PyObject *__pyx_n_s_OGRERR_UNSUPPORTED_GEOMETRY_TYPE;
static PyObject *__pyx_n_s_OGRERR_UNSUPPORTED_OPERATION;
static PyObject *__pyx_n_s_OGRERR_UNSUPPORTED_SRS;
static PyObject *__pyx_n_s_OGR_DETECTED_ENCODING;
static PyObject *__pyx_n_s_OSError;
static PyObject *__pyx_n_s_OrderedDict;
static PyObject *__pyx_kp_s_Params_s;
static PyObject *__pyx_n_s_Point;
static PyObject *__pyx_n_s_Polygon;
static PyObject *__pyx_kp_s_Projection_not_found_cogr_crs_wa;
static PyObject *__pyx_kp_s_Record_does_not_match_collection;
static PyObject *__pyx_kp_s_Record_s_geometry_type_does_not;
static PyObject *__pyx_n_s_RuntimeError;
static PyObject *__pyx_n_s_SchemaError;
static PyObject *__pyx_kp_s_Set_field_s_s;
static PyObject *__pyx_kp_s_Skipping_field_s_invalid_type_s;
static PyObject *__pyx_n_s_StopIteration;
static PyObject *__pyx_kp_s_Syncing_OGR_to_disk;
static PyObject *__pyx_n_s_TypeError;
static PyObject *__pyx_kp_s_Unexpected_proj_parameter_s;
static PyObject *__pyx_n_s_UnicodeDecodeError;
static PyObject *__pyx_n_s_Unknown;
static PyObject *__pyx_kp_s_Unsupported_geometry_type_s;
static PyObject *__pyx_kp_s_Users_seang_code_Fiona_src_fion;
static PyObject *__pyx_n_s_ValueError;
static PyObject *__pyx_kp_s_Writing_started;
static PyObject *__pyx_kp_s__20;
static PyObject *__pyx_kp_s__29;
static PyObject *__pyx_kp_s__31;
static PyObject *__pyx_kp_s__40;
static PyObject *__pyx_kp_s__46;
static PyObject *__pyx_kp_s__48;
static PyObject *__pyx_n_s_a;
static PyObject *__pyx_n_s_addHandler;
static PyObject *__pyx_n_s_args;
static PyObject *__pyx_n_s_bbox;
static PyObject *__pyx_n_s_bounds;
static PyObject *__pyx_n_s_build;
static PyObject *__pyx_n_s_buildGeometryCollection;
static PyObject *__pyx_n_s_buildLineString;
static PyObject *__pyx_n_s_buildLinearRing;
static PyObject *__pyx_n_s_buildMultiLineString;
static PyObject *__pyx_n_s_buildMultiPoint;
static PyObject *__pyx_n_s_buildMultiPolygon;
static PyObject *__pyx_n_s_buildPoint;
static PyObject *__pyx_n_s_buildPolygon;
static PyObject *__pyx_n_s_build_wkb;
static PyObject *__pyx_n_s_close;
static PyObject *__pyx_n_s_cogr_ds;
static PyObject *__pyx_n_s_cogr_feature;
static PyObject *__pyx_n_s_cogr_geometry;
static PyObject *__pyx_n_s_cogr_layer;
static PyObject *__pyx_n_s_collection;
static PyObject *__pyx_n_s_coordinates;
static PyObject *__pyx_n_s_coords;
static PyObject *__pyx_n_s_crs;
static PyObject *__pyx_kp_s_d;
static PyObject *__pyx_kp_s_d_2;
static PyObject *__pyx_n_s_date;
static PyObject *__pyx_n_s_datetime;
static PyObject *__pyx_n_s_debug;
static PyObject *__pyx_n_s_decode;
static PyObject *__pyx_n_s_doc;
static PyObject *__pyx_n_s_driver;
static PyObject *__pyx_n_s_e;
static PyObject *__pyx_n_s_emit;
static PyObject *__pyx_n_s_encode;
static PyObject *__pyx_n_s_encoding;
static PyObject *__pyx_n_s_exists;
static PyObject *__pyx_n_s_explode;
static PyObject *__pyx_n_s_f;
static PyObject *__pyx_n_s_feature;
static PyObject *__pyx_n_s_featureRT;
static PyObject *__pyx_n_s_fiona_errors;
static PyObject *__pyx_n_s_fiona_odict;
static PyObject *__pyx_n_s_fiona_ogrext;
static PyObject *__pyx_n_s_fiona_rfc3339;
static PyObject *__pyx_n_s_first;
static PyObject *__pyx_n_s_float;
static PyObject *__pyx_n_s_geom_type;
static PyObject *__pyx_n_s_geometries;
static PyObject *__pyx_n_s_geometry;
static PyObject *__pyx_n_s_geometryRT;
static PyObject *__pyx_n_s_get;
static PyObject *__pyx_n_s_getLogger;
static PyObject *__pyx_n_s_getNumDims;
static PyObject *__pyx_n_s_getNumDimsGeometryCollection;
static PyObject *__pyx_n_s_getNumDimsLineString;
static PyObject *__pyx_n_s_getNumDimsLinearRing;
static PyObject *__pyx_n_s_getNumDimsMultiLineString;
static PyObject *__pyx_n_s_getNumDimsMultiPoint;
static PyObject *__pyx_n_s_getNumDimsMultiPolygon;
static PyObject *__pyx_n_s_getNumDimsPoint;
static PyObject *__pyx_n_s_getNumDimsPolygon;
static PyObject *__pyx_n_s_get_driver;
static PyObject *__pyx_n_s_get_fileencoding;
static PyObject *__pyx_n_s_get_internalencoding;
static PyObject *__pyx_n_s_get_schema;
static PyObject *__pyx_n_s_getpreferredencoding;
static PyObject *__pyx_n_s_i;
static PyObject *__pyx_n_s_id;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_index;
static PyObject *__pyx_n_s_int;
static PyObject *__pyx_n_s_integer_types;
static PyObject *__pyx_n_s_isoformat;
static PyObject *__pyx_n_s_items;
static PyObject *__pyx_n_s_join;
static PyObject *__pyx_n_s_keys;
static PyObject *__pyx_n_s_layer_count;
static PyObject *__pyx_n_s_layer_names;
static PyObject *__pyx_n_s_listlayers;
static PyObject *__pyx_n_s_locale;
static PyObject *__pyx_n_s_log;
static PyObject *__pyx_n_s_logging;
static PyObject *__pyx_n_s_long;
static PyObject *__pyx_n_s_lstrip;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_map;
static PyObject *__pyx_n_s_max;
static PyObject *__pyx_n_s_metaclass;
static PyObject *__pyx_n_s_min;
static PyObject *__pyx_n_s_mode;
static PyObject *__pyx_n_s_module;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_name_b;
static PyObject *__pyx_n_s_name_c;
static PyObject *__pyx_n_s_no_defs;
static PyObject *__pyx_n_s_object;
static PyObject *__pyx_kp_s_ogr_detected_encoding;
static PyObject *__pyx_n_s_os;
static PyObject *__pyx_n_s_parse_date;
static PyObject *__pyx_n_s_parse_datetime;
static PyObject *__pyx_n_s_parse_time;
static PyObject *__pyx_n_s_path;
static PyObject *__pyx_n_s_path_b;
static PyObject *__pyx_n_s_path_c;
static PyObject *__pyx_n_s_prepare;
static PyObject *__pyx_n_s_properties;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_qualname;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_rec;
static PyObject *__pyx_n_s_record;
static PyObject *__pyx_n_s_records;
static PyObject *__pyx_n_s_result;
static PyObject *__pyx_kp_s_s;
static PyObject *__pyx_kp_s_s_None_fieldtype_r_r;
static PyObject *__pyx_kp_s_s_s;
static PyObject *__pyx_n_s_schema;
static PyObject *__pyx_n_s_self;
static PyObject *__pyx_n_s_send;
static PyObject *__pyx_n_s_session;
static PyObject *__pyx_n_s_six;
static PyObject *__pyx_n_s_split;
static PyObject *__pyx_n_s_stop;
static PyObject *__pyx_n_s_str;
static PyObject *__pyx_n_s_string_types;
static PyObject *__pyx_n_s_strip;
static PyObject *__pyx_n_s_sys;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_text_type;
static PyObject *__pyx_n_s_throw;
static PyObject *__pyx_n_s_time;
static PyObject *__pyx_n_s_type;
static PyObject *__pyx_n_s_upper;
static PyObject *__pyx_kp_s_utf_8;
static PyObject *__pyx_n_s_validate_geometry_type;
static PyObject *__pyx_n_s_w;
static PyObject *__pyx_n_s_warn;
static PyObject *__pyx_n_s_writerecs_locals_validate_geomet;
static PyObject *__pyx_n_s_x;
static PyObject *__pyx_n_s_y;
static PyObject *__pyx_n_s_zip;
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_2;
static PyObject *__pyx_int_3;
static PyObject *__pyx_int_4;
static PyObject *__pyx_int_5;
static PyObject *__pyx_int_6;
static PyObject *__pyx_int_7;
static PyObject *__pyx_int_8;
static PyObject *__pyx_int_11;
static PyObject *__pyx_int_15;
static PyObject *__pyx_int_24;
static PyObject *__pyx_int_80;
static PyObject *__pyx_int_100;
static PyObject *__pyx_int_101;
static PyObject *__pyx_int_2147483648;
static PyObject *__pyx_int_2147483649;
static PyObject *__pyx_int_2147483650;
static PyObject *__pyx_int_2147483651;
static PyObject *__pyx_int_2147483652;
static PyObject *__pyx_int_2147483653;
static PyObject *__pyx_int_2147483654;
static PyObject *__pyx_int_2147483655;
static PyObject *__pyx_int_neg_1;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_tuple__2;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__6;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_tuple__13;
static PyObject *__pyx_tuple__14;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__16;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_tuple__18;
static PyObject *__pyx_tuple__19;
static PyObject *__pyx_tuple__21;
static PyObject *__pyx_tuple__22;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__24;
static PyObject *__pyx_tuple__25;
static PyObject *__pyx_tuple__26;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_tuple__28;
static PyObject *__pyx_tuple__30;
static PyObject *__pyx_tuple__32;
static PyObject *__pyx_tuple__33;
static PyObject *__pyx_tuple__34;
static PyObject *__pyx_tuple__35;
static PyObject *__pyx_tuple__36;
static PyObject *__pyx_tuple__37;
static PyObject *__pyx_tuple__38;
static PyObject *__pyx_tuple__39;
static PyObject *__pyx_tuple__41;
static PyObject *__pyx_tuple__42;
static PyObject *__pyx_tuple__43;
static PyObject *__pyx_tuple__44;
static PyObject *__pyx_tuple__45;
static PyObject *__pyx_tuple__47;
static PyObject *__pyx_tuple__49;
static PyObject *__pyx_tuple__50;
static PyObject *__pyx_tuple__51;
static PyObject *__pyx_tuple__52;
static PyObject *__pyx_tuple__53;
static PyObject *__pyx_tuple__54;
static PyObject *__pyx_tuple__55;
static PyObject *__pyx_tuple__57;
static PyObject *__pyx_tuple__58;
static PyObject *__pyx_tuple__59;
static PyObject *__pyx_tuple__61;
static PyObject *__pyx_tuple__62;
static PyObject *__pyx_tuple__64;
static PyObject *__pyx_tuple__65;
static PyObject *__pyx_tuple__66;
static PyObject *__pyx_tuple__67;
static PyObject *__pyx_tuple__68;
static PyObject *__pyx_tuple__69;
static PyObject *__pyx_tuple__70;
static PyObject *__pyx_tuple__71;
static PyObject *__pyx_tuple__73;
static PyObject *__pyx_tuple__75;
static PyObject *__pyx_tuple__77;
static PyObject *__pyx_tuple__79;
static PyObject *__pyx_tuple__81;
static PyObject *__pyx_tuple__83;
static PyObject *__pyx_tuple__85;
static PyObject *__pyx_tuple__87;
static PyObject *__pyx_tuple__89;
static PyObject *__pyx_tuple__91;
static PyObject *__pyx_tuple__93;
static PyObject *__pyx_tuple__95;
static PyObject *__pyx_tuple__97;
static PyObject *__pyx_tuple__99;
static PyObject *__pyx_codeobj__56;
static PyObject *__pyx_codeobj__60;
static PyObject *__pyx_codeobj__63;
static PyObject *__pyx_codeobj__72;
static PyObject *__pyx_codeobj__74;
static PyObject *__pyx_codeobj__76;
static PyObject *__pyx_codeobj__78;
static PyObject *__pyx_codeobj__80;
static PyObject *__pyx_codeobj__82;
static PyObject *__pyx_codeobj__84;
static PyObject *__pyx_codeobj__86;
static PyObject *__pyx_codeobj__88;
static PyObject *__pyx_codeobj__90;
static PyObject *__pyx_codeobj__92;
static PyObject *__pyx_codeobj__94;
static PyObject *__pyx_codeobj__96;
static PyObject *__pyx_codeobj__98;
static PyObject *__pyx_codeobj__100;

/* "fiona/ogrext.pyx":20
 * log = logging.getLogger("Fiona")
 * class NullHandler(logging.Handler):
 *     def emit(self, record):             # <<<<<<<<<<<<<<
 *         pass
 * log.addHandler(NullHandler())
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_11NullHandler_1emit(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_5fiona_6ogrext_11NullHandler_1emit = {__Pyx_NAMESTR("emit"), (PyCFunction)__pyx_pw_5fiona_6ogrext_11NullHandler_1emit, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_5fiona_6ogrext_11NullHandler_1emit(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  CYTHON_UNUSED PyObject *__pyx_v_record = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("emit (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_record,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_record)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("emit", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "emit") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_record = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("emit", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("fiona.ogrext.NullHandler.emit", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5fiona_6ogrext_11NullHandler_emit(__pyx_self, __pyx_v_self, __pyx_v_record);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_11NullHandler_emit(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_record) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("emit", 0);

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":93
 * # Geometry related functions and classes follow.
 * 
 * cdef void * _createOgrGeomFromWKB(object wkb) except NULL:             # <<<<<<<<<<<<<<
 *     """Make an OGR geometry from a WKB string"""
 *     geom_type = bytearray(wkb)[1]
 */

static void *__pyx_f_5fiona_6ogrext__createOgrGeomFromWKB(PyObject *__pyx_v_wkb) {
  unsigned char __pyx_v_geom_type;
  unsigned char *__pyx_v_buffer;
  void *__pyx_v_cogr_geometry;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  unsigned char *__pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_createOgrGeomFromWKB", 0);

  /* "fiona/ogrext.pyx":95
 * cdef void * _createOgrGeomFromWKB(object wkb) except NULL:
 *     """Make an OGR geometry from a WKB string"""
 *     geom_type = bytearray(wkb)[1]             # <<<<<<<<<<<<<<
 *     cdef unsigned char *buffer = wkb
 *     cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(geom_type)
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_wkb);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_wkb);
  __Pyx_GIVEREF(__pyx_v_wkb);
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyByteArray_Type))), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_GetItemInt_ByteArray(__pyx_t_2, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 95; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_geom_type = __pyx_t_3;

  /* "fiona/ogrext.pyx":96
 *     """Make an OGR geometry from a WKB string"""
 *     geom_type = bytearray(wkb)[1]
 *     cdef unsigned char *buffer = wkb             # <<<<<<<<<<<<<<
 *     cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(geom_type)
 *     if cogr_geometry is not NULL:
 */
  __pyx_t_4 = __Pyx_PyObject_AsUString(__pyx_v_wkb); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 96; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_buffer = __pyx_t_4;

  /* "fiona/ogrext.pyx":97
 *     geom_type = bytearray(wkb)[1]
 *     cdef unsigned char *buffer = wkb
 *     cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(geom_type)             # <<<<<<<<<<<<<<
 *     if cogr_geometry is not NULL:
 *         ograpi.OGR_G_ImportFromWkb(cogr_geometry, buffer, len(wkb))
 */
  __pyx_v_cogr_geometry = OGR_G_CreateGeometry(__pyx_v_geom_type);

  /* "fiona/ogrext.pyx":98
 *     cdef unsigned char *buffer = wkb
 *     cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(geom_type)
 *     if cogr_geometry is not NULL:             # <<<<<<<<<<<<<<
 *         ograpi.OGR_G_ImportFromWkb(cogr_geometry, buffer, len(wkb))
 *     return cogr_geometry
 */
  __pyx_t_5 = ((__pyx_v_cogr_geometry != NULL) != 0);
  if (__pyx_t_5) {

    /* "fiona/ogrext.pyx":99
 *     cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(geom_type)
 *     if cogr_geometry is not NULL:
 *         ograpi.OGR_G_ImportFromWkb(cogr_geometry, buffer, len(wkb))             # <<<<<<<<<<<<<<
 *     return cogr_geometry
 * 
 */
    __pyx_t_6 = PyObject_Length(__pyx_v_wkb); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    OGR_G_ImportFromWkb(__pyx_v_cogr_geometry, __pyx_v_buffer, __pyx_t_6);
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "fiona/ogrext.pyx":100
 *     if cogr_geometry is not NULL:
 *         ograpi.OGR_G_ImportFromWkb(cogr_geometry, buffer, len(wkb))
 *     return cogr_geometry             # <<<<<<<<<<<<<<
 * 
 * cdef _deleteOgrGeom(void *cogr_geometry):
 */
  __pyx_r = __pyx_v_cogr_geometry;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":93
 * # Geometry related functions and classes follow.
 * 
 * cdef void * _createOgrGeomFromWKB(object wkb) except NULL:             # <<<<<<<<<<<<<<
 *     """Make an OGR geometry from a WKB string"""
 *     geom_type = bytearray(wkb)[1]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("fiona.ogrext._createOgrGeomFromWKB", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":102
 *     return cogr_geometry
 * 
 * cdef _deleteOgrGeom(void *cogr_geometry):             # <<<<<<<<<<<<<<
 *     """Delete an OGR geometry"""
 *     if cogr_geometry is not NULL:
 */

static PyObject *__pyx_f_5fiona_6ogrext__deleteOgrGeom(void *__pyx_v_cogr_geometry) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("_deleteOgrGeom", 0);

  /* "fiona/ogrext.pyx":104
 * cdef _deleteOgrGeom(void *cogr_geometry):
 *     """Delete an OGR geometry"""
 *     if cogr_geometry is not NULL:             # <<<<<<<<<<<<<<
 *         ograpi.OGR_G_DestroyGeometry(cogr_geometry)
 *     cogr_geometry = NULL
 */
  __pyx_t_1 = ((__pyx_v_cogr_geometry != NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":105
 *     """Delete an OGR geometry"""
 *     if cogr_geometry is not NULL:
 *         ograpi.OGR_G_DestroyGeometry(cogr_geometry)             # <<<<<<<<<<<<<<
 *     cogr_geometry = NULL
 * 
 */
    OGR_G_DestroyGeometry(__pyx_v_cogr_geometry);
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "fiona/ogrext.pyx":106
 *     if cogr_geometry is not NULL:
 *         ograpi.OGR_G_DestroyGeometry(cogr_geometry)
 *     cogr_geometry = NULL             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_cogr_geometry = NULL;

  /* "fiona/ogrext.pyx":102
 *     return cogr_geometry
 * 
 * cdef _deleteOgrGeom(void *cogr_geometry):             # <<<<<<<<<<<<<<
 *     """Delete an OGR geometry"""
 *     if cogr_geometry is not NULL:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":114
 *     coordinates = None
 * 
 *     def getNumDimsPoint(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_1getNumDimsPoint(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_5fiona_6ogrext_17DimensionsHandler_1getNumDimsPoint = {__Pyx_NAMESTR("getNumDimsPoint"), (PyCFunction)__pyx_pw_5fiona_6ogrext_17DimensionsHandler_1getNumDimsPoint, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_1getNumDimsPoint(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getNumDimsPoint (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_17DimensionsHandler_getNumDimsPoint(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_getNumDimsPoint(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNumDimsPoint", 0);

  /* "fiona/ogrext.pyx":115
 * 
 *     def getNumDimsPoint(self):
 *         return len(self.coordinates)             # <<<<<<<<<<<<<<
 * 
 *     def getNumDimsLineString(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_coordinates); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":114
 *     coordinates = None
 * 
 *     def getNumDimsPoint(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("fiona.ogrext.DimensionsHandler.getNumDimsPoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":117
 *         return len(self.coordinates)
 * 
 *     def getNumDimsLineString(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0])
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_3getNumDimsLineString(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_5fiona_6ogrext_17DimensionsHandler_3getNumDimsLineString = {__Pyx_NAMESTR("getNumDimsLineString"), (PyCFunction)__pyx_pw_5fiona_6ogrext_17DimensionsHandler_3getNumDimsLineString, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_3getNumDimsLineString(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getNumDimsLineString (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_17DimensionsHandler_2getNumDimsLineString(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_2getNumDimsLineString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNumDimsLineString", 0);

  /* "fiona/ogrext.pyx":118
 * 
 *     def getNumDimsLineString(self):
 *         return len(self.coordinates[0])             # <<<<<<<<<<<<<<
 * 
 *     def getNumDimsLinearRing(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_coordinates); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 118; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":117
 *         return len(self.coordinates)
 * 
 *     def getNumDimsLineString(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0])
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("fiona.ogrext.DimensionsHandler.getNumDimsLineString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":120
 *         return len(self.coordinates[0])
 * 
 *     def getNumDimsLinearRing(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0])
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_5getNumDimsLinearRing(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_5fiona_6ogrext_17DimensionsHandler_5getNumDimsLinearRing = {__Pyx_NAMESTR("getNumDimsLinearRing"), (PyCFunction)__pyx_pw_5fiona_6ogrext_17DimensionsHandler_5getNumDimsLinearRing, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_5getNumDimsLinearRing(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getNumDimsLinearRing (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_17DimensionsHandler_4getNumDimsLinearRing(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_4getNumDimsLinearRing(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNumDimsLinearRing", 0);

  /* "fiona/ogrext.pyx":121
 * 
 *     def getNumDimsLinearRing(self):
 *         return len(self.coordinates[0])             # <<<<<<<<<<<<<<
 * 
 *     def getNumDimsPolygon(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_coordinates); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 121; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":120
 *         return len(self.coordinates[0])
 * 
 *     def getNumDimsLinearRing(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0])
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("fiona.ogrext.DimensionsHandler.getNumDimsLinearRing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":123
 *         return len(self.coordinates[0])
 * 
 *     def getNumDimsPolygon(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0][0])
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_7getNumDimsPolygon(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_5fiona_6ogrext_17DimensionsHandler_7getNumDimsPolygon = {__Pyx_NAMESTR("getNumDimsPolygon"), (PyCFunction)__pyx_pw_5fiona_6ogrext_17DimensionsHandler_7getNumDimsPolygon, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_7getNumDimsPolygon(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getNumDimsPolygon (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_17DimensionsHandler_6getNumDimsPolygon(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_6getNumDimsPolygon(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNumDimsPolygon", 0);

  /* "fiona/ogrext.pyx":124
 * 
 *     def getNumDimsPolygon(self):
 *         return len(self.coordinates[0][0])             # <<<<<<<<<<<<<<
 * 
 *     def getNumDimsMultiPoint(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_coordinates); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 124; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":123
 *         return len(self.coordinates[0])
 * 
 *     def getNumDimsPolygon(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0][0])
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("fiona.ogrext.DimensionsHandler.getNumDimsPolygon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":126
 *         return len(self.coordinates[0][0])
 * 
 *     def getNumDimsMultiPoint(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0])
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_9getNumDimsMultiPoint(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_5fiona_6ogrext_17DimensionsHandler_9getNumDimsMultiPoint = {__Pyx_NAMESTR("getNumDimsMultiPoint"), (PyCFunction)__pyx_pw_5fiona_6ogrext_17DimensionsHandler_9getNumDimsMultiPoint, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_9getNumDimsMultiPoint(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getNumDimsMultiPoint (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_17DimensionsHandler_8getNumDimsMultiPoint(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_8getNumDimsMultiPoint(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNumDimsMultiPoint", 0);

  /* "fiona/ogrext.pyx":127
 * 
 *     def getNumDimsMultiPoint(self):
 *         return len(self.coordinates[0])             # <<<<<<<<<<<<<<
 * 
 *     def getNumDimsMultiLineString(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_coordinates); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":126
 *         return len(self.coordinates[0][0])
 * 
 *     def getNumDimsMultiPoint(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0])
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("fiona.ogrext.DimensionsHandler.getNumDimsMultiPoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":129
 *         return len(self.coordinates[0])
 * 
 *     def getNumDimsMultiLineString(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0][0])
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_11getNumDimsMultiLineString(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_5fiona_6ogrext_17DimensionsHandler_11getNumDimsMultiLineString = {__Pyx_NAMESTR("getNumDimsMultiLineString"), (PyCFunction)__pyx_pw_5fiona_6ogrext_17DimensionsHandler_11getNumDimsMultiLineString, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_11getNumDimsMultiLineString(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getNumDimsMultiLineString (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_17DimensionsHandler_10getNumDimsMultiLineString(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_10getNumDimsMultiLineString(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNumDimsMultiLineString", 0);

  /* "fiona/ogrext.pyx":130
 * 
 *     def getNumDimsMultiLineString(self):
 *         return len(self.coordinates[0][0])             # <<<<<<<<<<<<<<
 * 
 *     def getNumDimsMultiPolygon(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_coordinates); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":129
 *         return len(self.coordinates[0])
 * 
 *     def getNumDimsMultiLineString(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0][0])
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("fiona.ogrext.DimensionsHandler.getNumDimsMultiLineString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":132
 *         return len(self.coordinates[0][0])
 * 
 *     def getNumDimsMultiPolygon(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0][0][0])
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_13getNumDimsMultiPolygon(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_5fiona_6ogrext_17DimensionsHandler_13getNumDimsMultiPolygon = {__Pyx_NAMESTR("getNumDimsMultiPolygon"), (PyCFunction)__pyx_pw_5fiona_6ogrext_17DimensionsHandler_13getNumDimsMultiPolygon, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_13getNumDimsMultiPolygon(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getNumDimsMultiPolygon (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_17DimensionsHandler_12getNumDimsMultiPolygon(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_12getNumDimsMultiPolygon(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNumDimsMultiPolygon", 0);

  /* "fiona/ogrext.pyx":133
 * 
 *     def getNumDimsMultiPolygon(self):
 *         return len(self.coordinates[0][0][0])             # <<<<<<<<<<<<<<
 * 
 *     def getNumDimsGeometryCollection(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_coordinates); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":132
 *         return len(self.coordinates[0][0])
 * 
 *     def getNumDimsMultiPolygon(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0][0][0])
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("fiona.ogrext.DimensionsHandler.getNumDimsMultiPolygon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":135
 *         return len(self.coordinates[0][0][0])
 * 
 *     def getNumDimsGeometryCollection(self):             # <<<<<<<<<<<<<<
 *         first = self.coordinates[0]
 *         return self.getNumDims(first['type'], first['coordinates'])
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_15getNumDimsGeometryCollection(PyObject *__pyx_self, PyObject *__pyx_v_self); /*proto*/
static PyMethodDef __pyx_mdef_5fiona_6ogrext_17DimensionsHandler_15getNumDimsGeometryCollection = {__Pyx_NAMESTR("getNumDimsGeometryCollection"), (PyCFunction)__pyx_pw_5fiona_6ogrext_17DimensionsHandler_15getNumDimsGeometryCollection, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_15getNumDimsGeometryCollection(PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getNumDimsGeometryCollection (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_17DimensionsHandler_14getNumDimsGeometryCollection(__pyx_self, ((PyObject *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_14getNumDimsGeometryCollection(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self) {
  PyObject *__pyx_v_first = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNumDimsGeometryCollection", 0);

  /* "fiona/ogrext.pyx":136
 * 
 *     def getNumDimsGeometryCollection(self):
 *         first = self.coordinates[0]             # <<<<<<<<<<<<<<
 *         return self.getNumDims(first['type'], first['coordinates'])
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_coordinates); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 136; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_first = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":137
 *     def getNumDimsGeometryCollection(self):
 *         first = self.coordinates[0]
 *         return self.getNumDims(first['type'], first['coordinates'])             # <<<<<<<<<<<<<<
 * 
 *     def getNumDims(self, geom_type, coordinates):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_getNumDims); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_GetItem(__pyx_v_first, __pyx_n_s_type); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_GetItem(__pyx_v_first, __pyx_n_s_coordinates); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_1 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":135
 *         return len(self.coordinates[0][0][0])
 * 
 *     def getNumDimsGeometryCollection(self):             # <<<<<<<<<<<<<<
 *         first = self.coordinates[0]
 *         return self.getNumDims(first['type'], first['coordinates'])
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("fiona.ogrext.DimensionsHandler.getNumDimsGeometryCollection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_first);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":139
 *         return self.getNumDims(first['type'], first['coordinates'])
 * 
 *     def getNumDims(self, geom_type, coordinates):             # <<<<<<<<<<<<<<
 *         self.coordinates = coordinates
 *         return getattr(self, 'getNumDims' + geom_type)()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_17getNumDims(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_5fiona_6ogrext_17DimensionsHandler_17getNumDims = {__Pyx_NAMESTR("getNumDims"), (PyCFunction)__pyx_pw_5fiona_6ogrext_17DimensionsHandler_17getNumDims, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_5fiona_6ogrext_17DimensionsHandler_17getNumDims(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_geom_type = 0;
  PyObject *__pyx_v_coordinates = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getNumDims (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_geom_type,&__pyx_n_s_coordinates,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_geom_type)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("getNumDims", 1, 3, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_coordinates)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("getNumDims", 1, 3, 3, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "getNumDims") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_geom_type = values[1];
    __pyx_v_coordinates = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("getNumDims", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("fiona.ogrext.DimensionsHandler.getNumDims", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5fiona_6ogrext_17DimensionsHandler_16getNumDims(__pyx_self, __pyx_v_self, __pyx_v_geom_type, __pyx_v_coordinates);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_17DimensionsHandler_16getNumDims(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_geom_type, PyObject *__pyx_v_coordinates) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getNumDims", 0);

  /* "fiona/ogrext.pyx":140
 * 
 *     def getNumDims(self, geom_type, coordinates):
 *         self.coordinates = coordinates             # <<<<<<<<<<<<<<
 *         return getattr(self, 'getNumDims' + geom_type)()
 * 
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_coordinates, __pyx_v_coordinates) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":141
 *     def getNumDims(self, geom_type, coordinates):
 *         self.coordinates = coordinates
 *         return getattr(self, 'getNumDims' + geom_type)()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_n_s_getNumDims, __pyx_v_geom_type); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr(__pyx_v_self, __pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_2, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":139
 *         return self.getNumDims(first['type'], first['coordinates'])
 * 
 *     def getNumDims(self, geom_type, coordinates):             # <<<<<<<<<<<<<<
 *         self.coordinates = coordinates
 *         return getattr(self, 'getNumDims' + geom_type)()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("fiona.ogrext.DimensionsHandler.getNumDims", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":152
 *     cdef object ndims
 * 
 *     cdef _buildCoords(self, void *geom):             # <<<<<<<<<<<<<<
 *         # Build a coordinate sequence
 *         cdef int i
 */

static PyObject *__pyx_f_5fiona_6ogrext_11GeomBuilder__buildCoords(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self, void *__pyx_v_geom) {
  int __pyx_v_i;
  int __pyx_v_npoints;
  PyObject *__pyx_v_coords = NULL;
  PyObject *__pyx_v_values = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildCoords", 0);

  /* "fiona/ogrext.pyx":155
 *         # Build a coordinate sequence
 *         cdef int i
 *         if geom is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null geom")
 *         npoints = ograpi.OGR_G_GetPointCount(geom)
 */
  __pyx_t_1 = ((__pyx_v_geom == NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":156
 *         cdef int i
 *         if geom is NULL:
 *             raise ValueError("Null geom")             # <<<<<<<<<<<<<<
 *         npoints = ograpi.OGR_G_GetPointCount(geom)
 *         coords = []
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":157
 *         if geom is NULL:
 *             raise ValueError("Null geom")
 *         npoints = ograpi.OGR_G_GetPointCount(geom)             # <<<<<<<<<<<<<<
 *         coords = []
 *         for i in range(npoints):
 */
  __pyx_v_npoints = OGR_G_GetPointCount(__pyx_v_geom);

  /* "fiona/ogrext.pyx":158
 *             raise ValueError("Null geom")
 *         npoints = ograpi.OGR_G_GetPointCount(geom)
 *         coords = []             # <<<<<<<<<<<<<<
 *         for i in range(npoints):
 *             values = [ograpi.OGR_G_GetX(geom, i), ograpi.OGR_G_GetY(geom, i)]
 */
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 158; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_coords = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":159
 *         npoints = ograpi.OGR_G_GetPointCount(geom)
 *         coords = []
 *         for i in range(npoints):             # <<<<<<<<<<<<<<
 *             values = [ograpi.OGR_G_GetX(geom, i), ograpi.OGR_G_GetY(geom, i)]
 *             if self.ndims > 2:
 */
  __pyx_t_3 = __pyx_v_npoints;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "fiona/ogrext.pyx":160
 *         coords = []
 *         for i in range(npoints):
 *             values = [ograpi.OGR_G_GetX(geom, i), ograpi.OGR_G_GetY(geom, i)]             # <<<<<<<<<<<<<<
 *             if self.ndims > 2:
 *                 values.append(ograpi.OGR_G_GetZ(geom, i))
 */
    __pyx_t_2 = PyFloat_FromDouble(OGR_G_GetX(__pyx_v_geom, __pyx_v_i)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = PyFloat_FromDouble(OGR_G_GetY(__pyx_v_geom, __pyx_v_i)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = PyList_New(2); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 160; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    PyList_SET_ITEM(__pyx_t_6, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    PyList_SET_ITEM(__pyx_t_6, 1, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_2 = 0;
    __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_values, ((PyObject*)__pyx_t_6));
    __pyx_t_6 = 0;

    /* "fiona/ogrext.pyx":161
 *         for i in range(npoints):
 *             values = [ograpi.OGR_G_GetX(geom, i), ograpi.OGR_G_GetY(geom, i)]
 *             if self.ndims > 2:             # <<<<<<<<<<<<<<
 *                 values.append(ograpi.OGR_G_GetZ(geom, i))
 *             coords.append(tuple(values))
 */
    __pyx_t_6 = PyObject_RichCompare(__pyx_v_self->ndims, __pyx_int_2, Py_GT); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 161; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 161; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (__pyx_t_1) {

      /* "fiona/ogrext.pyx":162
 *             values = [ograpi.OGR_G_GetX(geom, i), ograpi.OGR_G_GetY(geom, i)]
 *             if self.ndims > 2:
 *                 values.append(ograpi.OGR_G_GetZ(geom, i))             # <<<<<<<<<<<<<<
 *             coords.append(tuple(values))
 *         return coords
 */
      __pyx_t_6 = PyFloat_FromDouble(OGR_G_GetZ(__pyx_v_geom, __pyx_v_i)); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_values, __pyx_t_6); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6;
    }
    __pyx_L6:;

    /* "fiona/ogrext.pyx":163
 *             if self.ndims > 2:
 *                 values.append(ograpi.OGR_G_GetZ(geom, i))
 *             coords.append(tuple(values))             # <<<<<<<<<<<<<<
 *         return coords
 * 
 */
    __pyx_t_6 = PyList_AsTuple(__pyx_v_values); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_coords, __pyx_t_6); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 163; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }

  /* "fiona/ogrext.pyx":164
 *                 values.append(ograpi.OGR_G_GetZ(geom, i))
 *             coords.append(tuple(values))
 *         return coords             # <<<<<<<<<<<<<<
 * 
 *     cpdef _buildPoint(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_coords);
  __pyx_r = __pyx_v_coords;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":152
 *     cdef object ndims
 * 
 *     cdef _buildCoords(self, void *geom):             # <<<<<<<<<<<<<<
 *         # Build a coordinate sequence
 *         cdef int i
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildCoords", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_coords);
  __Pyx_XDECREF(__pyx_v_values);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":166
 *         return coords
 * 
 *     cpdef _buildPoint(self):             # <<<<<<<<<<<<<<
 *         return {'type': 'Point', 'coordinates': self._buildCoords(self.geom)[0]}
 * 
 */

static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_1_buildPoint(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_5fiona_6ogrext_11GeomBuilder__buildPoint(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildPoint", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_buildPoint); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_1_buildPoint)) {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "fiona/ogrext.pyx":167
 * 
 *     cpdef _buildPoint(self):
 *         return {'type': 'Point', 'coordinates': self._buildCoords(self.geom)[0]}             # <<<<<<<<<<<<<<
 * 
 *     cpdef _buildLineString(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_type, __pyx_n_s_Point) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildCoords(__pyx_v_self, __pyx_v_self->geom); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_coordinates, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 167; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":166
 *         return coords
 * 
 *     cpdef _buildPoint(self):             # <<<<<<<<<<<<<<
 *         return {'type': 'Point', 'coordinates': self._buildCoords(self.geom)[0]}
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildPoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_1_buildPoint(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_1_buildPoint(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_buildPoint (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_11GeomBuilder__buildPoint(((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder__buildPoint(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildPoint", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildPoint(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 166; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildPoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":169
 *         return {'type': 'Point', 'coordinates': self._buildCoords(self.geom)[0]}
 * 
 *     cpdef _buildLineString(self):             # <<<<<<<<<<<<<<
 *         return {'type': 'LineString', 'coordinates': self._buildCoords(self.geom)}
 * 
 */

static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_3_buildLineString(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_5fiona_6ogrext_11GeomBuilder__buildLineString(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildLineString", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_buildLineString); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_3_buildLineString)) {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "fiona/ogrext.pyx":170
 * 
 *     cpdef _buildLineString(self):
 *         return {'type': 'LineString', 'coordinates': self._buildCoords(self.geom)}             # <<<<<<<<<<<<<<
 * 
 *     cpdef _buildLinearRing(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_type, __pyx_n_s_LineString) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildCoords(__pyx_v_self, __pyx_v_self->geom); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_coordinates, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 170; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":169
 *         return {'type': 'Point', 'coordinates': self._buildCoords(self.geom)[0]}
 * 
 *     cpdef _buildLineString(self):             # <<<<<<<<<<<<<<
 *         return {'type': 'LineString', 'coordinates': self._buildCoords(self.geom)}
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildLineString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_3_buildLineString(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_3_buildLineString(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_buildLineString (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_11GeomBuilder_2_buildLineString(((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_2_buildLineString(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildLineString", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildLineString(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildLineString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":172
 *         return {'type': 'LineString', 'coordinates': self._buildCoords(self.geom)}
 * 
 *     cpdef _buildLinearRing(self):             # <<<<<<<<<<<<<<
 *         return {'type': 'LinearRing', 'coordinates': self._buildCoords(self.geom)}
 * 
 */

static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_5_buildLinearRing(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_5fiona_6ogrext_11GeomBuilder__buildLinearRing(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildLinearRing", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_buildLinearRing); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_5_buildLinearRing)) {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "fiona/ogrext.pyx":173
 * 
 *     cpdef _buildLinearRing(self):
 *         return {'type': 'LinearRing', 'coordinates': self._buildCoords(self.geom)}             # <<<<<<<<<<<<<<
 * 
 *     cdef _buildParts(self, void *geom):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_type, __pyx_n_s_LinearRing) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildCoords(__pyx_v_self, __pyx_v_self->geom); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_coordinates, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 173; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":172
 *         return {'type': 'LineString', 'coordinates': self._buildCoords(self.geom)}
 * 
 *     cpdef _buildLinearRing(self):             # <<<<<<<<<<<<<<
 *         return {'type': 'LinearRing', 'coordinates': self._buildCoords(self.geom)}
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildLinearRing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_5_buildLinearRing(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_5_buildLinearRing(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_buildLinearRing (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_11GeomBuilder_4_buildLinearRing(((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_4_buildLinearRing(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildLinearRing", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildLinearRing(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildLinearRing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":175
 *         return {'type': 'LinearRing', 'coordinates': self._buildCoords(self.geom)}
 * 
 *     cdef _buildParts(self, void *geom):             # <<<<<<<<<<<<<<
 *         cdef int j
 *         cdef void *part
 */

static PyObject *__pyx_f_5fiona_6ogrext_11GeomBuilder__buildParts(CYTHON_UNUSED struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self, void *__pyx_v_geom) {
  int __pyx_v_j;
  void *__pyx_v_part;
  PyObject *__pyx_v_parts = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildParts", 0);

  /* "fiona/ogrext.pyx":178
 *         cdef int j
 *         cdef void *part
 *         if geom is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null geom")
 *         parts = []
 */
  __pyx_t_1 = ((__pyx_v_geom == NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":179
 *         cdef void *part
 *         if geom is NULL:
 *             raise ValueError("Null geom")             # <<<<<<<<<<<<<<
 *         parts = []
 *         for j in range(ograpi.OGR_G_GetGeometryCount(geom)):
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 179; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 179; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":180
 *         if geom is NULL:
 *             raise ValueError("Null geom")
 *         parts = []             # <<<<<<<<<<<<<<
 *         for j in range(ograpi.OGR_G_GetGeometryCount(geom)):
 *             part = ograpi.OGR_G_GetGeometryRef(geom, j)
 */
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_parts = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":181
 *             raise ValueError("Null geom")
 *         parts = []
 *         for j in range(ograpi.OGR_G_GetGeometryCount(geom)):             # <<<<<<<<<<<<<<
 *             part = ograpi.OGR_G_GetGeometryRef(geom, j)
 *             parts.append(GeomBuilder().build(part))
 */
  __pyx_t_3 = OGR_G_GetGeometryCount(__pyx_v_geom);
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_j = __pyx_t_4;

    /* "fiona/ogrext.pyx":182
 *         parts = []
 *         for j in range(ograpi.OGR_G_GetGeometryCount(geom)):
 *             part = ograpi.OGR_G_GetGeometryRef(geom, j)             # <<<<<<<<<<<<<<
 *             parts.append(GeomBuilder().build(part))
 *         return parts
 */
    __pyx_v_part = OGR_G_GetGeometryRef(__pyx_v_geom, __pyx_v_j);

    /* "fiona/ogrext.pyx":183
 *         for j in range(ograpi.OGR_G_GetGeometryCount(geom)):
 *             part = ograpi.OGR_G_GetGeometryRef(geom, j)
 *             parts.append(GeomBuilder().build(part))             # <<<<<<<<<<<<<<
 *         return parts
 * 
 */
    __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5fiona_6ogrext_GeomBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 183; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_t_2)->__pyx_vtab)->build(((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_t_2), __pyx_v_part); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 183; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_parts, __pyx_t_5); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 183; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }

  /* "fiona/ogrext.pyx":184
 *             part = ograpi.OGR_G_GetGeometryRef(geom, j)
 *             parts.append(GeomBuilder().build(part))
 *         return parts             # <<<<<<<<<<<<<<
 * 
 *     cpdef _buildPolygon(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_parts);
  __pyx_r = __pyx_v_parts;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":175
 *         return {'type': 'LinearRing', 'coordinates': self._buildCoords(self.geom)}
 * 
 *     cdef _buildParts(self, void *geom):             # <<<<<<<<<<<<<<
 *         cdef int j
 *         cdef void *part
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildParts", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_parts);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":186
 *         return parts
 * 
 *     cpdef _buildPolygon(self):             # <<<<<<<<<<<<<<
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]
 *         return {'type': 'Polygon', 'coordinates': coordinates}
 */

static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_7_buildPolygon(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_5fiona_6ogrext_11GeomBuilder__buildPolygon(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_coordinates = NULL;
  PyObject *__pyx_v_p = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildPolygon", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_buildPolygon); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 186; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_7_buildPolygon)) {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 186; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "fiona/ogrext.pyx":187
 * 
 *     cpdef _buildPolygon(self):
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]             # <<<<<<<<<<<<<<
 *         return {'type': 'Polygon', 'coordinates': coordinates}
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildParts(__pyx_v_self, __pyx_v_self->geom); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyList_CheckExact(__pyx_t_2) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_3)) {
      if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_3)) {
      if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_2 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_p, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_GetItem(__pyx_v_p, __pyx_n_s_coordinates); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_2))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_coordinates = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":188
 *     cpdef _buildPolygon(self):
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]
 *         return {'type': 'Polygon', 'coordinates': coordinates}             # <<<<<<<<<<<<<<
 * 
 *     cpdef _buildMultiPoint(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_type, __pyx_n_s_Polygon) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_coordinates, __pyx_v_coordinates) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":186
 *         return parts
 * 
 *     cpdef _buildPolygon(self):             # <<<<<<<<<<<<<<
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]
 *         return {'type': 'Polygon', 'coordinates': coordinates}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildPolygon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_coordinates);
  __Pyx_XDECREF(__pyx_v_p);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_7_buildPolygon(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_7_buildPolygon(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_buildPolygon (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_11GeomBuilder_6_buildPolygon(((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_6_buildPolygon(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildPolygon", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildPolygon(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 186; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildPolygon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":190
 *         return {'type': 'Polygon', 'coordinates': coordinates}
 * 
 *     cpdef _buildMultiPoint(self):             # <<<<<<<<<<<<<<
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]
 *         return {'type': 'MultiPoint', 'coordinates': coordinates}
 */

static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_9_buildMultiPoint(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_5fiona_6ogrext_11GeomBuilder__buildMultiPoint(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_coordinates = NULL;
  PyObject *__pyx_v_p = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildMultiPoint", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_buildMultiPoint); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_9_buildMultiPoint)) {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "fiona/ogrext.pyx":191
 * 
 *     cpdef _buildMultiPoint(self):
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]             # <<<<<<<<<<<<<<
 *         return {'type': 'MultiPoint', 'coordinates': coordinates}
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 191; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildParts(__pyx_v_self, __pyx_v_self->geom); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 191; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyList_CheckExact(__pyx_t_2) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 191; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_3)) {
      if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 191; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 191; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_3)) {
      if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 191; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 191; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_2 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 191; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_p, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_GetItem(__pyx_v_p, __pyx_n_s_coordinates); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 191; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_2))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 191; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_coordinates = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":192
 *     cpdef _buildMultiPoint(self):
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]
 *         return {'type': 'MultiPoint', 'coordinates': coordinates}             # <<<<<<<<<<<<<<
 * 
 *     cpdef _buildMultiLineString(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 192; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_type, __pyx_n_s_MultiPoint) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 192; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_coordinates, __pyx_v_coordinates) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 192; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":190
 *         return {'type': 'Polygon', 'coordinates': coordinates}
 * 
 *     cpdef _buildMultiPoint(self):             # <<<<<<<<<<<<<<
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]
 *         return {'type': 'MultiPoint', 'coordinates': coordinates}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildMultiPoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_coordinates);
  __Pyx_XDECREF(__pyx_v_p);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_9_buildMultiPoint(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_9_buildMultiPoint(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_buildMultiPoint (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_11GeomBuilder_8_buildMultiPoint(((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_8_buildMultiPoint(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildMultiPoint", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildMultiPoint(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 190; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildMultiPoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":194
 *         return {'type': 'MultiPoint', 'coordinates': coordinates}
 * 
 *     cpdef _buildMultiLineString(self):             # <<<<<<<<<<<<<<
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]
 *         return {'type': 'MultiLineString', 'coordinates': coordinates}
 */

static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_11_buildMultiLineString(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_5fiona_6ogrext_11GeomBuilder__buildMultiLineString(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_coordinates = NULL;
  PyObject *__pyx_v_p = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildMultiLineString", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_buildMultiLineString); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_11_buildMultiLineString)) {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "fiona/ogrext.pyx":195
 * 
 *     cpdef _buildMultiLineString(self):
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]             # <<<<<<<<<<<<<<
 *         return {'type': 'MultiLineString', 'coordinates': coordinates}
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildParts(__pyx_v_self, __pyx_v_self->geom); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyList_CheckExact(__pyx_t_2) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_3)) {
      if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_3)) {
      if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_2 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_p, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_GetItem(__pyx_v_p, __pyx_n_s_coordinates); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_2))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 195; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_coordinates = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":196
 *     cpdef _buildMultiLineString(self):
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]
 *         return {'type': 'MultiLineString', 'coordinates': coordinates}             # <<<<<<<<<<<<<<
 * 
 *     cpdef _buildMultiPolygon(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_type, __pyx_n_s_MultiLineString) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_coordinates, __pyx_v_coordinates) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 196; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":194
 *         return {'type': 'MultiPoint', 'coordinates': coordinates}
 * 
 *     cpdef _buildMultiLineString(self):             # <<<<<<<<<<<<<<
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]
 *         return {'type': 'MultiLineString', 'coordinates': coordinates}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildMultiLineString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_coordinates);
  __Pyx_XDECREF(__pyx_v_p);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_11_buildMultiLineString(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_11_buildMultiLineString(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_buildMultiLineString (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_11GeomBuilder_10_buildMultiLineString(((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_10_buildMultiLineString(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildMultiLineString", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildMultiLineString(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 194; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildMultiLineString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":198
 *         return {'type': 'MultiLineString', 'coordinates': coordinates}
 * 
 *     cpdef _buildMultiPolygon(self):             # <<<<<<<<<<<<<<
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]
 *         return {'type': 'MultiPolygon', 'coordinates': coordinates}
 */

static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_13_buildMultiPolygon(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_5fiona_6ogrext_11GeomBuilder__buildMultiPolygon(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_coordinates = NULL;
  PyObject *__pyx_v_p = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildMultiPolygon", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_buildMultiPolygon); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 198; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_13_buildMultiPolygon)) {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 198; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "fiona/ogrext.pyx":199
 * 
 *     cpdef _buildMultiPolygon(self):
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]             # <<<<<<<<<<<<<<
 *         return {'type': 'MultiPolygon', 'coordinates': coordinates}
 * 
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildParts(__pyx_v_self, __pyx_v_self->geom); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyList_CheckExact(__pyx_t_2) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_3)) {
      if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_3)) {
      if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_2 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_p, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_GetItem(__pyx_v_p, __pyx_n_s_coordinates); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_2))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_coordinates = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":200
 *     cpdef _buildMultiPolygon(self):
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]
 *         return {'type': 'MultiPolygon', 'coordinates': coordinates}             # <<<<<<<<<<<<<<
 * 
 *     cpdef _buildGeometryCollection(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 200; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_type, __pyx_n_s_MultiPolygon) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 200; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_coordinates, __pyx_v_coordinates) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 200; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":198
 *         return {'type': 'MultiLineString', 'coordinates': coordinates}
 * 
 *     cpdef _buildMultiPolygon(self):             # <<<<<<<<<<<<<<
 *         coordinates = [p['coordinates'] for p in self._buildParts(self.geom)]
 *         return {'type': 'MultiPolygon', 'coordinates': coordinates}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildMultiPolygon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_coordinates);
  __Pyx_XDECREF(__pyx_v_p);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_13_buildMultiPolygon(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_13_buildMultiPolygon(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_buildMultiPolygon (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_11GeomBuilder_12_buildMultiPolygon(((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_12_buildMultiPolygon(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildMultiPolygon", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildMultiPolygon(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 198; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildMultiPolygon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":202
 *         return {'type': 'MultiPolygon', 'coordinates': coordinates}
 * 
 *     cpdef _buildGeometryCollection(self):             # <<<<<<<<<<<<<<
 *         parts = self._buildParts(self.geom)
 *         return {'type': 'GeometryCollection', 'geometries': parts}
 */

static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_15_buildGeometryCollection(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_5fiona_6ogrext_11GeomBuilder__buildGeometryCollection(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_parts = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildGeometryCollection", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_buildGeometryCollection); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_15_buildGeometryCollection)) {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "fiona/ogrext.pyx":203
 * 
 *     cpdef _buildGeometryCollection(self):
 *         parts = self._buildParts(self.geom)             # <<<<<<<<<<<<<<
 *         return {'type': 'GeometryCollection', 'geometries': parts}
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildParts(__pyx_v_self, __pyx_v_self->geom); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 203; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_parts = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":204
 *     cpdef _buildGeometryCollection(self):
 *         parts = self._buildParts(self.geom)
 *         return {'type': 'GeometryCollection', 'geometries': parts}             # <<<<<<<<<<<<<<
 * 
 *     cdef build(self, void *geom):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_type, __pyx_n_s_GeometryCollection) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_geometries, __pyx_v_parts) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":202
 *         return {'type': 'MultiPolygon', 'coordinates': coordinates}
 * 
 *     cpdef _buildGeometryCollection(self):             # <<<<<<<<<<<<<<
 *         parts = self._buildParts(self.geom)
 *         return {'type': 'GeometryCollection', 'geometries': parts}
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildGeometryCollection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_parts);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_15_buildGeometryCollection(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_15_buildGeometryCollection(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_buildGeometryCollection (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_11GeomBuilder_14_buildGeometryCollection(((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_14_buildGeometryCollection(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildGeometryCollection", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildGeometryCollection(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder._buildGeometryCollection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":206
 *         return {'type': 'GeometryCollection', 'geometries': parts}
 * 
 *     cdef build(self, void *geom):             # <<<<<<<<<<<<<<
 *         # The only method anyone needs to call
 *         if geom is NULL:
 */

static PyObject *__pyx_f_5fiona_6ogrext_11GeomBuilder_build(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self, void *__pyx_v_geom) {
  unsigned int __pyx_v_etype;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("build", 0);

  /* "fiona/ogrext.pyx":208
 *     cdef build(self, void *geom):
 *         # The only method anyone needs to call
 *         if geom is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null geom")
 * 
 */
  __pyx_t_1 = ((__pyx_v_geom == NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":209
 *         # The only method anyone needs to call
 *         if geom is NULL:
 *             raise ValueError("Null geom")             # <<<<<<<<<<<<<<
 * 
 *         cdef unsigned int etype = ograpi.OGR_G_GetGeometryType(geom)
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 209; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 209; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":211
 *             raise ValueError("Null geom")
 * 
 *         cdef unsigned int etype = ograpi.OGR_G_GetGeometryType(geom)             # <<<<<<<<<<<<<<
 *         self.code = etype
 *         self.typename = GEOMETRY_TYPES[self.code & (~0x80000000)]
 */
  __pyx_v_etype = OGR_G_GetGeometryType(__pyx_v_geom);

  /* "fiona/ogrext.pyx":212
 * 
 *         cdef unsigned int etype = ograpi.OGR_G_GetGeometryType(geom)
 *         self.code = etype             # <<<<<<<<<<<<<<
 *         self.typename = GEOMETRY_TYPES[self.code & (~0x80000000)]
 *         self.ndims = ograpi.OGR_G_GetCoordinateDimension(geom)
 */
  __pyx_t_2 = __Pyx_PyInt_From_unsigned_int(__pyx_v_etype); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 212; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->code);
  __Pyx_DECREF(__pyx_v_self->code);
  __pyx_v_self->code = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":213
 *         cdef unsigned int etype = ograpi.OGR_G_GetGeometryType(geom)
 *         self.code = etype
 *         self.typename = GEOMETRY_TYPES[self.code & (~0x80000000)]             # <<<<<<<<<<<<<<
 *         self.ndims = ograpi.OGR_G_GetCoordinateDimension(geom)
 *         self.geom = geom
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_GEOMETRY_TYPES); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 213; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Invert(__pyx_int_2147483648); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 213; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyNumber_And(__pyx_v_self->code, __pyx_t_3); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 213; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_GetItem(__pyx_t_2, __pyx_t_4); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 213; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->typename);
  __Pyx_DECREF(__pyx_v_self->typename);
  __pyx_v_self->typename = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "fiona/ogrext.pyx":214
 *         self.code = etype
 *         self.typename = GEOMETRY_TYPES[self.code & (~0x80000000)]
 *         self.ndims = ograpi.OGR_G_GetCoordinateDimension(geom)             # <<<<<<<<<<<<<<
 *         self.geom = geom
 *         return getattr(self, '_build' + self.typename)()
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(OGR_G_GetCoordinateDimension(__pyx_v_geom)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 214; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->ndims);
  __Pyx_DECREF(__pyx_v_self->ndims);
  __pyx_v_self->ndims = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "fiona/ogrext.pyx":215
 *         self.typename = GEOMETRY_TYPES[self.code & (~0x80000000)]
 *         self.ndims = ograpi.OGR_G_GetCoordinateDimension(geom)
 *         self.geom = geom             # <<<<<<<<<<<<<<
 *         return getattr(self, '_build' + self.typename)()
 * 
 */
  __pyx_v_self->geom = __pyx_v_geom;

  /* "fiona/ogrext.pyx":216
 *         self.ndims = ograpi.OGR_G_GetCoordinateDimension(geom)
 *         self.geom = geom
 *         return getattr(self, '_build' + self.typename)()             # <<<<<<<<<<<<<<
 * 
 *     cpdef build_wkb(self, object wkb):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = PyNumber_Add(__pyx_n_s_build, __pyx_v_self->typename); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 216; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_GetAttr(((PyObject *)__pyx_v_self), __pyx_t_3); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 216; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_4, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 216; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":206
 *         return {'type': 'GeometryCollection', 'geometries': parts}
 * 
 *     cdef build(self, void *geom):             # <<<<<<<<<<<<<<
 *         # The only method anyone needs to call
 *         if geom is NULL:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder.build", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":218
 *         return getattr(self, '_build' + self.typename)()
 * 
 *     cpdef build_wkb(self, object wkb):             # <<<<<<<<<<<<<<
 *         # The only other method anyone needs to call
 *         cdef object data = wkb
 */

static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_17build_wkb(PyObject *__pyx_v_self, PyObject *__pyx_v_wkb); /*proto*/
static PyObject *__pyx_f_5fiona_6ogrext_11GeomBuilder_build_wkb(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self, PyObject *__pyx_v_wkb, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_data = 0;
  void *__pyx_v_cogr_geometry;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  void *__pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("build_wkb", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0)) {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_build_wkb); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_17build_wkb)) {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_INCREF(__pyx_v_wkb);
      PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_wkb);
      __Pyx_GIVEREF(__pyx_v_wkb);
      __pyx_t_3 = PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "fiona/ogrext.pyx":220
 *     cpdef build_wkb(self, object wkb):
 *         # The only other method anyone needs to call
 *         cdef object data = wkb             # <<<<<<<<<<<<<<
 *         cdef void *cogr_geometry = _createOgrGeomFromWKB(data)
 *         result = self.build(cogr_geometry)
 */
  __Pyx_INCREF(__pyx_v_wkb);
  __pyx_v_data = __pyx_v_wkb;

  /* "fiona/ogrext.pyx":221
 *         # The only other method anyone needs to call
 *         cdef object data = wkb
 *         cdef void *cogr_geometry = _createOgrGeomFromWKB(data)             # <<<<<<<<<<<<<<
 *         result = self.build(cogr_geometry)
 *         _deleteOgrGeom(cogr_geometry)
 */
  __pyx_t_4 = __pyx_f_5fiona_6ogrext__createOgrGeomFromWKB(__pyx_v_data); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 221; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_cogr_geometry = __pyx_t_4;

  /* "fiona/ogrext.pyx":222
 *         cdef object data = wkb
 *         cdef void *cogr_geometry = _createOgrGeomFromWKB(data)
 *         result = self.build(cogr_geometry)             # <<<<<<<<<<<<<<
 *         _deleteOgrGeom(cogr_geometry)
 *         return result
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->build(__pyx_v_self, __pyx_v_cogr_geometry); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 222; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":223
 *         cdef void *cogr_geometry = _createOgrGeomFromWKB(data)
 *         result = self.build(cogr_geometry)
 *         _deleteOgrGeom(cogr_geometry)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __pyx_t_1 = __pyx_f_5fiona_6ogrext__deleteOgrGeom(__pyx_v_cogr_geometry); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 223; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":224
 *         result = self.build(cogr_geometry)
 *         _deleteOgrGeom(cogr_geometry)
 *         return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":218
 *         return getattr(self, '_build' + self.typename)()
 * 
 *     cpdef build_wkb(self, object wkb):             # <<<<<<<<<<<<<<
 *         # The only other method anyone needs to call
 *         cdef object data = wkb
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder.build_wkb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_17build_wkb(PyObject *__pyx_v_self, PyObject *__pyx_v_wkb); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_11GeomBuilder_17build_wkb(PyObject *__pyx_v_self, PyObject *__pyx_v_wkb) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("build_wkb (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_11GeomBuilder_16build_wkb(((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_v_self), ((PyObject *)__pyx_v_wkb));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_11GeomBuilder_16build_wkb(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *__pyx_v_self, PyObject *__pyx_v_wkb) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("build_wkb", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)__pyx_v_self->__pyx_vtab)->build_wkb(__pyx_v_self, __pyx_v_wkb, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("fiona.ogrext.GeomBuilder.build_wkb", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":234
 *     cdef object ndims
 * 
 *     cdef void * _buildPoint(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(1)
 *         if cogr_geometry is NULL:
 */

static void *__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildPoint(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *__pyx_v_self) {
  void *__pyx_v_cogr_geometry;
  PyObject *__pyx_v_x = NULL;
  PyObject *__pyx_v_y = NULL;
  PyObject *__pyx_v_z = NULL;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *(*__pyx_t_7)(PyObject *);
  double __pyx_t_8;
  double __pyx_t_9;
  double __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildPoint", 0);

  /* "fiona/ogrext.pyx":235
 * 
 *     cdef void * _buildPoint(self) except NULL:
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(1)             # <<<<<<<<<<<<<<
 *         if cogr_geometry is NULL:
 *             raise ValueError
 */
  __pyx_v_cogr_geometry = OGR_G_CreateGeometry(1);

  /* "fiona/ogrext.pyx":236
 *     cdef void * _buildPoint(self) except NULL:
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(1)
 *         if cogr_geometry is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError
 *         if self.ndims > 2:
 */
  __pyx_t_1 = ((__pyx_v_cogr_geometry == NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":237
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(1)
 *         if cogr_geometry is NULL:
 *             raise ValueError             # <<<<<<<<<<<<<<
 *         if self.ndims > 2:
 *             x, y, z = self.coordinates
 */
    __Pyx_Raise(__pyx_builtin_ValueError, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 237; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":238
 *         if cogr_geometry is NULL:
 *             raise ValueError
 *         if self.ndims > 2:             # <<<<<<<<<<<<<<
 *             x, y, z = self.coordinates
 *             ograpi.OGR_G_AddPoint(cogr_geometry, x, y, z)
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_self->ndims, __pyx_int_2, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 238; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 238; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":239
 *             raise ValueError
 *         if self.ndims > 2:
 *             x, y, z = self.coordinates             # <<<<<<<<<<<<<<
 *             ograpi.OGR_G_AddPoint(cogr_geometry, x, y, z)
 *         else:
 */
    __pyx_t_2 = __pyx_v_self->coordinates;
    __Pyx_INCREF(__pyx_t_2);
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 3)) {
        if (size > 3) __Pyx_RaiseTooManyValuesError(3);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 239; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 2); 
      } else {
        __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
        __pyx_t_5 = PyList_GET_ITEM(sequence, 2); 
      }
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 239; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 239; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 239; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_6 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 239; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = Py_TYPE(__pyx_t_6)->tp_iternext;
      index = 0; __pyx_t_3 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_3)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 1; __pyx_t_4 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      index = 2; __pyx_t_5 = __pyx_t_7(__pyx_t_6); if (unlikely(!__pyx_t_5)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_6), 3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 239; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_7 = NULL;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 239; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L6_unpacking_done:;
    }
    __pyx_v_x = __pyx_t_3;
    __pyx_t_3 = 0;
    __pyx_v_y = __pyx_t_4;
    __pyx_t_4 = 0;
    __pyx_v_z = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "fiona/ogrext.pyx":240
 *         if self.ndims > 2:
 *             x, y, z = self.coordinates
 *             ograpi.OGR_G_AddPoint(cogr_geometry, x, y, z)             # <<<<<<<<<<<<<<
 *         else:
 *             x, y = self.coordinates
 */
    __pyx_t_8 = __pyx_PyFloat_AsDouble(__pyx_v_x); if (unlikely((__pyx_t_8 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 240; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_v_y); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 240; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_10 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_10 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 240; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    OGR_G_AddPoint(__pyx_v_cogr_geometry, __pyx_t_8, __pyx_t_9, __pyx_t_10);
    goto __pyx_L4;
  }
  /*else*/ {

    /* "fiona/ogrext.pyx":242
 *             ograpi.OGR_G_AddPoint(cogr_geometry, x, y, z)
 *         else:
 *             x, y = self.coordinates             # <<<<<<<<<<<<<<
 *             ograpi.OGR_G_AddPoint_2D(cogr_geometry, x, y)
 *         return cogr_geometry
 */
    __pyx_t_2 = __pyx_v_self->coordinates;
    __Pyx_INCREF(__pyx_t_2);
    if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
      PyObject* sequence = __pyx_t_2;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 242; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      #else
      __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 242; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 242; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      #endif
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 242; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = Py_TYPE(__pyx_t_3)->tp_iternext;
      index = 0; __pyx_t_5 = __pyx_t_7(__pyx_t_3); if (unlikely(!__pyx_t_5)) goto __pyx_L7_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_5);
      index = 1; __pyx_t_4 = __pyx_t_7(__pyx_t_3); if (unlikely(!__pyx_t_4)) goto __pyx_L7_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_7(__pyx_t_3), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 242; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_7 = NULL;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L8_unpacking_done;
      __pyx_L7_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 242; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L8_unpacking_done:;
    }
    __pyx_v_x = __pyx_t_5;
    __pyx_t_5 = 0;
    __pyx_v_y = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "fiona/ogrext.pyx":243
 *         else:
 *             x, y = self.coordinates
 *             ograpi.OGR_G_AddPoint_2D(cogr_geometry, x, y)             # <<<<<<<<<<<<<<
 *         return cogr_geometry
 * 
 */
    __pyx_t_10 = __pyx_PyFloat_AsDouble(__pyx_v_x); if (unlikely((__pyx_t_10 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 243; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_9 = __pyx_PyFloat_AsDouble(__pyx_v_y); if (unlikely((__pyx_t_9 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 243; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    OGR_G_AddPoint_2D(__pyx_v_cogr_geometry, __pyx_t_10, __pyx_t_9);
  }
  __pyx_L4:;

  /* "fiona/ogrext.pyx":244
 *             x, y = self.coordinates
 *             ograpi.OGR_G_AddPoint_2D(cogr_geometry, x, y)
 *         return cogr_geometry             # <<<<<<<<<<<<<<
 * 
 *     cdef void * _buildLineString(self) except NULL:
 */
  __pyx_r = __pyx_v_cogr_geometry;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":234
 *     cdef object ndims
 * 
 *     cdef void * _buildPoint(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(1)
 *         if cogr_geometry is NULL:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("fiona.ogrext.OGRGeomBuilder._buildPoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XDECREF(__pyx_v_y);
  __Pyx_XDECREF(__pyx_v_z);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":246
 *         return cogr_geometry
 * 
 *     cdef void * _buildLineString(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(2)
 *         if cogr_geometry is NULL:
 */

static void *__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildLineString(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *__pyx_v_self) {
  void *__pyx_v_cogr_geometry;
  PyObject *__pyx_v_values = NULL;
  PyObject *__pyx_v_x = NULL;
  PyObject *__pyx_v_y = NULL;
  PyObject *__pyx_v_z = NULL;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *(*__pyx_t_10)(PyObject *);
  double __pyx_t_11;
  double __pyx_t_12;
  double __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildLineString", 0);

  /* "fiona/ogrext.pyx":247
 * 
 *     cdef void * _buildLineString(self) except NULL:
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(2)             # <<<<<<<<<<<<<<
 *         if cogr_geometry is NULL:
 *             raise ValueError
 */
  __pyx_v_cogr_geometry = OGR_G_CreateGeometry(2);

  /* "fiona/ogrext.pyx":248
 *     cdef void * _buildLineString(self) except NULL:
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(2)
 *         if cogr_geometry is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError
 *         for values in self.coordinates:
 */
  __pyx_t_1 = ((__pyx_v_cogr_geometry == NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":249
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(2)
 *         if cogr_geometry is NULL:
 *             raise ValueError             # <<<<<<<<<<<<<<
 *         for values in self.coordinates:
 *             log.debug("Adding point %s", values)
 */
    __Pyx_Raise(__pyx_builtin_ValueError, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":250
 *         if cogr_geometry is NULL:
 *             raise ValueError
 *         for values in self.coordinates:             # <<<<<<<<<<<<<<
 *             log.debug("Adding point %s", values)
 *             if len(values) > 2:
 */
  if (PyList_CheckExact(__pyx_v_self->coordinates) || PyTuple_CheckExact(__pyx_v_self->coordinates)) {
    __pyx_t_2 = __pyx_v_self->coordinates; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_self->coordinates); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_4 && PyList_CheckExact(__pyx_t_2)) {
      if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_4 && PyTuple_CheckExact(__pyx_t_2)) {
      if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_values, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "fiona/ogrext.pyx":251
 *             raise ValueError
 *         for values in self.coordinates:
 *             log.debug("Adding point %s", values)             # <<<<<<<<<<<<<<
 *             if len(values) > 2:
 *                 x, y, z = values
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 251; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_debug); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 251; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 251; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_kp_s_Adding_point_s);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_s_Adding_point_s);
    __Pyx_GIVEREF(__pyx_kp_s_Adding_point_s);
    __Pyx_INCREF(__pyx_v_values);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_values);
    __Pyx_GIVEREF(__pyx_v_values);
    __pyx_t_7 = PyObject_Call(__pyx_t_6, __pyx_t_5, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 251; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "fiona/ogrext.pyx":252
 *         for values in self.coordinates:
 *             log.debug("Adding point %s", values)
 *             if len(values) > 2:             # <<<<<<<<<<<<<<
 *                 x, y, z = values
 *                 ograpi.OGR_G_AddPoint(cogr_geometry, x, y, z)
 */
    __pyx_t_8 = PyObject_Length(__pyx_v_values); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 252; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_1 = ((__pyx_t_8 > 2) != 0);
    if (__pyx_t_1) {

      /* "fiona/ogrext.pyx":253
 *             log.debug("Adding point %s", values)
 *             if len(values) > 2:
 *                 x, y, z = values             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_G_AddPoint(cogr_geometry, x, y, z)
 *             else:
 */
      if ((likely(PyTuple_CheckExact(__pyx_v_values))) || (PyList_CheckExact(__pyx_v_values))) {
        PyObject* sequence = __pyx_v_values;
        #if CYTHON_COMPILING_IN_CPYTHON
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 3)) {
          if (size > 3) __Pyx_RaiseTooManyValuesError(3);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        #if CYTHON_COMPILING_IN_CPYTHON
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 2); 
        } else {
          __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
          __pyx_t_6 = PyList_GET_ITEM(sequence, 2); 
        }
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        #else
        __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      } else {
        Py_ssize_t index = -1;
        __pyx_t_9 = PyObject_GetIter(__pyx_v_values); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_10 = Py_TYPE(__pyx_t_9)->tp_iternext;
        index = 0; __pyx_t_7 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_7)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        index = 1; __pyx_t_5 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_5)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_5);
        index = 2; __pyx_t_6 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_6)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_9), 3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_10 = NULL;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L8_unpacking_done;
        __pyx_L7_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_10 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_L8_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_x, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_XDECREF_SET(__pyx_v_y, __pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_XDECREF_SET(__pyx_v_z, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "fiona/ogrext.pyx":254
 *             if len(values) > 2:
 *                 x, y, z = values
 *                 ograpi.OGR_G_AddPoint(cogr_geometry, x, y, z)             # <<<<<<<<<<<<<<
 *             else:
 *                 x, y = values
 */
      __pyx_t_11 = __pyx_PyFloat_AsDouble(__pyx_v_x); if (unlikely((__pyx_t_11 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 254; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_12 = __pyx_PyFloat_AsDouble(__pyx_v_y); if (unlikely((__pyx_t_12 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 254; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 254; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      OGR_G_AddPoint(__pyx_v_cogr_geometry, __pyx_t_11, __pyx_t_12, __pyx_t_13);
      goto __pyx_L6;
    }
    /*else*/ {

      /* "fiona/ogrext.pyx":256
 *                 ograpi.OGR_G_AddPoint(cogr_geometry, x, y, z)
 *             else:
 *                 x, y = values             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_G_AddPoint_2D(cogr_geometry, x, y)
 *         return cogr_geometry
 */
      if ((likely(PyTuple_CheckExact(__pyx_v_values))) || (PyList_CheckExact(__pyx_v_values))) {
        PyObject* sequence = __pyx_v_values;
        #if CYTHON_COMPILING_IN_CPYTHON
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 256; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        #if CYTHON_COMPILING_IN_CPYTHON
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        #else
        __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 256; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 256; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        Py_ssize_t index = -1;
        __pyx_t_7 = PyObject_GetIter(__pyx_v_values); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 256; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_10 = Py_TYPE(__pyx_t_7)->tp_iternext;
        index = 0; __pyx_t_6 = __pyx_t_10(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        index = 1; __pyx_t_5 = __pyx_t_10(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_5);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_7), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 256; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_10 = NULL;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L10_unpacking_done;
        __pyx_L9_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_10 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 256; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_L10_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_x, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_XDECREF_SET(__pyx_v_y, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "fiona/ogrext.pyx":257
 *             else:
 *                 x, y = values
 *                 ograpi.OGR_G_AddPoint_2D(cogr_geometry, x, y)             # <<<<<<<<<<<<<<
 *         return cogr_geometry
 * 
 */
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_v_x); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 257; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_12 = __pyx_PyFloat_AsDouble(__pyx_v_y); if (unlikely((__pyx_t_12 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 257; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      OGR_G_AddPoint_2D(__pyx_v_cogr_geometry, __pyx_t_13, __pyx_t_12);
    }
    __pyx_L6:;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":258
 *                 x, y = values
 *                 ograpi.OGR_G_AddPoint_2D(cogr_geometry, x, y)
 *         return cogr_geometry             # <<<<<<<<<<<<<<
 * 
 *     cdef void * _buildLinearRing(self) except NULL:
 */
  __pyx_r = __pyx_v_cogr_geometry;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":246
 *         return cogr_geometry
 * 
 *     cdef void * _buildLineString(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(2)
 *         if cogr_geometry is NULL:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("fiona.ogrext.OGRGeomBuilder._buildLineString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_values);
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XDECREF(__pyx_v_y);
  __Pyx_XDECREF(__pyx_v_z);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":260
 *         return cogr_geometry
 * 
 *     cdef void * _buildLinearRing(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(101)
 *         if cogr_geometry is NULL:
 */

static void *__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildLinearRing(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *__pyx_v_self) {
  void *__pyx_v_cogr_geometry;
  PyObject *__pyx_v_values = NULL;
  PyObject *__pyx_v_x = NULL;
  PyObject *__pyx_v_y = NULL;
  PyObject *__pyx_v_z = NULL;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *(*__pyx_t_10)(PyObject *);
  double __pyx_t_11;
  double __pyx_t_12;
  double __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildLinearRing", 0);

  /* "fiona/ogrext.pyx":261
 * 
 *     cdef void * _buildLinearRing(self) except NULL:
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(101)             # <<<<<<<<<<<<<<
 *         if cogr_geometry is NULL:
 *             raise ValueError
 */
  __pyx_v_cogr_geometry = OGR_G_CreateGeometry(101);

  /* "fiona/ogrext.pyx":262
 *     cdef void * _buildLinearRing(self) except NULL:
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(101)
 *         if cogr_geometry is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError
 *         for values in self.coordinates:
 */
  __pyx_t_1 = ((__pyx_v_cogr_geometry == NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":263
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(101)
 *         if cogr_geometry is NULL:
 *             raise ValueError             # <<<<<<<<<<<<<<
 *         for values in self.coordinates:
 *             log.debug("Adding point %s", values)
 */
    __Pyx_Raise(__pyx_builtin_ValueError, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 263; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":264
 *         if cogr_geometry is NULL:
 *             raise ValueError
 *         for values in self.coordinates:             # <<<<<<<<<<<<<<
 *             log.debug("Adding point %s", values)
 *             if len(values) > 2:
 */
  if (PyList_CheckExact(__pyx_v_self->coordinates) || PyTuple_CheckExact(__pyx_v_self->coordinates)) {
    __pyx_t_2 = __pyx_v_self->coordinates; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_self->coordinates); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_4 && PyList_CheckExact(__pyx_t_2)) {
      if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_4 && PyTuple_CheckExact(__pyx_t_2)) {
      if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_values, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "fiona/ogrext.pyx":265
 *             raise ValueError
 *         for values in self.coordinates:
 *             log.debug("Adding point %s", values)             # <<<<<<<<<<<<<<
 *             if len(values) > 2:
 *                 x, y, z = values
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 265; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_debug); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 265; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 265; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_kp_s_Adding_point_s);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_s_Adding_point_s);
    __Pyx_GIVEREF(__pyx_kp_s_Adding_point_s);
    __Pyx_INCREF(__pyx_v_values);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_values);
    __Pyx_GIVEREF(__pyx_v_values);
    __pyx_t_7 = PyObject_Call(__pyx_t_6, __pyx_t_5, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 265; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "fiona/ogrext.pyx":266
 *         for values in self.coordinates:
 *             log.debug("Adding point %s", values)
 *             if len(values) > 2:             # <<<<<<<<<<<<<<
 *                 x, y, z = values
 *                 ograpi.OGR_G_AddPoint(cogr_geometry, x, y, z)
 */
    __pyx_t_8 = PyObject_Length(__pyx_v_values); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 266; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_1 = ((__pyx_t_8 > 2) != 0);
    if (__pyx_t_1) {

      /* "fiona/ogrext.pyx":267
 *             log.debug("Adding point %s", values)
 *             if len(values) > 2:
 *                 x, y, z = values             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_G_AddPoint(cogr_geometry, x, y, z)
 *             else:
 */
      if ((likely(PyTuple_CheckExact(__pyx_v_values))) || (PyList_CheckExact(__pyx_v_values))) {
        PyObject* sequence = __pyx_v_values;
        #if CYTHON_COMPILING_IN_CPYTHON
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 3)) {
          if (size > 3) __Pyx_RaiseTooManyValuesError(3);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 267; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        #if CYTHON_COMPILING_IN_CPYTHON
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 2); 
        } else {
          __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
          __pyx_t_6 = PyList_GET_ITEM(sequence, 2); 
        }
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        #else
        __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 267; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 267; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 267; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      } else {
        Py_ssize_t index = -1;
        __pyx_t_9 = PyObject_GetIter(__pyx_v_values); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 267; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_10 = Py_TYPE(__pyx_t_9)->tp_iternext;
        index = 0; __pyx_t_7 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_7)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        index = 1; __pyx_t_5 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_5)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_5);
        index = 2; __pyx_t_6 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_6)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_9), 3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 267; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_10 = NULL;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L8_unpacking_done;
        __pyx_L7_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_10 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 267; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_L8_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_x, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_XDECREF_SET(__pyx_v_y, __pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_XDECREF_SET(__pyx_v_z, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "fiona/ogrext.pyx":268
 *             if len(values) > 2:
 *                 x, y, z = values
 *                 ograpi.OGR_G_AddPoint(cogr_geometry, x, y, z)             # <<<<<<<<<<<<<<
 *             else:
 *                 x, y = values
 */
      __pyx_t_11 = __pyx_PyFloat_AsDouble(__pyx_v_x); if (unlikely((__pyx_t_11 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 268; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_12 = __pyx_PyFloat_AsDouble(__pyx_v_y); if (unlikely((__pyx_t_12 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 268; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 268; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      OGR_G_AddPoint(__pyx_v_cogr_geometry, __pyx_t_11, __pyx_t_12, __pyx_t_13);
      goto __pyx_L6;
    }
    /*else*/ {

      /* "fiona/ogrext.pyx":270
 *                 ograpi.OGR_G_AddPoint(cogr_geometry, x, y, z)
 *             else:
 *                 x, y = values             # <<<<<<<<<<<<<<
 *                 log.debug("Adding values %f, %f", x, y)
 *                 ograpi.OGR_G_AddPoint_2D(cogr_geometry, x, y)
 */
      if ((likely(PyTuple_CheckExact(__pyx_v_values))) || (PyList_CheckExact(__pyx_v_values))) {
        PyObject* sequence = __pyx_v_values;
        #if CYTHON_COMPILING_IN_CPYTHON
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        #if CYTHON_COMPILING_IN_CPYTHON
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        #else
        __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        Py_ssize_t index = -1;
        __pyx_t_7 = PyObject_GetIter(__pyx_v_values); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_10 = Py_TYPE(__pyx_t_7)->tp_iternext;
        index = 0; __pyx_t_6 = __pyx_t_10(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        index = 1; __pyx_t_5 = __pyx_t_10(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_5);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_7), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_10 = NULL;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L10_unpacking_done;
        __pyx_L9_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_10 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 270; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_L10_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_x, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_XDECREF_SET(__pyx_v_y, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "fiona/ogrext.pyx":271
 *             else:
 *                 x, y = values
 *                 log.debug("Adding values %f, %f", x, y)             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_G_AddPoint_2D(cogr_geometry, x, y)
 *         log.debug("Closing ring")
 */
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 271; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_debug); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 271; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 271; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_kp_s_Adding_values_f_f);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_s_Adding_values_f_f);
      __Pyx_GIVEREF(__pyx_kp_s_Adding_values_f_f);
      __Pyx_INCREF(__pyx_v_x);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_x);
      __Pyx_GIVEREF(__pyx_v_x);
      __Pyx_INCREF(__pyx_v_y);
      PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_y);
      __Pyx_GIVEREF(__pyx_v_y);
      __pyx_t_7 = PyObject_Call(__pyx_t_6, __pyx_t_5, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 271; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "fiona/ogrext.pyx":272
 *                 x, y = values
 *                 log.debug("Adding values %f, %f", x, y)
 *                 ograpi.OGR_G_AddPoint_2D(cogr_geometry, x, y)             # <<<<<<<<<<<<<<
 *         log.debug("Closing ring")
 *         ograpi.OGR_G_CloseRings(cogr_geometry)
 */
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_v_x); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 272; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_12 = __pyx_PyFloat_AsDouble(__pyx_v_y); if (unlikely((__pyx_t_12 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 272; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      OGR_G_AddPoint_2D(__pyx_v_cogr_geometry, __pyx_t_13, __pyx_t_12);
    }
    __pyx_L6:;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":273
 *                 log.debug("Adding values %f, %f", x, y)
 *                 ograpi.OGR_G_AddPoint_2D(cogr_geometry, x, y)
 *         log.debug("Closing ring")             # <<<<<<<<<<<<<<
 *         ograpi.OGR_G_CloseRings(cogr_geometry)
 *         return cogr_geometry
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 273; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_debug); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 273; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_7, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 273; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":274
 *                 ograpi.OGR_G_AddPoint_2D(cogr_geometry, x, y)
 *         log.debug("Closing ring")
 *         ograpi.OGR_G_CloseRings(cogr_geometry)             # <<<<<<<<<<<<<<
 *         return cogr_geometry
 * 
 */
  OGR_G_CloseRings(__pyx_v_cogr_geometry);

  /* "fiona/ogrext.pyx":275
 *         log.debug("Closing ring")
 *         ograpi.OGR_G_CloseRings(cogr_geometry)
 *         return cogr_geometry             # <<<<<<<<<<<<<<
 * 
 *     cdef void * _buildPolygon(self) except NULL:
 */
  __pyx_r = __pyx_v_cogr_geometry;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":260
 *         return cogr_geometry
 * 
 *     cdef void * _buildLinearRing(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(101)
 *         if cogr_geometry is NULL:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("fiona.ogrext.OGRGeomBuilder._buildLinearRing", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_values);
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XDECREF(__pyx_v_y);
  __Pyx_XDECREF(__pyx_v_z);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":277
 *         return cogr_geometry
 * 
 *     cdef void * _buildPolygon(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_ring
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(3)
 */

static void *__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildPolygon(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *__pyx_v_self) {
  void *__pyx_v_cogr_ring;
  void *__pyx_v_cogr_geometry;
  PyObject *__pyx_v_ring = NULL;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  void *__pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildPolygon", 0);

  /* "fiona/ogrext.pyx":279
 *     cdef void * _buildPolygon(self) except NULL:
 *         cdef void *cogr_ring
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(3)             # <<<<<<<<<<<<<<
 *         if cogr_geometry is NULL:
 *             raise ValueError
 */
  __pyx_v_cogr_geometry = OGR_G_CreateGeometry(3);

  /* "fiona/ogrext.pyx":280
 *         cdef void *cogr_ring
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(3)
 *         if cogr_geometry is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError
 *         self.ndims = len(self.coordinates[0][0])
 */
  __pyx_t_1 = ((__pyx_v_cogr_geometry == NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":281
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(3)
 *         if cogr_geometry is NULL:
 *             raise ValueError             # <<<<<<<<<<<<<<
 *         self.ndims = len(self.coordinates[0][0])
 *         for ring in self.coordinates:
 */
    __Pyx_Raise(__pyx_builtin_ValueError, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 281; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":282
 *         if cogr_geometry is NULL:
 *             raise ValueError
 *         self.ndims = len(self.coordinates[0][0])             # <<<<<<<<<<<<<<
 *         for ring in self.coordinates:
 *             log.debug("Adding ring %s", ring)
 */
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_self->coordinates, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 282; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 282; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyInt_FromSsize_t(__pyx_t_4); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->ndims);
  __Pyx_DECREF(__pyx_v_self->ndims);
  __pyx_v_self->ndims = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "fiona/ogrext.pyx":283
 *             raise ValueError
 *         self.ndims = len(self.coordinates[0][0])
 *         for ring in self.coordinates:             # <<<<<<<<<<<<<<
 *             log.debug("Adding ring %s", ring)
 *             cogr_ring = OGRGeomBuilder().build(
 */
  if (PyList_CheckExact(__pyx_v_self->coordinates) || PyTuple_CheckExact(__pyx_v_self->coordinates)) {
    __pyx_t_3 = __pyx_v_self->coordinates; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_self->coordinates); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 283; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_5 && PyList_CheckExact(__pyx_t_3)) {
      if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 283; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 283; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_5 && PyTuple_CheckExact(__pyx_t_3)) {
      if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 283; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 283; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_2 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 283; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_ring, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "fiona/ogrext.pyx":284
 *         self.ndims = len(self.coordinates[0][0])
 *         for ring in self.coordinates:
 *             log.debug("Adding ring %s", ring)             # <<<<<<<<<<<<<<
 *             cogr_ring = OGRGeomBuilder().build(
 *                 {'type': 'LinearRing', 'coordinates': ring} )
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 284; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_debug); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 284; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 284; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_kp_s_Adding_ring_s);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_s_Adding_ring_s);
    __Pyx_GIVEREF(__pyx_kp_s_Adding_ring_s);
    __Pyx_INCREF(__pyx_v_ring);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_ring);
    __Pyx_GIVEREF(__pyx_v_ring);
    __pyx_t_7 = PyObject_Call(__pyx_t_6, __pyx_t_2, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 284; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "fiona/ogrext.pyx":285
 *         for ring in self.coordinates:
 *             log.debug("Adding ring %s", ring)
 *             cogr_ring = OGRGeomBuilder().build(             # <<<<<<<<<<<<<<
 *                 {'type': 'LinearRing', 'coordinates': ring} )
 *             log.debug("Built ring")
 */
    __pyx_t_7 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5fiona_6ogrext_OGRGeomBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 285; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);

    /* "fiona/ogrext.pyx":286
 *             log.debug("Adding ring %s", ring)
 *             cogr_ring = OGRGeomBuilder().build(
 *                 {'type': 'LinearRing', 'coordinates': ring} )             # <<<<<<<<<<<<<<
 *             log.debug("Built ring")
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_ring)
 */
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 286; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_type, __pyx_n_s_LinearRing) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 286; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_coordinates, __pyx_v_ring) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 286; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "fiona/ogrext.pyx":285
 *         for ring in self.coordinates:
 *             log.debug("Adding ring %s", ring)
 *             cogr_ring = OGRGeomBuilder().build(             # <<<<<<<<<<<<<<
 *                 {'type': 'LinearRing', 'coordinates': ring} )
 *             log.debug("Built ring")
 */
    __pyx_t_8 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *)((struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)__pyx_t_7)->__pyx_vtab)->build(((struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)__pyx_t_7), __pyx_t_2); if (unlikely(__pyx_t_8 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 285; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_cogr_ring = __pyx_t_8;

    /* "fiona/ogrext.pyx":287
 *             cogr_ring = OGRGeomBuilder().build(
 *                 {'type': 'LinearRing', 'coordinates': ring} )
 *             log.debug("Built ring")             # <<<<<<<<<<<<<<
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_ring)
 *             log.debug("Added ring %s", ring)
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 287; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_debug); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 287; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(__pyx_t_7, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 287; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "fiona/ogrext.pyx":288
 *                 {'type': 'LinearRing', 'coordinates': ring} )
 *             log.debug("Built ring")
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_ring)             # <<<<<<<<<<<<<<
 *             log.debug("Added ring %s", ring)
 *         return cogr_geometry
 */
    OGR_G_AddGeometryDirectly(__pyx_v_cogr_geometry, __pyx_v_cogr_ring);

    /* "fiona/ogrext.pyx":289
 *             log.debug("Built ring")
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_ring)
 *             log.debug("Added ring %s", ring)             # <<<<<<<<<<<<<<
 *         return cogr_geometry
 * 
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 289; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_debug); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 289; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 289; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_kp_s_Added_ring_s);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_s_Added_ring_s);
    __Pyx_GIVEREF(__pyx_kp_s_Added_ring_s);
    __Pyx_INCREF(__pyx_v_ring);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_ring);
    __Pyx_GIVEREF(__pyx_v_ring);
    __pyx_t_6 = PyObject_Call(__pyx_t_7, __pyx_t_2, NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 289; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "fiona/ogrext.pyx":290
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_ring)
 *             log.debug("Added ring %s", ring)
 *         return cogr_geometry             # <<<<<<<<<<<<<<
 * 
 *     cdef void * _buildMultiPoint(self) except NULL:
 */
  __pyx_r = __pyx_v_cogr_geometry;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":277
 *         return cogr_geometry
 * 
 *     cdef void * _buildPolygon(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_ring
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(3)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("fiona.ogrext.OGRGeomBuilder._buildPolygon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_ring);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":292
 *         return cogr_geometry
 * 
 *     cdef void * _buildMultiPoint(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(4)
 */

static void *__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildMultiPoint(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *__pyx_v_self) {
  void *__pyx_v_cogr_part;
  void *__pyx_v_cogr_geometry;
  PyObject *__pyx_v_values = NULL;
  PyObject *__pyx_v_x = NULL;
  PyObject *__pyx_v_y = NULL;
  PyObject *__pyx_v_z = NULL;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *(*__pyx_t_10)(PyObject *);
  double __pyx_t_11;
  double __pyx_t_12;
  double __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildMultiPoint", 0);

  /* "fiona/ogrext.pyx":294
 *     cdef void * _buildMultiPoint(self) except NULL:
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(4)             # <<<<<<<<<<<<<<
 *         if cogr_geometry is NULL:
 *             raise ValueError
 */
  __pyx_v_cogr_geometry = OGR_G_CreateGeometry(4);

  /* "fiona/ogrext.pyx":295
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(4)
 *         if cogr_geometry is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError
 *         for values in self.coordinates:
 */
  __pyx_t_1 = ((__pyx_v_cogr_geometry == NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":296
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(4)
 *         if cogr_geometry is NULL:
 *             raise ValueError             # <<<<<<<<<<<<<<
 *         for values in self.coordinates:
 *             log.debug("Adding point %s", values)
 */
    __Pyx_Raise(__pyx_builtin_ValueError, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 296; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":297
 *         if cogr_geometry is NULL:
 *             raise ValueError
 *         for values in self.coordinates:             # <<<<<<<<<<<<<<
 *             log.debug("Adding point %s", values)
 *             cogr_part = ograpi.OGR_G_CreateGeometry(1)
 */
  if (PyList_CheckExact(__pyx_v_self->coordinates) || PyTuple_CheckExact(__pyx_v_self->coordinates)) {
    __pyx_t_2 = __pyx_v_self->coordinates; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_self->coordinates); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_4 && PyList_CheckExact(__pyx_t_2)) {
      if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_4 && PyTuple_CheckExact(__pyx_t_2)) {
      if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_values, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "fiona/ogrext.pyx":298
 *             raise ValueError
 *         for values in self.coordinates:
 *             log.debug("Adding point %s", values)             # <<<<<<<<<<<<<<
 *             cogr_part = ograpi.OGR_G_CreateGeometry(1)
 *             if len(values) > 2:
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 298; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_debug); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 298; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 298; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_kp_s_Adding_point_s);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_s_Adding_point_s);
    __Pyx_GIVEREF(__pyx_kp_s_Adding_point_s);
    __Pyx_INCREF(__pyx_v_values);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_values);
    __Pyx_GIVEREF(__pyx_v_values);
    __pyx_t_7 = PyObject_Call(__pyx_t_6, __pyx_t_5, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 298; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "fiona/ogrext.pyx":299
 *         for values in self.coordinates:
 *             log.debug("Adding point %s", values)
 *             cogr_part = ograpi.OGR_G_CreateGeometry(1)             # <<<<<<<<<<<<<<
 *             if len(values) > 2:
 *                 x, y, z = values
 */
    __pyx_v_cogr_part = OGR_G_CreateGeometry(1);

    /* "fiona/ogrext.pyx":300
 *             log.debug("Adding point %s", values)
 *             cogr_part = ograpi.OGR_G_CreateGeometry(1)
 *             if len(values) > 2:             # <<<<<<<<<<<<<<
 *                 x, y, z = values
 *                 ograpi.OGR_G_AddPoint(cogr_part, x, y, z)
 */
    __pyx_t_8 = PyObject_Length(__pyx_v_values); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 300; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_1 = ((__pyx_t_8 > 2) != 0);
    if (__pyx_t_1) {

      /* "fiona/ogrext.pyx":301
 *             cogr_part = ograpi.OGR_G_CreateGeometry(1)
 *             if len(values) > 2:
 *                 x, y, z = values             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_G_AddPoint(cogr_part, x, y, z)
 *             else:
 */
      if ((likely(PyTuple_CheckExact(__pyx_v_values))) || (PyList_CheckExact(__pyx_v_values))) {
        PyObject* sequence = __pyx_v_values;
        #if CYTHON_COMPILING_IN_CPYTHON
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 3)) {
          if (size > 3) __Pyx_RaiseTooManyValuesError(3);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 301; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        #if CYTHON_COMPILING_IN_CPYTHON
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_7 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 2); 
        } else {
          __pyx_t_7 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
          __pyx_t_6 = PyList_GET_ITEM(sequence, 2); 
        }
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        #else
        __pyx_t_7 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 301; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 301; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = PySequence_ITEM(sequence, 2); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 301; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      } else {
        Py_ssize_t index = -1;
        __pyx_t_9 = PyObject_GetIter(__pyx_v_values); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 301; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_10 = Py_TYPE(__pyx_t_9)->tp_iternext;
        index = 0; __pyx_t_7 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_7)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_7);
        index = 1; __pyx_t_5 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_5)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_5);
        index = 2; __pyx_t_6 = __pyx_t_10(__pyx_t_9); if (unlikely(!__pyx_t_6)) goto __pyx_L7_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_9), 3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 301; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_10 = NULL;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        goto __pyx_L8_unpacking_done;
        __pyx_L7_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_10 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 301; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_L8_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_x, __pyx_t_7);
      __pyx_t_7 = 0;
      __Pyx_XDECREF_SET(__pyx_v_y, __pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_XDECREF_SET(__pyx_v_z, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "fiona/ogrext.pyx":302
 *             if len(values) > 2:
 *                 x, y, z = values
 *                 ograpi.OGR_G_AddPoint(cogr_part, x, y, z)             # <<<<<<<<<<<<<<
 *             else:
 *                 x, y = values
 */
      __pyx_t_11 = __pyx_PyFloat_AsDouble(__pyx_v_x); if (unlikely((__pyx_t_11 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 302; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_12 = __pyx_PyFloat_AsDouble(__pyx_v_y); if (unlikely((__pyx_t_12 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 302; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_v_z); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 302; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      OGR_G_AddPoint(__pyx_v_cogr_part, __pyx_t_11, __pyx_t_12, __pyx_t_13);
      goto __pyx_L6;
    }
    /*else*/ {

      /* "fiona/ogrext.pyx":304
 *                 ograpi.OGR_G_AddPoint(cogr_part, x, y, z)
 *             else:
 *                 x, y = values             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_G_AddPoint_2D(cogr_part, x, y)
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 */
      if ((likely(PyTuple_CheckExact(__pyx_v_values))) || (PyList_CheckExact(__pyx_v_values))) {
        PyObject* sequence = __pyx_v_values;
        #if CYTHON_COMPILING_IN_CPYTHON
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        #if CYTHON_COMPILING_IN_CPYTHON
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_5 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_5 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        #else
        __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        Py_ssize_t index = -1;
        __pyx_t_7 = PyObject_GetIter(__pyx_v_values); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_10 = Py_TYPE(__pyx_t_7)->tp_iternext;
        index = 0; __pyx_t_6 = __pyx_t_10(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        index = 1; __pyx_t_5 = __pyx_t_10(__pyx_t_7); if (unlikely(!__pyx_t_5)) goto __pyx_L9_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_5);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_10(__pyx_t_7), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_10 = NULL;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L10_unpacking_done;
        __pyx_L9_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_10 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_L10_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_x, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_XDECREF_SET(__pyx_v_y, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "fiona/ogrext.pyx":305
 *             else:
 *                 x, y = values
 *                 ograpi.OGR_G_AddPoint_2D(cogr_part, x, y)             # <<<<<<<<<<<<<<
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 *             log.debug("Added point %s", values)
 */
      __pyx_t_13 = __pyx_PyFloat_AsDouble(__pyx_v_x); if (unlikely((__pyx_t_13 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 305; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_12 = __pyx_PyFloat_AsDouble(__pyx_v_y); if (unlikely((__pyx_t_12 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 305; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      OGR_G_AddPoint_2D(__pyx_v_cogr_part, __pyx_t_13, __pyx_t_12);
    }
    __pyx_L6:;

    /* "fiona/ogrext.pyx":306
 *                 x, y = values
 *                 ograpi.OGR_G_AddPoint_2D(cogr_part, x, y)
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)             # <<<<<<<<<<<<<<
 *             log.debug("Added point %s", values)
 *         return cogr_geometry
 */
    OGR_G_AddGeometryDirectly(__pyx_v_cogr_geometry, __pyx_v_cogr_part);

    /* "fiona/ogrext.pyx":307
 *                 ograpi.OGR_G_AddPoint_2D(cogr_part, x, y)
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 *             log.debug("Added point %s", values)             # <<<<<<<<<<<<<<
 *         return cogr_geometry
 * 
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 307; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_debug); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 307; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 307; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_kp_s_Added_point_s);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_s_Added_point_s);
    __Pyx_GIVEREF(__pyx_kp_s_Added_point_s);
    __Pyx_INCREF(__pyx_v_values);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_values);
    __Pyx_GIVEREF(__pyx_v_values);
    __pyx_t_7 = PyObject_Call(__pyx_t_6, __pyx_t_5, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 307; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":308
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 *             log.debug("Added point %s", values)
 *         return cogr_geometry             # <<<<<<<<<<<<<<
 * 
 *     cdef void * _buildMultiLineString(self) except NULL:
 */
  __pyx_r = __pyx_v_cogr_geometry;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":292
 *         return cogr_geometry
 * 
 *     cdef void * _buildMultiPoint(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(4)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("fiona.ogrext.OGRGeomBuilder._buildMultiPoint", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_values);
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XDECREF(__pyx_v_y);
  __Pyx_XDECREF(__pyx_v_z);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":310
 *         return cogr_geometry
 * 
 *     cdef void * _buildMultiLineString(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(5)
 */

static void *__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildMultiLineString(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *__pyx_v_self) {
  void *__pyx_v_cogr_part;
  void *__pyx_v_cogr_geometry;
  PyObject *__pyx_v_line = NULL;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  void *__pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildMultiLineString", 0);

  /* "fiona/ogrext.pyx":312
 *     cdef void * _buildMultiLineString(self) except NULL:
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(5)             # <<<<<<<<<<<<<<
 *         if cogr_geometry is NULL:
 *             raise ValueError
 */
  __pyx_v_cogr_geometry = OGR_G_CreateGeometry(5);

  /* "fiona/ogrext.pyx":313
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(5)
 *         if cogr_geometry is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError
 *         for line in self.coordinates:
 */
  __pyx_t_1 = ((__pyx_v_cogr_geometry == NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":314
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(5)
 *         if cogr_geometry is NULL:
 *             raise ValueError             # <<<<<<<<<<<<<<
 *         for line in self.coordinates:
 *             log.debug("Adding line %s", line)
 */
    __Pyx_Raise(__pyx_builtin_ValueError, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 314; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":315
 *         if cogr_geometry is NULL:
 *             raise ValueError
 *         for line in self.coordinates:             # <<<<<<<<<<<<<<
 *             log.debug("Adding line %s", line)
 *             cogr_part = OGRGeomBuilder().build(
 */
  if (PyList_CheckExact(__pyx_v_self->coordinates) || PyTuple_CheckExact(__pyx_v_self->coordinates)) {
    __pyx_t_2 = __pyx_v_self->coordinates; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_self->coordinates); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 315; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_4 && PyList_CheckExact(__pyx_t_2)) {
      if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 315; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 315; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_4 && PyTuple_CheckExact(__pyx_t_2)) {
      if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 315; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 315; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 315; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_line, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "fiona/ogrext.pyx":316
 *             raise ValueError
 *         for line in self.coordinates:
 *             log.debug("Adding line %s", line)             # <<<<<<<<<<<<<<
 *             cogr_part = OGRGeomBuilder().build(
 *                 {'type': 'LineString', 'coordinates': line} )
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 316; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_debug); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 316; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 316; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_kp_s_Adding_line_s);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_s_Adding_line_s);
    __Pyx_GIVEREF(__pyx_kp_s_Adding_line_s);
    __Pyx_INCREF(__pyx_v_line);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_line);
    __Pyx_GIVEREF(__pyx_v_line);
    __pyx_t_7 = PyObject_Call(__pyx_t_6, __pyx_t_5, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 316; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "fiona/ogrext.pyx":317
 *         for line in self.coordinates:
 *             log.debug("Adding line %s", line)
 *             cogr_part = OGRGeomBuilder().build(             # <<<<<<<<<<<<<<
 *                 {'type': 'LineString', 'coordinates': line} )
 *             log.debug("Built line")
 */
    __pyx_t_7 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5fiona_6ogrext_OGRGeomBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 317; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);

    /* "fiona/ogrext.pyx":318
 *             log.debug("Adding line %s", line)
 *             cogr_part = OGRGeomBuilder().build(
 *                 {'type': 'LineString', 'coordinates': line} )             # <<<<<<<<<<<<<<
 *             log.debug("Built line")
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 */
    __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 318; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_type, __pyx_n_s_LineString) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 318; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_coordinates, __pyx_v_line) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 318; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "fiona/ogrext.pyx":317
 *         for line in self.coordinates:
 *             log.debug("Adding line %s", line)
 *             cogr_part = OGRGeomBuilder().build(             # <<<<<<<<<<<<<<
 *                 {'type': 'LineString', 'coordinates': line} )
 *             log.debug("Built line")
 */
    __pyx_t_8 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *)((struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)__pyx_t_7)->__pyx_vtab)->build(((struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)__pyx_t_7), __pyx_t_5); if (unlikely(__pyx_t_8 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 317; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_cogr_part = __pyx_t_8;

    /* "fiona/ogrext.pyx":319
 *             cogr_part = OGRGeomBuilder().build(
 *                 {'type': 'LineString', 'coordinates': line} )
 *             log.debug("Built line")             # <<<<<<<<<<<<<<
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 *             log.debug("Added line %s", line)
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 319; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_debug); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 319; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyObject_Call(__pyx_t_7, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 319; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "fiona/ogrext.pyx":320
 *                 {'type': 'LineString', 'coordinates': line} )
 *             log.debug("Built line")
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)             # <<<<<<<<<<<<<<
 *             log.debug("Added line %s", line)
 *         return cogr_geometry
 */
    OGR_G_AddGeometryDirectly(__pyx_v_cogr_geometry, __pyx_v_cogr_part);

    /* "fiona/ogrext.pyx":321
 *             log.debug("Built line")
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 *             log.debug("Added line %s", line)             # <<<<<<<<<<<<<<
 *         return cogr_geometry
 * 
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 321; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_debug); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 321; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 321; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_kp_s_Added_line_s);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_s_Added_line_s);
    __Pyx_GIVEREF(__pyx_kp_s_Added_line_s);
    __Pyx_INCREF(__pyx_v_line);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_line);
    __Pyx_GIVEREF(__pyx_v_line);
    __pyx_t_6 = PyObject_Call(__pyx_t_7, __pyx_t_5, NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 321; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":322
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 *             log.debug("Added line %s", line)
 *         return cogr_geometry             # <<<<<<<<<<<<<<
 * 
 *     cdef void * _buildMultiPolygon(self) except NULL:
 */
  __pyx_r = __pyx_v_cogr_geometry;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":310
 *         return cogr_geometry
 * 
 *     cdef void * _buildMultiLineString(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(5)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("fiona.ogrext.OGRGeomBuilder._buildMultiLineString", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_line);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":324
 *         return cogr_geometry
 * 
 *     cdef void * _buildMultiPolygon(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(6)
 */

static void *__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildMultiPolygon(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *__pyx_v_self) {
  void *__pyx_v_cogr_part;
  void *__pyx_v_cogr_geometry;
  PyObject *__pyx_v_part = NULL;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  void *__pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildMultiPolygon", 0);

  /* "fiona/ogrext.pyx":326
 *     cdef void * _buildMultiPolygon(self) except NULL:
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(6)             # <<<<<<<<<<<<<<
 *         if cogr_geometry is NULL:
 *             raise ValueError
 */
  __pyx_v_cogr_geometry = OGR_G_CreateGeometry(6);

  /* "fiona/ogrext.pyx":327
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(6)
 *         if cogr_geometry is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError
 *         for part in self.coordinates:
 */
  __pyx_t_1 = ((__pyx_v_cogr_geometry == NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":328
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(6)
 *         if cogr_geometry is NULL:
 *             raise ValueError             # <<<<<<<<<<<<<<
 *         for part in self.coordinates:
 *             log.debug("Adding polygon %s", part)
 */
    __Pyx_Raise(__pyx_builtin_ValueError, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":329
 *         if cogr_geometry is NULL:
 *             raise ValueError
 *         for part in self.coordinates:             # <<<<<<<<<<<<<<
 *             log.debug("Adding polygon %s", part)
 *             cogr_part = OGRGeomBuilder().build(
 */
  if (PyList_CheckExact(__pyx_v_self->coordinates) || PyTuple_CheckExact(__pyx_v_self->coordinates)) {
    __pyx_t_2 = __pyx_v_self->coordinates; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_self->coordinates); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_4 && PyList_CheckExact(__pyx_t_2)) {
      if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_4 && PyTuple_CheckExact(__pyx_t_2)) {
      if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_part, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "fiona/ogrext.pyx":330
 *             raise ValueError
 *         for part in self.coordinates:
 *             log.debug("Adding polygon %s", part)             # <<<<<<<<<<<<<<
 *             cogr_part = OGRGeomBuilder().build(
 *                 {'type': 'Polygon', 'coordinates': part} )
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 330; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_debug); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 330; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 330; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_kp_s_Adding_polygon_s);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_s_Adding_polygon_s);
    __Pyx_GIVEREF(__pyx_kp_s_Adding_polygon_s);
    __Pyx_INCREF(__pyx_v_part);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_part);
    __Pyx_GIVEREF(__pyx_v_part);
    __pyx_t_7 = PyObject_Call(__pyx_t_6, __pyx_t_5, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 330; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "fiona/ogrext.pyx":331
 *         for part in self.coordinates:
 *             log.debug("Adding polygon %s", part)
 *             cogr_part = OGRGeomBuilder().build(             # <<<<<<<<<<<<<<
 *                 {'type': 'Polygon', 'coordinates': part} )
 *             log.debug("Built polygon")
 */
    __pyx_t_7 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5fiona_6ogrext_OGRGeomBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 331; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);

    /* "fiona/ogrext.pyx":332
 *             log.debug("Adding polygon %s", part)
 *             cogr_part = OGRGeomBuilder().build(
 *                 {'type': 'Polygon', 'coordinates': part} )             # <<<<<<<<<<<<<<
 *             log.debug("Built polygon")
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 */
    __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_type, __pyx_n_s_Polygon) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_coordinates, __pyx_v_part) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "fiona/ogrext.pyx":331
 *         for part in self.coordinates:
 *             log.debug("Adding polygon %s", part)
 *             cogr_part = OGRGeomBuilder().build(             # <<<<<<<<<<<<<<
 *                 {'type': 'Polygon', 'coordinates': part} )
 *             log.debug("Built polygon")
 */
    __pyx_t_8 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *)((struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)__pyx_t_7)->__pyx_vtab)->build(((struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)__pyx_t_7), __pyx_t_5); if (unlikely(__pyx_t_8 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 331; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_cogr_part = __pyx_t_8;

    /* "fiona/ogrext.pyx":333
 *             cogr_part = OGRGeomBuilder().build(
 *                 {'type': 'Polygon', 'coordinates': part} )
 *             log.debug("Built polygon")             # <<<<<<<<<<<<<<
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 *             log.debug("Added polygon %s", part)
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_debug); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyObject_Call(__pyx_t_7, __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "fiona/ogrext.pyx":334
 *                 {'type': 'Polygon', 'coordinates': part} )
 *             log.debug("Built polygon")
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)             # <<<<<<<<<<<<<<
 *             log.debug("Added polygon %s", part)
 *         return cogr_geometry
 */
    OGR_G_AddGeometryDirectly(__pyx_v_cogr_geometry, __pyx_v_cogr_part);

    /* "fiona/ogrext.pyx":335
 *             log.debug("Built polygon")
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 *             log.debug("Added polygon %s", part)             # <<<<<<<<<<<<<<
 *         return cogr_geometry
 * 
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_debug); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_kp_s_Added_polygon_s);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_s_Added_polygon_s);
    __Pyx_GIVEREF(__pyx_kp_s_Added_polygon_s);
    __Pyx_INCREF(__pyx_v_part);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_part);
    __Pyx_GIVEREF(__pyx_v_part);
    __pyx_t_6 = PyObject_Call(__pyx_t_7, __pyx_t_5, NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":336
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 *             log.debug("Added polygon %s", part)
 *         return cogr_geometry             # <<<<<<<<<<<<<<
 * 
 *     cdef void * _buildGeometryCollection(self) except NULL:
 */
  __pyx_r = __pyx_v_cogr_geometry;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":324
 *         return cogr_geometry
 * 
 *     cdef void * _buildMultiPolygon(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(6)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("fiona.ogrext.OGRGeomBuilder._buildMultiPolygon", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_part);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":338
 *         return cogr_geometry
 * 
 *     cdef void * _buildGeometryCollection(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(7)
 */

static void *__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildGeometryCollection(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *__pyx_v_self) {
  void *__pyx_v_cogr_part;
  void *__pyx_v_cogr_geometry;
  PyObject *__pyx_v_part = NULL;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  void *__pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_buildGeometryCollection", 0);

  /* "fiona/ogrext.pyx":340
 *     cdef void * _buildGeometryCollection(self) except NULL:
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(7)             # <<<<<<<<<<<<<<
 *         if cogr_geometry is NULL:
 *             raise ValueError
 */
  __pyx_v_cogr_geometry = OGR_G_CreateGeometry(7);

  /* "fiona/ogrext.pyx":341
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(7)
 *         if cogr_geometry is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError
 *         for part in self.coordinates:
 */
  __pyx_t_1 = ((__pyx_v_cogr_geometry == NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":342
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(7)
 *         if cogr_geometry is NULL:
 *             raise ValueError             # <<<<<<<<<<<<<<
 *         for part in self.coordinates:
 *             log.debug("Adding part %s", part)
 */
    __Pyx_Raise(__pyx_builtin_ValueError, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 342; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":343
 *         if cogr_geometry is NULL:
 *             raise ValueError
 *         for part in self.coordinates:             # <<<<<<<<<<<<<<
 *             log.debug("Adding part %s", part)
 *             cogr_part = OGRGeomBuilder().build(part)
 */
  if (PyList_CheckExact(__pyx_v_self->coordinates) || PyTuple_CheckExact(__pyx_v_self->coordinates)) {
    __pyx_t_2 = __pyx_v_self->coordinates; __Pyx_INCREF(__pyx_t_2); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_self->coordinates); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 343; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = Py_TYPE(__pyx_t_2)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_4 && PyList_CheckExact(__pyx_t_2)) {
      if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 343; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 343; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_4 && PyTuple_CheckExact(__pyx_t_2)) {
      if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 343; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_5 = PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 343; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 343; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_part, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "fiona/ogrext.pyx":344
 *             raise ValueError
 *         for part in self.coordinates:
 *             log.debug("Adding part %s", part)             # <<<<<<<<<<<<<<
 *             cogr_part = OGRGeomBuilder().build(part)
 *             log.debug("Built part")
 */
    __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 344; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_debug); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 344; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 344; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_kp_s_Adding_part_s);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_s_Adding_part_s);
    __Pyx_GIVEREF(__pyx_kp_s_Adding_part_s);
    __Pyx_INCREF(__pyx_v_part);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_part);
    __Pyx_GIVEREF(__pyx_v_part);
    __pyx_t_7 = PyObject_Call(__pyx_t_6, __pyx_t_5, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 344; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "fiona/ogrext.pyx":345
 *         for part in self.coordinates:
 *             log.debug("Adding part %s", part)
 *             cogr_part = OGRGeomBuilder().build(part)             # <<<<<<<<<<<<<<
 *             log.debug("Built part")
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 */
    __pyx_t_7 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5fiona_6ogrext_OGRGeomBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 345; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *)((struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)__pyx_t_7)->__pyx_vtab)->build(((struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)__pyx_t_7), __pyx_v_part); if (unlikely(__pyx_t_8 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 345; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_cogr_part = __pyx_t_8;

    /* "fiona/ogrext.pyx":346
 *             log.debug("Adding part %s", part)
 *             cogr_part = OGRGeomBuilder().build(part)
 *             log.debug("Built part")             # <<<<<<<<<<<<<<
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 *             log.debug("Added part %s", part)
 */
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 346; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_debug); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 346; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyObject_Call(__pyx_t_5, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 346; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "fiona/ogrext.pyx":347
 *             cogr_part = OGRGeomBuilder().build(part)
 *             log.debug("Built part")
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)             # <<<<<<<<<<<<<<
 *             log.debug("Added part %s", part)
 *         return cogr_geometry
 */
    OGR_G_AddGeometryDirectly(__pyx_v_cogr_geometry, __pyx_v_cogr_part);

    /* "fiona/ogrext.pyx":348
 *             log.debug("Built part")
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 *             log.debug("Added part %s", part)             # <<<<<<<<<<<<<<
 *         return cogr_geometry
 * 
 */
    __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_debug); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_kp_s_Added_part_s);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_kp_s_Added_part_s);
    __Pyx_GIVEREF(__pyx_kp_s_Added_part_s);
    __Pyx_INCREF(__pyx_v_part);
    PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_part);
    __Pyx_GIVEREF(__pyx_v_part);
    __pyx_t_6 = PyObject_Call(__pyx_t_5, __pyx_t_7, NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":349
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 *             log.debug("Added part %s", part)
 *         return cogr_geometry             # <<<<<<<<<<<<<<
 * 
 *     cdef void * build(self, object geometry) except NULL:
 */
  __pyx_r = __pyx_v_cogr_geometry;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":338
 *         return cogr_geometry
 * 
 *     cdef void * _buildGeometryCollection(self) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_part
 *         cdef void *cogr_geometry = ograpi.OGR_G_CreateGeometry(7)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("fiona.ogrext.OGRGeomBuilder._buildGeometryCollection", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_part);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":351
 *         return cogr_geometry
 * 
 *     cdef void * build(self, object geometry) except NULL:             # <<<<<<<<<<<<<<
 *         handler = DimensionsHandler()
 *         self.typename = geometry['type']
 */

static void *__pyx_f_5fiona_6ogrext_14OGRGeomBuilder_build(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *__pyx_v_self, PyObject *__pyx_v_geometry) {
  PyObject *__pyx_v_handler = NULL;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  void *__pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("build", 0);

  /* "fiona/ogrext.pyx":352
 * 
 *     cdef void * build(self, object geometry) except NULL:
 *         handler = DimensionsHandler()             # <<<<<<<<<<<<<<
 *         self.typename = geometry['type']
 *         self.coordinates = geometry.get('coordinates')
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_DimensionsHandler); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 352; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 352; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_handler = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":353
 *     cdef void * build(self, object geometry) except NULL:
 *         handler = DimensionsHandler()
 *         self.typename = geometry['type']             # <<<<<<<<<<<<<<
 *         self.coordinates = geometry.get('coordinates')
 *         if self.coordinates:
 */
  __pyx_t_2 = PyObject_GetItem(__pyx_v_geometry, __pyx_n_s_type); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 353; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->typename);
  __Pyx_DECREF(__pyx_v_self->typename);
  __pyx_v_self->typename = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":354
 *         handler = DimensionsHandler()
 *         self.typename = geometry['type']
 *         self.coordinates = geometry.get('coordinates')             # <<<<<<<<<<<<<<
 *         if self.coordinates:
 *             self.ndims = handler.getNumDims(self.typename, self.coordinates)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_geometry, __pyx_n_s_get); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_Call(__pyx_t_2, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->coordinates);
  __Pyx_DECREF(__pyx_v_self->coordinates);
  __pyx_v_self->coordinates = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":355
 *         self.typename = geometry['type']
 *         self.coordinates = geometry.get('coordinates')
 *         if self.coordinates:             # <<<<<<<<<<<<<<
 *             self.ndims = handler.getNumDims(self.typename, self.coordinates)
 *         if self.typename == 'Point':
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_self->coordinates); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 355; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":356
 *         self.coordinates = geometry.get('coordinates')
 *         if self.coordinates:
 *             self.ndims = handler.getNumDims(self.typename, self.coordinates)             # <<<<<<<<<<<<<<
 *         if self.typename == 'Point':
 *             return self._buildPoint()
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_handler, __pyx_n_s_getNumDims); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 356; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 356; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_self->typename);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_self->typename);
    __Pyx_GIVEREF(__pyx_v_self->typename);
    __Pyx_INCREF(__pyx_v_self->coordinates);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_self->coordinates);
    __Pyx_GIVEREF(__pyx_v_self->coordinates);
    __pyx_t_4 = PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 356; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GIVEREF(__pyx_t_4);
    __Pyx_GOTREF(__pyx_v_self->ndims);
    __Pyx_DECREF(__pyx_v_self->ndims);
    __pyx_v_self->ndims = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "fiona/ogrext.pyx":357
 *         if self.coordinates:
 *             self.ndims = handler.getNumDims(self.typename, self.coordinates)
 *         if self.typename == 'Point':             # <<<<<<<<<<<<<<
 *             return self._buildPoint()
 *         elif self.typename == 'LineString':
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_self->typename, __pyx_n_s_Point, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 357; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":358
 *             self.ndims = handler.getNumDims(self.typename, self.coordinates)
 *         if self.typename == 'Point':
 *             return self._buildPoint()             # <<<<<<<<<<<<<<
 *         elif self.typename == 'LineString':
 *             return self._buildLineString()
 */
    __pyx_t_5 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildPoint(__pyx_v_self); if (unlikely(__pyx_t_5 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 358; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_r = __pyx_t_5;
    goto __pyx_L0;
  }

  /* "fiona/ogrext.pyx":359
 *         if self.typename == 'Point':
 *             return self._buildPoint()
 *         elif self.typename == 'LineString':             # <<<<<<<<<<<<<<
 *             return self._buildLineString()
 *         elif self.typename == 'LinearRing':
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_self->typename, __pyx_n_s_LineString, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":360
 *             return self._buildPoint()
 *         elif self.typename == 'LineString':
 *             return self._buildLineString()             # <<<<<<<<<<<<<<
 *         elif self.typename == 'LinearRing':
 *             return self._buildLinearRing()
 */
    __pyx_t_5 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildLineString(__pyx_v_self); if (unlikely(__pyx_t_5 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 360; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_r = __pyx_t_5;
    goto __pyx_L0;
  }

  /* "fiona/ogrext.pyx":361
 *         elif self.typename == 'LineString':
 *             return self._buildLineString()
 *         elif self.typename == 'LinearRing':             # <<<<<<<<<<<<<<
 *             return self._buildLinearRing()
 *         elif self.typename == 'Polygon':
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_self->typename, __pyx_n_s_LinearRing, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 361; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":362
 *             return self._buildLineString()
 *         elif self.typename == 'LinearRing':
 *             return self._buildLinearRing()             # <<<<<<<<<<<<<<
 *         elif self.typename == 'Polygon':
 *             return self._buildPolygon()
 */
    __pyx_t_5 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildLinearRing(__pyx_v_self); if (unlikely(__pyx_t_5 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 362; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_r = __pyx_t_5;
    goto __pyx_L0;
  }

  /* "fiona/ogrext.pyx":363
 *         elif self.typename == 'LinearRing':
 *             return self._buildLinearRing()
 *         elif self.typename == 'Polygon':             # <<<<<<<<<<<<<<
 *             return self._buildPolygon()
 *         elif self.typename == 'MultiPoint':
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_self->typename, __pyx_n_s_Polygon, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 363; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":364
 *             return self._buildLinearRing()
 *         elif self.typename == 'Polygon':
 *             return self._buildPolygon()             # <<<<<<<<<<<<<<
 *         elif self.typename == 'MultiPoint':
 *             return self._buildMultiPoint()
 */
    __pyx_t_5 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildPolygon(__pyx_v_self); if (unlikely(__pyx_t_5 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 364; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_r = __pyx_t_5;
    goto __pyx_L0;
  }

  /* "fiona/ogrext.pyx":365
 *         elif self.typename == 'Polygon':
 *             return self._buildPolygon()
 *         elif self.typename == 'MultiPoint':             # <<<<<<<<<<<<<<
 *             return self._buildMultiPoint()
 *         elif self.typename == 'MultiLineString':
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_self->typename, __pyx_n_s_MultiPoint, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 365; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":366
 *             return self._buildPolygon()
 *         elif self.typename == 'MultiPoint':
 *             return self._buildMultiPoint()             # <<<<<<<<<<<<<<
 *         elif self.typename == 'MultiLineString':
 *             return self._buildMultiLineString()
 */
    __pyx_t_5 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildMultiPoint(__pyx_v_self); if (unlikely(__pyx_t_5 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 366; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_r = __pyx_t_5;
    goto __pyx_L0;
  }

  /* "fiona/ogrext.pyx":367
 *         elif self.typename == 'MultiPoint':
 *             return self._buildMultiPoint()
 *         elif self.typename == 'MultiLineString':             # <<<<<<<<<<<<<<
 *             return self._buildMultiLineString()
 *         elif self.typename == 'MultiPolygon':
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_self->typename, __pyx_n_s_MultiLineString, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 367; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":368
 *             return self._buildMultiPoint()
 *         elif self.typename == 'MultiLineString':
 *             return self._buildMultiLineString()             # <<<<<<<<<<<<<<
 *         elif self.typename == 'MultiPolygon':
 *             return self._buildMultiPolygon()
 */
    __pyx_t_5 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildMultiLineString(__pyx_v_self); if (unlikely(__pyx_t_5 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 368; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_r = __pyx_t_5;
    goto __pyx_L0;
  }

  /* "fiona/ogrext.pyx":369
 *         elif self.typename == 'MultiLineString':
 *             return self._buildMultiLineString()
 *         elif self.typename == 'MultiPolygon':             # <<<<<<<<<<<<<<
 *             return self._buildMultiPolygon()
 *         elif self.typename == 'GeometryCollection':
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_self->typename, __pyx_n_s_MultiPolygon, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 369; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":370
 *             return self._buildMultiLineString()
 *         elif self.typename == 'MultiPolygon':
 *             return self._buildMultiPolygon()             # <<<<<<<<<<<<<<
 *         elif self.typename == 'GeometryCollection':
 *             self.coordinates = geometry.get('geometries')
 */
    __pyx_t_5 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildMultiPolygon(__pyx_v_self); if (unlikely(__pyx_t_5 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_r = __pyx_t_5;
    goto __pyx_L0;
  }

  /* "fiona/ogrext.pyx":371
 *         elif self.typename == 'MultiPolygon':
 *             return self._buildMultiPolygon()
 *         elif self.typename == 'GeometryCollection':             # <<<<<<<<<<<<<<
 *             self.coordinates = geometry.get('geometries')
 *             self.ndims = handler.getNumDims(self.typename, self.coordinates)
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_self->typename, __pyx_n_s_GeometryCollection, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 371; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":372
 *             return self._buildMultiPolygon()
 *         elif self.typename == 'GeometryCollection':
 *             self.coordinates = geometry.get('geometries')             # <<<<<<<<<<<<<<
 *             self.ndims = handler.getNumDims(self.typename, self.coordinates)
 *             return self._buildGeometryCollection()
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_geometry, __pyx_n_s_get); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 372; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = PyObject_Call(__pyx_t_4, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 372; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->coordinates);
    __Pyx_DECREF(__pyx_v_self->coordinates);
    __pyx_v_self->coordinates = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "fiona/ogrext.pyx":373
 *         elif self.typename == 'GeometryCollection':
 *             self.coordinates = geometry.get('geometries')
 *             self.ndims = handler.getNumDims(self.typename, self.coordinates)             # <<<<<<<<<<<<<<
 *             return self._buildGeometryCollection()
 *         else:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_handler, __pyx_n_s_getNumDims); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 373; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 373; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_self->typename);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_self->typename);
    __Pyx_GIVEREF(__pyx_v_self->typename);
    __Pyx_INCREF(__pyx_v_self->coordinates);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_self->coordinates);
    __Pyx_GIVEREF(__pyx_v_self->coordinates);
    __pyx_t_1 = PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 373; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->ndims);
    __Pyx_DECREF(__pyx_v_self->ndims);
    __pyx_v_self->ndims = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "fiona/ogrext.pyx":374
 *             self.coordinates = geometry.get('geometries')
 *             self.ndims = handler.getNumDims(self.typename, self.coordinates)
 *             return self._buildGeometryCollection()             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError("Unsupported geometry type %s" % self.typename)
 */
    __pyx_t_5 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *)__pyx_v_self->__pyx_vtab)->_buildGeometryCollection(__pyx_v_self); if (unlikely(__pyx_t_5 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 374; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_r = __pyx_t_5;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "fiona/ogrext.pyx":376
 *             return self._buildGeometryCollection()
 *         else:
 *             raise ValueError("Unsupported geometry type %s" % self.typename)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Unsupported_geometry_type_s, __pyx_v_self->typename); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 376; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 376; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 376; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 376; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":351
 *         return cogr_geometry
 * 
 *     cdef void * build(self, object geometry) except NULL:             # <<<<<<<<<<<<<<
 *         handler = DimensionsHandler()
 *         self.typename = geometry['type']
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("fiona.ogrext.OGRGeomBuilder.build", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_handler);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":379
 * 
 * 
 * cdef geometry(void *geom):             # <<<<<<<<<<<<<<
 *     """Factory for Fiona geometries"""
 *     return GeomBuilder().build(geom)
 */

static PyObject *__pyx_f_5fiona_6ogrext_geometry(void *__pyx_v_geom) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("geometry", 0);

  /* "fiona/ogrext.pyx":381
 * cdef geometry(void *geom):
 *     """Factory for Fiona geometries"""
 *     return GeomBuilder().build(geom)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5fiona_6ogrext_GeomBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 381; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_t_1)->__pyx_vtab)->build(((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_t_1), __pyx_v_geom); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 381; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":379
 * 
 * 
 * cdef geometry(void *geom):             # <<<<<<<<<<<<<<
 *     """Factory for Fiona geometries"""
 *     return GeomBuilder().build(geom)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("fiona.ogrext.geometry", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":384
 * 
 * 
 * def geometryRT(geometry):             # <<<<<<<<<<<<<<
 *     # For testing purposes only, leaks the JSON data
 *     cdef void *cogr_geometry = OGRGeomBuilder().build(geometry)
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_1geometryRT(PyObject *__pyx_self, PyObject *__pyx_v_geometry); /*proto*/
static PyMethodDef __pyx_mdef_5fiona_6ogrext_1geometryRT = {__Pyx_NAMESTR("geometryRT"), (PyCFunction)__pyx_pw_5fiona_6ogrext_1geometryRT, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_5fiona_6ogrext_1geometryRT(PyObject *__pyx_self, PyObject *__pyx_v_geometry) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("geometryRT (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_geometryRT(__pyx_self, ((PyObject *)__pyx_v_geometry));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_geometryRT(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_geometry) {
  void *__pyx_v_cogr_geometry;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  void *__pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("geometryRT", 0);

  /* "fiona/ogrext.pyx":386
 * def geometryRT(geometry):
 *     # For testing purposes only, leaks the JSON data
 *     cdef void *cogr_geometry = OGRGeomBuilder().build(geometry)             # <<<<<<<<<<<<<<
 *     log.debug("Geometry: %s" % ograpi.OGR_G_ExportToJson(cogr_geometry))
 *     result = GeomBuilder().build(cogr_geometry)
 */
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5fiona_6ogrext_OGRGeomBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 386; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *)((struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)__pyx_t_1)->__pyx_vtab)->build(((struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)__pyx_t_1), __pyx_v_geometry); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 386; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_cogr_geometry = __pyx_t_2;

  /* "fiona/ogrext.pyx":387
 *     # For testing purposes only, leaks the JSON data
 *     cdef void *cogr_geometry = OGRGeomBuilder().build(geometry)
 *     log.debug("Geometry: %s" % ograpi.OGR_G_ExportToJson(cogr_geometry))             # <<<<<<<<<<<<<<
 *     result = GeomBuilder().build(cogr_geometry)
 *     _deleteOgrGeom(cogr_geometry)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_debug); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBytes_FromUString(OGR_G_ExportToJson(__pyx_v_cogr_geometry)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Geometry_s, __pyx_t_1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_Call(__pyx_t_3, __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":388
 *     cdef void *cogr_geometry = OGRGeomBuilder().build(geometry)
 *     log.debug("Geometry: %s" % ograpi.OGR_G_ExportToJson(cogr_geometry))
 *     result = GeomBuilder().build(cogr_geometry)             # <<<<<<<<<<<<<<
 *     _deleteOgrGeom(cogr_geometry)
 *     return result
 */
  __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5fiona_6ogrext_GeomBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 388; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_t_4)->__pyx_vtab)->build(((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_t_4), __pyx_v_cogr_geometry); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 388; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":389
 *     log.debug("Geometry: %s" % ograpi.OGR_G_ExportToJson(cogr_geometry))
 *     result = GeomBuilder().build(cogr_geometry)
 *     _deleteOgrGeom(cogr_geometry)             # <<<<<<<<<<<<<<
 *     return result
 * 
 */
  __pyx_t_1 = __pyx_f_5fiona_6ogrext__deleteOgrGeom(__pyx_v_cogr_geometry); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 389; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":390
 *     result = GeomBuilder().build(cogr_geometry)
 *     _deleteOgrGeom(cogr_geometry)
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":384
 * 
 * 
 * def geometryRT(geometry):             # <<<<<<<<<<<<<<
 *     # For testing purposes only, leaks the JSON data
 *     cdef void *cogr_geometry = OGRGeomBuilder().build(geometry)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("fiona.ogrext.geometryRT", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_5fiona_6ogrext_4generator(__pyx_GeneratorObject *__pyx_generator, PyObject *__pyx_sent_value); /* proto */

/* "fiona/ogrext.pyx":393
 * 
 * 
 * def _explode(coords):             # <<<<<<<<<<<<<<
 *     """Explode a GeoJSON geometry's coordinates object and yield
 *     coordinate tuples. As long as the input is conforming, the type of
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_3_explode(PyObject *__pyx_self, PyObject *__pyx_v_coords); /*proto*/
static char __pyx_doc_5fiona_6ogrext_2_explode[] = "Explode a GeoJSON geometry's coordinates object and yield\n    coordinate tuples. As long as the input is conforming, the type of\n    the geometry doesn't matter.";
static PyMethodDef __pyx_mdef_5fiona_6ogrext_3_explode = {__Pyx_NAMESTR("_explode"), (PyCFunction)__pyx_pw_5fiona_6ogrext_3_explode, METH_O, __Pyx_DOCSTR(__pyx_doc_5fiona_6ogrext_2_explode)};
static PyObject *__pyx_pw_5fiona_6ogrext_3_explode(PyObject *__pyx_self, PyObject *__pyx_v_coords) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_explode (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_2_explode(__pyx_self, ((PyObject *)__pyx_v_coords));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_2_explode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_coords) {
  struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_explode", 0);
  __pyx_cur_scope = (struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode *)__pyx_tp_new_5fiona_6ogrext___pyx_scope_struct___explode(__pyx_ptype_5fiona_6ogrext___pyx_scope_struct___explode, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_cur_scope);
  __pyx_cur_scope->__pyx_v_coords = __pyx_v_coords;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_coords);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_coords);
  {
    __pyx_GeneratorObject *gen = __Pyx_Generator_New((__pyx_generator_body_t) __pyx_gb_5fiona_6ogrext_4generator, (PyObject *) __pyx_cur_scope); if (unlikely(!gen)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("fiona.ogrext._explode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_5fiona_6ogrext_4generator(__pyx_GeneratorObject *__pyx_generator, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode *__pyx_cur_scope = ((struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  Py_ssize_t __pyx_t_10;
  PyObject *(*__pyx_t_11)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("None", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_yield;
    case 2: goto __pyx_L10_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":397
 *     coordinate tuples. As long as the input is conforming, the type of
 *     the geometry doesn't matter."""
 *     for e in coords:             # <<<<<<<<<<<<<<
 *         if isinstance(e, (float, int)):
 *             yield coords
 */
  if (PyList_CheckExact(__pyx_cur_scope->__pyx_v_coords) || PyTuple_CheckExact(__pyx_cur_scope->__pyx_v_coords)) {
    __pyx_t_1 = __pyx_cur_scope->__pyx_v_coords; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_cur_scope->__pyx_v_coords); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 397; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_3 && PyList_CheckExact(__pyx_t_1)) {
      if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 397; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 397; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_3 && PyTuple_CheckExact(__pyx_t_1)) {
      if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 397; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 397; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 397; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_e);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_e, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;

    /* "fiona/ogrext.pyx":398
 *     the geometry doesn't matter."""
 *     for e in coords:
 *         if isinstance(e, (float, int)):             # <<<<<<<<<<<<<<
 *             yield coords
 *             break
 */
    __Pyx_INCREF(__pyx_cur_scope->__pyx_v_e);
    __pyx_t_4 = __pyx_cur_scope->__pyx_v_e;
    __pyx_t_5 = PyFloat_Check(__pyx_t_4); 
    if (!__pyx_t_5) {
      __pyx_t_6 = PyInt_Check(__pyx_t_4); 
      __pyx_t_7 = __pyx_t_6;
    } else {
      __pyx_t_7 = __pyx_t_5;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = (__pyx_t_7 != 0);
    if (__pyx_t_5) {

      /* "fiona/ogrext.pyx":399
 *     for e in coords:
 *         if isinstance(e, (float, int)):
 *             yield coords             # <<<<<<<<<<<<<<
 *             break
 *         else:
 */
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_coords);
      __pyx_r = __pyx_cur_scope->__pyx_v_coords;
      __Pyx_XGIVEREF(__pyx_t_1);
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L7_resume_from_yield:;
      __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
      __pyx_cur_scope->__pyx_t_0 = 0;
      __Pyx_XGOTREF(__pyx_t_1);
      __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 399; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "fiona/ogrext.pyx":400
 *         if isinstance(e, (float, int)):
 *             yield coords
 *             break             # <<<<<<<<<<<<<<
 *         else:
 *             for f in _explode(e):
 */
      goto __pyx_L5_break;
    }
    /*else*/ {

      /* "fiona/ogrext.pyx":402
 *             break
 *         else:
 *             for f in _explode(e):             # <<<<<<<<<<<<<<
 *                 yield f
 * 
 */
      __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_explode); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_cur_scope->__pyx_v_e);
      PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_cur_scope->__pyx_v_e);
      __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_e);
      __pyx_t_9 = PyObject_Call(__pyx_t_4, __pyx_t_8, NULL); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (PyList_CheckExact(__pyx_t_9) || PyTuple_CheckExact(__pyx_t_9)) {
        __pyx_t_8 = __pyx_t_9; __Pyx_INCREF(__pyx_t_8); __pyx_t_10 = 0;
        __pyx_t_11 = NULL;
      } else {
        __pyx_t_10 = -1; __pyx_t_8 = PyObject_GetIter(__pyx_t_9); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_11 = Py_TYPE(__pyx_t_8)->tp_iternext;
      }
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      for (;;) {
        if (!__pyx_t_11 && PyList_CheckExact(__pyx_t_8)) {
          if (__pyx_t_10 >= PyList_GET_SIZE(__pyx_t_8)) break;
          #if CYTHON_COMPILING_IN_CPYTHON
          __pyx_t_9 = PyList_GET_ITEM(__pyx_t_8, __pyx_t_10); __Pyx_INCREF(__pyx_t_9); __pyx_t_10++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #else
          __pyx_t_9 = PySequence_ITEM(__pyx_t_8, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #endif
        } else if (!__pyx_t_11 && PyTuple_CheckExact(__pyx_t_8)) {
          if (__pyx_t_10 >= PyTuple_GET_SIZE(__pyx_t_8)) break;
          #if CYTHON_COMPILING_IN_CPYTHON
          __pyx_t_9 = PyTuple_GET_ITEM(__pyx_t_8, __pyx_t_10); __Pyx_INCREF(__pyx_t_9); __pyx_t_10++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #else
          __pyx_t_9 = PySequence_ITEM(__pyx_t_8, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #endif
        } else {
          __pyx_t_9 = __pyx_t_11(__pyx_t_8);
          if (unlikely(!__pyx_t_9)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 402; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_9);
        }
        __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_f);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_f, __pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_9);
        __pyx_t_9 = 0;

        /* "fiona/ogrext.pyx":403
 *         else:
 *             for f in _explode(e):
 *                 yield f             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_f);
        __pyx_r = __pyx_cur_scope->__pyx_v_f;
        __Pyx_XGIVEREF(__pyx_t_1);
        __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
        __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
        __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
        __Pyx_XGIVEREF(__pyx_t_8);
        __pyx_cur_scope->__pyx_t_3 = __pyx_t_8;
        __pyx_cur_scope->__pyx_t_4 = __pyx_t_10;
        __pyx_cur_scope->__pyx_t_5 = __pyx_t_11;
        __Pyx_XGIVEREF(__pyx_r);
        __Pyx_RefNannyFinishContext();
        /* return from generator, yielding value */
        __pyx_generator->resume_label = 2;
        return __pyx_r;
        __pyx_L10_resume_from_yield:;
        __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
        __pyx_cur_scope->__pyx_t_0 = 0;
        __Pyx_XGOTREF(__pyx_t_1);
        __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
        __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
        __pyx_t_8 = __pyx_cur_scope->__pyx_t_3;
        __pyx_cur_scope->__pyx_t_3 = 0;
        __Pyx_XGOTREF(__pyx_t_8);
        __pyx_t_10 = __pyx_cur_scope->__pyx_t_4;
        __pyx_t_11 = __pyx_cur_scope->__pyx_t_5;
        if (unlikely(!__pyx_sent_value)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 403; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
  }
  __pyx_L5_break:;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":393
 * 
 * 
 * def _explode(coords):             # <<<<<<<<<<<<<<
 *     """Explode a GeoJSON geometry's coordinates object and yield
 *     coordinate tuples. As long as the input is conforming, the type of
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("_explode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r);
  __pyx_generator->resume_label = -1;
  __Pyx_Generator_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return NULL;
}

/* "fiona/ogrext.pyx":406
 * 
 * 
 * def _bounds(geometry):             # <<<<<<<<<<<<<<
 *     """Bounding box of a GeoJSON geometry"""
 *     try:
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_6_bounds(PyObject *__pyx_self, PyObject *__pyx_v_geometry); /*proto*/
static char __pyx_doc_5fiona_6ogrext_5_bounds[] = "Bounding box of a GeoJSON geometry";
static PyMethodDef __pyx_mdef_5fiona_6ogrext_6_bounds = {__Pyx_NAMESTR("_bounds"), (PyCFunction)__pyx_pw_5fiona_6ogrext_6_bounds, METH_O, __Pyx_DOCSTR(__pyx_doc_5fiona_6ogrext_5_bounds)};
static PyObject *__pyx_pw_5fiona_6ogrext_6_bounds(PyObject *__pyx_self, PyObject *__pyx_v_geometry) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_bounds (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_5_bounds(__pyx_self, ((PyObject *)__pyx_v_geometry));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_5_bounds(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_geometry) {
  PyObject *__pyx_v_x = NULL;
  PyObject *__pyx_v_y = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_bounds", 0);

  /* "fiona/ogrext.pyx":408
 * def _bounds(geometry):
 *     """Bounding box of a GeoJSON geometry"""
 *     try:             # <<<<<<<<<<<<<<
 *         x, y = zip(*list(_explode(geometry['coordinates'])))
 *         return min(x), min(y), max(x), max(y)
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "fiona/ogrext.pyx":409
 *     """Bounding box of a GeoJSON geometry"""
 *     try:
 *         x, y = zip(*list(_explode(geometry['coordinates'])))             # <<<<<<<<<<<<<<
 *         return min(x), min(y), max(x), max(y)
 *     except (KeyError, TypeError):
 */
      __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_explode); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyObject_GetItem(__pyx_v_geometry, __pyx_n_s_coordinates); if (unlikely(__pyx_t_5 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L3_error;};
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_5 = PyObject_Call(__pyx_t_4, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_5 = PyObject_Call(((PyObject *)((PyObject*)(&PyList_Type))), __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = PySequence_Tuple(__pyx_t_5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyObject_Call(__pyx_builtin_zip, __pyx_t_6, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if ((likely(PyTuple_CheckExact(__pyx_t_5))) || (PyList_CheckExact(__pyx_t_5))) {
        PyObject* sequence = __pyx_t_5;
        #if CYTHON_COMPILING_IN_CPYTHON
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        #if CYTHON_COMPILING_IN_CPYTHON
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_6 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_6 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_4);
        #else
        __pyx_t_6 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        __Pyx_GOTREF(__pyx_t_4);
        #endif
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_7 = PyObject_GetIter(__pyx_t_5); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_8 = Py_TYPE(__pyx_t_7)->tp_iternext;
        index = 0; __pyx_t_6 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_6)) goto __pyx_L11_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_6);
        index = 1; __pyx_t_4 = __pyx_t_8(__pyx_t_7); if (unlikely(!__pyx_t_4)) goto __pyx_L11_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_4);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_8(__pyx_t_7), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        __pyx_t_8 = NULL;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L12_unpacking_done;
        __pyx_L11_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_8 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        __pyx_L12_unpacking_done:;
      }
      __pyx_v_x = __pyx_t_6;
      __pyx_t_6 = 0;
      __pyx_v_y = __pyx_t_4;
      __pyx_t_4 = 0;

      /* "fiona/ogrext.pyx":410
 *     try:
 *         x, y = zip(*list(_explode(geometry['coordinates'])))
 *         return min(x), min(y), max(x), max(y)             # <<<<<<<<<<<<<<
 *     except (KeyError, TypeError):
 *         return None
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_x);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_x);
      __Pyx_GIVEREF(__pyx_v_x);
      __pyx_t_4 = PyObject_Call(__pyx_builtin_min, __pyx_t_5, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_y);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_y);
      __Pyx_GIVEREF(__pyx_v_y);
      __pyx_t_6 = PyObject_Call(__pyx_builtin_min, __pyx_t_5, NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_x);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_x);
      __Pyx_GIVEREF(__pyx_v_x);
      __pyx_t_7 = PyObject_Call(__pyx_builtin_max, __pyx_t_5, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_INCREF(__pyx_v_y);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_y);
      __Pyx_GIVEREF(__pyx_v_y);
      __pyx_t_9 = PyObject_Call(__pyx_builtin_max, __pyx_t_5, NULL); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_9);
      __pyx_t_4 = 0;
      __pyx_t_6 = 0;
      __pyx_t_7 = 0;
      __pyx_t_9 = 0;
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L7_try_return;
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L10_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "fiona/ogrext.pyx":411
 *         x, y = zip(*list(_explode(geometry['coordinates'])))
 *         return min(x), min(y), max(x), max(y)
 *     except (KeyError, TypeError):             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
    __pyx_t_10 = PyErr_ExceptionMatches(__pyx_builtin_KeyError) || PyErr_ExceptionMatches(__pyx_builtin_TypeError);
    if (__pyx_t_10) {
      __Pyx_AddTraceback("fiona.ogrext._bounds", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_9, &__pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 411; __pyx_clineno = __LINE__; goto __pyx_L5_except_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GOTREF(__pyx_t_7);

      /* "fiona/ogrext.pyx":412
 *         return min(x), min(y), max(x), max(y)
 *     except (KeyError, TypeError):
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_None);
      __pyx_r = Py_None;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      goto __pyx_L6_except_return;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L7_try_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L0;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L10_try_end:;
  }

  /* "fiona/ogrext.pyx":406
 * 
 * 
 * def _bounds(geometry):             # <<<<<<<<<<<<<<
 *     """Bounding box of a GeoJSON geometry"""
 *     try:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("fiona.ogrext._bounds", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XDECREF(__pyx_v_y);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":424
 *     """
 * 
 *     cdef build(self, void *feature, encoding='utf-8', bbox=False):             # <<<<<<<<<<<<<<
 *         # The only method anyone ever needs to call
 *         cdef void *fdefn
 */

static PyObject *__pyx_f_5fiona_6ogrext_14FeatureBuilder_build(CYTHON_UNUSED struct __pyx_obj_5fiona_6ogrext_FeatureBuilder *__pyx_v_self, void *__pyx_v_feature, struct __pyx_opt_args_5fiona_6ogrext_14FeatureBuilder_build *__pyx_optional_args) {
  PyObject *__pyx_v_encoding = ((PyObject *)__pyx_kp_s_utf_8);
  void *__pyx_v_fdefn;
  int __pyx_v_i;
  int __pyx_v_y;
  int __pyx_v_m;
  int __pyx_v_d;
  int __pyx_v_hh;
  int __pyx_v_mm;
  int __pyx_v_ss;
  int __pyx_v_tz;
  CYTHON_UNUSED int __pyx_v_retval;
  char *__pyx_v_key_c;
  PyObject *__pyx_v_props = NULL;
  char *__pyx_v_key_b;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_fieldtypename = NULL;
  PyObject *__pyx_v_fieldtype = NULL;
  char *__pyx_v_val;
  void *__pyx_v_cogr_geometry;
  PyObject *__pyx_v_geom = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("build", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_encoding = __pyx_optional_args->encoding;
    }
  }

  /* "fiona/ogrext.pyx":428
 *         cdef void *fdefn
 *         cdef int i
 *         cdef int y = 0             # <<<<<<<<<<<<<<
 *         cdef int m = 0
 *         cdef int d = 0
 */
  __pyx_v_y = 0;

  /* "fiona/ogrext.pyx":429
 *         cdef int i
 *         cdef int y = 0
 *         cdef int m = 0             # <<<<<<<<<<<<<<
 *         cdef int d = 0
 *         cdef int hh = 0
 */
  __pyx_v_m = 0;

  /* "fiona/ogrext.pyx":430
 *         cdef int y = 0
 *         cdef int m = 0
 *         cdef int d = 0             # <<<<<<<<<<<<<<
 *         cdef int hh = 0
 *         cdef int mm = 0
 */
  __pyx_v_d = 0;

  /* "fiona/ogrext.pyx":431
 *         cdef int m = 0
 *         cdef int d = 0
 *         cdef int hh = 0             # <<<<<<<<<<<<<<
 *         cdef int mm = 0
 *         cdef int ss = 0
 */
  __pyx_v_hh = 0;

  /* "fiona/ogrext.pyx":432
 *         cdef int d = 0
 *         cdef int hh = 0
 *         cdef int mm = 0             # <<<<<<<<<<<<<<
 *         cdef int ss = 0
 *         cdef int tz = 0
 */
  __pyx_v_mm = 0;

  /* "fiona/ogrext.pyx":433
 *         cdef int hh = 0
 *         cdef int mm = 0
 *         cdef int ss = 0             # <<<<<<<<<<<<<<
 *         cdef int tz = 0
 *         cdef int retval
 */
  __pyx_v_ss = 0;

  /* "fiona/ogrext.pyx":434
 *         cdef int mm = 0
 *         cdef int ss = 0
 *         cdef int tz = 0             # <<<<<<<<<<<<<<
 *         cdef int retval
 *         cdef char *key_c
 */
  __pyx_v_tz = 0;

  /* "fiona/ogrext.pyx":437
 *         cdef int retval
 *         cdef char *key_c
 *         props = OrderedDict()             # <<<<<<<<<<<<<<
 *         for i in range(ograpi.OGR_F_GetFieldCount(feature)):
 *             fdefn = ograpi.OGR_F_GetFieldDefnRef(feature, i)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_OrderedDict); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 437; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 437; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_props = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":438
 *         cdef char *key_c
 *         props = OrderedDict()
 *         for i in range(ograpi.OGR_F_GetFieldCount(feature)):             # <<<<<<<<<<<<<<
 *             fdefn = ograpi.OGR_F_GetFieldDefnRef(feature, i)
 *             if fdefn is NULL:
 */
  __pyx_t_3 = OGR_F_GetFieldCount(__pyx_v_feature);
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "fiona/ogrext.pyx":439
 *         props = OrderedDict()
 *         for i in range(ograpi.OGR_F_GetFieldCount(feature)):
 *             fdefn = ograpi.OGR_F_GetFieldDefnRef(feature, i)             # <<<<<<<<<<<<<<
 *             if fdefn is NULL:
 *                 raise ValueError("Null feature definition")
 */
    __pyx_v_fdefn = OGR_F_GetFieldDefnRef(__pyx_v_feature, __pyx_v_i);

    /* "fiona/ogrext.pyx":440
 *         for i in range(ograpi.OGR_F_GetFieldCount(feature)):
 *             fdefn = ograpi.OGR_F_GetFieldDefnRef(feature, i)
 *             if fdefn is NULL:             # <<<<<<<<<<<<<<
 *                 raise ValueError("Null feature definition")
 *             key_c = ograpi.OGR_Fld_GetNameRef(fdefn)
 */
    __pyx_t_5 = ((__pyx_v_fdefn == NULL) != 0);
    if (__pyx_t_5) {

      /* "fiona/ogrext.pyx":441
 *             fdefn = ograpi.OGR_F_GetFieldDefnRef(feature, i)
 *             if fdefn is NULL:
 *                 raise ValueError("Null feature definition")             # <<<<<<<<<<<<<<
 *             key_c = ograpi.OGR_Fld_GetNameRef(fdefn)
 *             if key_c == NULL:
 */
      __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }

    /* "fiona/ogrext.pyx":442
 *             if fdefn is NULL:
 *                 raise ValueError("Null feature definition")
 *             key_c = ograpi.OGR_Fld_GetNameRef(fdefn)             # <<<<<<<<<<<<<<
 *             if key_c == NULL:
 *                 raise ValueError("Null field name reference")
 */
    __pyx_v_key_c = OGR_Fld_GetNameRef(__pyx_v_fdefn);

    /* "fiona/ogrext.pyx":443
 *                 raise ValueError("Null feature definition")
 *             key_c = ograpi.OGR_Fld_GetNameRef(fdefn)
 *             if key_c == NULL:             # <<<<<<<<<<<<<<
 *                 raise ValueError("Null field name reference")
 *             key_b = key_c
 */
    __pyx_t_5 = ((__pyx_v_key_c == NULL) != 0);
    if (__pyx_t_5) {

      /* "fiona/ogrext.pyx":444
 *             key_c = ograpi.OGR_Fld_GetNameRef(fdefn)
 *             if key_c == NULL:
 *                 raise ValueError("Null field name reference")             # <<<<<<<<<<<<<<
 *             key_b = key_c
 *             key = key_b.decode('utf-8')
 */
      __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 444; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 444; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }

    /* "fiona/ogrext.pyx":445
 *             if key_c == NULL:
 *                 raise ValueError("Null field name reference")
 *             key_b = key_c             # <<<<<<<<<<<<<<
 *             key = key_b.decode('utf-8')
 *             fieldtypename = FIELD_TYPES[ograpi.OGR_Fld_GetType(fdefn)]
 */
    __pyx_v_key_b = __pyx_v_key_c;

    /* "fiona/ogrext.pyx":446
 *                 raise ValueError("Null field name reference")
 *             key_b = key_c
 *             key = key_b.decode('utf-8')             # <<<<<<<<<<<<<<
 *             fieldtypename = FIELD_TYPES[ograpi.OGR_Fld_GetType(fdefn)]
 *             if not fieldtypename:
 */
    __pyx_t_2 = __Pyx_decode_c_string(__pyx_v_key_b, 0, strlen(__pyx_v_key_b), NULL, NULL, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 446; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "fiona/ogrext.pyx":447
 *             key_b = key_c
 *             key = key_b.decode('utf-8')
 *             fieldtypename = FIELD_TYPES[ograpi.OGR_Fld_GetType(fdefn)]             # <<<<<<<<<<<<<<
 *             if not fieldtypename:
 *                 log.warn(
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_FIELD_TYPES); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 447; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = OGR_Fld_GetType(__pyx_v_fdefn);
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_2, __pyx_t_6, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 447; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF_SET(__pyx_v_fieldtypename, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "fiona/ogrext.pyx":448
 *             key = key_b.decode('utf-8')
 *             fieldtypename = FIELD_TYPES[ograpi.OGR_Fld_GetType(fdefn)]
 *             if not fieldtypename:             # <<<<<<<<<<<<<<
 *                 log.warn(
 *                     "Skipping field %s: invalid type %s",
 */
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_fieldtypename); if (unlikely(__pyx_t_5 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 448; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_7 = ((!__pyx_t_5) != 0);
    if (__pyx_t_7) {

      /* "fiona/ogrext.pyx":449
 *             fieldtypename = FIELD_TYPES[ograpi.OGR_Fld_GetType(fdefn)]
 *             if not fieldtypename:
 *                 log.warn(             # <<<<<<<<<<<<<<
 *                     "Skipping field %s: invalid type %s",
 *                     key,
 */
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 449; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_warn); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 449; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "fiona/ogrext.pyx":452
 *                     "Skipping field %s: invalid type %s",
 *                     key,
 *                     ograpi.OGR_Fld_GetType(fdefn))             # <<<<<<<<<<<<<<
 *                 continue
 *             # TODO: other types
 */
      __pyx_t_1 = __Pyx_PyInt_From_int(OGR_Fld_GetType(__pyx_v_fdefn)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 452; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);

      /* "fiona/ogrext.pyx":449
 *             fieldtypename = FIELD_TYPES[ograpi.OGR_Fld_GetType(fdefn)]
 *             if not fieldtypename:
 *                 log.warn(             # <<<<<<<<<<<<<<
 *                     "Skipping field %s: invalid type %s",
 *                     key,
 */
      __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 449; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_kp_s_Skipping_field_s_invalid_type_s);
      PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_kp_s_Skipping_field_s_invalid_type_s);
      __Pyx_GIVEREF(__pyx_kp_s_Skipping_field_s_invalid_type_s);
      __Pyx_INCREF(__pyx_v_key);
      PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_v_key);
      __Pyx_GIVEREF(__pyx_v_key);
      PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_1 = PyObject_Call(__pyx_t_2, __pyx_t_8, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 449; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "fiona/ogrext.pyx":453
 *                     key,
 *                     ograpi.OGR_Fld_GetType(fdefn))
 *                 continue             # <<<<<<<<<<<<<<
 *             # TODO: other types
 *             fieldtype = FIELD_TYPES_MAP[fieldtypename]
 */
      goto __pyx_L3_continue;
    }

    /* "fiona/ogrext.pyx":455
 *                 continue
 *             # TODO: other types
 *             fieldtype = FIELD_TYPES_MAP[fieldtypename]             # <<<<<<<<<<<<<<
 *             if not ograpi.OGR_F_IsFieldSet(feature, i):
 *                 props[key] = None
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_FIELD_TYPES_MAP); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 455; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = PyObject_GetItem(__pyx_t_1, __pyx_v_fieldtypename); if (unlikely(__pyx_t_8 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 455; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_fieldtype, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "fiona/ogrext.pyx":456
 *             # TODO: other types
 *             fieldtype = FIELD_TYPES_MAP[fieldtypename]
 *             if not ograpi.OGR_F_IsFieldSet(feature, i):             # <<<<<<<<<<<<<<
 *                 props[key] = None
 *             elif fieldtype is int:
 */
    __pyx_t_7 = ((!(OGR_F_IsFieldSet(__pyx_v_feature, __pyx_v_i) != 0)) != 0);
    if (__pyx_t_7) {

      /* "fiona/ogrext.pyx":457
 *             fieldtype = FIELD_TYPES_MAP[fieldtypename]
 *             if not ograpi.OGR_F_IsFieldSet(feature, i):
 *                 props[key] = None             # <<<<<<<<<<<<<<
 *             elif fieldtype is int:
 *                 props[key] = ograpi.OGR_F_GetFieldAsInteger(feature, i)
 */
      if (unlikely(PyObject_SetItem(__pyx_v_props, __pyx_v_key, Py_None) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L8;
    }

    /* "fiona/ogrext.pyx":458
 *             if not ograpi.OGR_F_IsFieldSet(feature, i):
 *                 props[key] = None
 *             elif fieldtype is int:             # <<<<<<<<<<<<<<
 *                 props[key] = ograpi.OGR_F_GetFieldAsInteger(feature, i)
 *             elif fieldtype is float:
 */
    __pyx_t_7 = (__pyx_v_fieldtype == ((PyObject *)((PyObject*)(&PyInt_Type))));
    __pyx_t_5 = (__pyx_t_7 != 0);
    if (__pyx_t_5) {

      /* "fiona/ogrext.pyx":459
 *                 props[key] = None
 *             elif fieldtype is int:
 *                 props[key] = ograpi.OGR_F_GetFieldAsInteger(feature, i)             # <<<<<<<<<<<<<<
 *             elif fieldtype is float:
 *                 props[key] = ograpi.OGR_F_GetFieldAsDouble(feature, i)
 */
      __pyx_t_8 = __Pyx_PyInt_From_int(OGR_F_GetFieldAsInteger(__pyx_v_feature, __pyx_v_i)); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      if (unlikely(PyObject_SetItem(__pyx_v_props, __pyx_v_key, __pyx_t_8) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L8;
    }

    /* "fiona/ogrext.pyx":460
 *             elif fieldtype is int:
 *                 props[key] = ograpi.OGR_F_GetFieldAsInteger(feature, i)
 *             elif fieldtype is float:             # <<<<<<<<<<<<<<
 *                 props[key] = ograpi.OGR_F_GetFieldAsDouble(feature, i)
 *             elif fieldtype is text_type:
 */
    __pyx_t_5 = (__pyx_v_fieldtype == ((PyObject *)((PyObject*)(&PyFloat_Type))));
    __pyx_t_7 = (__pyx_t_5 != 0);
    if (__pyx_t_7) {

      /* "fiona/ogrext.pyx":461
 *                 props[key] = ograpi.OGR_F_GetFieldAsInteger(feature, i)
 *             elif fieldtype is float:
 *                 props[key] = ograpi.OGR_F_GetFieldAsDouble(feature, i)             # <<<<<<<<<<<<<<
 *             elif fieldtype is text_type:
 *                 try:
 */
      __pyx_t_8 = PyFloat_FromDouble(OGR_F_GetFieldAsDouble(__pyx_v_feature, __pyx_v_i)); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 461; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      if (unlikely(PyObject_SetItem(__pyx_v_props, __pyx_v_key, __pyx_t_8) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 461; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      goto __pyx_L8;
    }

    /* "fiona/ogrext.pyx":462
 *             elif fieldtype is float:
 *                 props[key] = ograpi.OGR_F_GetFieldAsDouble(feature, i)
 *             elif fieldtype is text_type:             # <<<<<<<<<<<<<<
 *                 try:
 *                     val = ograpi.OGR_F_GetFieldAsString(feature, i)
 */
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_text_type); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 462; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = (__pyx_v_fieldtype == __pyx_t_8);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_5 = (__pyx_t_7 != 0);
    if (__pyx_t_5) {

      /* "fiona/ogrext.pyx":463
 *                 props[key] = ograpi.OGR_F_GetFieldAsDouble(feature, i)
 *             elif fieldtype is text_type:
 *                 try:             # <<<<<<<<<<<<<<
 *                     val = ograpi.OGR_F_GetFieldAsString(feature, i)
 *                     props[key] = val.decode(encoding)
 */
      {
        __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
        __Pyx_XGOTREF(__pyx_t_9);
        __Pyx_XGOTREF(__pyx_t_10);
        __Pyx_XGOTREF(__pyx_t_11);
        /*try:*/ {

          /* "fiona/ogrext.pyx":464
 *             elif fieldtype is text_type:
 *                 try:
 *                     val = ograpi.OGR_F_GetFieldAsString(feature, i)             # <<<<<<<<<<<<<<
 *                     props[key] = val.decode(encoding)
 *                 except UnicodeDecodeError:
 */
          __pyx_v_val = OGR_F_GetFieldAsString(__pyx_v_feature, __pyx_v_i);

          /* "fiona/ogrext.pyx":465
 *                 try:
 *                     val = ograpi.OGR_F_GetFieldAsString(feature, i)
 *                     props[key] = val.decode(encoding)             # <<<<<<<<<<<<<<
 *                 except UnicodeDecodeError:
 *                     log.warn(
 */
          __pyx_t_8 = __Pyx_PyBytes_FromString(__pyx_v_val); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 465; __pyx_clineno = __LINE__; goto __pyx_L9_error;}
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_decode); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 465; __pyx_clineno = __LINE__; goto __pyx_L9_error;}
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 465; __pyx_clineno = __LINE__; goto __pyx_L9_error;}
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_INCREF(__pyx_v_encoding);
          PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_encoding);
          __Pyx_GIVEREF(__pyx_v_encoding);
          __pyx_t_2 = PyObject_Call(__pyx_t_1, __pyx_t_8, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 465; __pyx_clineno = __LINE__; goto __pyx_L9_error;}
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(PyObject_SetItem(__pyx_v_props, __pyx_v_key, __pyx_t_2) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 465; __pyx_clineno = __LINE__; goto __pyx_L9_error;}
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        }
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        goto __pyx_L16_try_end;
        __pyx_L9_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "fiona/ogrext.pyx":466
 *                     val = ograpi.OGR_F_GetFieldAsString(feature, i)
 *                     props[key] = val.decode(encoding)
 *                 except UnicodeDecodeError:             # <<<<<<<<<<<<<<
 *                     log.warn(
 *                         "Failed to decode %s using %s codec", val, encoding)
 */
        __pyx_t_6 = PyErr_ExceptionMatches(__pyx_builtin_UnicodeDecodeError);
        if (__pyx_t_6) {
          __Pyx_AddTraceback("fiona.ogrext.FeatureBuilder.build", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_8, &__pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L11_except_error;}
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GOTREF(__pyx_t_1);

          /* "fiona/ogrext.pyx":467
 *                     props[key] = val.decode(encoding)
 *                 except UnicodeDecodeError:
 *                     log.warn(             # <<<<<<<<<<<<<<
 *                         "Failed to decode %s using %s codec", val, encoding)
 *                     props[key] = val
 */
          __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 467; __pyx_clineno = __LINE__; goto __pyx_L11_except_error;}
          __Pyx_GOTREF(__pyx_t_12);
          __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_warn); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 467; __pyx_clineno = __LINE__; goto __pyx_L11_except_error;}
          __Pyx_GOTREF(__pyx_t_13);
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "fiona/ogrext.pyx":468
 *                 except UnicodeDecodeError:
 *                     log.warn(
 *                         "Failed to decode %s using %s codec", val, encoding)             # <<<<<<<<<<<<<<
 *                     props[key] = val
 *             elif fieldtype in (FionaDateType, FionaTimeType, FionaDateTimeType):
 */
          __pyx_t_12 = __Pyx_PyBytes_FromString(__pyx_v_val); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 468; __pyx_clineno = __LINE__; goto __pyx_L11_except_error;}
          __Pyx_GOTREF(__pyx_t_12);

          /* "fiona/ogrext.pyx":467
 *                     props[key] = val.decode(encoding)
 *                 except UnicodeDecodeError:
 *                     log.warn(             # <<<<<<<<<<<<<<
 *                         "Failed to decode %s using %s codec", val, encoding)
 *                     props[key] = val
 */
          __pyx_t_14 = PyTuple_New(3); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 467; __pyx_clineno = __LINE__; goto __pyx_L11_except_error;}
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_INCREF(__pyx_kp_s_Failed_to_decode_s_using_s_codec);
          PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_kp_s_Failed_to_decode_s_using_s_codec);
          __Pyx_GIVEREF(__pyx_kp_s_Failed_to_decode_s_using_s_codec);
          PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_t_12);
          __Pyx_GIVEREF(__pyx_t_12);
          __Pyx_INCREF(__pyx_v_encoding);
          PyTuple_SET_ITEM(__pyx_t_14, 2, __pyx_v_encoding);
          __Pyx_GIVEREF(__pyx_v_encoding);
          __pyx_t_12 = 0;
          __pyx_t_12 = PyObject_Call(__pyx_t_13, __pyx_t_14, NULL); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 467; __pyx_clineno = __LINE__; goto __pyx_L11_except_error;}
          __Pyx_GOTREF(__pyx_t_12);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

          /* "fiona/ogrext.pyx":469
 *                     log.warn(
 *                         "Failed to decode %s using %s codec", val, encoding)
 *                     props[key] = val             # <<<<<<<<<<<<<<
 *             elif fieldtype in (FionaDateType, FionaTimeType, FionaDateTimeType):
 *                 retval = ograpi.OGR_F_GetFieldAsDateTime(
 */
          __pyx_t_12 = __Pyx_PyBytes_FromString(__pyx_v_val); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 469; __pyx_clineno = __LINE__; goto __pyx_L11_except_error;}
          __Pyx_GOTREF(__pyx_t_12);
          if (unlikely(PyObject_SetItem(__pyx_v_props, __pyx_v_key, __pyx_t_12) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 469; __pyx_clineno = __LINE__; goto __pyx_L11_except_error;}
          __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          goto __pyx_L10_exception_handled;
        }
        goto __pyx_L11_except_error;
        __pyx_L11_except_error:;
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        goto __pyx_L1_error;
        __pyx_L10_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_9);
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        __pyx_L16_try_end:;
      }
      goto __pyx_L8;
    }

    /* "fiona/ogrext.pyx":470
 *                         "Failed to decode %s using %s codec", val, encoding)
 *                     props[key] = val
 *             elif fieldtype in (FionaDateType, FionaTimeType, FionaDateTimeType):             # <<<<<<<<<<<<<<
 *                 retval = ograpi.OGR_F_GetFieldAsDateTime(
 *                     feature, i, &y, &m, &d, &hh, &mm, &ss, &tz)
 */
    __Pyx_INCREF(__pyx_v_fieldtype);
    __pyx_t_1 = __pyx_v_fieldtype;
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_FionaDateType); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_t_8, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (!((int)__pyx_t_5)) {
      __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_FionaTimeType); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_8 = PyObject_RichCompare(__pyx_t_1, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_15 = ((int)__pyx_t_7);
    } else {
      __pyx_t_15 = ((int)__pyx_t_5);
    }
    if (!__pyx_t_15) {
      __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_FionaDateTimeType); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_t_8, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 470; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_7 = ((int)__pyx_t_5);
    } else {
      __pyx_t_7 = __pyx_t_15;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_15 = (__pyx_t_7 != 0);
    if (__pyx_t_15) {

      /* "fiona/ogrext.pyx":471
 *                     props[key] = val
 *             elif fieldtype in (FionaDateType, FionaTimeType, FionaDateTimeType):
 *                 retval = ograpi.OGR_F_GetFieldAsDateTime(             # <<<<<<<<<<<<<<
 *                     feature, i, &y, &m, &d, &hh, &mm, &ss, &tz)
 *                 if fieldtype is FionaDateType:
 */
      __pyx_v_retval = OGR_F_GetFieldAsDateTime(__pyx_v_feature, __pyx_v_i, (&__pyx_v_y), (&__pyx_v_m), (&__pyx_v_d), (&__pyx_v_hh), (&__pyx_v_mm), (&__pyx_v_ss), (&__pyx_v_tz));

      /* "fiona/ogrext.pyx":473
 *                 retval = ograpi.OGR_F_GetFieldAsDateTime(
 *                     feature, i, &y, &m, &d, &hh, &mm, &ss, &tz)
 *                 if fieldtype is FionaDateType:             # <<<<<<<<<<<<<<
 *                     props[key] = datetime.date(y, m, d).isoformat()
 *                 elif fieldtype is FionaTimeType:
 */
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_FionaDateType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 473; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_15 = (__pyx_v_fieldtype == __pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_7 = (__pyx_t_15 != 0);
      if (__pyx_t_7) {

        /* "fiona/ogrext.pyx":474
 *                     feature, i, &y, &m, &d, &hh, &mm, &ss, &tz)
 *                 if fieldtype is FionaDateType:
 *                     props[key] = datetime.date(y, m, d).isoformat()             # <<<<<<<<<<<<<<
 *                 elif fieldtype is FionaTimeType:
 *                     props[key] = datetime.time(hh, mm, ss).isoformat()
 */
        __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_datetime); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 474; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_date); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 474; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_y); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 474; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_m); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 474; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_d); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 474; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_14 = PyTuple_New(3); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 474; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_14);
        PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_14, 2, __pyx_t_12);
        __Pyx_GIVEREF(__pyx_t_12);
        __pyx_t_1 = 0;
        __pyx_t_8 = 0;
        __pyx_t_12 = 0;
        __pyx_t_12 = PyObject_Call(__pyx_t_2, __pyx_t_14, NULL); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 474; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_isoformat); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 474; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_12 = PyObject_Call(__pyx_t_14, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 474; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(PyObject_SetItem(__pyx_v_props, __pyx_v_key, __pyx_t_12) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 474; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        goto __pyx_L19;
      }

      /* "fiona/ogrext.pyx":475
 *                 if fieldtype is FionaDateType:
 *                     props[key] = datetime.date(y, m, d).isoformat()
 *                 elif fieldtype is FionaTimeType:             # <<<<<<<<<<<<<<
 *                     props[key] = datetime.time(hh, mm, ss).isoformat()
 *                 else:
 */
      __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_FionaTimeType); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 475; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_7 = (__pyx_v_fieldtype == __pyx_t_12);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_15 = (__pyx_t_7 != 0);
      if (__pyx_t_15) {

        /* "fiona/ogrext.pyx":476
 *                     props[key] = datetime.date(y, m, d).isoformat()
 *                 elif fieldtype is FionaTimeType:
 *                     props[key] = datetime.time(hh, mm, ss).isoformat()             # <<<<<<<<<<<<<<
 *                 else:
 *                     props[key] = datetime.datetime(
 */
        __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_datetime); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 476; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_time); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 476; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_hh); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 476; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_mm); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 476; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_ss); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 476; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 476; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_12);
        __Pyx_GIVEREF(__pyx_t_12);
        PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_8);
        __pyx_t_12 = 0;
        __pyx_t_2 = 0;
        __pyx_t_8 = 0;
        __pyx_t_8 = PyObject_Call(__pyx_t_14, __pyx_t_1, NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 476; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_isoformat); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 476; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 476; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(PyObject_SetItem(__pyx_v_props, __pyx_v_key, __pyx_t_8) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 476; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L19;
      }
      /*else*/ {

        /* "fiona/ogrext.pyx":478
 *                     props[key] = datetime.time(hh, mm, ss).isoformat()
 *                 else:
 *                     props[key] = datetime.datetime(             # <<<<<<<<<<<<<<
 *                         y, m, d, hh, mm, ss).isoformat()
 *             else:
 */
        __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_datetime); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 478; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_datetime); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 478; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "fiona/ogrext.pyx":479
 *                 else:
 *                     props[key] = datetime.datetime(
 *                         y, m, d, hh, mm, ss).isoformat()             # <<<<<<<<<<<<<<
 *             else:
 *                 log.debug("%s: None, fieldtype: %r, %r" % (key, fieldtype, fieldtype in string_types))
 */
        __pyx_t_8 = __Pyx_PyInt_From_int(__pyx_v_y); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 479; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_14 = __Pyx_PyInt_From_int(__pyx_v_m); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 479; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_d); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 479; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_hh); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 479; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_13 = __Pyx_PyInt_From_int(__pyx_v_mm); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 479; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_16 = __Pyx_PyInt_From_int(__pyx_v_ss); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 479; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_16);

        /* "fiona/ogrext.pyx":478
 *                     props[key] = datetime.time(hh, mm, ss).isoformat()
 *                 else:
 *                     props[key] = datetime.datetime(             # <<<<<<<<<<<<<<
 *                         y, m, d, hh, mm, ss).isoformat()
 *             else:
 */
        __pyx_t_17 = PyTuple_New(6); if (unlikely(!__pyx_t_17)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 478; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_17);
        PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_17, 1, __pyx_t_14);
        __Pyx_GIVEREF(__pyx_t_14);
        PyTuple_SET_ITEM(__pyx_t_17, 2, __pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_17, 3, __pyx_t_12);
        __Pyx_GIVEREF(__pyx_t_12);
        PyTuple_SET_ITEM(__pyx_t_17, 4, __pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_13);
        PyTuple_SET_ITEM(__pyx_t_17, 5, __pyx_t_16);
        __Pyx_GIVEREF(__pyx_t_16);
        __pyx_t_8 = 0;
        __pyx_t_14 = 0;
        __pyx_t_2 = 0;
        __pyx_t_12 = 0;
        __pyx_t_13 = 0;
        __pyx_t_16 = 0;
        __pyx_t_16 = PyObject_Call(__pyx_t_1, __pyx_t_17, NULL); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 478; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

        /* "fiona/ogrext.pyx":479
 *                 else:
 *                     props[key] = datetime.datetime(
 *                         y, m, d, hh, mm, ss).isoformat()             # <<<<<<<<<<<<<<
 *             else:
 *                 log.debug("%s: None, fieldtype: %r, %r" % (key, fieldtype, fieldtype in string_types))
 */
        __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_isoformat); if (unlikely(!__pyx_t_17)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 479; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        __pyx_t_16 = PyObject_Call(__pyx_t_17, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 479; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

        /* "fiona/ogrext.pyx":478
 *                     props[key] = datetime.time(hh, mm, ss).isoformat()
 *                 else:
 *                     props[key] = datetime.datetime(             # <<<<<<<<<<<<<<
 *                         y, m, d, hh, mm, ss).isoformat()
 *             else:
 */
        if (unlikely(PyObject_SetItem(__pyx_v_props, __pyx_v_key, __pyx_t_16) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 478; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __pyx_L19:;
      goto __pyx_L8;
    }
    /*else*/ {

      /* "fiona/ogrext.pyx":481
 *                         y, m, d, hh, mm, ss).isoformat()
 *             else:
 *                 log.debug("%s: None, fieldtype: %r, %r" % (key, fieldtype, fieldtype in string_types))             # <<<<<<<<<<<<<<
 *                 props[key] = None
 * 
 */
      __pyx_t_16 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_debug); if (unlikely(!__pyx_t_17)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_16 = __Pyx_GetModuleGlobalName(__pyx_n_s_string_types); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_15 = (__Pyx_PySequence_Contains(__pyx_v_fieldtype, __pyx_t_16, Py_EQ)); if (unlikely(__pyx_t_15 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_16 = __Pyx_PyBool_FromLong(__pyx_t_15); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_key);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_key);
      __Pyx_GIVEREF(__pyx_v_key);
      __Pyx_INCREF(__pyx_v_fieldtype);
      PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_fieldtype);
      __Pyx_GIVEREF(__pyx_v_fieldtype);
      PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_16);
      __Pyx_GIVEREF(__pyx_t_16);
      __pyx_t_16 = 0;
      __pyx_t_16 = __Pyx_PyString_Format(__pyx_kp_s_s_None_fieldtype_r_r, __pyx_t_1); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_16);
      __Pyx_GIVEREF(__pyx_t_16);
      __pyx_t_16 = 0;
      __pyx_t_16 = PyObject_Call(__pyx_t_17, __pyx_t_1, NULL); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 481; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

      /* "fiona/ogrext.pyx":482
 *             else:
 *                 log.debug("%s: None, fieldtype: %r, %r" % (key, fieldtype, fieldtype in string_types))
 *                 props[key] = None             # <<<<<<<<<<<<<<
 * 
 *         cdef void *cogr_geometry = ograpi.OGR_F_GetGeometryRef(feature)
 */
      if (unlikely(PyObject_SetItem(__pyx_v_props, __pyx_v_key, Py_None) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 482; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L8:;
    __pyx_L3_continue:;
  }

  /* "fiona/ogrext.pyx":484
 *                 props[key] = None
 * 
 *         cdef void *cogr_geometry = ograpi.OGR_F_GetGeometryRef(feature)             # <<<<<<<<<<<<<<
 *         if cogr_geometry is not NULL:
 *             geom = GeomBuilder().build(cogr_geometry)
 */
  __pyx_v_cogr_geometry = OGR_F_GetGeometryRef(__pyx_v_feature);

  /* "fiona/ogrext.pyx":485
 * 
 *         cdef void *cogr_geometry = ograpi.OGR_F_GetGeometryRef(feature)
 *         if cogr_geometry is not NULL:             # <<<<<<<<<<<<<<
 *             geom = GeomBuilder().build(cogr_geometry)
 *         else:
 */
  __pyx_t_15 = ((__pyx_v_cogr_geometry != NULL) != 0);
  if (__pyx_t_15) {

    /* "fiona/ogrext.pyx":486
 *         cdef void *cogr_geometry = ograpi.OGR_F_GetGeometryRef(feature)
 *         if cogr_geometry is not NULL:
 *             geom = GeomBuilder().build(cogr_geometry)             # <<<<<<<<<<<<<<
 *         else:
 *             geom = None
 */
    __pyx_t_16 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5fiona_6ogrext_GeomBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 486; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_16);
    __pyx_t_1 = ((struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder *)((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_t_16)->__pyx_vtab)->build(((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)__pyx_t_16), __pyx_v_cogr_geometry); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 486; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_v_geom = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L20;
  }
  /*else*/ {

    /* "fiona/ogrext.pyx":488
 *             geom = GeomBuilder().build(cogr_geometry)
 *         else:
 *             geom = None             # <<<<<<<<<<<<<<
 *         return {
 *             'type': 'Feature',
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_geom = Py_None;
  }
  __pyx_L20:;

  /* "fiona/ogrext.pyx":489
 *         else:
 *             geom = None
 *         return {             # <<<<<<<<<<<<<<
 *             'type': 'Feature',
 *             'id': str(ograpi.OGR_F_GetFID(feature)),
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_type, __pyx_n_s_Feature) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":491
 *         return {
 *             'type': 'Feature',
 *             'id': str(ograpi.OGR_F_GetFID(feature)),             # <<<<<<<<<<<<<<
 *             'geometry': geom,
 *             'properties': props }
 */
  __pyx_t_16 = __Pyx_PyInt_From_long(OGR_F_GetFID(__pyx_v_feature)); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 491; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_16);
  __pyx_t_17 = PyTuple_New(1); if (unlikely(!__pyx_t_17)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 491; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_17);
  PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_t_16);
  __Pyx_GIVEREF(__pyx_t_16);
  __pyx_t_16 = 0;
  __pyx_t_16 = PyObject_Call(((PyObject *)((PyObject*)(&PyString_Type))), __pyx_t_17, NULL); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 491; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_16);
  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_id, __pyx_t_16) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

  /* "fiona/ogrext.pyx":492
 *             'type': 'Feature',
 *             'id': str(ograpi.OGR_F_GetFID(feature)),
 *             'geometry': geom,             # <<<<<<<<<<<<<<
 *             'properties': props }
 * 
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_geometry, __pyx_v_geom) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":493
 *             'id': str(ograpi.OGR_F_GetFID(feature)),
 *             'geometry': geom,
 *             'properties': props }             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_properties, __pyx_v_props) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":424
 *     """
 * 
 *     cdef build(self, void *feature, encoding='utf-8', bbox=False):             # <<<<<<<<<<<<<<
 *         # The only method anyone ever needs to call
 *         cdef void *fdefn
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_AddTraceback("fiona.ogrext.FeatureBuilder.build", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_props);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_fieldtypename);
  __Pyx_XDECREF(__pyx_v_fieldtype);
  __Pyx_XDECREF(__pyx_v_geom);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":504
 *     """
 * 
 *     cdef void * build(self, feature, collection) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_geometry = NULL
 *         cdef char *string_c
 */

static void *__pyx_f_5fiona_6ogrext_17OGRFeatureBuilder_build(CYTHON_UNUSED struct __pyx_obj_5fiona_6ogrext_OGRFeatureBuilder *__pyx_v_self, PyObject *__pyx_v_feature, PyObject *__pyx_v_collection) {
  void *__pyx_v_cogr_geometry;
  char *__pyx_v_string_c;
  struct __pyx_obj_5fiona_6ogrext_WritingSession *__pyx_v_session = 0;
  void *__pyx_v_cogr_layer;
  void *__pyx_v_cogr_featuredefn;
  void *__pyx_v_cogr_feature;
  PyObject *__pyx_v_encoding = NULL;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_key_bytes = NULL;
  PyObject *__pyx_v_key_c = NULL;
  int __pyx_v_i;
  PyObject *__pyx_v_value_bytes = NULL;
  PyObject *__pyx_v_y = NULL;
  PyObject *__pyx_v_m = NULL;
  PyObject *__pyx_v_d = NULL;
  PyObject *__pyx_v_hh = NULL;
  PyObject *__pyx_v_mm = NULL;
  PyObject *__pyx_v_ss = NULL;
  CYTHON_UNUSED PyObject *__pyx_v_ff = NULL;
  void *__pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  void *__pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *(*__pyx_t_11)(PyObject *);
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  char *__pyx_t_18;
  double __pyx_t_19;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  int __pyx_t_23;
  int __pyx_t_24;
  int __pyx_t_25;
  int __pyx_t_26;
  int __pyx_t_27;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("build", 0);

  /* "fiona/ogrext.pyx":505
 * 
 *     cdef void * build(self, feature, collection) except NULL:
 *         cdef void *cogr_geometry = NULL             # <<<<<<<<<<<<<<
 *         cdef char *string_c
 *         cdef WritingSession session
 */
  __pyx_v_cogr_geometry = NULL;

  /* "fiona/ogrext.pyx":508
 *         cdef char *string_c
 *         cdef WritingSession session
 *         session = collection.session             # <<<<<<<<<<<<<<
 *         cdef void *cogr_layer = session.cogr_layer
 *         if cogr_layer is NULL:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_session); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5fiona_6ogrext_WritingSession))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 508; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_session = ((struct __pyx_obj_5fiona_6ogrext_WritingSession *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":509
 *         cdef WritingSession session
 *         session = collection.session
 *         cdef void *cogr_layer = session.cogr_layer             # <<<<<<<<<<<<<<
 *         if cogr_layer is NULL:
 *             raise ValueError("Null layer")
 */
  __pyx_t_2 = __pyx_v_session->__pyx_base.cogr_layer;
  __pyx_v_cogr_layer = __pyx_t_2;

  /* "fiona/ogrext.pyx":510
 *         session = collection.session
 *         cdef void *cogr_layer = session.cogr_layer
 *         if cogr_layer is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null layer")
 *         cdef void *cogr_featuredefn = ograpi.OGR_L_GetLayerDefn(cogr_layer)
 */
  __pyx_t_3 = ((__pyx_v_cogr_layer == NULL) != 0);
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":511
 *         cdef void *cogr_layer = session.cogr_layer
 *         if cogr_layer is NULL:
 *             raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 *         cdef void *cogr_featuredefn = ograpi.OGR_L_GetLayerDefn(cogr_layer)
 *         if cogr_featuredefn is NULL:
 */
    __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 511; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 511; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":512
 *         if cogr_layer is NULL:
 *             raise ValueError("Null layer")
 *         cdef void *cogr_featuredefn = ograpi.OGR_L_GetLayerDefn(cogr_layer)             # <<<<<<<<<<<<<<
 *         if cogr_featuredefn is NULL:
 *             raise ValueError("Null feature definition")
 */
  __pyx_v_cogr_featuredefn = OGR_L_GetLayerDefn(__pyx_v_cogr_layer);

  /* "fiona/ogrext.pyx":513
 *             raise ValueError("Null layer")
 *         cdef void *cogr_featuredefn = ograpi.OGR_L_GetLayerDefn(cogr_layer)
 *         if cogr_featuredefn is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null feature definition")
 *         cdef void *cogr_feature = ograpi.OGR_F_Create(cogr_featuredefn)
 */
  __pyx_t_3 = ((__pyx_v_cogr_featuredefn == NULL) != 0);
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":514
 *         cdef void *cogr_featuredefn = ograpi.OGR_L_GetLayerDefn(cogr_layer)
 *         if cogr_featuredefn is NULL:
 *             raise ValueError("Null feature definition")             # <<<<<<<<<<<<<<
 *         cdef void *cogr_feature = ograpi.OGR_F_Create(cogr_featuredefn)
 *         if cogr_feature is NULL:
 */
    __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__14, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 514; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 514; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":515
 *         if cogr_featuredefn is NULL:
 *             raise ValueError("Null feature definition")
 *         cdef void *cogr_feature = ograpi.OGR_F_Create(cogr_featuredefn)             # <<<<<<<<<<<<<<
 *         if cogr_feature is NULL:
 *             raise ValueError("Null feature")
 */
  __pyx_v_cogr_feature = OGR_F_Create(__pyx_v_cogr_featuredefn);

  /* "fiona/ogrext.pyx":516
 *             raise ValueError("Null feature definition")
 *         cdef void *cogr_feature = ograpi.OGR_F_Create(cogr_featuredefn)
 *         if cogr_feature is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null feature")
 * 
 */
  __pyx_t_3 = ((__pyx_v_cogr_feature == NULL) != 0);
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":517
 *         cdef void *cogr_feature = ograpi.OGR_F_Create(cogr_featuredefn)
 *         if cogr_feature is NULL:
 *             raise ValueError("Null feature")             # <<<<<<<<<<<<<<
 * 
 *         if feature['geometry'] is not None:
 */
    __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 517; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 517; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":519
 *             raise ValueError("Null feature")
 * 
 *         if feature['geometry'] is not None:             # <<<<<<<<<<<<<<
 *             cogr_geometry = OGRGeomBuilder().build(feature['geometry'])
 *         ograpi.OGR_F_SetGeometryDirectly(cogr_feature, cogr_geometry)
 */
  __pyx_t_1 = PyObject_GetItem(__pyx_v_feature, __pyx_n_s_geometry); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 519; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = (__pyx_t_1 != Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = (__pyx_t_3 != 0);
  if (__pyx_t_4) {

    /* "fiona/ogrext.pyx":520
 * 
 *         if feature['geometry'] is not None:
 *             cogr_geometry = OGRGeomBuilder().build(feature['geometry'])             # <<<<<<<<<<<<<<
 *         ograpi.OGR_F_SetGeometryDirectly(cogr_feature, cogr_geometry)
 * 
 */
    __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5fiona_6ogrext_OGRGeomBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 520; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = PyObject_GetItem(__pyx_v_feature, __pyx_n_s_geometry); if (unlikely(__pyx_t_5 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 520; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder *)((struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)__pyx_t_1)->__pyx_vtab)->build(((struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)__pyx_t_1), __pyx_t_5); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 520; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_cogr_geometry = __pyx_t_2;
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "fiona/ogrext.pyx":521
 *         if feature['geometry'] is not None:
 *             cogr_geometry = OGRGeomBuilder().build(feature['geometry'])
 *         ograpi.OGR_F_SetGeometryDirectly(cogr_feature, cogr_geometry)             # <<<<<<<<<<<<<<
 * 
 *         # OGR_F_SetFieldString takes UTF-8 encoded strings ('bytes' in
 */
  OGR_F_SetGeometryDirectly(__pyx_v_cogr_feature, __pyx_v_cogr_geometry);

  /* "fiona/ogrext.pyx":525
 *         # OGR_F_SetFieldString takes UTF-8 encoded strings ('bytes' in
 *         # Python 3).
 *         encoding = session.get_internalencoding()             # <<<<<<<<<<<<<<
 * 
 *         for key, value in feature['properties'].items():
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_session), __pyx_n_s_get_internalencoding); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 525; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyObject_Call(__pyx_t_5, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 525; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_encoding = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":527
 *         encoding = session.get_internalencoding()
 * 
 *         for key, value in feature['properties'].items():             # <<<<<<<<<<<<<<
 *             try:
 *                 log.debug(
 */
  __pyx_t_1 = PyObject_GetItem(__pyx_v_feature, __pyx_n_s_properties); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_items); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_5, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyList_CheckExact(__pyx_t_1) || PyTuple_CheckExact(__pyx_t_1)) {
    __pyx_t_5 = __pyx_t_1; __Pyx_INCREF(__pyx_t_5); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = Py_TYPE(__pyx_t_5)->tp_iternext;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  for (;;) {
    if (!__pyx_t_7 && PyList_CheckExact(__pyx_t_5)) {
      if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_5)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_1 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_1 = PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_7 && PyTuple_CheckExact(__pyx_t_5)) {
      if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_1); __pyx_t_6++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_1 = PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_1 = __pyx_t_7(__pyx_t_5);
      if (unlikely(!__pyx_t_1)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_1);
    }
    if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
      PyObject* sequence = __pyx_t_1;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      if (likely(PyTuple_CheckExact(sequence))) {
        __pyx_t_8 = PyTuple_GET_ITEM(sequence, 0); 
        __pyx_t_9 = PyTuple_GET_ITEM(sequence, 1); 
      } else {
        __pyx_t_8 = PyList_GET_ITEM(sequence, 0); 
        __pyx_t_9 = PyList_GET_ITEM(sequence, 1); 
      }
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_9);
      #else
      __pyx_t_8 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_9);
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else {
      Py_ssize_t index = -1;
      __pyx_t_10 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_11 = Py_TYPE(__pyx_t_10)->tp_iternext;
      index = 0; __pyx_t_8 = __pyx_t_11(__pyx_t_10); if (unlikely(!__pyx_t_8)) goto __pyx_L9_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_8);
      index = 1; __pyx_t_9 = __pyx_t_11(__pyx_t_10); if (unlikely(!__pyx_t_9)) goto __pyx_L9_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_9);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_10), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_11 = NULL;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L10_unpacking_done;
      __pyx_L9_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_11 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L10_unpacking_done:;
    }
    __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_9);
    __pyx_t_9 = 0;

    /* "fiona/ogrext.pyx":528
 * 
 *         for key, value in feature['properties'].items():
 *             try:             # <<<<<<<<<<<<<<
 *                 log.debug(
 *                     "Looking up %s in %s", key, repr(session._schema_mapping))
 */
    {
      __Pyx_ExceptionSave(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_12);
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      /*try:*/ {

        /* "fiona/ogrext.pyx":529
 *         for key, value in feature['properties'].items():
 *             try:
 *                 log.debug(             # <<<<<<<<<<<<<<
 *                     "Looking up %s in %s", key, repr(session._schema_mapping))
 *                 key_bytes = session._schema_mapping[key].encode(encoding)
 */
        __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 529; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_debug); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 529; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "fiona/ogrext.pyx":530
 *             try:
 *                 log.debug(
 *                     "Looking up %s in %s", key, repr(session._schema_mapping))             # <<<<<<<<<<<<<<
 *                 key_bytes = session._schema_mapping[key].encode(encoding)
 *             except UnicodeDecodeError:
 */
        __pyx_t_1 = __pyx_v_session->_schema_mapping;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_8 = PyObject_Repr(__pyx_t_1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 530; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "fiona/ogrext.pyx":529
 *         for key, value in feature['properties'].items():
 *             try:
 *                 log.debug(             # <<<<<<<<<<<<<<
 *                     "Looking up %s in %s", key, repr(session._schema_mapping))
 *                 key_bytes = session._schema_mapping[key].encode(encoding)
 */
        __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 529; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(__pyx_kp_s_Looking_up_s_in_s);
        PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_s_Looking_up_s_in_s);
        __Pyx_GIVEREF(__pyx_kp_s_Looking_up_s_in_s);
        __Pyx_INCREF(__pyx_v_key);
        PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_key);
        __Pyx_GIVEREF(__pyx_v_key);
        PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_8 = PyObject_Call(__pyx_t_9, __pyx_t_1, NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 529; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "fiona/ogrext.pyx":531
 *                 log.debug(
 *                     "Looking up %s in %s", key, repr(session._schema_mapping))
 *                 key_bytes = session._schema_mapping[key].encode(encoding)             # <<<<<<<<<<<<<<
 *             except UnicodeDecodeError:
 *                 log.warn("Failed to encode %s using %s codec", key, encoding)
 */
        __pyx_t_8 = PyObject_GetItem(__pyx_v_session->_schema_mapping, __pyx_v_key); if (unlikely(__pyx_t_8 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 531; __pyx_clineno = __LINE__; goto __pyx_L11_error;};
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_encode); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 531; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 531; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_v_encoding);
        PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_encoding);
        __Pyx_GIVEREF(__pyx_v_encoding);
        __pyx_t_9 = PyObject_Call(__pyx_t_1, __pyx_t_8, NULL); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 531; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_v_key_bytes, __pyx_t_9);
        __pyx_t_9 = 0;
      }
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      goto __pyx_L18_try_end;
      __pyx_L11_error:;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "fiona/ogrext.pyx":532
 *                     "Looking up %s in %s", key, repr(session._schema_mapping))
 *                 key_bytes = session._schema_mapping[key].encode(encoding)
 *             except UnicodeDecodeError:             # <<<<<<<<<<<<<<
 *                 log.warn("Failed to encode %s using %s codec", key, encoding)
 *                 key_bytes = key
 */
      __pyx_t_15 = PyErr_ExceptionMatches(__pyx_builtin_UnicodeDecodeError);
      if (__pyx_t_15) {
        __Pyx_AddTraceback("fiona.ogrext.OGRFeatureBuilder.build", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_8, &__pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 532; __pyx_clineno = __LINE__; goto __pyx_L13_except_error;}
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GOTREF(__pyx_t_1);

        /* "fiona/ogrext.pyx":533
 *                 key_bytes = session._schema_mapping[key].encode(encoding)
 *             except UnicodeDecodeError:
 *                 log.warn("Failed to encode %s using %s codec", key, encoding)             # <<<<<<<<<<<<<<
 *                 key_bytes = key
 *             key_c = key_bytes
 */
        __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 533; __pyx_clineno = __LINE__; goto __pyx_L13_except_error;}
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_warn); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 533; __pyx_clineno = __LINE__; goto __pyx_L13_except_error;}
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = PyTuple_New(3); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 533; __pyx_clineno = __LINE__; goto __pyx_L13_except_error;}
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_INCREF(__pyx_kp_s_Failed_to_encode_s_using_s_codec);
        PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_kp_s_Failed_to_encode_s_using_s_codec);
        __Pyx_GIVEREF(__pyx_kp_s_Failed_to_encode_s_using_s_codec);
        __Pyx_INCREF(__pyx_v_key);
        PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_v_key);
        __Pyx_GIVEREF(__pyx_v_key);
        __Pyx_INCREF(__pyx_v_encoding);
        PyTuple_SET_ITEM(__pyx_t_10, 2, __pyx_v_encoding);
        __Pyx_GIVEREF(__pyx_v_encoding);
        __pyx_t_17 = PyObject_Call(__pyx_t_16, __pyx_t_10, NULL); if (unlikely(!__pyx_t_17)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 533; __pyx_clineno = __LINE__; goto __pyx_L13_except_error;}
        __Pyx_GOTREF(__pyx_t_17);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

        /* "fiona/ogrext.pyx":534
 *             except UnicodeDecodeError:
 *                 log.warn("Failed to encode %s using %s codec", key, encoding)
 *                 key_bytes = key             # <<<<<<<<<<<<<<
 *             key_c = key_bytes
 *             i = ograpi.OGR_F_GetFieldIndex(cogr_feature, key_c)
 */
        __Pyx_INCREF(__pyx_v_key);
        __Pyx_XDECREF_SET(__pyx_v_key_bytes, __pyx_v_key);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L12_exception_handled;
      }
      goto __pyx_L13_except_error;
      __pyx_L13_except_error:;
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      goto __pyx_L1_error;
      __pyx_L12_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_12);
      __Pyx_XGIVEREF(__pyx_t_13);
      __Pyx_XGIVEREF(__pyx_t_14);
      __Pyx_ExceptionReset(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      __pyx_L18_try_end:;
    }

    /* "fiona/ogrext.pyx":535
 *                 log.warn("Failed to encode %s using %s codec", key, encoding)
 *                 key_bytes = key
 *             key_c = key_bytes             # <<<<<<<<<<<<<<
 *             i = ograpi.OGR_F_GetFieldIndex(cogr_feature, key_c)
 *             if i < 0:
 */
    __Pyx_INCREF(__pyx_v_key_bytes);
    __Pyx_XDECREF_SET(__pyx_v_key_c, __pyx_v_key_bytes);

    /* "fiona/ogrext.pyx":536
 *                 key_bytes = key
 *             key_c = key_bytes
 *             i = ograpi.OGR_F_GetFieldIndex(cogr_feature, key_c)             # <<<<<<<<<<<<<<
 *             if i < 0:
 *                 continue
 */
    __pyx_t_18 = __Pyx_PyObject_AsString(__pyx_v_key_c); if (unlikely((!__pyx_t_18) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 536; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_i = OGR_F_GetFieldIndex(__pyx_v_cogr_feature, __pyx_t_18);

    /* "fiona/ogrext.pyx":537
 *             key_c = key_bytes
 *             i = ograpi.OGR_F_GetFieldIndex(cogr_feature, key_c)
 *             if i < 0:             # <<<<<<<<<<<<<<
 *                 continue
 *             if isinstance(value, integer_types):
 */
    __pyx_t_4 = ((__pyx_v_i < 0) != 0);
    if (__pyx_t_4) {

      /* "fiona/ogrext.pyx":538
 *             i = ograpi.OGR_F_GetFieldIndex(cogr_feature, key_c)
 *             if i < 0:
 *                 continue             # <<<<<<<<<<<<<<
 *             if isinstance(value, integer_types):
 *                 ograpi.OGR_F_SetFieldInteger(cogr_feature, i, value)
 */
      goto __pyx_L7_continue;
    }

    /* "fiona/ogrext.pyx":539
 *             if i < 0:
 *                 continue
 *             if isinstance(value, integer_types):             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_F_SetFieldInteger(cogr_feature, i, value)
 *             elif isinstance(value, float):
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_integer_types); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 539; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyObject_IsInstance(__pyx_v_value, __pyx_t_1); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 539; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = (__pyx_t_4 != 0);
    if (__pyx_t_3) {

      /* "fiona/ogrext.pyx":540
 *                 continue
 *             if isinstance(value, integer_types):
 *                 ograpi.OGR_F_SetFieldInteger(cogr_feature, i, value)             # <<<<<<<<<<<<<<
 *             elif isinstance(value, float):
 *                 ograpi.OGR_F_SetFieldDouble(cogr_feature, i, value)
 */
      __pyx_t_15 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_15 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 540; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      OGR_F_SetFieldInteger(__pyx_v_cogr_feature, __pyx_v_i, __pyx_t_15);
      goto __pyx_L22;
    }

    /* "fiona/ogrext.pyx":541
 *             if isinstance(value, integer_types):
 *                 ograpi.OGR_F_SetFieldInteger(cogr_feature, i, value)
 *             elif isinstance(value, float):             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_F_SetFieldDouble(cogr_feature, i, value)
 *             elif isinstance(value, string_types):
 */
    __pyx_t_3 = PyFloat_Check(__pyx_v_value); 
    __pyx_t_4 = (__pyx_t_3 != 0);
    if (__pyx_t_4) {

      /* "fiona/ogrext.pyx":542
 *                 ograpi.OGR_F_SetFieldInteger(cogr_feature, i, value)
 *             elif isinstance(value, float):
 *                 ograpi.OGR_F_SetFieldDouble(cogr_feature, i, value)             # <<<<<<<<<<<<<<
 *             elif isinstance(value, string_types):
 *                 try:
 */
      __pyx_t_19 = __pyx_PyFloat_AsDouble(__pyx_v_value); if (unlikely((__pyx_t_19 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 542; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      OGR_F_SetFieldDouble(__pyx_v_cogr_feature, __pyx_v_i, __pyx_t_19);
      goto __pyx_L22;
    }

    /* "fiona/ogrext.pyx":543
 *             elif isinstance(value, float):
 *                 ograpi.OGR_F_SetFieldDouble(cogr_feature, i, value)
 *             elif isinstance(value, string_types):             # <<<<<<<<<<<<<<
 *                 try:
 *                     value_bytes = value.encode(encoding)
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_string_types); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 543; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyObject_IsInstance(__pyx_v_value, __pyx_t_1); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 543; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = (__pyx_t_4 != 0);
    if (__pyx_t_3) {

      /* "fiona/ogrext.pyx":544
 *                 ograpi.OGR_F_SetFieldDouble(cogr_feature, i, value)
 *             elif isinstance(value, string_types):
 *                 try:             # <<<<<<<<<<<<<<
 *                     value_bytes = value.encode(encoding)
 *                 except UnicodeDecodeError:
 */
      {
        __Pyx_ExceptionSave(&__pyx_t_14, &__pyx_t_13, &__pyx_t_12);
        __Pyx_XGOTREF(__pyx_t_14);
        __Pyx_XGOTREF(__pyx_t_13);
        __Pyx_XGOTREF(__pyx_t_12);
        /*try:*/ {

          /* "fiona/ogrext.pyx":545
 *             elif isinstance(value, string_types):
 *                 try:
 *                     value_bytes = value.encode(encoding)             # <<<<<<<<<<<<<<
 *                 except UnicodeDecodeError:
 *                     log.warn(
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_n_s_encode); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 545; __pyx_clineno = __LINE__; goto __pyx_L23_error;}
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 545; __pyx_clineno = __LINE__; goto __pyx_L23_error;}
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_INCREF(__pyx_v_encoding);
          PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_encoding);
          __Pyx_GIVEREF(__pyx_v_encoding);
          __pyx_t_9 = PyObject_Call(__pyx_t_1, __pyx_t_8, NULL); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 545; __pyx_clineno = __LINE__; goto __pyx_L23_error;}
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF_SET(__pyx_v_value_bytes, __pyx_t_9);
          __pyx_t_9 = 0;
        }
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        goto __pyx_L30_try_end;
        __pyx_L23_error:;
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

        /* "fiona/ogrext.pyx":546
 *                 try:
 *                     value_bytes = value.encode(encoding)
 *                 except UnicodeDecodeError:             # <<<<<<<<<<<<<<
 *                     log.warn(
 *                         "Failed to encode %s using %s codec", value, encoding)
 */
        __pyx_t_15 = PyErr_ExceptionMatches(__pyx_builtin_UnicodeDecodeError);
        if (__pyx_t_15) {
          __Pyx_AddTraceback("fiona.ogrext.OGRFeatureBuilder.build", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_8, &__pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 546; __pyx_clineno = __LINE__; goto __pyx_L25_except_error;}
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GOTREF(__pyx_t_1);

          /* "fiona/ogrext.pyx":547
 *                     value_bytes = value.encode(encoding)
 *                 except UnicodeDecodeError:
 *                     log.warn(             # <<<<<<<<<<<<<<
 *                         "Failed to encode %s using %s codec", value, encoding)
 *                     value_bytes = value
 */
          __pyx_t_17 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_17)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L25_except_error;}
          __Pyx_GOTREF(__pyx_t_17);
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_17, __pyx_n_s_warn); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L25_except_error;}
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;

          /* "fiona/ogrext.pyx":548
 *                 except UnicodeDecodeError:
 *                     log.warn(
 *                         "Failed to encode %s using %s codec", value, encoding)             # <<<<<<<<<<<<<<
 *                     value_bytes = value
 *                 string_c = value_bytes
 */
          __pyx_t_17 = PyTuple_New(3); if (unlikely(!__pyx_t_17)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L25_except_error;}
          __Pyx_GOTREF(__pyx_t_17);
          __Pyx_INCREF(__pyx_kp_s_Failed_to_encode_s_using_s_codec);
          PyTuple_SET_ITEM(__pyx_t_17, 0, __pyx_kp_s_Failed_to_encode_s_using_s_codec);
          __Pyx_GIVEREF(__pyx_kp_s_Failed_to_encode_s_using_s_codec);
          __Pyx_INCREF(__pyx_v_value);
          PyTuple_SET_ITEM(__pyx_t_17, 1, __pyx_v_value);
          __Pyx_GIVEREF(__pyx_v_value);
          __Pyx_INCREF(__pyx_v_encoding);
          PyTuple_SET_ITEM(__pyx_t_17, 2, __pyx_v_encoding);
          __Pyx_GIVEREF(__pyx_v_encoding);

          /* "fiona/ogrext.pyx":547
 *                     value_bytes = value.encode(encoding)
 *                 except UnicodeDecodeError:
 *                     log.warn(             # <<<<<<<<<<<<<<
 *                         "Failed to encode %s using %s codec", value, encoding)
 *                     value_bytes = value
 */
          __pyx_t_16 = PyObject_Call(__pyx_t_10, __pyx_t_17, NULL); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 547; __pyx_clineno = __LINE__; goto __pyx_L25_except_error;}
          __Pyx_GOTREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;

          /* "fiona/ogrext.pyx":549
 *                     log.warn(
 *                         "Failed to encode %s using %s codec", value, encoding)
 *                     value_bytes = value             # <<<<<<<<<<<<<<
 *                 string_c = value_bytes
 *                 ograpi.OGR_F_SetFieldString(cogr_feature, i, string_c)
 */
          __Pyx_INCREF(__pyx_v_value);
          __Pyx_XDECREF_SET(__pyx_v_value_bytes, __pyx_v_value);
          __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          goto __pyx_L24_exception_handled;
        }
        goto __pyx_L25_except_error;
        __pyx_L25_except_error:;
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_13, __pyx_t_12);
        goto __pyx_L1_error;
        __pyx_L24_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_14);
        __Pyx_XGIVEREF(__pyx_t_13);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_14, __pyx_t_13, __pyx_t_12);
        __pyx_L30_try_end:;
      }

      /* "fiona/ogrext.pyx":550
 *                         "Failed to encode %s using %s codec", value, encoding)
 *                     value_bytes = value
 *                 string_c = value_bytes             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_F_SetFieldString(cogr_feature, i, string_c)
 *             elif isinstance(value, (FionaDateType, FionaTimeType, FionaDateTimeType)):
 */
      __pyx_t_18 = __Pyx_PyObject_AsString(__pyx_v_value_bytes); if (unlikely((!__pyx_t_18) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 550; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_string_c = __pyx_t_18;

      /* "fiona/ogrext.pyx":551
 *                     value_bytes = value
 *                 string_c = value_bytes
 *                 ograpi.OGR_F_SetFieldString(cogr_feature, i, string_c)             # <<<<<<<<<<<<<<
 *             elif isinstance(value, (FionaDateType, FionaTimeType, FionaDateTimeType)):
 *                 if isinstance(value, FionaDateType):
 */
      OGR_F_SetFieldString(__pyx_v_cogr_feature, __pyx_v_i, __pyx_v_string_c);
      goto __pyx_L22;
    }

    /* "fiona/ogrext.pyx":552
 *                 string_c = value_bytes
 *                 ograpi.OGR_F_SetFieldString(cogr_feature, i, string_c)
 *             elif isinstance(value, (FionaDateType, FionaTimeType, FionaDateTimeType)):             # <<<<<<<<<<<<<<
 *                 if isinstance(value, FionaDateType):
 *                     y, m, d, hh, mm, ss, ff = parse_date(value)
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_FionaDateType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 552; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_FionaTimeType); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 552; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_GetModuleGlobalName(__pyx_n_s_FionaDateTimeType); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 552; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_16 = PyTuple_New(3); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 552; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_16);
    PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_16, 1, __pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_16, 2, __pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_9);
    __pyx_t_1 = 0;
    __pyx_t_8 = 0;
    __pyx_t_9 = 0;
    __pyx_t_3 = PyObject_IsInstance(__pyx_v_value, __pyx_t_16); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 552; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_4 = (__pyx_t_3 != 0);
    if (__pyx_t_4) {

      /* "fiona/ogrext.pyx":553
 *                 ograpi.OGR_F_SetFieldString(cogr_feature, i, string_c)
 *             elif isinstance(value, (FionaDateType, FionaTimeType, FionaDateTimeType)):
 *                 if isinstance(value, FionaDateType):             # <<<<<<<<<<<<<<
 *                     y, m, d, hh, mm, ss, ff = parse_date(value)
 *                 elif isinstance(value, FionaTimeType):
 */
      __pyx_t_16 = __Pyx_GetModuleGlobalName(__pyx_n_s_FionaDateType); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_4 = PyObject_IsInstance(__pyx_v_value, __pyx_t_16); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_3 = (__pyx_t_4 != 0);
      if (__pyx_t_3) {

        /* "fiona/ogrext.pyx":554
 *             elif isinstance(value, (FionaDateType, FionaTimeType, FionaDateTimeType)):
 *                 if isinstance(value, FionaDateType):
 *                     y, m, d, hh, mm, ss, ff = parse_date(value)             # <<<<<<<<<<<<<<
 *                 elif isinstance(value, FionaTimeType):
 *                     y, m, d, hh, mm, ss, ff = parse_time(value)
 */
        __pyx_t_16 = __Pyx_GetModuleGlobalName(__pyx_n_s_parse_date); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 554; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 554; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_INCREF(__pyx_v_value);
        PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_value);
        __Pyx_GIVEREF(__pyx_v_value);
        __pyx_t_8 = PyObject_Call(__pyx_t_16, __pyx_t_9, NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 554; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if ((likely(PyTuple_CheckExact(__pyx_t_8))) || (PyList_CheckExact(__pyx_t_8))) {
          PyObject* sequence = __pyx_t_8;
          #if CYTHON_COMPILING_IN_CPYTHON
          Py_ssize_t size = Py_SIZE(sequence);
          #else
          Py_ssize_t size = PySequence_Size(sequence);
          #endif
          if (unlikely(size != 7)) {
            if (size > 7) __Pyx_RaiseTooManyValuesError(7);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            {__pyx_filename = __pyx_f[0]; __pyx_lineno = 554; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          #if CYTHON_COMPILING_IN_CPYTHON
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_16 = PyTuple_GET_ITEM(sequence, 1); 
            __pyx_t_1 = PyTuple_GET_ITEM(sequence, 2); 
            __pyx_t_17 = PyTuple_GET_ITEM(sequence, 3); 
            __pyx_t_10 = PyTuple_GET_ITEM(sequence, 4); 
            __pyx_t_20 = PyTuple_GET_ITEM(sequence, 5); 
            __pyx_t_21 = PyTuple_GET_ITEM(sequence, 6); 
          } else {
            __pyx_t_9 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_16 = PyList_GET_ITEM(sequence, 1); 
            __pyx_t_1 = PyList_GET_ITEM(sequence, 2); 
            __pyx_t_17 = PyList_GET_ITEM(sequence, 3); 
            __pyx_t_10 = PyList_GET_ITEM(sequence, 4); 
            __pyx_t_20 = PyList_GET_ITEM(sequence, 5); 
            __pyx_t_21 = PyList_GET_ITEM(sequence, 6); 
          }
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_16);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_17);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_20);
          __Pyx_INCREF(__pyx_t_21);
          #else
          {
            Py_ssize_t i;
            PyObject** temps[7] = {&__pyx_t_9,&__pyx_t_16,&__pyx_t_1,&__pyx_t_17,&__pyx_t_10,&__pyx_t_20,&__pyx_t_21};
            for (i=0; i < 7; i++) {
              PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 554; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(item);
              *(temps[i]) = item;
            }
          }
          #endif
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        } else {
          Py_ssize_t index = -1;
          PyObject** temps[7] = {&__pyx_t_9,&__pyx_t_16,&__pyx_t_1,&__pyx_t_17,&__pyx_t_10,&__pyx_t_20,&__pyx_t_21};
          __pyx_t_22 = PyObject_GetIter(__pyx_t_8); if (unlikely(!__pyx_t_22)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 554; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_22);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_11 = Py_TYPE(__pyx_t_22)->tp_iternext;
          for (index=0; index < 7; index++) {
            PyObject* item = __pyx_t_11(__pyx_t_22); if (unlikely(!item)) goto __pyx_L34_unpacking_failed;
            __Pyx_GOTREF(item);
            *(temps[index]) = item;
          }
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_22), 7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 554; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_11 = NULL;
          __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
          goto __pyx_L35_unpacking_done;
          __pyx_L34_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
          __pyx_t_11 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 554; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_L35_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_y, __pyx_t_9);
        __pyx_t_9 = 0;
        __Pyx_XDECREF_SET(__pyx_v_m, __pyx_t_16);
        __pyx_t_16 = 0;
        __Pyx_XDECREF_SET(__pyx_v_d, __pyx_t_1);
        __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_hh, __pyx_t_17);
        __pyx_t_17 = 0;
        __Pyx_XDECREF_SET(__pyx_v_mm, __pyx_t_10);
        __pyx_t_10 = 0;
        __Pyx_XDECREF_SET(__pyx_v_ss, __pyx_t_20);
        __pyx_t_20 = 0;
        __Pyx_XDECREF_SET(__pyx_v_ff, __pyx_t_21);
        __pyx_t_21 = 0;
        goto __pyx_L33;
      }

      /* "fiona/ogrext.pyx":555
 *                 if isinstance(value, FionaDateType):
 *                     y, m, d, hh, mm, ss, ff = parse_date(value)
 *                 elif isinstance(value, FionaTimeType):             # <<<<<<<<<<<<<<
 *                     y, m, d, hh, mm, ss, ff = parse_time(value)
 *                 else:
 */
      __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_FionaTimeType); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 555; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_3 = PyObject_IsInstance(__pyx_v_value, __pyx_t_8); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 555; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_4 = (__pyx_t_3 != 0);
      if (__pyx_t_4) {

        /* "fiona/ogrext.pyx":556
 *                     y, m, d, hh, mm, ss, ff = parse_date(value)
 *                 elif isinstance(value, FionaTimeType):
 *                     y, m, d, hh, mm, ss, ff = parse_time(value)             # <<<<<<<<<<<<<<
 *                 else:
 *                     y, m, d, hh, mm, ss, ff = parse_datetime(value)
 */
        __pyx_t_8 = __Pyx_GetModuleGlobalName(__pyx_n_s_parse_time); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 556; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_21 = PyTuple_New(1); if (unlikely(!__pyx_t_21)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 556; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_21);
        __Pyx_INCREF(__pyx_v_value);
        PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_v_value);
        __Pyx_GIVEREF(__pyx_v_value);
        __pyx_t_20 = PyObject_Call(__pyx_t_8, __pyx_t_21, NULL); if (unlikely(!__pyx_t_20)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 556; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_20);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
        if ((likely(PyTuple_CheckExact(__pyx_t_20))) || (PyList_CheckExact(__pyx_t_20))) {
          PyObject* sequence = __pyx_t_20;
          #if CYTHON_COMPILING_IN_CPYTHON
          Py_ssize_t size = Py_SIZE(sequence);
          #else
          Py_ssize_t size = PySequence_Size(sequence);
          #endif
          if (unlikely(size != 7)) {
            if (size > 7) __Pyx_RaiseTooManyValuesError(7);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            {__pyx_filename = __pyx_f[0]; __pyx_lineno = 556; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          #if CYTHON_COMPILING_IN_CPYTHON
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_21 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_8 = PyTuple_GET_ITEM(sequence, 1); 
            __pyx_t_10 = PyTuple_GET_ITEM(sequence, 2); 
            __pyx_t_17 = PyTuple_GET_ITEM(sequence, 3); 
            __pyx_t_1 = PyTuple_GET_ITEM(sequence, 4); 
            __pyx_t_16 = PyTuple_GET_ITEM(sequence, 5); 
            __pyx_t_9 = PyTuple_GET_ITEM(sequence, 6); 
          } else {
            __pyx_t_21 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_8 = PyList_GET_ITEM(sequence, 1); 
            __pyx_t_10 = PyList_GET_ITEM(sequence, 2); 
            __pyx_t_17 = PyList_GET_ITEM(sequence, 3); 
            __pyx_t_1 = PyList_GET_ITEM(sequence, 4); 
            __pyx_t_16 = PyList_GET_ITEM(sequence, 5); 
            __pyx_t_9 = PyList_GET_ITEM(sequence, 6); 
          }
          __Pyx_INCREF(__pyx_t_21);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_17);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_16);
          __Pyx_INCREF(__pyx_t_9);
          #else
          {
            Py_ssize_t i;
            PyObject** temps[7] = {&__pyx_t_21,&__pyx_t_8,&__pyx_t_10,&__pyx_t_17,&__pyx_t_1,&__pyx_t_16,&__pyx_t_9};
            for (i=0; i < 7; i++) {
              PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 556; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(item);
              *(temps[i]) = item;
            }
          }
          #endif
          __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
        } else {
          Py_ssize_t index = -1;
          PyObject** temps[7] = {&__pyx_t_21,&__pyx_t_8,&__pyx_t_10,&__pyx_t_17,&__pyx_t_1,&__pyx_t_16,&__pyx_t_9};
          __pyx_t_22 = PyObject_GetIter(__pyx_t_20); if (unlikely(!__pyx_t_22)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 556; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_22);
          __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
          __pyx_t_11 = Py_TYPE(__pyx_t_22)->tp_iternext;
          for (index=0; index < 7; index++) {
            PyObject* item = __pyx_t_11(__pyx_t_22); if (unlikely(!item)) goto __pyx_L36_unpacking_failed;
            __Pyx_GOTREF(item);
            *(temps[index]) = item;
          }
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_22), 7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 556; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_11 = NULL;
          __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
          goto __pyx_L37_unpacking_done;
          __pyx_L36_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
          __pyx_t_11 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 556; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_L37_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_y, __pyx_t_21);
        __pyx_t_21 = 0;
        __Pyx_XDECREF_SET(__pyx_v_m, __pyx_t_8);
        __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_v_d, __pyx_t_10);
        __pyx_t_10 = 0;
        __Pyx_XDECREF_SET(__pyx_v_hh, __pyx_t_17);
        __pyx_t_17 = 0;
        __Pyx_XDECREF_SET(__pyx_v_mm, __pyx_t_1);
        __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_ss, __pyx_t_16);
        __pyx_t_16 = 0;
        __Pyx_XDECREF_SET(__pyx_v_ff, __pyx_t_9);
        __pyx_t_9 = 0;
        goto __pyx_L33;
      }
      /*else*/ {

        /* "fiona/ogrext.pyx":558
 *                     y, m, d, hh, mm, ss, ff = parse_time(value)
 *                 else:
 *                     y, m, d, hh, mm, ss, ff = parse_datetime(value)             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_F_SetFieldDateTime(
 *                     cogr_feature, i, y, m, d, hh, mm, ss, 0)
 */
        __pyx_t_20 = __Pyx_GetModuleGlobalName(__pyx_n_s_parse_datetime); if (unlikely(!__pyx_t_20)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 558; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_20);
        __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 558; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_INCREF(__pyx_v_value);
        PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_value);
        __Pyx_GIVEREF(__pyx_v_value);
        __pyx_t_16 = PyObject_Call(__pyx_t_20, __pyx_t_9, NULL); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 558; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_16);
        __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if ((likely(PyTuple_CheckExact(__pyx_t_16))) || (PyList_CheckExact(__pyx_t_16))) {
          PyObject* sequence = __pyx_t_16;
          #if CYTHON_COMPILING_IN_CPYTHON
          Py_ssize_t size = Py_SIZE(sequence);
          #else
          Py_ssize_t size = PySequence_Size(sequence);
          #endif
          if (unlikely(size != 7)) {
            if (size > 7) __Pyx_RaiseTooManyValuesError(7);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            {__pyx_filename = __pyx_f[0]; __pyx_lineno = 558; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          #if CYTHON_COMPILING_IN_CPYTHON
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_9 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_20 = PyTuple_GET_ITEM(sequence, 1); 
            __pyx_t_1 = PyTuple_GET_ITEM(sequence, 2); 
            __pyx_t_17 = PyTuple_GET_ITEM(sequence, 3); 
            __pyx_t_10 = PyTuple_GET_ITEM(sequence, 4); 
            __pyx_t_8 = PyTuple_GET_ITEM(sequence, 5); 
            __pyx_t_21 = PyTuple_GET_ITEM(sequence, 6); 
          } else {
            __pyx_t_9 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_20 = PyList_GET_ITEM(sequence, 1); 
            __pyx_t_1 = PyList_GET_ITEM(sequence, 2); 
            __pyx_t_17 = PyList_GET_ITEM(sequence, 3); 
            __pyx_t_10 = PyList_GET_ITEM(sequence, 4); 
            __pyx_t_8 = PyList_GET_ITEM(sequence, 5); 
            __pyx_t_21 = PyList_GET_ITEM(sequence, 6); 
          }
          __Pyx_INCREF(__pyx_t_9);
          __Pyx_INCREF(__pyx_t_20);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_17);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_21);
          #else
          {
            Py_ssize_t i;
            PyObject** temps[7] = {&__pyx_t_9,&__pyx_t_20,&__pyx_t_1,&__pyx_t_17,&__pyx_t_10,&__pyx_t_8,&__pyx_t_21};
            for (i=0; i < 7; i++) {
              PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 558; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(item);
              *(temps[i]) = item;
            }
          }
          #endif
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        } else {
          Py_ssize_t index = -1;
          PyObject** temps[7] = {&__pyx_t_9,&__pyx_t_20,&__pyx_t_1,&__pyx_t_17,&__pyx_t_10,&__pyx_t_8,&__pyx_t_21};
          __pyx_t_22 = PyObject_GetIter(__pyx_t_16); if (unlikely(!__pyx_t_22)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 558; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_22);
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __pyx_t_11 = Py_TYPE(__pyx_t_22)->tp_iternext;
          for (index=0; index < 7; index++) {
            PyObject* item = __pyx_t_11(__pyx_t_22); if (unlikely(!item)) goto __pyx_L38_unpacking_failed;
            __Pyx_GOTREF(item);
            *(temps[index]) = item;
          }
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_11(__pyx_t_22), 7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 558; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_11 = NULL;
          __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
          goto __pyx_L39_unpacking_done;
          __pyx_L38_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
          __pyx_t_11 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 558; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_L39_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_y, __pyx_t_9);
        __pyx_t_9 = 0;
        __Pyx_XDECREF_SET(__pyx_v_m, __pyx_t_20);
        __pyx_t_20 = 0;
        __Pyx_XDECREF_SET(__pyx_v_d, __pyx_t_1);
        __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_hh, __pyx_t_17);
        __pyx_t_17 = 0;
        __Pyx_XDECREF_SET(__pyx_v_mm, __pyx_t_10);
        __pyx_t_10 = 0;
        __Pyx_XDECREF_SET(__pyx_v_ss, __pyx_t_8);
        __pyx_t_8 = 0;
        __Pyx_XDECREF_SET(__pyx_v_ff, __pyx_t_21);
        __pyx_t_21 = 0;
      }
      __pyx_L33:;

      /* "fiona/ogrext.pyx":560
 *                     y, m, d, hh, mm, ss, ff = parse_datetime(value)
 *                 ograpi.OGR_F_SetFieldDateTime(
 *                     cogr_feature, i, y, m, d, hh, mm, ss, 0)             # <<<<<<<<<<<<<<
 *             elif value is None:
 *                 pass # keep field unset/null
 */
      __pyx_t_15 = __Pyx_PyInt_As_int(__pyx_v_y); if (unlikely((__pyx_t_15 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 560; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_23 = __Pyx_PyInt_As_int(__pyx_v_m); if (unlikely((__pyx_t_23 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 560; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_24 = __Pyx_PyInt_As_int(__pyx_v_d); if (unlikely((__pyx_t_24 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 560; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_25 = __Pyx_PyInt_As_int(__pyx_v_hh); if (unlikely((__pyx_t_25 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 560; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_26 = __Pyx_PyInt_As_int(__pyx_v_mm); if (unlikely((__pyx_t_26 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 560; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_27 = __Pyx_PyInt_As_int(__pyx_v_ss); if (unlikely((__pyx_t_27 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 560; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "fiona/ogrext.pyx":559
 *                 else:
 *                     y, m, d, hh, mm, ss, ff = parse_datetime(value)
 *                 ograpi.OGR_F_SetFieldDateTime(             # <<<<<<<<<<<<<<
 *                     cogr_feature, i, y, m, d, hh, mm, ss, 0)
 *             elif value is None:
 */
      OGR_F_SetFieldDateTime(__pyx_v_cogr_feature, __pyx_v_i, __pyx_t_15, __pyx_t_23, __pyx_t_24, __pyx_t_25, __pyx_t_26, __pyx_t_27, 0);
      goto __pyx_L22;
    }

    /* "fiona/ogrext.pyx":561
 *                 ograpi.OGR_F_SetFieldDateTime(
 *                     cogr_feature, i, y, m, d, hh, mm, ss, 0)
 *             elif value is None:             # <<<<<<<<<<<<<<
 *                 pass # keep field unset/null
 *             else:
 */
    __pyx_t_4 = (__pyx_v_value == Py_None);
    __pyx_t_3 = (__pyx_t_4 != 0);
    if (__pyx_t_3) {
      goto __pyx_L22;
    }
    /*else*/ {

      /* "fiona/ogrext.pyx":564
 *                 pass # keep field unset/null
 *             else:
 *                 raise ValueError("Invalid field type %s" % type(value))             # <<<<<<<<<<<<<<
 *             log.debug("Set field %s: %s" % (key, value))
 *         return cogr_feature
 */
      __pyx_t_16 = __Pyx_PyString_Format(__pyx_kp_s_Invalid_field_type_s, ((PyObject *)Py_TYPE(__pyx_v_value))); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 564; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_21 = PyTuple_New(1); if (unlikely(!__pyx_t_21)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 564; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_21);
      PyTuple_SET_ITEM(__pyx_t_21, 0, __pyx_t_16);
      __Pyx_GIVEREF(__pyx_t_16);
      __pyx_t_16 = 0;
      __pyx_t_16 = PyObject_Call(__pyx_builtin_ValueError, __pyx_t_21, NULL); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 564; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
      __Pyx_Raise(__pyx_t_16, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 564; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L22:;

    /* "fiona/ogrext.pyx":565
 *             else:
 *                 raise ValueError("Invalid field type %s" % type(value))
 *             log.debug("Set field %s: %s" % (key, value))             # <<<<<<<<<<<<<<
 *         return cogr_feature
 * 
 */
    __pyx_t_16 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 565; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_16);
    __pyx_t_21 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_n_s_debug); if (unlikely(!__pyx_t_21)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 565; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_21);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_16 = PyTuple_New(2); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 565; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_INCREF(__pyx_v_key);
    PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_v_key);
    __Pyx_GIVEREF(__pyx_v_key);
    __Pyx_INCREF(__pyx_v_value);
    PyTuple_SET_ITEM(__pyx_t_16, 1, __pyx_v_value);
    __Pyx_GIVEREF(__pyx_v_value);
    __pyx_t_8 = __Pyx_PyString_Format(__pyx_kp_s_Set_field_s_s, __pyx_t_16); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 565; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __pyx_t_16 = PyTuple_New(1); if (unlikely(!__pyx_t_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 565; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_16);
    PyTuple_SET_ITEM(__pyx_t_16, 0, __pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    __pyx_t_8 = 0;
    __pyx_t_8 = PyObject_Call(__pyx_t_21, __pyx_t_16, NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 565; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
    __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_L7_continue:;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "fiona/ogrext.pyx":566
 *                 raise ValueError("Invalid field type %s" % type(value))
 *             log.debug("Set field %s: %s" % (key, value))
 *         return cogr_feature             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_cogr_feature;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":504
 *     """
 * 
 *     cdef void * build(self, feature, collection) except NULL:             # <<<<<<<<<<<<<<
 *         cdef void *cogr_geometry = NULL
 *         cdef char *string_c
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_XDECREF(__pyx_t_22);
  __Pyx_AddTraceback("fiona.ogrext.OGRFeatureBuilder.build", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_session);
  __Pyx_XDECREF(__pyx_v_encoding);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_key_bytes);
  __Pyx_XDECREF(__pyx_v_key_c);
  __Pyx_XDECREF(__pyx_v_value_bytes);
  __Pyx_XDECREF(__pyx_v_y);
  __Pyx_XDECREF(__pyx_v_m);
  __Pyx_XDECREF(__pyx_v_d);
  __Pyx_XDECREF(__pyx_v_hh);
  __Pyx_XDECREF(__pyx_v_mm);
  __Pyx_XDECREF(__pyx_v_ss);
  __Pyx_XDECREF(__pyx_v_ff);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":569
 * 
 * 
 * cdef _deleteOgrFeature(void *cogr_feature):             # <<<<<<<<<<<<<<
 *     """Delete an OGR feature"""
 *     if cogr_feature is not NULL:
 */

static PyObject *__pyx_f_5fiona_6ogrext__deleteOgrFeature(void *__pyx_v_cogr_feature) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("_deleteOgrFeature", 0);

  /* "fiona/ogrext.pyx":571
 * cdef _deleteOgrFeature(void *cogr_feature):
 *     """Delete an OGR feature"""
 *     if cogr_feature is not NULL:             # <<<<<<<<<<<<<<
 *         ograpi.OGR_F_Destroy(cogr_feature)
 *     cogr_feature = NULL
 */
  __pyx_t_1 = ((__pyx_v_cogr_feature != NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":572
 *     """Delete an OGR feature"""
 *     if cogr_feature is not NULL:
 *         ograpi.OGR_F_Destroy(cogr_feature)             # <<<<<<<<<<<<<<
 *     cogr_feature = NULL
 * 
 */
    OGR_F_Destroy(__pyx_v_cogr_feature);
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "fiona/ogrext.pyx":573
 *     if cogr_feature is not NULL:
 *         ograpi.OGR_F_Destroy(cogr_feature)
 *     cogr_feature = NULL             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_cogr_feature = NULL;

  /* "fiona/ogrext.pyx":569
 * 
 * 
 * cdef _deleteOgrFeature(void *cogr_feature):             # <<<<<<<<<<<<<<
 *     """Delete an OGR feature"""
 *     if cogr_feature is not NULL:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":576
 * 
 * 
 * def featureRT(feature, collection):             # <<<<<<<<<<<<<<
 *     # For testing purposes only, leaks the JSON data
 *     cdef void *cogr_feature = OGRFeatureBuilder().build(feature, collection)
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_8featureRT(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_5fiona_6ogrext_8featureRT = {__Pyx_NAMESTR("featureRT"), (PyCFunction)__pyx_pw_5fiona_6ogrext_8featureRT, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_5fiona_6ogrext_8featureRT(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_feature = 0;
  PyObject *__pyx_v_collection = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("featureRT (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_feature,&__pyx_n_s_collection,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_feature)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_collection)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("featureRT", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 576; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "featureRT") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 576; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_feature = values[0];
    __pyx_v_collection = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("featureRT", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 576; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("fiona.ogrext.featureRT", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5fiona_6ogrext_7featureRT(__pyx_self, __pyx_v_feature, __pyx_v_collection);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_7featureRT(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_feature, PyObject *__pyx_v_collection) {
  void *__pyx_v_cogr_feature;
  void *__pyx_v_cogr_geometry;
  PyObject *__pyx_v_encoding = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  void *__pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  struct __pyx_opt_args_5fiona_6ogrext_14FeatureBuilder_build __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("featureRT", 0);

  /* "fiona/ogrext.pyx":578
 * def featureRT(feature, collection):
 *     # For testing purposes only, leaks the JSON data
 *     cdef void *cogr_feature = OGRFeatureBuilder().build(feature, collection)             # <<<<<<<<<<<<<<
 *     cdef void *cogr_geometry = ograpi.OGR_F_GetGeometryRef(cogr_feature)
 *     if cogr_geometry is NULL:
 */
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5fiona_6ogrext_OGRFeatureBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 578; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRFeatureBuilder *)((struct __pyx_obj_5fiona_6ogrext_OGRFeatureBuilder *)__pyx_t_1)->__pyx_vtab)->build(((struct __pyx_obj_5fiona_6ogrext_OGRFeatureBuilder *)__pyx_t_1), __pyx_v_feature, __pyx_v_collection); if (unlikely(__pyx_t_2 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 578; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_cogr_feature = __pyx_t_2;

  /* "fiona/ogrext.pyx":579
 *     # For testing purposes only, leaks the JSON data
 *     cdef void *cogr_feature = OGRFeatureBuilder().build(feature, collection)
 *     cdef void *cogr_geometry = ograpi.OGR_F_GetGeometryRef(cogr_feature)             # <<<<<<<<<<<<<<
 *     if cogr_geometry is NULL:
 *         raise ValueError("Null geometry")
 */
  __pyx_v_cogr_geometry = OGR_F_GetGeometryRef(__pyx_v_cogr_feature);

  /* "fiona/ogrext.pyx":580
 *     cdef void *cogr_feature = OGRFeatureBuilder().build(feature, collection)
 *     cdef void *cogr_geometry = ograpi.OGR_F_GetGeometryRef(cogr_feature)
 *     if cogr_geometry is NULL:             # <<<<<<<<<<<<<<
 *         raise ValueError("Null geometry")
 *     log.debug("Geometry: %s" % ograpi.OGR_G_ExportToJson(cogr_geometry))
 */
  __pyx_t_3 = ((__pyx_v_cogr_geometry == NULL) != 0);
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":581
 *     cdef void *cogr_geometry = ograpi.OGR_F_GetGeometryRef(cogr_feature)
 *     if cogr_geometry is NULL:
 *         raise ValueError("Null geometry")             # <<<<<<<<<<<<<<
 *     log.debug("Geometry: %s" % ograpi.OGR_G_ExportToJson(cogr_geometry))
 *     encoding = collection.encoding or 'utf-8'
 */
    __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 581; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 581; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":582
 *     if cogr_geometry is NULL:
 *         raise ValueError("Null geometry")
 *     log.debug("Geometry: %s" % ograpi.OGR_G_ExportToJson(cogr_geometry))             # <<<<<<<<<<<<<<
 *     encoding = collection.encoding or 'utf-8'
 *     result = FeatureBuilder().build(cogr_feature, encoding)
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_debug); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBytes_FromUString(OGR_G_ExportToJson(__pyx_v_cogr_geometry)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyString_Format(__pyx_kp_s_Geometry_s, __pyx_t_1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_Call(__pyx_t_4, __pyx_t_1, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "fiona/ogrext.pyx":583
 *         raise ValueError("Null geometry")
 *     log.debug("Geometry: %s" % ograpi.OGR_G_ExportToJson(cogr_geometry))
 *     encoding = collection.encoding or 'utf-8'             # <<<<<<<<<<<<<<
 *     result = FeatureBuilder().build(cogr_feature, encoding)
 *     _deleteOgrFeature(cogr_feature)
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_encoding); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 583; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 583; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (!__pyx_t_3) {
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_INCREF(__pyx_kp_s_utf_8);
    __pyx_t_1 = __pyx_kp_s_utf_8;
  } else {
    __pyx_t_1 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __pyx_v_encoding = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":584
 *     log.debug("Geometry: %s" % ograpi.OGR_G_ExportToJson(cogr_geometry))
 *     encoding = collection.encoding or 'utf-8'
 *     result = FeatureBuilder().build(cogr_feature, encoding)             # <<<<<<<<<<<<<<
 *     _deleteOgrFeature(cogr_feature)
 *     return result
 */
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5fiona_6ogrext_FeatureBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 584; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6.__pyx_n = 1;
  __pyx_t_6.encoding = __pyx_v_encoding;
  __pyx_t_5 = ((struct __pyx_vtabstruct_5fiona_6ogrext_FeatureBuilder *)((struct __pyx_obj_5fiona_6ogrext_FeatureBuilder *)__pyx_t_1)->__pyx_vtab)->build(((struct __pyx_obj_5fiona_6ogrext_FeatureBuilder *)__pyx_t_1), __pyx_v_cogr_feature, &__pyx_t_6); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 584; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_result = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "fiona/ogrext.pyx":585
 *     encoding = collection.encoding or 'utf-8'
 *     result = FeatureBuilder().build(cogr_feature, encoding)
 *     _deleteOgrFeature(cogr_feature)             # <<<<<<<<<<<<<<
 *     return result
 * 
 */
  __pyx_t_5 = __pyx_f_5fiona_6ogrext__deleteOgrFeature(__pyx_v_cogr_feature); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 585; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "fiona/ogrext.pyx":586
 *     result = FeatureBuilder().build(cogr_feature, encoding)
 *     _deleteOgrFeature(cogr_feature)
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":576
 * 
 * 
 * def featureRT(feature, collection):             # <<<<<<<<<<<<<<
 *     # For testing purposes only, leaks the JSON data
 *     cdef void *cogr_feature = OGRFeatureBuilder().build(feature, collection)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("fiona.ogrext.featureRT", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_encoding);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":599
 *     cdef object collection
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.cogr_ds = NULL
 *         self.cogr_layer = NULL
 */

/* Python wrapper */
static int __pyx_pw_5fiona_6ogrext_7Session_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_5fiona_6ogrext_7Session_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_5fiona_6ogrext_7Session___cinit__(((struct __pyx_obj_5fiona_6ogrext_Session *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5fiona_6ogrext_7Session___cinit__(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "fiona/ogrext.pyx":600
 * 
 *     def __cinit__(self):
 *         self.cogr_ds = NULL             # <<<<<<<<<<<<<<
 *         self.cogr_layer = NULL
 *         self._fileencoding = None
 */
  __pyx_v_self->cogr_ds = NULL;

  /* "fiona/ogrext.pyx":601
 *     def __cinit__(self):
 *         self.cogr_ds = NULL
 *         self.cogr_layer = NULL             # <<<<<<<<<<<<<<
 *         self._fileencoding = None
 *         self._encoding = None
 */
  __pyx_v_self->cogr_layer = NULL;

  /* "fiona/ogrext.pyx":602
 *         self.cogr_ds = NULL
 *         self.cogr_layer = NULL
 *         self._fileencoding = None             # <<<<<<<<<<<<<<
 *         self._encoding = None
 * 
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_fileencoding);
  __Pyx_DECREF(__pyx_v_self->_fileencoding);
  __pyx_v_self->_fileencoding = Py_None;

  /* "fiona/ogrext.pyx":603
 *         self.cogr_layer = NULL
 *         self._fileencoding = None
 *         self._encoding = None             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->_encoding);
  __Pyx_DECREF(__pyx_v_self->_encoding);
  __pyx_v_self->_encoding = Py_None;

  /* "fiona/ogrext.pyx":599
 *     cdef object collection
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.cogr_ds = NULL
 *         self.cogr_layer = NULL
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":605
 *         self._encoding = None
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         self.stop()
 * 
 */

/* Python wrapper */
static void __pyx_pw_5fiona_6ogrext_7Session_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_5fiona_6ogrext_7Session_3__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_5fiona_6ogrext_7Session_2__dealloc__(((struct __pyx_obj_5fiona_6ogrext_Session *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_5fiona_6ogrext_7Session_2__dealloc__(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "fiona/ogrext.pyx":606
 * 
 *     def __dealloc__(self):
 *         self.stop()             # <<<<<<<<<<<<<<
 * 
 *     def start(self, collection):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_stop); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 606; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 606; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":605
 *         self._encoding = None
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         self.stop()
 * 
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_WriteUnraisable("fiona.ogrext.Session.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename, 0);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "fiona/ogrext.pyx":608
 *         self.stop()
 * 
 *     def start(self, collection):             # <<<<<<<<<<<<<<
 *         cdef char *path_c
 *         cdef char *name_c
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_5start(PyObject *__pyx_v_self, PyObject *__pyx_v_collection); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_5start(PyObject *__pyx_v_self, PyObject *__pyx_v_collection) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("start (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_7Session_4start(((struct __pyx_obj_5fiona_6ogrext_Session *)__pyx_v_self), ((PyObject *)__pyx_v_collection));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_7Session_4start(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self, PyObject *__pyx_v_collection) {
  char *__pyx_v_path_c;
  char *__pyx_v_name_c;
  PyObject *__pyx_v_path_b = NULL;
  PyObject *__pyx_v_name_b = NULL;
  PyObject *__pyx_v_userencoding = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("start", 0);

  /* "fiona/ogrext.pyx":612
 *         cdef char *name_c
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             path_b = collection.path.encode('utf-8')
 *         except UnicodeDecodeError:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "fiona/ogrext.pyx":613
 * 
 *         try:
 *             path_b = collection.path.encode('utf-8')             # <<<<<<<<<<<<<<
 *         except UnicodeDecodeError:
 *             # Presume already a UTF-8 encoded string
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_path); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 613; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_encode); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 613; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyObject_Call(__pyx_t_5, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 613; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_path_b = __pyx_t_4;
      __pyx_t_4 = 0;
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L10_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "fiona/ogrext.pyx":614
 *         try:
 *             path_b = collection.path.encode('utf-8')
 *         except UnicodeDecodeError:             # <<<<<<<<<<<<<<
 *             # Presume already a UTF-8 encoded string
 *             path_b = collection.path
 */
    __pyx_t_6 = PyErr_ExceptionMatches(__pyx_builtin_UnicodeDecodeError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("fiona.ogrext.Session.start", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_5, &__pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 614; __pyx_clineno = __LINE__; goto __pyx_L5_except_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_7);

      /* "fiona/ogrext.pyx":616
 *         except UnicodeDecodeError:
 *             # Presume already a UTF-8 encoded string
 *             path_b = collection.path             # <<<<<<<<<<<<<<
 *         path_c = path_b
 * 
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_path); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 616; __pyx_clineno = __LINE__; goto __pyx_L5_except_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_XDECREF_SET(__pyx_v_path_b, __pyx_t_8);
      __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L10_try_end:;
  }

  /* "fiona/ogrext.pyx":617
 *             # Presume already a UTF-8 encoded string
 *             path_b = collection.path
 *         path_c = path_b             # <<<<<<<<<<<<<<
 * 
 *         self.cogr_ds = ograpi.OGROpen(path_c, 0, NULL)
 */
  __pyx_t_9 = __Pyx_PyObject_AsString(__pyx_v_path_b); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 617; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_path_c = __pyx_t_9;

  /* "fiona/ogrext.pyx":619
 *         path_c = path_b
 * 
 *         self.cogr_ds = ograpi.OGROpen(path_c, 0, NULL)             # <<<<<<<<<<<<<<
 *         if self.cogr_ds is NULL:
 *             raise ValueError(
 */
  __pyx_v_self->cogr_ds = OGROpen(__pyx_v_path_c, 0, NULL);

  /* "fiona/ogrext.pyx":620
 * 
 *         self.cogr_ds = ograpi.OGROpen(path_c, 0, NULL)
 *         if self.cogr_ds is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError(
 *                 "No data available at path '%s'" % collection.path)
 */
  __pyx_t_10 = ((__pyx_v_self->cogr_ds == NULL) != 0);
  if (__pyx_t_10) {

    /* "fiona/ogrext.pyx":622
 *         if self.cogr_ds is NULL:
 *             raise ValueError(
 *                 "No data available at path '%s'" % collection.path)             # <<<<<<<<<<<<<<
 * 
 *         if isinstance(collection.name, string_types):
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_path); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 622; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = __Pyx_PyString_Format(__pyx_kp_s_No_data_available_at_path_s, __pyx_t_7); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 622; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "fiona/ogrext.pyx":621
 *         self.cogr_ds = ograpi.OGROpen(path_c, 0, NULL)
 *         if self.cogr_ds is NULL:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 "No data available at path '%s'" % collection.path)
 * 
 */
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 621; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_t_5 = PyObject_Call(__pyx_builtin_ValueError, __pyx_t_7, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 621; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 621; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":624
 *                 "No data available at path '%s'" % collection.path)
 * 
 *         if isinstance(collection.name, string_types):             # <<<<<<<<<<<<<<
 *             name_b = collection.name.encode('utf-8')
 *             name_c = name_b
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 624; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_string_types); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 624; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_10 = PyObject_IsInstance(__pyx_t_5, __pyx_t_7); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 624; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_11 = (__pyx_t_10 != 0);
  if (__pyx_t_11) {

    /* "fiona/ogrext.pyx":625
 * 
 *         if isinstance(collection.name, string_types):
 *             name_b = collection.name.encode('utf-8')             # <<<<<<<<<<<<<<
 *             name_c = name_b
 *             self.cogr_layer = ograpi.OGR_DS_GetLayerByName(
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 625; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_encode); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 625; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyObject_Call(__pyx_t_5, __pyx_tuple__18, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 625; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_name_b = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "fiona/ogrext.pyx":626
 *         if isinstance(collection.name, string_types):
 *             name_b = collection.name.encode('utf-8')
 *             name_c = name_b             # <<<<<<<<<<<<<<
 *             self.cogr_layer = ograpi.OGR_DS_GetLayerByName(
 *                                 self.cogr_ds, name_c)
 */
    __pyx_t_9 = __Pyx_PyObject_AsString(__pyx_v_name_b); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 626; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_name_c = __pyx_t_9;

    /* "fiona/ogrext.pyx":627
 *             name_b = collection.name.encode('utf-8')
 *             name_c = name_b
 *             self.cogr_layer = ograpi.OGR_DS_GetLayerByName(             # <<<<<<<<<<<<<<
 *                                 self.cogr_ds, name_c)
 *         elif isinstance(collection.name, int):
 */
    __pyx_v_self->cogr_layer = OGR_DS_GetLayerByName(__pyx_v_self->cogr_ds, __pyx_v_name_c);
    goto __pyx_L14;
  }

  /* "fiona/ogrext.pyx":629
 *             self.cogr_layer = ograpi.OGR_DS_GetLayerByName(
 *                                 self.cogr_ds, name_c)
 *         elif isinstance(collection.name, int):             # <<<<<<<<<<<<<<
 *             self.cogr_layer = ograpi.OGR_DS_GetLayer(
 *                                 self.cogr_ds, collection.name)
 */
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 629; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_11 = PyInt_Check(__pyx_t_7); 
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_10 = (__pyx_t_11 != 0);
  if (__pyx_t_10) {

    /* "fiona/ogrext.pyx":631
 *         elif isinstance(collection.name, int):
 *             self.cogr_layer = ograpi.OGR_DS_GetLayer(
 *                                 self.cogr_ds, collection.name)             # <<<<<<<<<<<<<<
 *             name_c = ograpi.OGR_L_GetName(self.cogr_layer)
 *             name_b = name_c
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 631; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_7); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 631; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "fiona/ogrext.pyx":630
 *                                 self.cogr_ds, name_c)
 *         elif isinstance(collection.name, int):
 *             self.cogr_layer = ograpi.OGR_DS_GetLayer(             # <<<<<<<<<<<<<<
 *                                 self.cogr_ds, collection.name)
 *             name_c = ograpi.OGR_L_GetName(self.cogr_layer)
 */
    __pyx_v_self->cogr_layer = OGR_DS_GetLayer(__pyx_v_self->cogr_ds, __pyx_t_6);

    /* "fiona/ogrext.pyx":632
 *             self.cogr_layer = ograpi.OGR_DS_GetLayer(
 *                                 self.cogr_ds, collection.name)
 *             name_c = ograpi.OGR_L_GetName(self.cogr_layer)             # <<<<<<<<<<<<<<
 *             name_b = name_c
 *             collection.name = name_b.decode('utf-8')
 */
    __pyx_v_name_c = OGR_L_GetName(__pyx_v_self->cogr_layer);

    /* "fiona/ogrext.pyx":633
 *                                 self.cogr_ds, collection.name)
 *             name_c = ograpi.OGR_L_GetName(self.cogr_layer)
 *             name_b = name_c             # <<<<<<<<<<<<<<
 *             collection.name = name_b.decode('utf-8')
 * 
 */
    __pyx_t_7 = __Pyx_PyBytes_FromString(__pyx_v_name_c); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 633; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_v_name_b = __pyx_t_7;
    __pyx_t_7 = 0;

    /* "fiona/ogrext.pyx":634
 *             name_c = ograpi.OGR_L_GetName(self.cogr_layer)
 *             name_b = name_c
 *             collection.name = name_b.decode('utf-8')             # <<<<<<<<<<<<<<
 * 
 *         if self.cogr_layer is NULL:
 */
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_name_b, __pyx_n_s_decode); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 634; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = PyObject_Call(__pyx_t_7, __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 634; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_collection, __pyx_n_s_name, __pyx_t_5) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 634; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L14;
  }
  __pyx_L14:;

  /* "fiona/ogrext.pyx":636
 *             collection.name = name_b.decode('utf-8')
 * 
 *         if self.cogr_layer is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null layer: " + repr(collection.name))
 * 
 */
  __pyx_t_10 = ((__pyx_v_self->cogr_layer == NULL) != 0);
  if (__pyx_t_10) {

    /* "fiona/ogrext.pyx":637
 * 
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer: " + repr(collection.name))             # <<<<<<<<<<<<<<
 * 
 *         self.collection = collection
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 637; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = PyObject_Repr(__pyx_t_5); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 637; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Add(__pyx_kp_s_Null_layer_2, __pyx_t_7); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 637; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 637; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_t_5 = PyObject_Call(__pyx_builtin_ValueError, __pyx_t_7, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 637; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 637; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":639
 *             raise ValueError("Null layer: " + repr(collection.name))
 * 
 *         self.collection = collection             # <<<<<<<<<<<<<<
 * 
 *         userencoding = self.collection.encoding
 */
  __Pyx_INCREF(__pyx_v_collection);
  __Pyx_GIVEREF(__pyx_v_collection);
  __Pyx_GOTREF(__pyx_v_self->collection);
  __Pyx_DECREF(__pyx_v_self->collection);
  __pyx_v_self->collection = __pyx_v_collection;

  /* "fiona/ogrext.pyx":641
 *         self.collection = collection
 * 
 *         userencoding = self.collection.encoding             # <<<<<<<<<<<<<<
 *         if userencoding:
 *             ograpi.CPLSetThreadLocalConfigOption('SHAPE_ENCODING', '')
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->collection, __pyx_n_s_encoding); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 641; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_userencoding = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "fiona/ogrext.pyx":642
 * 
 *         userencoding = self.collection.encoding
 *         if userencoding:             # <<<<<<<<<<<<<<
 *             ograpi.CPLSetThreadLocalConfigOption('SHAPE_ENCODING', '')
 *             self._fileencoding = userencoding.upper()
 */
  __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_userencoding); if (unlikely(__pyx_t_10 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 642; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_10) {

    /* "fiona/ogrext.pyx":643
 *         userencoding = self.collection.encoding
 *         if userencoding:
 *             ograpi.CPLSetThreadLocalConfigOption('SHAPE_ENCODING', '')             # <<<<<<<<<<<<<<
 *             self._fileencoding = userencoding.upper()
 *         else:
 */
    CPLSetThreadLocalConfigOption(__pyx_k_SHAPE_ENCODING, __pyx_k__20);

    /* "fiona/ogrext.pyx":644
 *         if userencoding:
 *             ograpi.CPLSetThreadLocalConfigOption('SHAPE_ENCODING', '')
 *             self._fileencoding = userencoding.upper()             # <<<<<<<<<<<<<<
 *         else:
 *             self._fileencoding = (
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_userencoding, __pyx_n_s_upper); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 644; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = PyObject_Call(__pyx_t_5, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 644; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GIVEREF(__pyx_t_7);
    __Pyx_GOTREF(__pyx_v_self->_fileencoding);
    __Pyx_DECREF(__pyx_v_self->_fileencoding);
    __pyx_v_self->_fileencoding = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L16;
  }
  /*else*/ {

    /* "fiona/ogrext.pyx":647
 *         else:
 *             self._fileencoding = (
 *                 ograpi.OGR_L_TestCapability(             # <<<<<<<<<<<<<<
 *                     self.cogr_layer, "StringsAsUTF8") and
 *                 OGR_DETECTED_ENCODING) or (
 */
    __pyx_t_7 = __Pyx_PyInt_From_int(OGR_L_TestCapability(__pyx_v_self->cogr_layer, __pyx_k_StringsAsUTF8)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 647; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_10 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 648; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (__pyx_t_10) {
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "fiona/ogrext.pyx":649
 *                 ograpi.OGR_L_TestCapability(
 *                     self.cogr_layer, "StringsAsUTF8") and
 *                 OGR_DETECTED_ENCODING) or (             # <<<<<<<<<<<<<<
 *                 self.get_driver() == "ESRI Shapefile" and
 *                 'ISO-8859-1') or locale.getpreferredencoding().upper()
 */
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_OGR_DETECTED_ENCODING); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 649; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_4 = __pyx_t_5;
      __pyx_t_5 = 0;
    } else {
      __pyx_t_4 = __pyx_t_7;
      __pyx_t_7 = 0;
    }
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_10 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 649; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!__pyx_t_10) {
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "fiona/ogrext.pyx":650
 *                     self.cogr_layer, "StringsAsUTF8") and
 *                 OGR_DETECTED_ENCODING) or (
 *                 self.get_driver() == "ESRI Shapefile" and             # <<<<<<<<<<<<<<
 *                 'ISO-8859-1') or locale.getpreferredencoding().upper()
 * 
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_driver); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 650; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_5 = PyObject_Call(__pyx_t_7, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 650; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = PyObject_RichCompare(__pyx_t_5, __pyx_kp_s_ESRI_Shapefile, Py_EQ); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 650; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_10 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 650; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (__pyx_t_10) {
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_INCREF(__pyx_kp_s_ISO_8859_1);
        __pyx_t_5 = __pyx_kp_s_ISO_8859_1;
      } else {
        __pyx_t_5 = __pyx_t_7;
        __pyx_t_7 = 0;
      }
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_10 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 651; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (!__pyx_t_10) {
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "fiona/ogrext.pyx":651
 *                 OGR_DETECTED_ENCODING) or (
 *                 self.get_driver() == "ESRI Shapefile" and
 *                 'ISO-8859-1') or locale.getpreferredencoding().upper()             # <<<<<<<<<<<<<<
 * 
 *     def stop(self):
 */
        __pyx_t_7 = __Pyx_GetModuleGlobalName(__pyx_n_s_locale); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 651; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_getpreferredencoding); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 651; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = PyObject_Call(__pyx_t_8, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 651; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_upper); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 651; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_7 = PyObject_Call(__pyx_t_8, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 651; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_8 = __pyx_t_7;
        __pyx_t_7 = 0;
      } else {
        __pyx_t_8 = __pyx_t_5;
        __pyx_t_5 = 0;
      }
      __pyx_t_5 = __pyx_t_8;
      __pyx_t_8 = 0;
    } else {
      __pyx_t_5 = __pyx_t_4;
      __pyx_t_4 = 0;
    }

    /* "fiona/ogrext.pyx":646
 *             self._fileencoding = userencoding.upper()
 *         else:
 *             self._fileencoding = (             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_L_TestCapability(
 *                     self.cogr_layer, "StringsAsUTF8") and
 */
    __Pyx_GIVEREF(__pyx_t_5);
    __Pyx_GOTREF(__pyx_v_self->_fileencoding);
    __Pyx_DECREF(__pyx_v_self->_fileencoding);
    __pyx_v_self->_fileencoding = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __pyx_L16:;

  /* "fiona/ogrext.pyx":608
 *         self.stop()
 * 
 *     def start(self, collection):             # <<<<<<<<<<<<<<
 *         cdef char *path_c
 *         cdef char *name_c
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("fiona.ogrext.Session.start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_path_b);
  __Pyx_XDECREF(__pyx_v_name_b);
  __Pyx_XDECREF(__pyx_v_userencoding);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":653
 *                 'ISO-8859-1') or locale.getpreferredencoding().upper()
 * 
 *     def stop(self):             # <<<<<<<<<<<<<<
 *         self.cogr_layer = NULL
 *         if self.cogr_ds is not NULL:
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_7stop(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_7stop(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stop (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_7Session_6stop(((struct __pyx_obj_5fiona_6ogrext_Session *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_7Session_6stop(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("stop", 0);

  /* "fiona/ogrext.pyx":654
 * 
 *     def stop(self):
 *         self.cogr_layer = NULL             # <<<<<<<<<<<<<<
 *         if self.cogr_ds is not NULL:
 *             ograpi.OGR_DS_Destroy(self.cogr_ds)
 */
  __pyx_v_self->cogr_layer = NULL;

  /* "fiona/ogrext.pyx":655
 *     def stop(self):
 *         self.cogr_layer = NULL
 *         if self.cogr_ds is not NULL:             # <<<<<<<<<<<<<<
 *             ograpi.OGR_DS_Destroy(self.cogr_ds)
 *         self.cogr_ds = NULL
 */
  __pyx_t_1 = ((__pyx_v_self->cogr_ds != NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":656
 *         self.cogr_layer = NULL
 *         if self.cogr_ds is not NULL:
 *             ograpi.OGR_DS_Destroy(self.cogr_ds)             # <<<<<<<<<<<<<<
 *         self.cogr_ds = NULL
 * 
 */
    OGR_DS_Destroy(__pyx_v_self->cogr_ds);
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "fiona/ogrext.pyx":657
 *         if self.cogr_ds is not NULL:
 *             ograpi.OGR_DS_Destroy(self.cogr_ds)
 *         self.cogr_ds = NULL             # <<<<<<<<<<<<<<
 * 
 *     def get_fileencoding(self):
 */
  __pyx_v_self->cogr_ds = NULL;

  /* "fiona/ogrext.pyx":653
 *                 'ISO-8859-1') or locale.getpreferredencoding().upper()
 * 
 *     def stop(self):             # <<<<<<<<<<<<<<
 *         self.cogr_layer = NULL
 *         if self.cogr_ds is not NULL:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":659
 *         self.cogr_ds = NULL
 * 
 *     def get_fileencoding(self):             # <<<<<<<<<<<<<<
 *         return self._fileencoding
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_9get_fileencoding(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_9get_fileencoding(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_fileencoding (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_7Session_8get_fileencoding(((struct __pyx_obj_5fiona_6ogrext_Session *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_7Session_8get_fileencoding(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_fileencoding", 0);

  /* "fiona/ogrext.pyx":660
 * 
 *     def get_fileencoding(self):
 *         return self._fileencoding             # <<<<<<<<<<<<<<
 * 
 *     def get_internalencoding(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_fileencoding);
  __pyx_r = __pyx_v_self->_fileencoding;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":659
 *         self.cogr_ds = NULL
 * 
 *     def get_fileencoding(self):             # <<<<<<<<<<<<<<
 *         return self._fileencoding
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":662
 *         return self._fileencoding
 * 
 *     def get_internalencoding(self):             # <<<<<<<<<<<<<<
 *         if not self._encoding:
 *             fileencoding = self.get_fileencoding()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_11get_internalencoding(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_11get_internalencoding(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_internalencoding (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_7Session_10get_internalencoding(((struct __pyx_obj_5fiona_6ogrext_Session *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_7Session_10get_internalencoding(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self) {
  PyObject *__pyx_v_fileencoding = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_internalencoding", 0);

  /* "fiona/ogrext.pyx":663
 * 
 *     def get_internalencoding(self):
 *         if not self._encoding:             # <<<<<<<<<<<<<<
 *             fileencoding = self.get_fileencoding()
 *             self._encoding = (
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_self->_encoding); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 663; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = ((!__pyx_t_1) != 0);
  if (__pyx_t_2) {

    /* "fiona/ogrext.pyx":664
 *     def get_internalencoding(self):
 *         if not self._encoding:
 *             fileencoding = self.get_fileencoding()             # <<<<<<<<<<<<<<
 *             self._encoding = (
 *                 ograpi.OGR_L_TestCapability(
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_fileencoding); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 664; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_Call(__pyx_t_3, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 664; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_fileencoding = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "fiona/ogrext.pyx":666
 *             fileencoding = self.get_fileencoding()
 *             self._encoding = (
 *                 ograpi.OGR_L_TestCapability(             # <<<<<<<<<<<<<<
 *                     self.cogr_layer, "StringsAsUTF8") and
 *                 'utf-8') or fileencoding
 */
    __pyx_t_4 = __Pyx_PyInt_From_int(OGR_L_TestCapability(__pyx_v_self->cogr_layer, __pyx_k_StringsAsUTF8)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 666; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 667; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (__pyx_t_2) {
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_INCREF(__pyx_kp_s_utf_8);
      __pyx_t_3 = __pyx_kp_s_utf_8;
    } else {
      __pyx_t_3 = __pyx_t_4;
      __pyx_t_4 = 0;
    }
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 668; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!__pyx_t_2) {
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "fiona/ogrext.pyx":668
 *                 ograpi.OGR_L_TestCapability(
 *                     self.cogr_layer, "StringsAsUTF8") and
 *                 'utf-8') or fileencoding             # <<<<<<<<<<<<<<
 *         return self._encoding
 * 
 */
      __Pyx_INCREF(__pyx_v_fileencoding);
      __pyx_t_4 = __pyx_v_fileencoding;
    } else {
      __pyx_t_4 = __pyx_t_3;
      __pyx_t_3 = 0;
    }

    /* "fiona/ogrext.pyx":665
 *         if not self._encoding:
 *             fileencoding = self.get_fileencoding()
 *             self._encoding = (             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_L_TestCapability(
 *                     self.cogr_layer, "StringsAsUTF8") and
 */
    __Pyx_GIVEREF(__pyx_t_4);
    __Pyx_GOTREF(__pyx_v_self->_encoding);
    __Pyx_DECREF(__pyx_v_self->_encoding);
    __pyx_v_self->_encoding = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "fiona/ogrext.pyx":669
 *                     self.cogr_layer, "StringsAsUTF8") and
 *                 'utf-8') or fileencoding
 *         return self._encoding             # <<<<<<<<<<<<<<
 * 
 *     def get_length(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_encoding);
  __pyx_r = __pyx_v_self->_encoding;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":662
 *         return self._fileencoding
 * 
 *     def get_internalencoding(self):             # <<<<<<<<<<<<<<
 *         if not self._encoding:
 *             fileencoding = self.get_fileencoding()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("fiona.ogrext.Session.get_internalencoding", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_fileencoding);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":671
 *         return self._encoding
 * 
 *     def get_length(self):             # <<<<<<<<<<<<<<
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer")
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_13get_length(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_13get_length(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_length (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_7Session_12get_length(((struct __pyx_obj_5fiona_6ogrext_Session *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_7Session_12get_length(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_length", 0);

  /* "fiona/ogrext.pyx":672
 * 
 *     def get_length(self):
 *         if self.cogr_layer is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null layer")
 *         return ograpi.OGR_L_GetFeatureCount(self.cogr_layer, 0)
 */
  __pyx_t_1 = ((__pyx_v_self->cogr_layer == NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":673
 *     def get_length(self):
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 *         return ograpi.OGR_L_GetFeatureCount(self.cogr_layer, 0)
 * 
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__21, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 673; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 673; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":674
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer")
 *         return ograpi.OGR_L_GetFeatureCount(self.cogr_layer, 0)             # <<<<<<<<<<<<<<
 * 
 *     def get_driver(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyInt_From_int(OGR_L_GetFeatureCount(__pyx_v_self->cogr_layer, 0)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 674; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":671
 *         return self._encoding
 * 
 *     def get_length(self):             # <<<<<<<<<<<<<<
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("fiona.ogrext.Session.get_length", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":676
 *         return ograpi.OGR_L_GetFeatureCount(self.cogr_layer, 0)
 * 
 *     def get_driver(self):             # <<<<<<<<<<<<<<
 *         cdef void *cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 *         if cogr_driver is NULL:
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_15get_driver(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_15get_driver(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_driver (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_7Session_14get_driver(((struct __pyx_obj_5fiona_6ogrext_Session *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_7Session_14get_driver(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self) {
  void *__pyx_v_cogr_driver;
  char *__pyx_v_name;
  char *__pyx_v_driver_name;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_driver", 0);

  /* "fiona/ogrext.pyx":677
 * 
 *     def get_driver(self):
 *         cdef void *cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)             # <<<<<<<<<<<<<<
 *         if cogr_driver is NULL:
 *             raise ValueError("Null driver")
 */
  __pyx_v_cogr_driver = OGR_DS_GetDriver(__pyx_v_self->cogr_ds);

  /* "fiona/ogrext.pyx":678
 *     def get_driver(self):
 *         cdef void *cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 *         if cogr_driver is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null driver")
 *         cdef char *name = ograpi.OGR_Dr_GetName(cogr_driver)
 */
  __pyx_t_1 = ((__pyx_v_cogr_driver == NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":679
 *         cdef void *cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 *         if cogr_driver is NULL:
 *             raise ValueError("Null driver")             # <<<<<<<<<<<<<<
 *         cdef char *name = ograpi.OGR_Dr_GetName(cogr_driver)
 *         driver_name = name
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__22, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 679; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 679; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":680
 *         if cogr_driver is NULL:
 *             raise ValueError("Null driver")
 *         cdef char *name = ograpi.OGR_Dr_GetName(cogr_driver)             # <<<<<<<<<<<<<<
 *         driver_name = name
 *         return driver_name.decode()
 */
  __pyx_v_name = OGR_Dr_GetName(__pyx_v_cogr_driver);

  /* "fiona/ogrext.pyx":681
 *             raise ValueError("Null driver")
 *         cdef char *name = ograpi.OGR_Dr_GetName(cogr_driver)
 *         driver_name = name             # <<<<<<<<<<<<<<
 *         return driver_name.decode()
 * 
 */
  __pyx_v_driver_name = __pyx_v_name;

  /* "fiona/ogrext.pyx":682
 *         cdef char *name = ograpi.OGR_Dr_GetName(cogr_driver)
 *         driver_name = name
 *         return driver_name.decode()             # <<<<<<<<<<<<<<
 * 
 *     def get_schema(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_decode_c_string(__pyx_v_driver_name, 0, strlen(__pyx_v_driver_name), NULL, NULL, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 682; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":676
 *         return ograpi.OGR_L_GetFeatureCount(self.cogr_layer, 0)
 * 
 *     def get_driver(self):             # <<<<<<<<<<<<<<
 *         cdef void *cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 *         if cogr_driver is NULL:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("fiona.ogrext.Session.get_driver", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":684
 *         return driver_name.decode()
 * 
 *     def get_schema(self):             # <<<<<<<<<<<<<<
 *         cdef int i
 *         cdef int n
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_17get_schema(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_17get_schema(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_schema (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_7Session_16get_schema(((struct __pyx_obj_5fiona_6ogrext_Session *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_7Session_16get_schema(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self) {
  int __pyx_v_i;
  int __pyx_v_n;
  void *__pyx_v_cogr_featuredefn;
  void *__pyx_v_cogr_fielddefn;
  char *__pyx_v_key_c;
  PyObject *__pyx_v_props = NULL;
  char *__pyx_v_key_b;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_fieldtypename = NULL;
  PyObject *__pyx_v_val = NULL;
  PyObject *__pyx_v_fmt = NULL;
  PyObject *__pyx_v_width = NULL;
  PyObject *__pyx_v_precision = NULL;
  unsigned int __pyx_v_geom_type;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_schema", 0);

  /* "fiona/ogrext.pyx":690
 *         cdef void *cogr_fielddefn
 *         cdef char *key_c
 *         props = []             # <<<<<<<<<<<<<<
 * 
 *         if self.cogr_layer is NULL:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 690; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_props = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":692
 *         props = []
 * 
 *         if self.cogr_layer is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null layer")
 * 
 */
  __pyx_t_2 = ((__pyx_v_self->cogr_layer == NULL) != 0);
  if (__pyx_t_2) {

    /* "fiona/ogrext.pyx":693
 * 
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 * 
 *         cogr_featuredefn = ograpi.OGR_L_GetLayerDefn(self.cogr_layer)
 */
    __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__23, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 693; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 693; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":695
 *             raise ValueError("Null layer")
 * 
 *         cogr_featuredefn = ograpi.OGR_L_GetLayerDefn(self.cogr_layer)             # <<<<<<<<<<<<<<
 *         if cogr_featuredefn is NULL:
 *             raise ValueError("Null feature definition")
 */
  __pyx_v_cogr_featuredefn = OGR_L_GetLayerDefn(__pyx_v_self->cogr_layer);

  /* "fiona/ogrext.pyx":696
 * 
 *         cogr_featuredefn = ograpi.OGR_L_GetLayerDefn(self.cogr_layer)
 *         if cogr_featuredefn is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null feature definition")
 *         n = ograpi.OGR_FD_GetFieldCount(cogr_featuredefn)
 */
  __pyx_t_2 = ((__pyx_v_cogr_featuredefn == NULL) != 0);
  if (__pyx_t_2) {

    /* "fiona/ogrext.pyx":697
 *         cogr_featuredefn = ograpi.OGR_L_GetLayerDefn(self.cogr_layer)
 *         if cogr_featuredefn is NULL:
 *             raise ValueError("Null feature definition")             # <<<<<<<<<<<<<<
 *         n = ograpi.OGR_FD_GetFieldCount(cogr_featuredefn)
 *         for i from 0 <= i < n:
 */
    __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__24, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 697; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 697; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":698
 *         if cogr_featuredefn is NULL:
 *             raise ValueError("Null feature definition")
 *         n = ograpi.OGR_FD_GetFieldCount(cogr_featuredefn)             # <<<<<<<<<<<<<<
 *         for i from 0 <= i < n:
 *             cogr_fielddefn = ograpi.OGR_FD_GetFieldDefn(cogr_featuredefn, i)
 */
  __pyx_v_n = OGR_FD_GetFieldCount(__pyx_v_cogr_featuredefn);

  /* "fiona/ogrext.pyx":699
 *             raise ValueError("Null feature definition")
 *         n = ograpi.OGR_FD_GetFieldCount(cogr_featuredefn)
 *         for i from 0 <= i < n:             # <<<<<<<<<<<<<<
 *             cogr_fielddefn = ograpi.OGR_FD_GetFieldDefn(cogr_featuredefn, i)
 *             if cogr_fielddefn is NULL:
 */
  __pyx_t_3 = __pyx_v_n;
  for (__pyx_v_i = 0; __pyx_v_i < __pyx_t_3; __pyx_v_i++) {

    /* "fiona/ogrext.pyx":700
 *         n = ograpi.OGR_FD_GetFieldCount(cogr_featuredefn)
 *         for i from 0 <= i < n:
 *             cogr_fielddefn = ograpi.OGR_FD_GetFieldDefn(cogr_featuredefn, i)             # <<<<<<<<<<<<<<
 *             if cogr_fielddefn is NULL:
 *                 raise ValueError("Null field definition")
 */
    __pyx_v_cogr_fielddefn = OGR_FD_GetFieldDefn(__pyx_v_cogr_featuredefn, __pyx_v_i);

    /* "fiona/ogrext.pyx":701
 *         for i from 0 <= i < n:
 *             cogr_fielddefn = ograpi.OGR_FD_GetFieldDefn(cogr_featuredefn, i)
 *             if cogr_fielddefn is NULL:             # <<<<<<<<<<<<<<
 *                 raise ValueError("Null field definition")
 *             key_c = ograpi.OGR_Fld_GetNameRef(cogr_fielddefn)
 */
    __pyx_t_2 = ((__pyx_v_cogr_fielddefn == NULL) != 0);
    if (__pyx_t_2) {

      /* "fiona/ogrext.pyx":702
 *             cogr_fielddefn = ograpi.OGR_FD_GetFieldDefn(cogr_featuredefn, i)
 *             if cogr_fielddefn is NULL:
 *                 raise ValueError("Null field definition")             # <<<<<<<<<<<<<<
 *             key_c = ograpi.OGR_Fld_GetNameRef(cogr_fielddefn)
 *             key_b = key_c
 */
      __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__25, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 702; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 702; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }

    /* "fiona/ogrext.pyx":703
 *             if cogr_fielddefn is NULL:
 *                 raise ValueError("Null field definition")
 *             key_c = ograpi.OGR_Fld_GetNameRef(cogr_fielddefn)             # <<<<<<<<<<<<<<
 *             key_b = key_c
 *             if not bool(key_b):
 */
    __pyx_v_key_c = OGR_Fld_GetNameRef(__pyx_v_cogr_fielddefn);

    /* "fiona/ogrext.pyx":704
 *                 raise ValueError("Null field definition")
 *             key_c = ograpi.OGR_Fld_GetNameRef(cogr_fielddefn)
 *             key_b = key_c             # <<<<<<<<<<<<<<
 *             if not bool(key_b):
 *                 raise ValueError("Invalid field name ref: %s" % key)
 */
    __pyx_v_key_b = __pyx_v_key_c;

    /* "fiona/ogrext.pyx":705
 *             key_c = ograpi.OGR_Fld_GetNameRef(cogr_fielddefn)
 *             key_b = key_c
 *             if not bool(key_b):             # <<<<<<<<<<<<<<
 *                 raise ValueError("Invalid field name ref: %s" % key)
 *             key = key_b.decode('utf-8')
 */
    __pyx_t_1 = __Pyx_PyBytes_FromString(__pyx_v_key_b); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 705; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = (__pyx_t_1 != Py_None) && (PyBytes_GET_SIZE(__pyx_t_1) != 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_4 = ((!((!(!__pyx_t_2)) != 0)) != 0);
    if (__pyx_t_4) {

      /* "fiona/ogrext.pyx":706
 *             key_b = key_c
 *             if not bool(key_b):
 *                 raise ValueError("Invalid field name ref: %s" % key)             # <<<<<<<<<<<<<<
 *             key = key_b.decode('utf-8')
 *             fieldtypename = FIELD_TYPES[ograpi.OGR_Fld_GetType(cogr_fielddefn)]
 */
      if (unlikely(!__pyx_v_key)) { __Pyx_RaiseUnboundLocalError("key"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 706; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
      __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Invalid_field_name_ref_s, __pyx_v_key); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 706; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 706; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 706; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 706; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }

    /* "fiona/ogrext.pyx":707
 *             if not bool(key_b):
 *                 raise ValueError("Invalid field name ref: %s" % key)
 *             key = key_b.decode('utf-8')             # <<<<<<<<<<<<<<
 *             fieldtypename = FIELD_TYPES[ograpi.OGR_Fld_GetType(cogr_fielddefn)]
 *             if not fieldtypename:
 */
    __pyx_t_1 = __Pyx_decode_c_string(__pyx_v_key_b, 0, strlen(__pyx_v_key_b), NULL, NULL, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 707; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "fiona/ogrext.pyx":708
 *                 raise ValueError("Invalid field name ref: %s" % key)
 *             key = key_b.decode('utf-8')
 *             fieldtypename = FIELD_TYPES[ograpi.OGR_Fld_GetType(cogr_fielddefn)]             # <<<<<<<<<<<<<<
 *             if not fieldtypename:
 *                 log.warn(
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_FIELD_TYPES); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 708; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = OGR_Fld_GetType(__pyx_v_cogr_fielddefn);
    __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_1, __pyx_t_6, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(__pyx_t_5 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 708; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_fieldtypename, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "fiona/ogrext.pyx":709
 *             key = key_b.decode('utf-8')
 *             fieldtypename = FIELD_TYPES[ograpi.OGR_Fld_GetType(cogr_fielddefn)]
 *             if not fieldtypename:             # <<<<<<<<<<<<<<
 *                 log.warn(
 *                     "Skipping field %s: invalid type %s",
 */
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_fieldtypename); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 709; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_2 = ((!__pyx_t_4) != 0);
    if (__pyx_t_2) {

      /* "fiona/ogrext.pyx":710
 *             fieldtypename = FIELD_TYPES[ograpi.OGR_Fld_GetType(cogr_fielddefn)]
 *             if not fieldtypename:
 *                 log.warn(             # <<<<<<<<<<<<<<
 *                     "Skipping field %s: invalid type %s",
 *                     key,
 */
      __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 710; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_warn); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 710; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "fiona/ogrext.pyx":713
 *                     "Skipping field %s: invalid type %s",
 *                     key,
 *                     ograpi.OGR_Fld_GetType(cogr_fielddefn))             # <<<<<<<<<<<<<<
 *                 continue
 *             val = fieldtypename
 */
      __pyx_t_5 = __Pyx_PyInt_From_int(OGR_Fld_GetType(__pyx_v_cogr_fielddefn)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 713; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);

      /* "fiona/ogrext.pyx":710
 *             fieldtypename = FIELD_TYPES[ograpi.OGR_Fld_GetType(cogr_fielddefn)]
 *             if not fieldtypename:
 *                 log.warn(             # <<<<<<<<<<<<<<
 *                     "Skipping field %s: invalid type %s",
 *                     key,
 */
      __pyx_t_7 = PyTuple_New(3); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 710; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_kp_s_Skipping_field_s_invalid_type_s);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_kp_s_Skipping_field_s_invalid_type_s);
      __Pyx_GIVEREF(__pyx_kp_s_Skipping_field_s_invalid_type_s);
      __Pyx_INCREF(__pyx_v_key);
      PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_key);
      __Pyx_GIVEREF(__pyx_v_key);
      PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      __pyx_t_5 = 0;
      __pyx_t_5 = PyObject_Call(__pyx_t_1, __pyx_t_7, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 710; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "fiona/ogrext.pyx":714
 *                     key,
 *                     ograpi.OGR_Fld_GetType(cogr_fielddefn))
 *                 continue             # <<<<<<<<<<<<<<
 *             val = fieldtypename
 *             if fieldtypename == 'float':
 */
      goto __pyx_L5_continue;
    }

    /* "fiona/ogrext.pyx":715
 *                     ograpi.OGR_Fld_GetType(cogr_fielddefn))
 *                 continue
 *             val = fieldtypename             # <<<<<<<<<<<<<<
 *             if fieldtypename == 'float':
 *                 fmt = ""
 */
    __Pyx_INCREF(__pyx_v_fieldtypename);
    __Pyx_XDECREF_SET(__pyx_v_val, __pyx_v_fieldtypename);

    /* "fiona/ogrext.pyx":716
 *                 continue
 *             val = fieldtypename
 *             if fieldtypename == 'float':             # <<<<<<<<<<<<<<
 *                 fmt = ""
 *                 width = ograpi.OGR_Fld_GetWidth(cogr_fielddefn)
 */
    __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_v_fieldtypename, __pyx_n_s_float, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 716; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (__pyx_t_2) {

      /* "fiona/ogrext.pyx":717
 *             val = fieldtypename
 *             if fieldtypename == 'float':
 *                 fmt = ""             # <<<<<<<<<<<<<<
 *                 width = ograpi.OGR_Fld_GetWidth(cogr_fielddefn)
 *                 if width and width != 24:
 */
      __Pyx_INCREF(__pyx_kp_s__20);
      __Pyx_XDECREF_SET(__pyx_v_fmt, __pyx_kp_s__20);

      /* "fiona/ogrext.pyx":718
 *             if fieldtypename == 'float':
 *                 fmt = ""
 *                 width = ograpi.OGR_Fld_GetWidth(cogr_fielddefn)             # <<<<<<<<<<<<<<
 *                 if width and width != 24:
 *                     fmt = ":%d" % width
 */
      __pyx_t_5 = __Pyx_PyInt_From_int(OGR_Fld_GetWidth(__pyx_v_cogr_fielddefn)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 718; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_width, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "fiona/ogrext.pyx":719
 *                 fmt = ""
 *                 width = ograpi.OGR_Fld_GetWidth(cogr_fielddefn)
 *                 if width and width != 24:             # <<<<<<<<<<<<<<
 *                     fmt = ":%d" % width
 *                 precision = ograpi.OGR_Fld_GetPrecision(cogr_fielddefn)
 */
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_width); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 719; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (__pyx_t_2) {
        __pyx_t_5 = PyObject_RichCompare(__pyx_v_width, __pyx_int_24, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 719; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 719; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_8 = __pyx_t_4;
      } else {
        __pyx_t_8 = __pyx_t_2;
      }
      if (__pyx_t_8) {

        /* "fiona/ogrext.pyx":720
 *                 width = ograpi.OGR_Fld_GetWidth(cogr_fielddefn)
 *                 if width and width != 24:
 *                     fmt = ":%d" % width             # <<<<<<<<<<<<<<
 *                 precision = ograpi.OGR_Fld_GetPrecision(cogr_fielddefn)
 *                 if precision and precision != 15:
 */
        __pyx_t_5 = __Pyx_PyString_Format(__pyx_kp_s_d, __pyx_v_width); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 720; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF_SET(__pyx_v_fmt, __pyx_t_5);
        __pyx_t_5 = 0;
        goto __pyx_L11;
      }
      __pyx_L11:;

      /* "fiona/ogrext.pyx":721
 *                 if width and width != 24:
 *                     fmt = ":%d" % width
 *                 precision = ograpi.OGR_Fld_GetPrecision(cogr_fielddefn)             # <<<<<<<<<<<<<<
 *                 if precision and precision != 15:
 *                     fmt += ".%d" % precision
 */
      __pyx_t_5 = __Pyx_PyInt_From_int(OGR_Fld_GetPrecision(__pyx_v_cogr_fielddefn)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 721; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_precision, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "fiona/ogrext.pyx":722
 *                     fmt = ":%d" % width
 *                 precision = ograpi.OGR_Fld_GetPrecision(cogr_fielddefn)
 *                 if precision and precision != 15:             # <<<<<<<<<<<<<<
 *                     fmt += ".%d" % precision
 *                 val = "float" + fmt
 */
      __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_precision); if (unlikely(__pyx_t_8 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 722; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (__pyx_t_8) {
        __pyx_t_5 = PyObject_RichCompare(__pyx_v_precision, __pyx_int_15, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 722; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 722; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_4 = __pyx_t_2;
      } else {
        __pyx_t_4 = __pyx_t_8;
      }
      if (__pyx_t_4) {

        /* "fiona/ogrext.pyx":723
 *                 precision = ograpi.OGR_Fld_GetPrecision(cogr_fielddefn)
 *                 if precision and precision != 15:
 *                     fmt += ".%d" % precision             # <<<<<<<<<<<<<<
 *                 val = "float" + fmt
 *             elif fieldtypename == 'int':
 */
        __pyx_t_5 = __Pyx_PyString_Format(__pyx_kp_s_d_2, __pyx_v_precision); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 723; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_7 = PyNumber_InPlaceAdd(__pyx_v_fmt, __pyx_t_5); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 723; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF_SET(__pyx_v_fmt, __pyx_t_7);
        __pyx_t_7 = 0;
        goto __pyx_L12;
      }
      __pyx_L12:;

      /* "fiona/ogrext.pyx":724
 *                 if precision and precision != 15:
 *                     fmt += ".%d" % precision
 *                 val = "float" + fmt             # <<<<<<<<<<<<<<
 *             elif fieldtypename == 'int':
 *                 fmt = ""
 */
      __pyx_t_7 = PyNumber_Add(__pyx_n_s_float, __pyx_v_fmt); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 724; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF_SET(__pyx_v_val, __pyx_t_7);
      __pyx_t_7 = 0;
      goto __pyx_L10;
    }

    /* "fiona/ogrext.pyx":725
 *                     fmt += ".%d" % precision
 *                 val = "float" + fmt
 *             elif fieldtypename == 'int':             # <<<<<<<<<<<<<<
 *                 fmt = ""
 *                 width = ograpi.OGR_Fld_GetWidth(cogr_fielddefn)
 */
    __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_fieldtypename, __pyx_n_s_int, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 725; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (__pyx_t_4) {

      /* "fiona/ogrext.pyx":726
 *                 val = "float" + fmt
 *             elif fieldtypename == 'int':
 *                 fmt = ""             # <<<<<<<<<<<<<<
 *                 width = ograpi.OGR_Fld_GetWidth(cogr_fielddefn)
 *                 if width and width != 11:
 */
      __Pyx_INCREF(__pyx_kp_s__20);
      __Pyx_XDECREF_SET(__pyx_v_fmt, __pyx_kp_s__20);

      /* "fiona/ogrext.pyx":727
 *             elif fieldtypename == 'int':
 *                 fmt = ""
 *                 width = ograpi.OGR_Fld_GetWidth(cogr_fielddefn)             # <<<<<<<<<<<<<<
 *                 if width and width != 11:
 *                     fmt = ":%d" % width
 */
      __pyx_t_7 = __Pyx_PyInt_From_int(OGR_Fld_GetWidth(__pyx_v_cogr_fielddefn)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 727; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_XDECREF_SET(__pyx_v_width, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "fiona/ogrext.pyx":728
 *                 fmt = ""
 *                 width = ograpi.OGR_Fld_GetWidth(cogr_fielddefn)
 *                 if width and width != 11:             # <<<<<<<<<<<<<<
 *                     fmt = ":%d" % width
 *                 val = fieldtypename + fmt
 */
      __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_width); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 728; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (__pyx_t_4) {
        __pyx_t_7 = PyObject_RichCompare(__pyx_v_width, __pyx_int_11, Py_NE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 728; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_8 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 728; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_2 = __pyx_t_8;
      } else {
        __pyx_t_2 = __pyx_t_4;
      }
      if (__pyx_t_2) {

        /* "fiona/ogrext.pyx":729
 *                 width = ograpi.OGR_Fld_GetWidth(cogr_fielddefn)
 *                 if width and width != 11:
 *                     fmt = ":%d" % width             # <<<<<<<<<<<<<<
 *                 val = fieldtypename + fmt
 *             elif fieldtypename == 'str':
 */
        __pyx_t_7 = __Pyx_PyString_Format(__pyx_kp_s_d, __pyx_v_width); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 729; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF_SET(__pyx_v_fmt, __pyx_t_7);
        __pyx_t_7 = 0;
        goto __pyx_L13;
      }
      __pyx_L13:;

      /* "fiona/ogrext.pyx":730
 *                 if width and width != 11:
 *                     fmt = ":%d" % width
 *                 val = fieldtypename + fmt             # <<<<<<<<<<<<<<
 *             elif fieldtypename == 'str':
 *                 fmt = ""
 */
      __pyx_t_7 = PyNumber_Add(__pyx_v_fieldtypename, __pyx_v_fmt); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 730; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF_SET(__pyx_v_val, __pyx_t_7);
      __pyx_t_7 = 0;
      goto __pyx_L10;
    }

    /* "fiona/ogrext.pyx":731
 *                     fmt = ":%d" % width
 *                 val = fieldtypename + fmt
 *             elif fieldtypename == 'str':             # <<<<<<<<<<<<<<
 *                 fmt = ""
 *                 width = ograpi.OGR_Fld_GetWidth(cogr_fielddefn)
 */
    __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_v_fieldtypename, __pyx_n_s_str, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 731; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (__pyx_t_2) {

      /* "fiona/ogrext.pyx":732
 *                 val = fieldtypename + fmt
 *             elif fieldtypename == 'str':
 *                 fmt = ""             # <<<<<<<<<<<<<<
 *                 width = ograpi.OGR_Fld_GetWidth(cogr_fielddefn)
 *                 if width and width != 80:
 */
      __Pyx_INCREF(__pyx_kp_s__20);
      __Pyx_XDECREF_SET(__pyx_v_fmt, __pyx_kp_s__20);

      /* "fiona/ogrext.pyx":733
 *             elif fieldtypename == 'str':
 *                 fmt = ""
 *                 width = ograpi.OGR_Fld_GetWidth(cogr_fielddefn)             # <<<<<<<<<<<<<<
 *                 if width and width != 80:
 *                     fmt = ":%d" % width
 */
      __pyx_t_7 = __Pyx_PyInt_From_int(OGR_Fld_GetWidth(__pyx_v_cogr_fielddefn)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 733; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_XDECREF_SET(__pyx_v_width, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "fiona/ogrext.pyx":734
 *                 fmt = ""
 *                 width = ograpi.OGR_Fld_GetWidth(cogr_fielddefn)
 *                 if width and width != 80:             # <<<<<<<<<<<<<<
 *                     fmt = ":%d" % width
 *                 val = fieldtypename + fmt
 */
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_width); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 734; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (__pyx_t_2) {
        __pyx_t_7 = PyObject_RichCompare(__pyx_v_width, __pyx_int_80, Py_NE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 734; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 734; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_8 = __pyx_t_4;
      } else {
        __pyx_t_8 = __pyx_t_2;
      }
      if (__pyx_t_8) {

        /* "fiona/ogrext.pyx":735
 *                 width = ograpi.OGR_Fld_GetWidth(cogr_fielddefn)
 *                 if width and width != 80:
 *                     fmt = ":%d" % width             # <<<<<<<<<<<<<<
 *                 val = fieldtypename + fmt
 * 
 */
        __pyx_t_7 = __Pyx_PyString_Format(__pyx_kp_s_d, __pyx_v_width); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 735; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF_SET(__pyx_v_fmt, __pyx_t_7);
        __pyx_t_7 = 0;
        goto __pyx_L14;
      }
      __pyx_L14:;

      /* "fiona/ogrext.pyx":736
 *                 if width and width != 80:
 *                     fmt = ":%d" % width
 *                 val = fieldtypename + fmt             # <<<<<<<<<<<<<<
 * 
 *             props.append((key, val))
 */
      __pyx_t_7 = PyNumber_Add(__pyx_v_fieldtypename, __pyx_v_fmt); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 736; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF_SET(__pyx_v_val, __pyx_t_7);
      __pyx_t_7 = 0;
      goto __pyx_L10;
    }
    __pyx_L10:;

    /* "fiona/ogrext.pyx":738
 *                 val = fieldtypename + fmt
 * 
 *             props.append((key, val))             # <<<<<<<<<<<<<<
 * 
 *         cdef unsigned int geom_type = ograpi.OGR_FD_GetGeomType(
 */
    __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 738; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_v_key);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_key);
    __Pyx_GIVEREF(__pyx_v_key);
    __Pyx_INCREF(__pyx_v_val);
    PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_v_val);
    __Pyx_GIVEREF(__pyx_v_val);
    __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_props, __pyx_t_7); if (unlikely(__pyx_t_9 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 738; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_L5_continue:;
  }

  /* "fiona/ogrext.pyx":740
 *             props.append((key, val))
 * 
 *         cdef unsigned int geom_type = ograpi.OGR_FD_GetGeomType(             # <<<<<<<<<<<<<<
 *             cogr_featuredefn)
 *         return {
 */
  __pyx_v_geom_type = OGR_FD_GetGeomType(__pyx_v_cogr_featuredefn);

  /* "fiona/ogrext.pyx":742
 *         cdef unsigned int geom_type = ograpi.OGR_FD_GetGeomType(
 *             cogr_featuredefn)
 *         return {             # <<<<<<<<<<<<<<
 *             'properties': OrderedDict(props),
 *             'geometry': GEOMETRY_TYPES[geom_type]}
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = PyDict_New(); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 742; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);

  /* "fiona/ogrext.pyx":743
 *             cogr_featuredefn)
 *         return {
 *             'properties': OrderedDict(props),             # <<<<<<<<<<<<<<
 *             'geometry': GEOMETRY_TYPES[geom_type]}
 * 
 */
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_OrderedDict); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 743; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 743; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_props);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_props);
  __Pyx_GIVEREF(__pyx_v_props);
  __pyx_t_10 = PyObject_Call(__pyx_t_5, __pyx_t_1, NULL); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 743; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_properties, __pyx_t_10) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 742; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "fiona/ogrext.pyx":744
 *         return {
 *             'properties': OrderedDict(props),
 *             'geometry': GEOMETRY_TYPES[geom_type]}             # <<<<<<<<<<<<<<
 * 
 *     def get_crs(self):
 */
  __pyx_t_10 = __Pyx_GetModuleGlobalName(__pyx_n_s_GEOMETRY_TYPES); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 744; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_t_10, __pyx_v_geom_type, unsigned int, 0, __Pyx_PyInt_From_unsigned_int, 0, 0, 1); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 744; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_geometry, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 742; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_7;
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":684
 *         return driver_name.decode()
 * 
 *     def get_schema(self):             # <<<<<<<<<<<<<<
 *         cdef int i
 *         cdef int n
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("fiona.ogrext.Session.get_schema", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_props);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_fieldtypename);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XDECREF(__pyx_v_fmt);
  __Pyx_XDECREF(__pyx_v_width);
  __Pyx_XDECREF(__pyx_v_precision);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":746
 *             'geometry': GEOMETRY_TYPES[geom_type]}
 * 
 *     def get_crs(self):             # <<<<<<<<<<<<<<
 *         cdef char *proj_c = NULL
 *         if self.cogr_layer is NULL:
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_19get_crs(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_19get_crs(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_crs (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_7Session_18get_crs(((struct __pyx_obj_5fiona_6ogrext_Session *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_7Session_18get_crs(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self) {
  char *__pyx_v_proj_c;
  void *__pyx_v_cogr_crs;
  PyObject *__pyx_v_crs = NULL;
  char *__pyx_v_proj_b;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_param = NULL;
  PyObject *__pyx_v_kv = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *(*__pyx_t_9)(PyObject *);
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  double __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_crs", 0);

  /* "fiona/ogrext.pyx":747
 * 
 *     def get_crs(self):
 *         cdef char *proj_c = NULL             # <<<<<<<<<<<<<<
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer")
 */
  __pyx_v_proj_c = NULL;

  /* "fiona/ogrext.pyx":748
 *     def get_crs(self):
 *         cdef char *proj_c = NULL
 *         if self.cogr_layer is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null layer")
 *         cdef void *cogr_crs = ograpi.OGR_L_GetSpatialRef(self.cogr_layer)
 */
  __pyx_t_1 = ((__pyx_v_self->cogr_layer == NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":749
 *         cdef char *proj_c = NULL
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 *         cdef void *cogr_crs = ograpi.OGR_L_GetSpatialRef(self.cogr_layer)
 *         log.debug("Got coordinate system")
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__26, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 749; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 749; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":750
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer")
 *         cdef void *cogr_crs = ograpi.OGR_L_GetSpatialRef(self.cogr_layer)             # <<<<<<<<<<<<<<
 *         log.debug("Got coordinate system")
 *         crs = {}
 */
  __pyx_v_cogr_crs = OGR_L_GetSpatialRef(__pyx_v_self->cogr_layer);

  /* "fiona/ogrext.pyx":751
 *             raise ValueError("Null layer")
 *         cdef void *cogr_crs = ograpi.OGR_L_GetSpatialRef(self.cogr_layer)
 *         log.debug("Got coordinate system")             # <<<<<<<<<<<<<<
 *         crs = {}
 *         if cogr_crs is not NULL:
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 751; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_debug); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 751; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_3, __pyx_tuple__27, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 751; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":752
 *         cdef void *cogr_crs = ograpi.OGR_L_GetSpatialRef(self.cogr_layer)
 *         log.debug("Got coordinate system")
 *         crs = {}             # <<<<<<<<<<<<<<
 *         if cogr_crs is not NULL:
 *             ograpi.OSRExportToProj4(cogr_crs, &proj_c)
 */
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 752; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_crs = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":753
 *         log.debug("Got coordinate system")
 *         crs = {}
 *         if cogr_crs is not NULL:             # <<<<<<<<<<<<<<
 *             ograpi.OSRExportToProj4(cogr_crs, &proj_c)
 *             if proj_c is NULL:
 */
  __pyx_t_1 = ((__pyx_v_cogr_crs != NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":754
 *         crs = {}
 *         if cogr_crs is not NULL:
 *             ograpi.OSRExportToProj4(cogr_crs, &proj_c)             # <<<<<<<<<<<<<<
 *             if proj_c is NULL:
 *                 raise ValueError("Null projection")
 */
    OSRExportToProj4(__pyx_v_cogr_crs, (&__pyx_v_proj_c));

    /* "fiona/ogrext.pyx":755
 *         if cogr_crs is not NULL:
 *             ograpi.OSRExportToProj4(cogr_crs, &proj_c)
 *             if proj_c is NULL:             # <<<<<<<<<<<<<<
 *                 raise ValueError("Null projection")
 *             proj_b = proj_c
 */
    __pyx_t_1 = ((__pyx_v_proj_c == NULL) != 0);
    if (__pyx_t_1) {

      /* "fiona/ogrext.pyx":756
 *             ograpi.OSRExportToProj4(cogr_crs, &proj_c)
 *             if proj_c is NULL:
 *                 raise ValueError("Null projection")             # <<<<<<<<<<<<<<
 *             proj_b = proj_c
 *             log.debug("Params: %s", proj_b)
 */
      __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__28, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 756; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 756; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }

    /* "fiona/ogrext.pyx":757
 *             if proj_c is NULL:
 *                 raise ValueError("Null projection")
 *             proj_b = proj_c             # <<<<<<<<<<<<<<
 *             log.debug("Params: %s", proj_b)
 *             value = proj_b.decode()
 */
    __pyx_v_proj_b = __pyx_v_proj_c;

    /* "fiona/ogrext.pyx":758
 *                 raise ValueError("Null projection")
 *             proj_b = proj_c
 *             log.debug("Params: %s", proj_b)             # <<<<<<<<<<<<<<
 *             value = proj_b.decode()
 *             value = value.strip()
 */
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 758; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_debug); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 758; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyBytes_FromString(__pyx_v_proj_b); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 758; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 758; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_kp_s_Params_s);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_kp_s_Params_s);
    __Pyx_GIVEREF(__pyx_kp_s_Params_s);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 758; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "fiona/ogrext.pyx":759
 *             proj_b = proj_c
 *             log.debug("Params: %s", proj_b)
 *             value = proj_b.decode()             # <<<<<<<<<<<<<<
 *             value = value.strip()
 *             for param in value.split():
 */
    __pyx_t_2 = __Pyx_decode_c_string(__pyx_v_proj_b, 0, strlen(__pyx_v_proj_b), NULL, NULL, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 759; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_value = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "fiona/ogrext.pyx":760
 *             log.debug("Params: %s", proj_b)
 *             value = proj_b.decode()
 *             value = value.strip()             # <<<<<<<<<<<<<<
 *             for param in value.split():
 *                 kv = param.split("=")
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_n_s_strip); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 760; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyObject_Call(__pyx_t_2, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 760; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "fiona/ogrext.pyx":761
 *             value = proj_b.decode()
 *             value = value.strip()
 *             for param in value.split():             # <<<<<<<<<<<<<<
 *                 kv = param.split("=")
 *                 if len(kv) == 2:
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_n_s_split); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 761; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = PyObject_Call(__pyx_t_4, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 761; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (PyList_CheckExact(__pyx_t_2) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_4 = __pyx_t_2; __Pyx_INCREF(__pyx_t_4); __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 761; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = Py_TYPE(__pyx_t_4)->tp_iternext;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (!__pyx_t_6 && PyList_CheckExact(__pyx_t_4)) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 761; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 761; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else if (!__pyx_t_6 && PyTuple_CheckExact(__pyx_t_4)) {
        if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 761; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 761; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else {
        __pyx_t_2 = __pyx_t_6(__pyx_t_4);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 761; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_v_param, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "fiona/ogrext.pyx":762
 *             value = value.strip()
 *             for param in value.split():
 *                 kv = param.split("=")             # <<<<<<<<<<<<<<
 *                 if len(kv) == 2:
 *                     k, v = kv
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_param, __pyx_n_s_split); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 762; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyObject_Call(__pyx_t_2, __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 762; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_kv, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "fiona/ogrext.pyx":763
 *             for param in value.split():
 *                 kv = param.split("=")
 *                 if len(kv) == 2:             # <<<<<<<<<<<<<<
 *                     k, v = kv
 *                     try:
 */
      __pyx_t_7 = PyObject_Length(__pyx_v_kv); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 763; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_1 = ((__pyx_t_7 == 2) != 0);
      if (__pyx_t_1) {

        /* "fiona/ogrext.pyx":764
 *                 kv = param.split("=")
 *                 if len(kv) == 2:
 *                     k, v = kv             # <<<<<<<<<<<<<<
 *                     try:
 *                         v = float(v)
 */
        if ((likely(PyTuple_CheckExact(__pyx_v_kv))) || (PyList_CheckExact(__pyx_v_kv))) {
          PyObject* sequence = __pyx_v_kv;
          #if CYTHON_COMPILING_IN_CPYTHON
          Py_ssize_t size = Py_SIZE(sequence);
          #else
          Py_ssize_t size = PySequence_Size(sequence);
          #endif
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            {__pyx_filename = __pyx_f[0]; __pyx_lineno = 764; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          #if CYTHON_COMPILING_IN_CPYTHON
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_2);
          #else
          __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 764; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 764; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          Py_ssize_t index = -1;
          __pyx_t_8 = PyObject_GetIter(__pyx_v_kv); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 764; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_9 = Py_TYPE(__pyx_t_8)->tp_iternext;
          index = 0; __pyx_t_3 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_3)) goto __pyx_L9_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_3);
          index = 1; __pyx_t_2 = __pyx_t_9(__pyx_t_8); if (unlikely(!__pyx_t_2)) goto __pyx_L9_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_2);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_9(__pyx_t_8), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 764; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_9 = NULL;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          goto __pyx_L10_unpacking_done;
          __pyx_L9_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_9 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 764; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_L10_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_3);
        __pyx_t_3 = 0;
        __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "fiona/ogrext.pyx":765
 *                 if len(kv) == 2:
 *                     k, v = kv
 *                     try:             # <<<<<<<<<<<<<<
 *                         v = float(v)
 *                         if v % 1 == 0:
 */
        {
          __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          /*try:*/ {

            /* "fiona/ogrext.pyx":766
 *                     k, v = kv
 *                     try:
 *                         v = float(v)             # <<<<<<<<<<<<<<
 *                         if v % 1 == 0:
 *                             v = int(v)
 */
            __pyx_t_13 = __Pyx_PyObject_AsDouble(__pyx_v_v); if (unlikely(__pyx_t_13 == ((double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 766; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
            __pyx_t_2 = PyFloat_FromDouble(__pyx_t_13); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 766; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF_SET(__pyx_v_v, __pyx_t_2);
            __pyx_t_2 = 0;

            /* "fiona/ogrext.pyx":767
 *                     try:
 *                         v = float(v)
 *                         if v % 1 == 0:             # <<<<<<<<<<<<<<
 *                             v = int(v)
 *                     except ValueError:
 */
            __pyx_t_2 = PyNumber_Remainder(__pyx_v_v, __pyx_int_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 767; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_int_0, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 767; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 767; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (__pyx_t_1) {

              /* "fiona/ogrext.pyx":768
 *                         v = float(v)
 *                         if v % 1 == 0:
 *                             v = int(v)             # <<<<<<<<<<<<<<
 *                     except ValueError:
 *                         # Leave v as a string
 */
              __pyx_t_3 = PyNumber_Int(__pyx_v_v); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 768; __pyx_clineno = __LINE__; goto __pyx_L11_error;}
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF_SET(__pyx_v_v, __pyx_t_3);
              __pyx_t_3 = 0;
              goto __pyx_L19;
            }
            __pyx_L19:;
          }
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          goto __pyx_L18_try_end;
          __pyx_L11_error:;
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

          /* "fiona/ogrext.pyx":769
 *                         if v % 1 == 0:
 *                             v = int(v)
 *                     except ValueError:             # <<<<<<<<<<<<<<
 *                         # Leave v as a string
 *                         pass
 */
          __pyx_t_14 = PyErr_ExceptionMatches(__pyx_builtin_ValueError);
          if (__pyx_t_14) {
            PyErr_Restore(0,0,0);
            goto __pyx_L12_exception_handled;
          }
          goto __pyx_L13_except_error;
          __pyx_L13_except_error:;
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          goto __pyx_L1_error;
          __pyx_L12_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          __pyx_L18_try_end:;
        }
        goto __pyx_L8;
      }

      /* "fiona/ogrext.pyx":772
 *                         # Leave v as a string
 *                         pass
 *                 elif len(kv) == 1:             # <<<<<<<<<<<<<<
 *                     k, v = kv[0], True
 *                 else:
 */
      __pyx_t_7 = PyObject_Length(__pyx_v_kv); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_1 = ((__pyx_t_7 == 1) != 0);
      if (__pyx_t_1) {

        /* "fiona/ogrext.pyx":773
 *                         pass
 *                 elif len(kv) == 1:
 *                     k, v = kv[0], True             # <<<<<<<<<<<<<<
 *                 else:
 *                     raise ValueError("Unexpected proj parameter %s" % param)
 */
        __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_kv, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 773; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = Py_True;
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_3);
        __pyx_t_3 = 0;
        __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_2);
        __pyx_t_2 = 0;
        goto __pyx_L8;
      }
      /*else*/ {

        /* "fiona/ogrext.pyx":775
 *                     k, v = kv[0], True
 *                 else:
 *                     raise ValueError("Unexpected proj parameter %s" % param)             # <<<<<<<<<<<<<<
 *                 k = k.lstrip("+")
 *                 crs[k] = v
 */
        __pyx_t_2 = __Pyx_PyString_Format(__pyx_kp_s_Unexpected_proj_parameter_s, __pyx_v_param); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_2);
        __pyx_t_2 = 0;
        __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_L8:;

      /* "fiona/ogrext.pyx":776
 *                 else:
 *                     raise ValueError("Unexpected proj parameter %s" % param)
 *                 k = k.lstrip("+")             # <<<<<<<<<<<<<<
 *                 crs[k] = v
 *             ograpi.CPLFree(proj_c)
 */
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_k, __pyx_n_s_lstrip); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyObject_Call(__pyx_t_2, __pyx_tuple__32, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF_SET(__pyx_v_k, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "fiona/ogrext.pyx":777
 *                     raise ValueError("Unexpected proj parameter %s" % param)
 *                 k = k.lstrip("+")
 *                 crs[k] = v             # <<<<<<<<<<<<<<
 *             ograpi.CPLFree(proj_c)
 *         else:
 */
      if (unlikely(PyDict_SetItem(__pyx_v_crs, __pyx_v_k, __pyx_v_v) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "fiona/ogrext.pyx":778
 *                 k = k.lstrip("+")
 *                 crs[k] = v
 *             ograpi.CPLFree(proj_c)             # <<<<<<<<<<<<<<
 *         else:
 *             log.debug("Projection not found (cogr_crs was NULL)")
 */
    CPLFree(__pyx_v_proj_c);
    goto __pyx_L4;
  }
  /*else*/ {

    /* "fiona/ogrext.pyx":780
 *             ograpi.CPLFree(proj_c)
 *         else:
 *             log.debug("Projection not found (cogr_crs was NULL)")             # <<<<<<<<<<<<<<
 *         return crs
 * 
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 780; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_debug); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 780; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(__pyx_t_3, __pyx_tuple__33, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 780; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_L4:;

  /* "fiona/ogrext.pyx":781
 *         else:
 *             log.debug("Projection not found (cogr_crs was NULL)")
 *         return crs             # <<<<<<<<<<<<<<
 * 
 *     def get_extent(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_crs);
  __pyx_r = __pyx_v_crs;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":746
 *             'geometry': GEOMETRY_TYPES[geom_type]}
 * 
 *     def get_crs(self):             # <<<<<<<<<<<<<<
 *         cdef char *proj_c = NULL
 *         if self.cogr_layer is NULL:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("fiona.ogrext.Session.get_crs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_crs);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_param);
  __Pyx_XDECREF(__pyx_v_kv);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":783
 *         return crs
 * 
 *     def get_extent(self):             # <<<<<<<<<<<<<<
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer")
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_21get_extent(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_21get_extent(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_extent (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_7Session_20get_extent(((struct __pyx_obj_5fiona_6ogrext_Session *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_7Session_20get_extent(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self) {
  __pyx_t_5fiona_6ograpi_OGREnvelope __pyx_v_extent;
  CYTHON_UNUSED __pyx_t_5fiona_6ograpi_OGRErr __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_extent", 0);

  /* "fiona/ogrext.pyx":784
 * 
 *     def get_extent(self):
 *         if self.cogr_layer is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null layer")
 *         cdef ograpi.OGREnvelope extent
 */
  __pyx_t_1 = ((__pyx_v_self->cogr_layer == NULL) != 0);
  if (__pyx_t_1) {

    /* "fiona/ogrext.pyx":785
 *     def get_extent(self):
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 *         cdef ograpi.OGREnvelope extent
 *         result = ograpi.OGR_L_GetExtent(self.cogr_layer, &extent, 1)
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__34, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 785; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 785; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":787
 *             raise ValueError("Null layer")
 *         cdef ograpi.OGREnvelope extent
 *         result = ograpi.OGR_L_GetExtent(self.cogr_layer, &extent, 1)             # <<<<<<<<<<<<<<
 *         return (extent.MinX, extent.MinY, extent.MaxX, extent.MaxY)
 * 
 */
  __pyx_v_result = OGR_L_GetExtent(__pyx_v_self->cogr_layer, (&__pyx_v_extent), 1);

  /* "fiona/ogrext.pyx":788
 *         cdef ograpi.OGREnvelope extent
 *         result = ograpi.OGR_L_GetExtent(self.cogr_layer, &extent, 1)
 *         return (extent.MinX, extent.MinY, extent.MaxX, extent.MaxY)             # <<<<<<<<<<<<<<
 * 
 *     def isactive(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_extent.MinX); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 788; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_extent.MinY); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 788; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyFloat_FromDouble(__pyx_v_extent.MaxX); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 788; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyFloat_FromDouble(__pyx_v_extent.MaxY); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 788; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyTuple_New(4); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 788; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":783
 *         return crs
 * 
 *     def get_extent(self):             # <<<<<<<<<<<<<<
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("fiona.ogrext.Session.get_extent", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":790
 *         return (extent.MinX, extent.MinY, extent.MaxX, extent.MaxY)
 * 
 *     def isactive(self):             # <<<<<<<<<<<<<<
 *         if self.cogr_layer != NULL and self.cogr_ds != NULL:
 *             return 1
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_23isactive(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_7Session_23isactive(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("isactive (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_7Session_22isactive(((struct __pyx_obj_5fiona_6ogrext_Session *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_7Session_22isactive(struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  __Pyx_RefNannySetupContext("isactive", 0);

  /* "fiona/ogrext.pyx":791
 * 
 *     def isactive(self):
 *         if self.cogr_layer != NULL and self.cogr_ds != NULL:             # <<<<<<<<<<<<<<
 *             return 1
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_self->cogr_layer != NULL) != 0);
  if (__pyx_t_1) {
    __pyx_t_2 = ((__pyx_v_self->cogr_ds != NULL) != 0);
    __pyx_t_3 = __pyx_t_2;
  } else {
    __pyx_t_3 = __pyx_t_1;
  }
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":792
 *     def isactive(self):
 *         if self.cogr_layer != NULL and self.cogr_ds != NULL:
 *             return 1             # <<<<<<<<<<<<<<
 *         else:
 *             return 0
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_int_1);
    __pyx_r = __pyx_int_1;
    goto __pyx_L0;
  }
  /*else*/ {

    /* "fiona/ogrext.pyx":794
 *             return 1
 *         else:
 *             return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_int_0);
    __pyx_r = __pyx_int_0;
    goto __pyx_L0;
  }

  /* "fiona/ogrext.pyx":790
 *         return (extent.MinX, extent.MinY, extent.MaxX, extent.MaxY)
 * 
 *     def isactive(self):             # <<<<<<<<<<<<<<
 *         if self.cogr_layer != NULL and self.cogr_ds != NULL:
 *             return 1
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":801
 *     cdef object _schema_mapping
 * 
 *     def start(self, collection):             # <<<<<<<<<<<<<<
 *         cdef void *cogr_fielddefn
 *         cdef void *cogr_driver
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_14WritingSession_1start(PyObject *__pyx_v_self, PyObject *__pyx_v_collection); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_14WritingSession_1start(PyObject *__pyx_v_self, PyObject *__pyx_v_collection) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("start (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_14WritingSession_start(((struct __pyx_obj_5fiona_6ogrext_WritingSession *)__pyx_v_self), ((PyObject *)__pyx_v_collection));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_14WritingSession_start(struct __pyx_obj_5fiona_6ogrext_WritingSession *__pyx_v_self, PyObject *__pyx_v_collection) {
  void *__pyx_v_cogr_fielddefn;
  void *__pyx_v_cogr_driver;
  void *__pyx_v_cogr_ds;
  void *__pyx_v_cogr_layer;
  void *__pyx_v_cogr_srs;
  char **__pyx_v_options;
  char *__pyx_v_path_c;
  char *__pyx_v_driver_c;
  char *__pyx_v_name_c;
  char *__pyx_v_proj_c;
  char *__pyx_v_fileencoding_c;
  PyObject *__pyx_v_path = NULL;
  PyObject *__pyx_v_path_b = NULL;
  PyObject *__pyx_v_name_b = NULL;
  PyObject *__pyx_v_userencoding = NULL;
  PyObject *__pyx_v_driver_b = NULL;
  PyObject *__pyx_v_params = NULL;
  PyObject *__pyx_v_k = NULL;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_v_proj = NULL;
  PyObject *__pyx_v_proj_b = NULL;
  PyObject *__pyx_v_sysencoding = NULL;
  PyObject *__pyx_v_fileencoding = NULL;
  PyObject *__pyx_v_fileencoding_b = NULL;
  int __pyx_v_layer_count;
  PyObject *__pyx_v_layer_names = NULL;
  int __pyx_v_i;
  PyObject *__pyx_v_idx = NULL;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_value = NULL;
  PyObject *__pyx_v_width = NULL;
  PyObject *__pyx_v_precision = NULL;
  PyObject *__pyx_v_fmt = NULL;
  PyObject *__pyx_v_encoding = NULL;
  PyObject *__pyx_v_key_bytes = NULL;
  PyObject *__pyx_v_ogr_schema = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  char *__pyx_t_9;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  Py_ssize_t __pyx_t_12;
  PyObject *(*__pyx_t_13)(PyObject *);
  PyObject *__pyx_t_14 = NULL;
  PyObject *(*__pyx_t_15)(PyObject *);
  int __pyx_t_16;
  int __pyx_t_17;
  int __pyx_t_18;
  int __pyx_t_19;
  PyObject *__pyx_t_20 = NULL;
  unsigned int __pyx_t_21;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("start", 0);

  /* "fiona/ogrext.pyx":806
 *         cdef void *cogr_ds
 *         cdef void *cogr_layer
 *         cdef void *cogr_srs = NULL             # <<<<<<<<<<<<<<
 *         cdef char **options = NULL
 *         self.collection = collection
 */
  __pyx_v_cogr_srs = NULL;

  /* "fiona/ogrext.pyx":807
 *         cdef void *cogr_layer
 *         cdef void *cogr_srs = NULL
 *         cdef char **options = NULL             # <<<<<<<<<<<<<<
 *         self.collection = collection
 *         cdef char *path_c
 */
  __pyx_v_options = NULL;

  /* "fiona/ogrext.pyx":808
 *         cdef void *cogr_srs = NULL
 *         cdef char **options = NULL
 *         self.collection = collection             # <<<<<<<<<<<<<<
 *         cdef char *path_c
 *         cdef char *driver_c
 */
  __Pyx_INCREF(__pyx_v_collection);
  __Pyx_GIVEREF(__pyx_v_collection);
  __Pyx_GOTREF(__pyx_v_self->__pyx_base.collection);
  __Pyx_DECREF(__pyx_v_self->__pyx_base.collection);
  __pyx_v_self->__pyx_base.collection = __pyx_v_collection;

  /* "fiona/ogrext.pyx":814
 *         cdef char *proj_c
 *         cdef char *fileencoding_c
 *         path = collection.path             # <<<<<<<<<<<<<<
 * 
 *         if collection.mode == 'a':
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_path); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 814; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_path = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":816
 *         path = collection.path
 * 
 *         if collection.mode == 'a':             # <<<<<<<<<<<<<<
 *             if os.path.exists(path):
 *                 try:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_mode); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 816; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_n_s_a, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 816; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "fiona/ogrext.pyx":817
 * 
 *         if collection.mode == 'a':
 *             if os.path.exists(path):             # <<<<<<<<<<<<<<
 *                 try:
 *                     path_b = path.encode('utf-8')
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 817; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_path); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 817; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_exists); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 817; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 817; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_path);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_path);
    __Pyx_GIVEREF(__pyx_v_path);
    __pyx_t_4 = PyObject_Call(__pyx_t_1, __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 817; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 817; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_2) {

      /* "fiona/ogrext.pyx":818
 *         if collection.mode == 'a':
 *             if os.path.exists(path):
 *                 try:             # <<<<<<<<<<<<<<
 *                     path_b = path.encode('utf-8')
 *                 except UnicodeDecodeError:
 */
      {
        __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        /*try:*/ {

          /* "fiona/ogrext.pyx":819
 *             if os.path.exists(path):
 *                 try:
 *                     path_b = path.encode('utf-8')             # <<<<<<<<<<<<<<
 *                 except UnicodeDecodeError:
 *                     path_b = path
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_path, __pyx_n_s_encode); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 819; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_3 = PyObject_Call(__pyx_t_4, __pyx_tuple__35, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 819; __pyx_clineno = __LINE__; goto __pyx_L5_error;}
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __pyx_v_path_b = __pyx_t_3;
          __pyx_t_3 = 0;
        }
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L12_try_end;
        __pyx_L5_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "fiona/ogrext.pyx":820
 *                 try:
 *                     path_b = path.encode('utf-8')
 *                 except UnicodeDecodeError:             # <<<<<<<<<<<<<<
 *                     path_b = path
 *                 path_c = path_b
 */
        __pyx_t_8 = PyErr_ExceptionMatches(__pyx_builtin_UnicodeDecodeError);
        if (__pyx_t_8) {
          __Pyx_AddTraceback("fiona.ogrext.WritingSession.start", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_4, &__pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 820; __pyx_clineno = __LINE__; goto __pyx_L7_except_error;}
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_GOTREF(__pyx_t_1);

          /* "fiona/ogrext.pyx":821
 *                     path_b = path.encode('utf-8')
 *                 except UnicodeDecodeError:
 *                     path_b = path             # <<<<<<<<<<<<<<
 *                 path_c = path_b
 *                 self.cogr_ds = ograpi.OGROpen(path_c, 1, NULL)
 */
          __Pyx_INCREF(__pyx_v_path);
          __Pyx_XDECREF_SET(__pyx_v_path_b, __pyx_v_path);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          goto __pyx_L6_exception_handled;
        }
        goto __pyx_L7_except_error;
        __pyx_L7_except_error:;
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
        goto __pyx_L1_error;
        __pyx_L6_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
        __pyx_L12_try_end:;
      }

      /* "fiona/ogrext.pyx":822
 *                 except UnicodeDecodeError:
 *                     path_b = path
 *                 path_c = path_b             # <<<<<<<<<<<<<<
 *                 self.cogr_ds = ograpi.OGROpen(path_c, 1, NULL)
 *                 if self.cogr_ds is NULL:
 */
      __pyx_t_9 = __Pyx_PyObject_AsString(__pyx_v_path_b); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 822; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_path_c = __pyx_t_9;

      /* "fiona/ogrext.pyx":823
 *                     path_b = path
 *                 path_c = path_b
 *                 self.cogr_ds = ograpi.OGROpen(path_c, 1, NULL)             # <<<<<<<<<<<<<<
 *                 if self.cogr_ds is NULL:
 *                     raise RuntimeError("Failed to open %s" % path)
 */
      __pyx_v_self->__pyx_base.cogr_ds = OGROpen(__pyx_v_path_c, 1, NULL);

      /* "fiona/ogrext.pyx":824
 *                 path_c = path_b
 *                 self.cogr_ds = ograpi.OGROpen(path_c, 1, NULL)
 *                 if self.cogr_ds is NULL:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError("Failed to open %s" % path)
 *                 cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 */
      __pyx_t_2 = ((__pyx_v_self->__pyx_base.cogr_ds == NULL) != 0);
      if (__pyx_t_2) {

        /* "fiona/ogrext.pyx":825
 *                 self.cogr_ds = ograpi.OGROpen(path_c, 1, NULL)
 *                 if self.cogr_ds is NULL:
 *                     raise RuntimeError("Failed to open %s" % path)             # <<<<<<<<<<<<<<
 *                 cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 *                 if cogr_driver is NULL:
 */
        __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_open_s, __pyx_v_path); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 825; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 825; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __pyx_t_1 = 0;
        __pyx_t_1 = PyObject_Call(__pyx_builtin_RuntimeError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 825; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_Raise(__pyx_t_1, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 825; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }

      /* "fiona/ogrext.pyx":826
 *                 if self.cogr_ds is NULL:
 *                     raise RuntimeError("Failed to open %s" % path)
 *                 cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)             # <<<<<<<<<<<<<<
 *                 if cogr_driver is NULL:
 *                     raise ValueError("Null driver")
 */
      __pyx_v_cogr_driver = OGR_DS_GetDriver(__pyx_v_self->__pyx_base.cogr_ds);

      /* "fiona/ogrext.pyx":827
 *                     raise RuntimeError("Failed to open %s" % path)
 *                 cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 *                 if cogr_driver is NULL:             # <<<<<<<<<<<<<<
 *                     raise ValueError("Null driver")
 * 
 */
      __pyx_t_2 = ((__pyx_v_cogr_driver == NULL) != 0);
      if (__pyx_t_2) {

        /* "fiona/ogrext.pyx":828
 *                 cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 *                 if cogr_driver is NULL:
 *                     raise ValueError("Null driver")             # <<<<<<<<<<<<<<
 * 
 *                 if isinstance(collection.name, string_types):
 */
        __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__36, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_Raise(__pyx_t_1, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }

      /* "fiona/ogrext.pyx":830
 *                     raise ValueError("Null driver")
 * 
 *                 if isinstance(collection.name, string_types):             # <<<<<<<<<<<<<<
 *                     name_b = collection.name.encode()
 *                     name_c = name_b
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_string_types); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyObject_IsInstance(__pyx_t_1, __pyx_t_4); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_10 = (__pyx_t_2 != 0);
      if (__pyx_t_10) {

        /* "fiona/ogrext.pyx":831
 * 
 *                 if isinstance(collection.name, string_types):
 *                     name_b = collection.name.encode()             # <<<<<<<<<<<<<<
 *                     name_c = name_b
 *                     self.cogr_layer = ograpi.OGR_DS_GetLayerByName(
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_encode); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_v_name_b = __pyx_t_4;
        __pyx_t_4 = 0;

        /* "fiona/ogrext.pyx":832
 *                 if isinstance(collection.name, string_types):
 *                     name_b = collection.name.encode()
 *                     name_c = name_b             # <<<<<<<<<<<<<<
 *                     self.cogr_layer = ograpi.OGR_DS_GetLayerByName(
 *                                         self.cogr_ds, name_c)
 */
        __pyx_t_9 = __Pyx_PyObject_AsString(__pyx_v_name_b); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_v_name_c = __pyx_t_9;

        /* "fiona/ogrext.pyx":833
 *                     name_b = collection.name.encode()
 *                     name_c = name_b
 *                     self.cogr_layer = ograpi.OGR_DS_GetLayerByName(             # <<<<<<<<<<<<<<
 *                                         self.cogr_ds, name_c)
 *                 elif isinstance(collection.name, int):
 */
        __pyx_v_self->__pyx_base.cogr_layer = OGR_DS_GetLayerByName(__pyx_v_self->__pyx_base.cogr_ds, __pyx_v_name_c);
        goto __pyx_L17;
      }

      /* "fiona/ogrext.pyx":835
 *                     self.cogr_layer = ograpi.OGR_DS_GetLayerByName(
 *                                         self.cogr_ds, name_c)
 *                 elif isinstance(collection.name, int):             # <<<<<<<<<<<<<<
 *                     self.cogr_layer = ograpi.OGR_DS_GetLayer(
 *                                         self.cogr_ds, collection.name)
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_10 = PyInt_Check(__pyx_t_4); 
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_2 = (__pyx_t_10 != 0);
      if (__pyx_t_2) {

        /* "fiona/ogrext.pyx":837
 *                 elif isinstance(collection.name, int):
 *                     self.cogr_layer = ograpi.OGR_DS_GetLayer(
 *                                         self.cogr_ds, collection.name)             # <<<<<<<<<<<<<<
 * 
 *                 if self.cogr_layer is NULL:
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_t_4); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "fiona/ogrext.pyx":836
 *                                         self.cogr_ds, name_c)
 *                 elif isinstance(collection.name, int):
 *                     self.cogr_layer = ograpi.OGR_DS_GetLayer(             # <<<<<<<<<<<<<<
 *                                         self.cogr_ds, collection.name)
 * 
 */
        __pyx_v_self->__pyx_base.cogr_layer = OGR_DS_GetLayer(__pyx_v_self->__pyx_base.cogr_ds, __pyx_t_8);
        goto __pyx_L17;
      }
      __pyx_L17:;

      /* "fiona/ogrext.pyx":839
 *                                         self.cogr_ds, collection.name)
 * 
 *                 if self.cogr_layer is NULL:             # <<<<<<<<<<<<<<
 *                     raise RuntimeError(
 *                         "Failed to get layer %s" % collection.name)
 */
      __pyx_t_2 = ((__pyx_v_self->__pyx_base.cogr_layer == NULL) != 0);
      if (__pyx_t_2) {

        /* "fiona/ogrext.pyx":841
 *                 if self.cogr_layer is NULL:
 *                     raise RuntimeError(
 *                         "Failed to get layer %s" % collection.name)             # <<<<<<<<<<<<<<
 *             else:
 *                 raise OSError("No such file or directory %s" % path)
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_get_layer_s, __pyx_t_4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "fiona/ogrext.pyx":840
 * 
 *                 if self.cogr_layer is NULL:
 *                     raise RuntimeError(             # <<<<<<<<<<<<<<
 *                         "Failed to get layer %s" % collection.name)
 *             else:
 */
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __pyx_t_1 = 0;
        __pyx_t_1 = PyObject_Call(__pyx_builtin_RuntimeError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_Raise(__pyx_t_1, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      goto __pyx_L4;
    }
    /*else*/ {

      /* "fiona/ogrext.pyx":843
 *                         "Failed to get layer %s" % collection.name)
 *             else:
 *                 raise OSError("No such file or directory %s" % path)             # <<<<<<<<<<<<<<
 * 
 *             userencoding = self.collection.encoding
 */
      __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_No_such_file_or_directory_s, __pyx_v_path); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 843; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 843; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_1 = PyObject_Call(__pyx_builtin_OSError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 843; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 843; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L4:;

    /* "fiona/ogrext.pyx":845
 *                 raise OSError("No such file or directory %s" % path)
 * 
 *             userencoding = self.collection.encoding             # <<<<<<<<<<<<<<
 *             self._fileencoding = (userencoding or (
 *                 ograpi.OGR_L_TestCapability(self.cogr_layer, "StringsAsUTF8") and
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->__pyx_base.collection, __pyx_n_s_encoding); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_userencoding = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "fiona/ogrext.pyx":846
 * 
 *             userencoding = self.collection.encoding
 *             self._fileencoding = (userencoding or (             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_L_TestCapability(self.cogr_layer, "StringsAsUTF8") and
 *                 OGR_DETECTED_ENCODING) or (
 */
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_userencoding); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!__pyx_t_2) {

      /* "fiona/ogrext.pyx":847
 *             userencoding = self.collection.encoding
 *             self._fileencoding = (userencoding or (
 *                 ograpi.OGR_L_TestCapability(self.cogr_layer, "StringsAsUTF8") and             # <<<<<<<<<<<<<<
 *                 OGR_DETECTED_ENCODING) or (
 *                 self.get_driver() == "ESRI Shapefile" and
 */
      __pyx_t_1 = __Pyx_PyInt_From_int(OGR_L_TestCapability(__pyx_v_self->__pyx_base.cogr_layer, __pyx_k_StringsAsUTF8)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 847; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 847; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (__pyx_t_2) {
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "fiona/ogrext.pyx":848
 *             self._fileencoding = (userencoding or (
 *                 ograpi.OGR_L_TestCapability(self.cogr_layer, "StringsAsUTF8") and
 *                 OGR_DETECTED_ENCODING) or (             # <<<<<<<<<<<<<<
 *                 self.get_driver() == "ESRI Shapefile" and
 *                 'ISO-8859-1') or locale.getpreferredencoding()).upper()
 */
        __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_OGR_DETECTED_ENCODING); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 848; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = __pyx_t_4;
        __pyx_t_4 = 0;
      } else {
        __pyx_t_3 = __pyx_t_1;
        __pyx_t_1 = 0;
      }
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 848; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (!__pyx_t_2) {
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

        /* "fiona/ogrext.pyx":849
 *                 ograpi.OGR_L_TestCapability(self.cogr_layer, "StringsAsUTF8") and
 *                 OGR_DETECTED_ENCODING) or (
 *                 self.get_driver() == "ESRI Shapefile" and             # <<<<<<<<<<<<<<
 *                 'ISO-8859-1') or locale.getpreferredencoding()).upper()
 * 
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_driver); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 849; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_4 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 849; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = PyObject_RichCompare(__pyx_t_4, __pyx_kp_s_ESRI_Shapefile, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 849; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 849; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        if (__pyx_t_2) {
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_INCREF(__pyx_kp_s_ISO_8859_1);
          __pyx_t_4 = __pyx_kp_s_ISO_8859_1;
        } else {
          __pyx_t_4 = __pyx_t_1;
          __pyx_t_1 = 0;
        }
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        if (!__pyx_t_2) {
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "fiona/ogrext.pyx":850
 *                 OGR_DETECTED_ENCODING) or (
 *                 self.get_driver() == "ESRI Shapefile" and
 *                 'ISO-8859-1') or locale.getpreferredencoding()).upper()             # <<<<<<<<<<<<<<
 * 
 *         elif collection.mode == 'w':
 */
          __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_locale); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_getpreferredencoding); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = PyObject_Call(__pyx_t_11, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_11 = __pyx_t_1;
          __pyx_t_1 = 0;
        } else {
          __pyx_t_11 = __pyx_t_4;
          __pyx_t_4 = 0;
        }
        __pyx_t_4 = __pyx_t_11;
        __pyx_t_11 = 0;
      } else {
        __pyx_t_4 = __pyx_t_3;
        __pyx_t_3 = 0;
      }
      __pyx_t_3 = __pyx_t_4;
      __pyx_t_4 = 0;
    } else {
      __Pyx_INCREF(__pyx_v_userencoding);
      __pyx_t_3 = __pyx_v_userencoding;
    }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_upper); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_t_4, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "fiona/ogrext.pyx":846
 * 
 *             userencoding = self.collection.encoding
 *             self._fileencoding = (userencoding or (             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_L_TestCapability(self.cogr_layer, "StringsAsUTF8") and
 *                 OGR_DETECTED_ENCODING) or (
 */
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_v_self->__pyx_base._fileencoding);
    __Pyx_DECREF(__pyx_v_self->__pyx_base._fileencoding);
    __pyx_v_self->__pyx_base._fileencoding = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L3;
  }

  /* "fiona/ogrext.pyx":852
 *                 'ISO-8859-1') or locale.getpreferredencoding()).upper()
 * 
 *         elif collection.mode == 'w':             # <<<<<<<<<<<<<<
 *             try:
 *                 path_b = path.encode('utf-8')
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_mode); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_t_3, __pyx_n_s_w, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "fiona/ogrext.pyx":853
 * 
 *         elif collection.mode == 'w':
 *             try:             # <<<<<<<<<<<<<<
 *                 path_b = path.encode('utf-8')
 *             except UnicodeDecodeError:
 */
    {
      __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_6, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "fiona/ogrext.pyx":854
 *         elif collection.mode == 'w':
 *             try:
 *                 path_b = path.encode('utf-8')             # <<<<<<<<<<<<<<
 *             except UnicodeDecodeError:
 *                 path_b = path
 */
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_path, __pyx_n_s_encode); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 854; __pyx_clineno = __LINE__; goto __pyx_L19_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyObject_Call(__pyx_t_3, __pyx_tuple__37, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 854; __pyx_clineno = __LINE__; goto __pyx_L19_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_v_path_b = __pyx_t_4;
        __pyx_t_4 = 0;
      }
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L26_try_end;
      __pyx_L19_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "fiona/ogrext.pyx":855
 *             try:
 *                 path_b = path.encode('utf-8')
 *             except UnicodeDecodeError:             # <<<<<<<<<<<<<<
 *                 path_b = path
 *             path_c = path_b
 */
      __pyx_t_8 = PyErr_ExceptionMatches(__pyx_builtin_UnicodeDecodeError);
      if (__pyx_t_8) {
        __Pyx_AddTraceback("fiona.ogrext.WritingSession.start", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_3, &__pyx_t_11) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 855; __pyx_clineno = __LINE__; goto __pyx_L21_except_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_GOTREF(__pyx_t_11);

        /* "fiona/ogrext.pyx":856
 *                 path_b = path.encode('utf-8')
 *             except UnicodeDecodeError:
 *                 path_b = path             # <<<<<<<<<<<<<<
 *             path_c = path_b
 *             driver_b = collection.driver.encode()
 */
        __Pyx_INCREF(__pyx_v_path);
        __Pyx_XDECREF_SET(__pyx_v_path_b, __pyx_v_path);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        goto __pyx_L20_exception_handled;
      }
      goto __pyx_L21_except_error;
      __pyx_L21_except_error:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_6, __pyx_t_5);
      goto __pyx_L1_error;
      __pyx_L20_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_6, __pyx_t_5);
      __pyx_L26_try_end:;
    }

    /* "fiona/ogrext.pyx":857
 *             except UnicodeDecodeError:
 *                 path_b = path
 *             path_c = path_b             # <<<<<<<<<<<<<<
 *             driver_b = collection.driver.encode()
 *             driver_c = driver_b
 */
    __pyx_t_9 = __Pyx_PyObject_AsString(__pyx_v_path_b); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 857; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_path_c = __pyx_t_9;

    /* "fiona/ogrext.pyx":858
 *                 path_b = path
 *             path_c = path_b
 *             driver_b = collection.driver.encode()             # <<<<<<<<<<<<<<
 *             driver_c = driver_b
 * 
 */
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_driver); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 858; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_encode); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 858; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = PyObject_Call(__pyx_t_3, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 858; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_driver_b = __pyx_t_11;
    __pyx_t_11 = 0;

    /* "fiona/ogrext.pyx":859
 *             path_c = path_b
 *             driver_b = collection.driver.encode()
 *             driver_c = driver_b             # <<<<<<<<<<<<<<
 * 
 *             cogr_driver = ograpi.OGRGetDriverByName(driver_c)
 */
    __pyx_t_9 = __Pyx_PyObject_AsString(__pyx_v_driver_b); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 859; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_driver_c = __pyx_t_9;

    /* "fiona/ogrext.pyx":861
 *             driver_c = driver_b
 * 
 *             cogr_driver = ograpi.OGRGetDriverByName(driver_c)             # <<<<<<<<<<<<<<
 *             if cogr_driver is NULL:
 *                 raise ValueError("Null driver")
 */
    __pyx_v_cogr_driver = OGRGetDriverByName(__pyx_v_driver_c);

    /* "fiona/ogrext.pyx":862
 * 
 *             cogr_driver = ograpi.OGRGetDriverByName(driver_c)
 *             if cogr_driver is NULL:             # <<<<<<<<<<<<<<
 *                 raise ValueError("Null driver")
 * 
 */
    __pyx_t_2 = ((__pyx_v_cogr_driver == NULL) != 0);
    if (__pyx_t_2) {

      /* "fiona/ogrext.pyx":863
 *             cogr_driver = ograpi.OGRGetDriverByName(driver_c)
 *             if cogr_driver is NULL:
 *                 raise ValueError("Null driver")             # <<<<<<<<<<<<<<
 * 
 *             if not os.path.exists(path):
 */
      __pyx_t_11 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__38, NULL); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_Raise(__pyx_t_11, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }

    /* "fiona/ogrext.pyx":865
 *                 raise ValueError("Null driver")
 * 
 *             if not os.path.exists(path):             # <<<<<<<<<<<<<<
 *                 cogr_ds = ograpi.OGR_Dr_CreateDataSource(
 *                     cogr_driver, path_c, NULL)
 */
    __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_os); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 865; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_path); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 865; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_exists); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 865; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 865; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_path);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_path);
    __Pyx_GIVEREF(__pyx_v_path);
    __pyx_t_4 = PyObject_Call(__pyx_t_11, __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 865; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 865; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_10 = ((!__pyx_t_2) != 0);
    if (__pyx_t_10) {

      /* "fiona/ogrext.pyx":866
 * 
 *             if not os.path.exists(path):
 *                 cogr_ds = ograpi.OGR_Dr_CreateDataSource(             # <<<<<<<<<<<<<<
 *                     cogr_driver, path_c, NULL)
 * 
 */
      __pyx_v_cogr_ds = OGR_Dr_CreateDataSource(__pyx_v_cogr_driver, __pyx_v_path_c, NULL);
      goto __pyx_L30;
    }
    /*else*/ {

      /* "fiona/ogrext.pyx":870
 * 
 *             else:
 *                 cogr_ds = ograpi.OGROpen(path_c, 1, NULL)             # <<<<<<<<<<<<<<
 * 
 *                 if not cogr_ds:
 */
      __pyx_v_cogr_ds = OGROpen(__pyx_v_path_c, 1, NULL);

      /* "fiona/ogrext.pyx":872
 *                 cogr_ds = ograpi.OGROpen(path_c, 1, NULL)
 * 
 *                 if not cogr_ds:             # <<<<<<<<<<<<<<
 *                     cogr_ds = ograpi.OGR_Dr_CreateDataSource(
 *                         cogr_driver, path_c, NULL)
 */
      __pyx_t_10 = ((!(__pyx_v_cogr_ds != 0)) != 0);
      if (__pyx_t_10) {

        /* "fiona/ogrext.pyx":873
 * 
 *                 if not cogr_ds:
 *                     cogr_ds = ograpi.OGR_Dr_CreateDataSource(             # <<<<<<<<<<<<<<
 *                         cogr_driver, path_c, NULL)
 * 
 */
        __pyx_v_cogr_ds = OGR_Dr_CreateDataSource(__pyx_v_cogr_driver, __pyx_v_path_c, NULL);
        goto __pyx_L31;
      }

      /* "fiona/ogrext.pyx":876
 *                         cogr_driver, path_c, NULL)
 * 
 *                 elif collection.name is None:             # <<<<<<<<<<<<<<
 *                     ograpi.OGR_DS_Destroy(cogr_ds)
 *                     cogr_ds == NULL
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 876; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_10 = (__pyx_t_4 == Py_None);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_2 = (__pyx_t_10 != 0);
      if (__pyx_t_2) {

        /* "fiona/ogrext.pyx":877
 * 
 *                 elif collection.name is None:
 *                     ograpi.OGR_DS_Destroy(cogr_ds)             # <<<<<<<<<<<<<<
 *                     cogr_ds == NULL
 *                     log.debug("Deleted pre-existing data at %s", path)
 */
        OGR_DS_Destroy(__pyx_v_cogr_ds);

        /* "fiona/ogrext.pyx":878
 *                 elif collection.name is None:
 *                     ograpi.OGR_DS_Destroy(cogr_ds)
 *                     cogr_ds == NULL             # <<<<<<<<<<<<<<
 *                     log.debug("Deleted pre-existing data at %s", path)
 * 
 */
        (__pyx_v_cogr_ds == NULL);

        /* "fiona/ogrext.pyx":879
 *                     ograpi.OGR_DS_Destroy(cogr_ds)
 *                     cogr_ds == NULL
 *                     log.debug("Deleted pre-existing data at %s", path)             # <<<<<<<<<<<<<<
 * 
 *                     cogr_ds = ograpi.OGR_Dr_CreateDataSource(
 */
        __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 879; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_debug); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 879; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 879; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_kp_s_Deleted_pre_existing_data_at_s);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_kp_s_Deleted_pre_existing_data_at_s);
        __Pyx_GIVEREF(__pyx_kp_s_Deleted_pre_existing_data_at_s);
        __Pyx_INCREF(__pyx_v_path);
        PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_v_path);
        __Pyx_GIVEREF(__pyx_v_path);
        __pyx_t_11 = PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 879; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

        /* "fiona/ogrext.pyx":881
 *                     log.debug("Deleted pre-existing data at %s", path)
 * 
 *                     cogr_ds = ograpi.OGR_Dr_CreateDataSource(             # <<<<<<<<<<<<<<
 *                         cogr_driver, path_c, NULL)
 * 
 */
        __pyx_v_cogr_ds = OGR_Dr_CreateDataSource(__pyx_v_cogr_driver, __pyx_v_path_c, NULL);
        goto __pyx_L31;
      }
      /*else*/ {
      }
      __pyx_L31:;
    }
    __pyx_L30:;

    /* "fiona/ogrext.pyx":887
 *                     pass
 * 
 *             if cogr_ds is NULL:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError("Failed to open %s" % path)
 *             else:
 */
    __pyx_t_2 = ((__pyx_v_cogr_ds == NULL) != 0);
    if (__pyx_t_2) {

      /* "fiona/ogrext.pyx":888
 * 
 *             if cogr_ds is NULL:
 *                 raise RuntimeError("Failed to open %s" % path)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.cogr_ds = cogr_ds
 */
      __pyx_t_11 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_open_s, __pyx_v_path); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 888; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 888; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_11);
      __Pyx_GIVEREF(__pyx_t_11);
      __pyx_t_11 = 0;
      __pyx_t_11 = PyObject_Call(__pyx_builtin_RuntimeError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 888; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_Raise(__pyx_t_11, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 888; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    /*else*/ {

      /* "fiona/ogrext.pyx":890
 *                 raise RuntimeError("Failed to open %s" % path)
 *             else:
 *                 self.cogr_ds = cogr_ds             # <<<<<<<<<<<<<<
 * 
 *             # Set the spatial reference system from the given crs.
 */
      __pyx_v_self->__pyx_base.cogr_ds = __pyx_v_cogr_ds;
    }

    /* "fiona/ogrext.pyx":893
 * 
 *             # Set the spatial reference system from the given crs.
 *             if collection.crs:             # <<<<<<<<<<<<<<
 *                 cogr_srs = ograpi.OSRNewSpatialReference(NULL)
 *                 if cogr_srs is NULL:
 */
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_crs); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 893; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 893; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (__pyx_t_2) {

      /* "fiona/ogrext.pyx":894
 *             # Set the spatial reference system from the given crs.
 *             if collection.crs:
 *                 cogr_srs = ograpi.OSRNewSpatialReference(NULL)             # <<<<<<<<<<<<<<
 *                 if cogr_srs is NULL:
 *                     raise ValueError("Null spatial reference")
 */
      __pyx_v_cogr_srs = OSRNewSpatialReference(NULL);

      /* "fiona/ogrext.pyx":895
 *             if collection.crs:
 *                 cogr_srs = ograpi.OSRNewSpatialReference(NULL)
 *                 if cogr_srs is NULL:             # <<<<<<<<<<<<<<
 *                     raise ValueError("Null spatial reference")
 *                 params = []
 */
      __pyx_t_2 = ((__pyx_v_cogr_srs == NULL) != 0);
      if (__pyx_t_2) {

        /* "fiona/ogrext.pyx":896
 *                 cogr_srs = ograpi.OSRNewSpatialReference(NULL)
 *                 if cogr_srs is NULL:
 *                     raise ValueError("Null spatial reference")             # <<<<<<<<<<<<<<
 *                 params = []
 *                 for k, v in collection.crs.items():
 */
        __pyx_t_11 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__39, NULL); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_11);
        __Pyx_Raise(__pyx_t_11, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }

      /* "fiona/ogrext.pyx":897
 *                 if cogr_srs is NULL:
 *                     raise ValueError("Null spatial reference")
 *                 params = []             # <<<<<<<<<<<<<<
 *                 for k, v in collection.crs.items():
 *                     if v is True or (k == 'no_defs' and v):
 */
      __pyx_t_11 = PyList_New(0); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 897; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_v_params = ((PyObject*)__pyx_t_11);
      __pyx_t_11 = 0;

      /* "fiona/ogrext.pyx":898
 *                     raise ValueError("Null spatial reference")
 *                 params = []
 *                 for k, v in collection.crs.items():             # <<<<<<<<<<<<<<
 *                     if v is True or (k == 'no_defs' and v):
 *                         params.append("+%s" % k)
 */
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_crs); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_items); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = PyObject_Call(__pyx_t_4, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (PyList_CheckExact(__pyx_t_11) || PyTuple_CheckExact(__pyx_t_11)) {
        __pyx_t_4 = __pyx_t_11; __Pyx_INCREF(__pyx_t_4); __pyx_t_12 = 0;
        __pyx_t_13 = NULL;
      } else {
        __pyx_t_12 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_11); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_13 = Py_TYPE(__pyx_t_4)->tp_iternext;
      }
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      for (;;) {
        if (!__pyx_t_13 && PyList_CheckExact(__pyx_t_4)) {
          if (__pyx_t_12 >= PyList_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_COMPILING_IN_CPYTHON
          __pyx_t_11 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_12); __Pyx_INCREF(__pyx_t_11); __pyx_t_12++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #else
          __pyx_t_11 = PySequence_ITEM(__pyx_t_4, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #endif
        } else if (!__pyx_t_13 && PyTuple_CheckExact(__pyx_t_4)) {
          if (__pyx_t_12 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_COMPILING_IN_CPYTHON
          __pyx_t_11 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_12); __Pyx_INCREF(__pyx_t_11); __pyx_t_12++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #else
          __pyx_t_11 = PySequence_ITEM(__pyx_t_4, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #endif
        } else {
          __pyx_t_11 = __pyx_t_13(__pyx_t_4);
          if (unlikely(!__pyx_t_11)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_11);
        }
        if ((likely(PyTuple_CheckExact(__pyx_t_11))) || (PyList_CheckExact(__pyx_t_11))) {
          PyObject* sequence = __pyx_t_11;
          #if CYTHON_COMPILING_IN_CPYTHON
          Py_ssize_t size = Py_SIZE(sequence);
          #else
          Py_ssize_t size = PySequence_Size(sequence);
          #endif
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          #if CYTHON_COMPILING_IN_CPYTHON
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_1 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_1 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_1);
          #else
          __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_1 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_1);
          #endif
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_14 = PyObject_GetIter(__pyx_t_11); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_15 = Py_TYPE(__pyx_t_14)->tp_iternext;
          index = 0; __pyx_t_3 = __pyx_t_15(__pyx_t_14); if (unlikely(!__pyx_t_3)) goto __pyx_L37_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_3);
          index = 1; __pyx_t_1 = __pyx_t_15(__pyx_t_14); if (unlikely(!__pyx_t_1)) goto __pyx_L37_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_1);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_14), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_15 = NULL;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          goto __pyx_L38_unpacking_done;
          __pyx_L37_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_15 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_L38_unpacking_done:;
        }
        __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_3);
        __pyx_t_3 = 0;
        __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "fiona/ogrext.pyx":899
 *                 params = []
 *                 for k, v in collection.crs.items():
 *                     if v is True or (k == 'no_defs' and v):             # <<<<<<<<<<<<<<
 *                         params.append("+%s" % k)
 *                     else:
 */
        __pyx_t_2 = (__pyx_v_v == Py_True);
        if (!__pyx_t_2) {
          __pyx_t_10 = (__Pyx_PyString_Equals(__pyx_v_k, __pyx_n_s_no_defs, Py_EQ)); if (unlikely(__pyx_t_10 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 899; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          if (__pyx_t_10) {
            __pyx_t_16 = __Pyx_PyObject_IsTrue(__pyx_v_v); if (unlikely(__pyx_t_16 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 899; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __pyx_t_17 = __pyx_t_16;
          } else {
            __pyx_t_17 = __pyx_t_10;
          }
          __pyx_t_10 = __pyx_t_17;
        } else {
          __pyx_t_10 = __pyx_t_2;
        }
        if (__pyx_t_10) {

          /* "fiona/ogrext.pyx":900
 *                 for k, v in collection.crs.items():
 *                     if v is True or (k == 'no_defs' and v):
 *                         params.append("+%s" % k)             # <<<<<<<<<<<<<<
 *                     else:
 *                         params.append("+%s=%s" % (k, v))
 */
          __pyx_t_11 = __Pyx_PyString_Format(__pyx_kp_s_s, __pyx_v_k); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 900; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_18 = __Pyx_PyList_Append(__pyx_v_params, __pyx_t_11); if (unlikely(__pyx_t_18 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 900; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          goto __pyx_L39;
        }
        /*else*/ {

          /* "fiona/ogrext.pyx":902
 *                         params.append("+%s" % k)
 *                     else:
 *                         params.append("+%s=%s" % (k, v))             # <<<<<<<<<<<<<<
 *                 proj = " ".join(params)
 *                 proj_b = proj.encode()
 */
          __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 902; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_INCREF(__pyx_v_k);
          PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_v_k);
          __Pyx_GIVEREF(__pyx_v_k);
          __Pyx_INCREF(__pyx_v_v);
          PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_v_v);
          __Pyx_GIVEREF(__pyx_v_v);
          __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_s_s, __pyx_t_11); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 902; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_t_18 = __Pyx_PyList_Append(__pyx_v_params, __pyx_t_1); if (unlikely(__pyx_t_18 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 902; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __pyx_L39:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "fiona/ogrext.pyx":903
 *                     else:
 *                         params.append("+%s=%s" % (k, v))
 *                 proj = " ".join(params)             # <<<<<<<<<<<<<<
 *                 proj_b = proj.encode()
 *                 proj_c = proj_b
 */
      __pyx_t_4 = __Pyx_PyString_Join(__pyx_kp_s__40, __pyx_v_params); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 903; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_v_proj = ((PyObject*)__pyx_t_4);
      __pyx_t_4 = 0;

      /* "fiona/ogrext.pyx":904
 *                         params.append("+%s=%s" % (k, v))
 *                 proj = " ".join(params)
 *                 proj_b = proj.encode()             # <<<<<<<<<<<<<<
 *                 proj_c = proj_b
 *                 ograpi.OSRImportFromProj4(cogr_srs, proj_c)
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_proj, __pyx_n_s_encode); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 904; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = PyObject_Call(__pyx_t_4, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 904; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_proj_b = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "fiona/ogrext.pyx":905
 *                 proj = " ".join(params)
 *                 proj_b = proj.encode()
 *                 proj_c = proj_b             # <<<<<<<<<<<<<<
 *                 ograpi.OSRImportFromProj4(cogr_srs, proj_c)
 * 
 */
      __pyx_t_9 = __Pyx_PyObject_AsString(__pyx_v_proj_b); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 905; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_proj_c = __pyx_t_9;

      /* "fiona/ogrext.pyx":906
 *                 proj_b = proj.encode()
 *                 proj_c = proj_b
 *                 ograpi.OSRImportFromProj4(cogr_srs, proj_c)             # <<<<<<<<<<<<<<
 * 
 *             # Figure out what encoding to use. The encoding parameter given
 */
      OSRImportFromProj4(__pyx_v_cogr_srs, __pyx_v_proj_c);
      goto __pyx_L33;
    }
    __pyx_L33:;

    /* "fiona/ogrext.pyx":911
 *             # to the collection constructor takes highest precedence, then
 *             # 'iso-8859-1', then the system's default encoding as last resort.
 *             sysencoding = locale.getpreferredencoding()             # <<<<<<<<<<<<<<
 *             userencoding = collection.encoding
 *             self._fileencoding = (userencoding or (
 */
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_locale); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 911; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_getpreferredencoding); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 911; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_Call(__pyx_t_4, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 911; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_sysencoding = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "fiona/ogrext.pyx":912
 *             # 'iso-8859-1', then the system's default encoding as last resort.
 *             sysencoding = locale.getpreferredencoding()
 *             userencoding = collection.encoding             # <<<<<<<<<<<<<<
 *             self._fileencoding = (userencoding or (
 *                 collection.driver == "ESRI Shapefile" and
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_encoding); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 912; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_userencoding = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "fiona/ogrext.pyx":913
 *             sysencoding = locale.getpreferredencoding()
 *             userencoding = collection.encoding
 *             self._fileencoding = (userencoding or (             # <<<<<<<<<<<<<<
 *                 collection.driver == "ESRI Shapefile" and
 *                 'ISO-8859-1') or sysencoding).upper()
 */
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_userencoding); if (unlikely(__pyx_t_10 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 913; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!__pyx_t_10) {

      /* "fiona/ogrext.pyx":914
 *             userencoding = collection.encoding
 *             self._fileencoding = (userencoding or (
 *                 collection.driver == "ESRI Shapefile" and             # <<<<<<<<<<<<<<
 *                 'ISO-8859-1') or sysencoding).upper()
 * 
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_driver); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 914; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_1, __pyx_kp_s_ESRI_Shapefile, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 914; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_10 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 914; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (__pyx_t_10) {
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_INCREF(__pyx_kp_s_ISO_8859_1);
        __pyx_t_1 = __pyx_kp_s_ISO_8859_1;
      } else {
        __pyx_t_1 = __pyx_t_4;
        __pyx_t_4 = 0;
      }
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_10 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 915; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (!__pyx_t_10) {
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

        /* "fiona/ogrext.pyx":915
 *             self._fileencoding = (userencoding or (
 *                 collection.driver == "ESRI Shapefile" and
 *                 'ISO-8859-1') or sysencoding).upper()             # <<<<<<<<<<<<<<
 * 
 *             fileencoding = self.get_fileencoding()
 */
        __Pyx_INCREF(__pyx_v_sysencoding);
        __pyx_t_4 = __pyx_v_sysencoding;
      } else {
        __pyx_t_4 = __pyx_t_1;
        __pyx_t_1 = 0;
      }
      __pyx_t_1 = __pyx_t_4;
      __pyx_t_4 = 0;
    } else {
      __Pyx_INCREF(__pyx_v_userencoding);
      __pyx_t_1 = __pyx_v_userencoding;
    }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_upper); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 915; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_Call(__pyx_t_4, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 915; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "fiona/ogrext.pyx":913
 *             sysencoding = locale.getpreferredencoding()
 *             userencoding = collection.encoding
 *             self._fileencoding = (userencoding or (             # <<<<<<<<<<<<<<
 *                 collection.driver == "ESRI Shapefile" and
 *                 'ISO-8859-1') or sysencoding).upper()
 */
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->__pyx_base._fileencoding);
    __Pyx_DECREF(__pyx_v_self->__pyx_base._fileencoding);
    __pyx_v_self->__pyx_base._fileencoding = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "fiona/ogrext.pyx":917
 *                 'ISO-8859-1') or sysencoding).upper()
 * 
 *             fileencoding = self.get_fileencoding()             # <<<<<<<<<<<<<<
 *             if fileencoding:
 *                 fileencoding_b = fileencoding.encode()
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_fileencoding); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 917; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 917; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_fileencoding = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "fiona/ogrext.pyx":918
 * 
 *             fileencoding = self.get_fileencoding()
 *             if fileencoding:             # <<<<<<<<<<<<<<
 *                 fileencoding_b = fileencoding.encode()
 *                 fileencoding_c = fileencoding_b
 */
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_v_fileencoding); if (unlikely(__pyx_t_10 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 918; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (__pyx_t_10) {

      /* "fiona/ogrext.pyx":919
 *             fileencoding = self.get_fileencoding()
 *             if fileencoding:
 *                 fileencoding_b = fileencoding.encode()             # <<<<<<<<<<<<<<
 *                 fileencoding_c = fileencoding_b
 *                 options = ograpi.CSLSetNameValue(options, "ENCODING", fileencoding_c)
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_fileencoding, __pyx_n_s_encode); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 919; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = PyObject_Call(__pyx_t_4, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 919; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_fileencoding_b = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "fiona/ogrext.pyx":920
 *             if fileencoding:
 *                 fileencoding_b = fileencoding.encode()
 *                 fileencoding_c = fileencoding_b             # <<<<<<<<<<<<<<
 *                 options = ograpi.CSLSetNameValue(options, "ENCODING", fileencoding_c)
 * 
 */
      __pyx_t_9 = __Pyx_PyObject_AsString(__pyx_v_fileencoding_b); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 920; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_fileencoding_c = __pyx_t_9;

      /* "fiona/ogrext.pyx":921
 *                 fileencoding_b = fileencoding.encode()
 *                 fileencoding_c = fileencoding_b
 *                 options = ograpi.CSLSetNameValue(options, "ENCODING", fileencoding_c)             # <<<<<<<<<<<<<<
 * 
 *             # Does the layer exist already? If so, we delete it.
 */
      __pyx_v_options = CSLSetNameValue(__pyx_v_options, __pyx_k_ENCODING, __pyx_v_fileencoding_c);
      goto __pyx_L40;
    }
    __pyx_L40:;

    /* "fiona/ogrext.pyx":924
 * 
 *             # Does the layer exist already? If so, we delete it.
 *             layer_count = ograpi.OGR_DS_GetLayerCount(self.cogr_ds)             # <<<<<<<<<<<<<<
 *             layer_names = []
 *             for i in range(layer_count):
 */
    __pyx_v_layer_count = OGR_DS_GetLayerCount(__pyx_v_self->__pyx_base.cogr_ds);

    /* "fiona/ogrext.pyx":925
 *             # Does the layer exist already? If so, we delete it.
 *             layer_count = ograpi.OGR_DS_GetLayerCount(self.cogr_ds)
 *             layer_names = []             # <<<<<<<<<<<<<<
 *             for i in range(layer_count):
 *                 cogr_layer = ograpi.OGR_DS_GetLayer(cogr_ds, i)
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 925; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_layer_names = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "fiona/ogrext.pyx":926
 *             layer_count = ograpi.OGR_DS_GetLayerCount(self.cogr_ds)
 *             layer_names = []
 *             for i in range(layer_count):             # <<<<<<<<<<<<<<
 *                 cogr_layer = ograpi.OGR_DS_GetLayer(cogr_ds, i)
 *                 name_c = ograpi.OGR_L_GetName(cogr_layer)
 */
    __pyx_t_8 = __pyx_v_layer_count;
    for (__pyx_t_19 = 0; __pyx_t_19 < __pyx_t_8; __pyx_t_19+=1) {
      __pyx_v_i = __pyx_t_19;

      /* "fiona/ogrext.pyx":927
 *             layer_names = []
 *             for i in range(layer_count):
 *                 cogr_layer = ograpi.OGR_DS_GetLayer(cogr_ds, i)             # <<<<<<<<<<<<<<
 *                 name_c = ograpi.OGR_L_GetName(cogr_layer)
 *                 name_b = name_c
 */
      __pyx_v_cogr_layer = OGR_DS_GetLayer(__pyx_v_cogr_ds, __pyx_v_i);

      /* "fiona/ogrext.pyx":928
 *             for i in range(layer_count):
 *                 cogr_layer = ograpi.OGR_DS_GetLayer(cogr_ds, i)
 *                 name_c = ograpi.OGR_L_GetName(cogr_layer)             # <<<<<<<<<<<<<<
 *                 name_b = name_c
 *                 layer_names.append(name_b.decode('utf-8'))
 */
      __pyx_v_name_c = OGR_L_GetName(__pyx_v_cogr_layer);

      /* "fiona/ogrext.pyx":929
 *                 cogr_layer = ograpi.OGR_DS_GetLayer(cogr_ds, i)
 *                 name_c = ograpi.OGR_L_GetName(cogr_layer)
 *                 name_b = name_c             # <<<<<<<<<<<<<<
 *                 layer_names.append(name_b.decode('utf-8'))
 * 
 */
      __pyx_t_1 = __Pyx_PyBytes_FromString(__pyx_v_name_c); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 929; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_name_b, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "fiona/ogrext.pyx":930
 *                 name_c = ograpi.OGR_L_GetName(cogr_layer)
 *                 name_b = name_c
 *                 layer_names.append(name_b.decode('utf-8'))             # <<<<<<<<<<<<<<
 * 
 *             idx = -1
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_name_b, __pyx_n_s_decode); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 930; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = PyObject_Call(__pyx_t_1, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 930; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_18 = __Pyx_PyList_Append(__pyx_v_layer_names, __pyx_t_4); if (unlikely(__pyx_t_18 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 930; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }

    /* "fiona/ogrext.pyx":932
 *                 layer_names.append(name_b.decode('utf-8'))
 * 
 *             idx = -1             # <<<<<<<<<<<<<<
 *             if isinstance(collection.name, string_types):
 *                 if collection.name in layer_names:
 */
    __Pyx_INCREF(__pyx_int_neg_1);
    __pyx_v_idx = __pyx_int_neg_1;

    /* "fiona/ogrext.pyx":933
 * 
 *             idx = -1
 *             if isinstance(collection.name, string_types):             # <<<<<<<<<<<<<<
 *                 if collection.name in layer_names:
 *                     idx = layer_names.index(collection.name)
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 933; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_string_types); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 933; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_10 = PyObject_IsInstance(__pyx_t_4, __pyx_t_1); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 933; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_2 = (__pyx_t_10 != 0);
    if (__pyx_t_2) {

      /* "fiona/ogrext.pyx":934
 *             idx = -1
 *             if isinstance(collection.name, string_types):
 *                 if collection.name in layer_names:             # <<<<<<<<<<<<<<
 *                     idx = layer_names.index(collection.name)
 *             elif isinstance(collection.name, int):
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 934; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = (__Pyx_PySequence_Contains(__pyx_t_1, __pyx_v_layer_names, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 934; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_10 = (__pyx_t_2 != 0);
      if (__pyx_t_10) {

        /* "fiona/ogrext.pyx":935
 *             if isinstance(collection.name, string_types):
 *                 if collection.name in layer_names:
 *                     idx = layer_names.index(collection.name)             # <<<<<<<<<<<<<<
 *             elif isinstance(collection.name, int):
 *                 if collection.name >= 0 and collection.name < layer_count:
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_layer_names, __pyx_n_s_index); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_11 = PyTuple_New(1); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_11);
        PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        __pyx_t_4 = 0;
        __pyx_t_4 = PyObject_Call(__pyx_t_1, __pyx_t_11, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 935; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF_SET(__pyx_v_idx, __pyx_t_4);
        __pyx_t_4 = 0;
        goto __pyx_L44;
      }
      __pyx_L44:;
      goto __pyx_L43;
    }

    /* "fiona/ogrext.pyx":936
 *                 if collection.name in layer_names:
 *                     idx = layer_names.index(collection.name)
 *             elif isinstance(collection.name, int):             # <<<<<<<<<<<<<<
 *                 if collection.name >= 0 and collection.name < layer_count:
 *                     idx = collection.name
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 936; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_10 = PyInt_Check(__pyx_t_4); 
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_2 = (__pyx_t_10 != 0);
    if (__pyx_t_2) {

      /* "fiona/ogrext.pyx":937
 *                     idx = layer_names.index(collection.name)
 *             elif isinstance(collection.name, int):
 *                 if collection.name >= 0 and collection.name < layer_count:             # <<<<<<<<<<<<<<
 *                     idx = collection.name
 *             if idx >= 0:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 937; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_11 = PyObject_RichCompare(__pyx_t_4, __pyx_int_0, Py_GE); __Pyx_XGOTREF(__pyx_t_11); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 937; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_11); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 937; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (__pyx_t_2) {
        __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 937; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_11);
        __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_layer_count); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 937; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_1 = PyObject_RichCompare(__pyx_t_11, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 937; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_10 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 937; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_17 = __pyx_t_10;
      } else {
        __pyx_t_17 = __pyx_t_2;
      }
      if (__pyx_t_17) {

        /* "fiona/ogrext.pyx":938
 *             elif isinstance(collection.name, int):
 *                 if collection.name >= 0 and collection.name < layer_count:
 *                     idx = collection.name             # <<<<<<<<<<<<<<
 *             if idx >= 0:
 *                 log.debug("Deleted pre-existing layer at %s", collection.name)
 */
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 938; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF_SET(__pyx_v_idx, __pyx_t_1);
        __pyx_t_1 = 0;
        goto __pyx_L45;
      }
      __pyx_L45:;
      goto __pyx_L43;
    }
    __pyx_L43:;

    /* "fiona/ogrext.pyx":939
 *                 if collection.name >= 0 and collection.name < layer_count:
 *                     idx = collection.name
 *             if idx >= 0:             # <<<<<<<<<<<<<<
 *                 log.debug("Deleted pre-existing layer at %s", collection.name)
 *                 ograpi.OGR_DS_DeleteLayer(self.cogr_ds, idx)
 */
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_idx, __pyx_int_0, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 939; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_17 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 939; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_17) {

      /* "fiona/ogrext.pyx":940
 *                     idx = collection.name
 *             if idx >= 0:
 *                 log.debug("Deleted pre-existing layer at %s", collection.name)             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_DS_DeleteLayer(self.cogr_ds, idx)
 * 
 */
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 940; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_debug); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 940; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 940; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = PyTuple_New(2); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 940; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_INCREF(__pyx_kp_s_Deleted_pre_existing_layer_at_s);
      PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_kp_s_Deleted_pre_existing_layer_at_s);
      __Pyx_GIVEREF(__pyx_kp_s_Deleted_pre_existing_layer_at_s);
      PyTuple_SET_ITEM(__pyx_t_11, 1, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_1 = PyObject_Call(__pyx_t_4, __pyx_t_11, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 940; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "fiona/ogrext.pyx":941
 *             if idx >= 0:
 *                 log.debug("Deleted pre-existing layer at %s", collection.name)
 *                 ograpi.OGR_DS_DeleteLayer(self.cogr_ds, idx)             # <<<<<<<<<<<<<<
 * 
 *             # Create the named layer in the datasource.
 */
      __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_v_idx); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 941; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      OGR_DS_DeleteLayer(__pyx_v_self->__pyx_base.cogr_ds, __pyx_t_8);
      goto __pyx_L46;
    }
    __pyx_L46:;

    /* "fiona/ogrext.pyx":944
 * 
 *             # Create the named layer in the datasource.
 *             name_b = collection.name.encode('utf-8')             # <<<<<<<<<<<<<<
 *             name_c = name_b
 *             self.cogr_layer = ograpi.OGR_DS_CreateLayer(
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_name); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_encode); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_Call(__pyx_t_11, __pyx_tuple__42, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF_SET(__pyx_v_name_b, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "fiona/ogrext.pyx":945
 *             # Create the named layer in the datasource.
 *             name_b = collection.name.encode('utf-8')
 *             name_c = name_b             # <<<<<<<<<<<<<<
 *             self.cogr_layer = ograpi.OGR_DS_CreateLayer(
 *                 self.cogr_ds,
 */
    __pyx_t_9 = __Pyx_PyObject_AsString(__pyx_v_name_b); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 945; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_name_c = __pyx_t_9;

    /* "fiona/ogrext.pyx":950
 *                 name_c,
 *                 cogr_srs,
 *                 <unsigned int>[k for k,v in GEOMETRY_TYPES.items() if             # <<<<<<<<<<<<<<
 *                     v == collection.schema.get('geometry', 'Unknown')][0],
 *                 options
 */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_11 = __Pyx_GetModuleGlobalName(__pyx_n_s_GEOMETRY_TYPES); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_items); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __pyx_t_11 = PyObject_Call(__pyx_t_4, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (PyList_CheckExact(__pyx_t_11) || PyTuple_CheckExact(__pyx_t_11)) {
      __pyx_t_4 = __pyx_t_11; __Pyx_INCREF(__pyx_t_4); __pyx_t_12 = 0;
      __pyx_t_13 = NULL;
    } else {
      __pyx_t_12 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_11); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = Py_TYPE(__pyx_t_4)->tp_iternext;
    }
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    for (;;) {
      if (!__pyx_t_13 && PyList_CheckExact(__pyx_t_4)) {
        if (__pyx_t_12 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_11 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_12); __Pyx_INCREF(__pyx_t_11); __pyx_t_12++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_11 = PySequence_ITEM(__pyx_t_4, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else if (!__pyx_t_13 && PyTuple_CheckExact(__pyx_t_4)) {
        if (__pyx_t_12 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_11 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_12); __Pyx_INCREF(__pyx_t_11); __pyx_t_12++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_11 = PySequence_ITEM(__pyx_t_4, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else {
        __pyx_t_11 = __pyx_t_13(__pyx_t_4);
        if (unlikely(!__pyx_t_11)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_11);
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_11))) || (PyList_CheckExact(__pyx_t_11))) {
        PyObject* sequence = __pyx_t_11;
        #if CYTHON_COMPILING_IN_CPYTHON
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        #if CYTHON_COMPILING_IN_CPYTHON
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_14 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_14 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_14);
        #else
        __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_14 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_14);
        #endif
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_20 = PyObject_GetIter(__pyx_t_11); if (unlikely(!__pyx_t_20)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_20);
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __pyx_t_15 = Py_TYPE(__pyx_t_20)->tp_iternext;
        index = 0; __pyx_t_3 = __pyx_t_15(__pyx_t_20); if (unlikely(!__pyx_t_3)) goto __pyx_L49_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_3);
        index = 1; __pyx_t_14 = __pyx_t_15(__pyx_t_20); if (unlikely(!__pyx_t_14)) goto __pyx_L49_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_14);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_20), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_15 = NULL;
        __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
        goto __pyx_L50_unpacking_done;
        __pyx_L49_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_20); __pyx_t_20 = 0;
        __pyx_t_15 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_L50_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_k, __pyx_t_3);
      __pyx_t_3 = 0;
      __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_14);
      __pyx_t_14 = 0;

      /* "fiona/ogrext.pyx":951
 *                 cogr_srs,
 *                 <unsigned int>[k for k,v in GEOMETRY_TYPES.items() if
 *                     v == collection.schema.get('geometry', 'Unknown')][0],             # <<<<<<<<<<<<<<
 *                 options
 *                 )
 */
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_schema); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_get); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_11 = PyObject_Call(__pyx_t_14, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = PyObject_RichCompare(__pyx_v_v, __pyx_t_11, Py_EQ); __Pyx_XGOTREF(__pyx_t_14); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_t_14); if (unlikely(__pyx_t_17 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      if (__pyx_t_17) {

        /* "fiona/ogrext.pyx":950
 *                 name_c,
 *                 cogr_srs,
 *                 <unsigned int>[k for k,v in GEOMETRY_TYPES.items() if             # <<<<<<<<<<<<<<
 *                     v == collection.schema.get('geometry', 'Unknown')][0],
 *                 options
 */
        if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_v_k))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L51;
      }
      __pyx_L51:;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "fiona/ogrext.pyx":951
 *                 cogr_srs,
 *                 <unsigned int>[k for k,v in GEOMETRY_TYPES.items() if
 *                     v == collection.schema.get('geometry', 'Unknown')][0],             # <<<<<<<<<<<<<<
 *                 options
 *                 )
 */
    __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_t_1, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_21 = __Pyx_PyInt_As_unsigned_int(__pyx_t_4); if (unlikely((__pyx_t_21 == (unsigned int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "fiona/ogrext.pyx":946
 *             name_b = collection.name.encode('utf-8')
 *             name_c = name_b
 *             self.cogr_layer = ograpi.OGR_DS_CreateLayer(             # <<<<<<<<<<<<<<
 *                 self.cogr_ds,
 *                 name_c,
 */
    __pyx_v_self->__pyx_base.cogr_layer = OGR_DS_CreateLayer(__pyx_v_self->__pyx_base.cogr_ds, __pyx_v_name_c, __pyx_v_cogr_srs, ((unsigned int)__pyx_t_21), __pyx_v_options);

    /* "fiona/ogrext.pyx":954
 *                 options
 *                 )
 *             if options:             # <<<<<<<<<<<<<<
 *                 ograpi.CSLDestroy(options)
 * 
 */
    __pyx_t_17 = (__pyx_v_options != 0);
    if (__pyx_t_17) {

      /* "fiona/ogrext.pyx":955
 *                 )
 *             if options:
 *                 ograpi.CSLDestroy(options)             # <<<<<<<<<<<<<<
 * 
 *             if self.cogr_layer is NULL:
 */
      CSLDestroy(__pyx_v_options);
      goto __pyx_L52;
    }
    __pyx_L52:;

    /* "fiona/ogrext.pyx":957
 *                 ograpi.CSLDestroy(options)
 * 
 *             if self.cogr_layer is NULL:             # <<<<<<<<<<<<<<
 *                 raise ValueError("Null layer")
 *             log.debug("Created layer")
 */
    __pyx_t_17 = ((__pyx_v_self->__pyx_base.cogr_layer == NULL) != 0);
    if (__pyx_t_17) {

      /* "fiona/ogrext.pyx":958
 * 
 *             if self.cogr_layer is NULL:
 *                 raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 *             log.debug("Created layer")
 * 
 */
      __pyx_t_4 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__44, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }

    /* "fiona/ogrext.pyx":959
 *             if self.cogr_layer is NULL:
 *                 raise ValueError("Null layer")
 *             log.debug("Created layer")             # <<<<<<<<<<<<<<
 * 
 *             # Next, make a layer definition from the given schema properties,
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 959; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_debug); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 959; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(__pyx_t_1, __pyx_tuple__45, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 959; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "fiona/ogrext.pyx":963
 *             # Next, make a layer definition from the given schema properties,
 *             # which are an ordered dict since Fiona 1.0.1.
 *             for key, value in collection.schema['properties'].items():             # <<<<<<<<<<<<<<
 *                 log.debug("Creating field: %s %s", key, value)
 * 
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_schema); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_properties); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_items); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_Call(__pyx_t_4, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (PyList_CheckExact(__pyx_t_1) || PyTuple_CheckExact(__pyx_t_1)) {
      __pyx_t_4 = __pyx_t_1; __Pyx_INCREF(__pyx_t_4); __pyx_t_12 = 0;
      __pyx_t_13 = NULL;
    } else {
      __pyx_t_12 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_13 = Py_TYPE(__pyx_t_4)->tp_iternext;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    for (;;) {
      if (!__pyx_t_13 && PyList_CheckExact(__pyx_t_4)) {
        if (__pyx_t_12 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_1 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_12); __Pyx_INCREF(__pyx_t_1); __pyx_t_12++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_4, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else if (!__pyx_t_13 && PyTuple_CheckExact(__pyx_t_4)) {
        if (__pyx_t_12 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_12); __Pyx_INCREF(__pyx_t_1); __pyx_t_12++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_1 = PySequence_ITEM(__pyx_t_4, __pyx_t_12); __pyx_t_12++; if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else {
        __pyx_t_1 = __pyx_t_13(__pyx_t_4);
        if (unlikely(!__pyx_t_1)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_1);
      }
      if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
        PyObject* sequence = __pyx_t_1;
        #if CYTHON_COMPILING_IN_CPYTHON
        Py_ssize_t size = Py_SIZE(sequence);
        #else
        Py_ssize_t size = PySequence_Size(sequence);
        #endif
        if (unlikely(size != 2)) {
          if (size > 2) __Pyx_RaiseTooManyValuesError(2);
          else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        #if CYTHON_COMPILING_IN_CPYTHON
        if (likely(PyTuple_CheckExact(sequence))) {
          __pyx_t_14 = PyTuple_GET_ITEM(sequence, 0); 
          __pyx_t_11 = PyTuple_GET_ITEM(sequence, 1); 
        } else {
          __pyx_t_14 = PyList_GET_ITEM(sequence, 0); 
          __pyx_t_11 = PyList_GET_ITEM(sequence, 1); 
        }
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_11);
        #else
        __pyx_t_14 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_11 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_11);
        #endif
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      } else {
        Py_ssize_t index = -1;
        __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_15 = Py_TYPE(__pyx_t_3)->tp_iternext;
        index = 0; __pyx_t_14 = __pyx_t_15(__pyx_t_3); if (unlikely(!__pyx_t_14)) goto __pyx_L56_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_14);
        index = 1; __pyx_t_11 = __pyx_t_15(__pyx_t_3); if (unlikely(!__pyx_t_11)) goto __pyx_L56_unpacking_failed;
        __Pyx_GOTREF(__pyx_t_11);
        if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_3), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_15 = NULL;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L57_unpacking_done;
        __pyx_L56_unpacking_failed:;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_15 = NULL;
        if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_L57_unpacking_done:;
      }
      __Pyx_XDECREF_SET(__pyx_v_key, __pyx_t_14);
      __pyx_t_14 = 0;
      __Pyx_XDECREF_SET(__pyx_v_value, __pyx_t_11);
      __pyx_t_11 = 0;

      /* "fiona/ogrext.pyx":964
 *             # which are an ordered dict since Fiona 1.0.1.
 *             for key, value in collection.schema['properties'].items():
 *                 log.debug("Creating field: %s %s", key, value)             # <<<<<<<<<<<<<<
 * 
 *                 # Convert 'long' to 'int'. See
 */
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 964; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_debug); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 964; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 964; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_kp_s_Creating_field_s_s);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_s_Creating_field_s_s);
      __Pyx_GIVEREF(__pyx_kp_s_Creating_field_s_s);
      __Pyx_INCREF(__pyx_v_key);
      PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_key);
      __Pyx_GIVEREF(__pyx_v_key);
      __Pyx_INCREF(__pyx_v_value);
      PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __pyx_t_14 = PyObject_Call(__pyx_t_11, __pyx_t_1, NULL); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 964; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

      /* "fiona/ogrext.pyx":968
 *                 # Convert 'long' to 'int'. See
 *                 # https://github.com/Toblerity/Fiona/issues/101.
 *                 if value == 'long':             # <<<<<<<<<<<<<<
 *                     value = 'int'
 * 
 */
      __pyx_t_17 = (__Pyx_PyString_Equals(__pyx_v_value, __pyx_n_s_long, Py_EQ)); if (unlikely(__pyx_t_17 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 968; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (__pyx_t_17) {

        /* "fiona/ogrext.pyx":969
 *                 # https://github.com/Toblerity/Fiona/issues/101.
 *                 if value == 'long':
 *                     value = 'int'             # <<<<<<<<<<<<<<
 * 
 *                 # Is there a field width/precision?
 */
        __Pyx_INCREF(__pyx_n_s_int);
        __Pyx_DECREF_SET(__pyx_v_value, __pyx_n_s_int);
        goto __pyx_L58;
      }
      __pyx_L58:;

      /* "fiona/ogrext.pyx":972
 * 
 *                 # Is there a field width/precision?
 *                 width = precision = None             # <<<<<<<<<<<<<<
 *                 if ':' in value:
 *                     value, fmt = value.split(':')
 */
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_width, Py_None);
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_precision, Py_None);

      /* "fiona/ogrext.pyx":973
 *                 # Is there a field width/precision?
 *                 width = precision = None
 *                 if ':' in value:             # <<<<<<<<<<<<<<
 *                     value, fmt = value.split(':')
 *                     if '.' in fmt:
 */
      __pyx_t_17 = (__Pyx_PySequence_Contains(__pyx_kp_s__46, __pyx_v_value, Py_EQ)); if (unlikely(__pyx_t_17 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 973; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_2 = (__pyx_t_17 != 0);
      if (__pyx_t_2) {

        /* "fiona/ogrext.pyx":974
 *                 width = precision = None
 *                 if ':' in value:
 *                     value, fmt = value.split(':')             # <<<<<<<<<<<<<<
 *                     if '.' in fmt:
 *                         width, precision = map(int, fmt.split('.'))
 */
        __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_value, __pyx_n_s_split); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 974; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_1 = PyObject_Call(__pyx_t_14, __pyx_tuple__47, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 974; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
          PyObject* sequence = __pyx_t_1;
          #if CYTHON_COMPILING_IN_CPYTHON
          Py_ssize_t size = Py_SIZE(sequence);
          #else
          Py_ssize_t size = PySequence_Size(sequence);
          #endif
          if (unlikely(size != 2)) {
            if (size > 2) __Pyx_RaiseTooManyValuesError(2);
            else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
            {__pyx_filename = __pyx_f[0]; __pyx_lineno = 974; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          #if CYTHON_COMPILING_IN_CPYTHON
          if (likely(PyTuple_CheckExact(sequence))) {
            __pyx_t_14 = PyTuple_GET_ITEM(sequence, 0); 
            __pyx_t_11 = PyTuple_GET_ITEM(sequence, 1); 
          } else {
            __pyx_t_14 = PyList_GET_ITEM(sequence, 0); 
            __pyx_t_11 = PyList_GET_ITEM(sequence, 1); 
          }
          __Pyx_INCREF(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_11);
          #else
          __pyx_t_14 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 974; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_11 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 974; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_11);
          #endif
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else {
          Py_ssize_t index = -1;
          __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 974; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_15 = Py_TYPE(__pyx_t_3)->tp_iternext;
          index = 0; __pyx_t_14 = __pyx_t_15(__pyx_t_3); if (unlikely(!__pyx_t_14)) goto __pyx_L60_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_14);
          index = 1; __pyx_t_11 = __pyx_t_15(__pyx_t_3); if (unlikely(!__pyx_t_11)) goto __pyx_L60_unpacking_failed;
          __Pyx_GOTREF(__pyx_t_11);
          if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_3), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 974; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_t_15 = NULL;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          goto __pyx_L61_unpacking_done;
          __pyx_L60_unpacking_failed:;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __pyx_t_15 = NULL;
          if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 974; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __pyx_L61_unpacking_done:;
        }
        __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_14);
        __pyx_t_14 = 0;
        __Pyx_XDECREF_SET(__pyx_v_fmt, __pyx_t_11);
        __pyx_t_11 = 0;

        /* "fiona/ogrext.pyx":975
 *                 if ':' in value:
 *                     value, fmt = value.split(':')
 *                     if '.' in fmt:             # <<<<<<<<<<<<<<
 *                         width, precision = map(int, fmt.split('.'))
 *                     else:
 */
        __pyx_t_2 = (__Pyx_PySequence_Contains(__pyx_kp_s__48, __pyx_v_fmt, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 975; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __pyx_t_17 = (__pyx_t_2 != 0);
        if (__pyx_t_17) {

          /* "fiona/ogrext.pyx":976
 *                     value, fmt = value.split(':')
 *                     if '.' in fmt:
 *                         width, precision = map(int, fmt.split('.'))             # <<<<<<<<<<<<<<
 *                     else:
 *                         width = int(fmt)
 */
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_fmt, __pyx_n_s_split); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 976; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_11 = PyObject_Call(__pyx_t_1, __pyx_tuple__49, NULL); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 976; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 976; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_INCREF(((PyObject *)((PyObject*)(&PyInt_Type))));
          PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)((PyObject*)(&PyInt_Type))));
          __Pyx_GIVEREF(((PyObject *)((PyObject*)(&PyInt_Type))));
          PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_11);
          __Pyx_GIVEREF(__pyx_t_11);
          __pyx_t_11 = 0;
          __pyx_t_11 = PyObject_Call(__pyx_builtin_map, __pyx_t_1, NULL); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 976; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if ((likely(PyTuple_CheckExact(__pyx_t_11))) || (PyList_CheckExact(__pyx_t_11))) {
            PyObject* sequence = __pyx_t_11;
            #if CYTHON_COMPILING_IN_CPYTHON
            Py_ssize_t size = Py_SIZE(sequence);
            #else
            Py_ssize_t size = PySequence_Size(sequence);
            #endif
            if (unlikely(size != 2)) {
              if (size > 2) __Pyx_RaiseTooManyValuesError(2);
              else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
              {__pyx_filename = __pyx_f[0]; __pyx_lineno = 976; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            }
            #if CYTHON_COMPILING_IN_CPYTHON
            if (likely(PyTuple_CheckExact(sequence))) {
              __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
              __pyx_t_14 = PyTuple_GET_ITEM(sequence, 1); 
            } else {
              __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
              __pyx_t_14 = PyList_GET_ITEM(sequence, 1); 
            }
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_14);
            #else
            __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 976; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_14 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 976; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_14);
            #endif
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          } else {
            Py_ssize_t index = -1;
            __pyx_t_3 = PyObject_GetIter(__pyx_t_11); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 976; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __Pyx_GOTREF(__pyx_t_3);
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __pyx_t_15 = Py_TYPE(__pyx_t_3)->tp_iternext;
            index = 0; __pyx_t_1 = __pyx_t_15(__pyx_t_3); if (unlikely(!__pyx_t_1)) goto __pyx_L63_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_1);
            index = 1; __pyx_t_14 = __pyx_t_15(__pyx_t_3); if (unlikely(!__pyx_t_14)) goto __pyx_L63_unpacking_failed;
            __Pyx_GOTREF(__pyx_t_14);
            if (__Pyx_IternextUnpackEndCheck(__pyx_t_15(__pyx_t_3), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 976; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __pyx_t_15 = NULL;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            goto __pyx_L64_unpacking_done;
            __pyx_L63_unpacking_failed:;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __pyx_t_15 = NULL;
            if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
            {__pyx_filename = __pyx_f[0]; __pyx_lineno = 976; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            __pyx_L64_unpacking_done:;
          }
          __Pyx_DECREF_SET(__pyx_v_width, __pyx_t_1);
          __pyx_t_1 = 0;
          __Pyx_DECREF_SET(__pyx_v_precision, __pyx_t_14);
          __pyx_t_14 = 0;
          goto __pyx_L62;
        }
        /*else*/ {

          /* "fiona/ogrext.pyx":978
 *                         width, precision = map(int, fmt.split('.'))
 *                     else:
 *                         width = int(fmt)             # <<<<<<<<<<<<<<
 * 
 *                 encoding = self.get_internalencoding()
 */
          __pyx_t_11 = PyNumber_Int(__pyx_v_fmt); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 978; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_11);
          __Pyx_DECREF_SET(__pyx_v_width, __pyx_t_11);
          __pyx_t_11 = 0;
        }
        __pyx_L62:;
        goto __pyx_L59;
      }
      __pyx_L59:;

      /* "fiona/ogrext.pyx":980
 *                         width = int(fmt)
 * 
 *                 encoding = self.get_internalencoding()             # <<<<<<<<<<<<<<
 *                 key_bytes = key.encode(encoding)
 *                 cogr_fielddefn = ograpi.OGR_Fld_Create(
 */
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_internalencoding); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 980; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_14 = PyObject_Call(__pyx_t_11, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 980; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF_SET(__pyx_v_encoding, __pyx_t_14);
      __pyx_t_14 = 0;

      /* "fiona/ogrext.pyx":981
 * 
 *                 encoding = self.get_internalencoding()
 *                 key_bytes = key.encode(encoding)             # <<<<<<<<<<<<<<
 *                 cogr_fielddefn = ograpi.OGR_Fld_Create(
 *                     key_bytes,
 */
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_key, __pyx_n_s_encode); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 981; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_11 = PyTuple_New(1); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 981; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_INCREF(__pyx_v_encoding);
      PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_v_encoding);
      __Pyx_GIVEREF(__pyx_v_encoding);
      __pyx_t_1 = PyObject_Call(__pyx_t_14, __pyx_t_11, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 981; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF_SET(__pyx_v_key_bytes, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "fiona/ogrext.pyx":983
 *                 key_bytes = key.encode(encoding)
 *                 cogr_fielddefn = ograpi.OGR_Fld_Create(
 *                     key_bytes,             # <<<<<<<<<<<<<<
 *                     FIELD_TYPES.index(value) )
 *                 if cogr_fielddefn is NULL:
 */
      __pyx_t_9 = __Pyx_PyObject_AsString(__pyx_v_key_bytes); if (unlikely((!__pyx_t_9) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 983; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "fiona/ogrext.pyx":984
 *                 cogr_fielddefn = ograpi.OGR_Fld_Create(
 *                     key_bytes,
 *                     FIELD_TYPES.index(value) )             # <<<<<<<<<<<<<<
 *                 if cogr_fielddefn is NULL:
 *                     raise ValueError("Null field definition")
 */
      __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_FIELD_TYPES); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 984; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_index); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 984; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 984; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_value);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_value);
      __Pyx_GIVEREF(__pyx_v_value);
      __pyx_t_14 = PyObject_Call(__pyx_t_11, __pyx_t_1, NULL); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 984; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_t_14); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 984; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

      /* "fiona/ogrext.pyx":982
 *                 encoding = self.get_internalencoding()
 *                 key_bytes = key.encode(encoding)
 *                 cogr_fielddefn = ograpi.OGR_Fld_Create(             # <<<<<<<<<<<<<<
 *                     key_bytes,
 *                     FIELD_TYPES.index(value) )
 */
      __pyx_v_cogr_fielddefn = OGR_Fld_Create(__pyx_t_9, __pyx_t_8);

      /* "fiona/ogrext.pyx":985
 *                     key_bytes,
 *                     FIELD_TYPES.index(value) )
 *                 if cogr_fielddefn is NULL:             # <<<<<<<<<<<<<<
 *                     raise ValueError("Null field definition")
 *                 if width:
 */
      __pyx_t_17 = ((__pyx_v_cogr_fielddefn == NULL) != 0);
      if (__pyx_t_17) {

        /* "fiona/ogrext.pyx":986
 *                     FIELD_TYPES.index(value) )
 *                 if cogr_fielddefn is NULL:
 *                     raise ValueError("Null field definition")             # <<<<<<<<<<<<<<
 *                 if width:
 *                     ograpi.OGR_Fld_SetWidth(cogr_fielddefn, width)
 */
        __pyx_t_14 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__50, NULL); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 986; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_Raise(__pyx_t_14, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 986; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }

      /* "fiona/ogrext.pyx":987
 *                 if cogr_fielddefn is NULL:
 *                     raise ValueError("Null field definition")
 *                 if width:             # <<<<<<<<<<<<<<
 *                     ograpi.OGR_Fld_SetWidth(cogr_fielddefn, width)
 *                 if precision:
 */
      __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_v_width); if (unlikely(__pyx_t_17 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 987; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (__pyx_t_17) {

        /* "fiona/ogrext.pyx":988
 *                     raise ValueError("Null field definition")
 *                 if width:
 *                     ograpi.OGR_Fld_SetWidth(cogr_fielddefn, width)             # <<<<<<<<<<<<<<
 *                 if precision:
 *                     ograpi.OGR_Fld_SetPrecision(cogr_fielddefn, precision)
 */
        __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_v_width); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 988; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        OGR_Fld_SetWidth(__pyx_v_cogr_fielddefn, __pyx_t_8);
        goto __pyx_L66;
      }
      __pyx_L66:;

      /* "fiona/ogrext.pyx":989
 *                 if width:
 *                     ograpi.OGR_Fld_SetWidth(cogr_fielddefn, width)
 *                 if precision:             # <<<<<<<<<<<<<<
 *                     ograpi.OGR_Fld_SetPrecision(cogr_fielddefn, precision)
 *                 ograpi.OGR_L_CreateField(self.cogr_layer, cogr_fielddefn, 1)
 */
      __pyx_t_17 = __Pyx_PyObject_IsTrue(__pyx_v_precision); if (unlikely(__pyx_t_17 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 989; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (__pyx_t_17) {

        /* "fiona/ogrext.pyx":990
 *                     ograpi.OGR_Fld_SetWidth(cogr_fielddefn, width)
 *                 if precision:
 *                     ograpi.OGR_Fld_SetPrecision(cogr_fielddefn, precision)             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_L_CreateField(self.cogr_layer, cogr_fielddefn, 1)
 *                 ograpi.OGR_Fld_Destroy(cogr_fielddefn)
 */
        __pyx_t_8 = __Pyx_PyInt_As_int(__pyx_v_precision); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 990; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        OGR_Fld_SetPrecision(__pyx_v_cogr_fielddefn, __pyx_t_8);
        goto __pyx_L67;
      }
      __pyx_L67:;

      /* "fiona/ogrext.pyx":991
 *                 if precision:
 *                     ograpi.OGR_Fld_SetPrecision(cogr_fielddefn, precision)
 *                 ograpi.OGR_L_CreateField(self.cogr_layer, cogr_fielddefn, 1)             # <<<<<<<<<<<<<<
 *                 ograpi.OGR_Fld_Destroy(cogr_fielddefn)
 *             log.debug("Created fields")
 */
      OGR_L_CreateField(__pyx_v_self->__pyx_base.cogr_layer, __pyx_v_cogr_fielddefn, 1);

      /* "fiona/ogrext.pyx":992
 *                     ograpi.OGR_Fld_SetPrecision(cogr_fielddefn, precision)
 *                 ograpi.OGR_L_CreateField(self.cogr_layer, cogr_fielddefn, 1)
 *                 ograpi.OGR_Fld_Destroy(cogr_fielddefn)             # <<<<<<<<<<<<<<
 *             log.debug("Created fields")
 * 
 */
      OGR_Fld_Destroy(__pyx_v_cogr_fielddefn);
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "fiona/ogrext.pyx":993
 *                 ograpi.OGR_L_CreateField(self.cogr_layer, cogr_fielddefn, 1)
 *                 ograpi.OGR_Fld_Destroy(cogr_fielddefn)
 *             log.debug("Created fields")             # <<<<<<<<<<<<<<
 * 
 *         # Mapping of the Python collection schema to the munged
 */
    __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 993; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_debug); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 993; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(__pyx_t_14, __pyx_tuple__51, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 993; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "fiona/ogrext.pyx":997
 *         # Mapping of the Python collection schema to the munged
 *         # OGR schema.
 *         ogr_schema = self.get_schema()             # <<<<<<<<<<<<<<
 *         self._schema_mapping = dict(zip(
 *             collection.schema['properties'].keys(),
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_schema); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 997; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_14 = PyObject_Call(__pyx_t_4, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 997; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_ogr_schema = __pyx_t_14;
  __pyx_t_14 = 0;

  /* "fiona/ogrext.pyx":999
 *         ogr_schema = self.get_schema()
 *         self._schema_mapping = dict(zip(
 *             collection.schema['properties'].keys(),             # <<<<<<<<<<<<<<
 *             ogr_schema['properties'].keys() ))
 * 
 */
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_schema); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 999; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_4 = PyObject_GetItem(__pyx_t_14, __pyx_n_s_properties); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 999; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_keys); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 999; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_Call(__pyx_t_14, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 999; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "fiona/ogrext.pyx":1000
 *         self._schema_mapping = dict(zip(
 *             collection.schema['properties'].keys(),
 *             ogr_schema['properties'].keys() ))             # <<<<<<<<<<<<<<
 * 
 *         log.debug("Writing started")
 */
  __pyx_t_14 = PyObject_GetItem(__pyx_v_ogr_schema, __pyx_n_s_properties); if (unlikely(__pyx_t_14 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1000; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_keys); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1000; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1000; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":998
 *         # OGR schema.
 *         ogr_schema = self.get_schema()
 *         self._schema_mapping = dict(zip(             # <<<<<<<<<<<<<<
 *             collection.schema['properties'].keys(),
 *             ogr_schema['properties'].keys() ))
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 998; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_14);
  __pyx_t_4 = 0;
  __pyx_t_14 = 0;
  __pyx_t_14 = PyObject_Call(__pyx_builtin_zip, __pyx_t_1, NULL); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 998; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 998; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_14);
  __Pyx_GIVEREF(__pyx_t_14);
  __pyx_t_14 = 0;
  __pyx_t_14 = PyObject_Call(((PyObject *)((PyObject*)(&PyDict_Type))), __pyx_t_1, NULL); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 998; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_14);
  __Pyx_GOTREF(__pyx_v_self->_schema_mapping);
  __Pyx_DECREF(__pyx_v_self->_schema_mapping);
  __pyx_v_self->_schema_mapping = __pyx_t_14;
  __pyx_t_14 = 0;

  /* "fiona/ogrext.pyx":1002
 *             ogr_schema['properties'].keys() ))
 * 
 *         log.debug("Writing started")             # <<<<<<<<<<<<<<
 * 
 *     def writerecs(self, records, collection):
 */
  __pyx_t_14 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1002; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_debug); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1002; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_14 = PyObject_Call(__pyx_t_1, __pyx_tuple__52, NULL); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1002; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "fiona/ogrext.pyx":801
 *     cdef object _schema_mapping
 * 
 *     def start(self, collection):             # <<<<<<<<<<<<<<
 *         cdef void *cogr_fielddefn
 *         cdef void *cogr_driver
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_20);
  __Pyx_AddTraceback("fiona.ogrext.WritingSession.start", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_path);
  __Pyx_XDECREF(__pyx_v_path_b);
  __Pyx_XDECREF(__pyx_v_name_b);
  __Pyx_XDECREF(__pyx_v_userencoding);
  __Pyx_XDECREF(__pyx_v_driver_b);
  __Pyx_XDECREF(__pyx_v_params);
  __Pyx_XDECREF(__pyx_v_k);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XDECREF(__pyx_v_proj);
  __Pyx_XDECREF(__pyx_v_proj_b);
  __Pyx_XDECREF(__pyx_v_sysencoding);
  __Pyx_XDECREF(__pyx_v_fileencoding);
  __Pyx_XDECREF(__pyx_v_fileencoding_b);
  __Pyx_XDECREF(__pyx_v_layer_names);
  __Pyx_XDECREF(__pyx_v_idx);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF(__pyx_v_width);
  __Pyx_XDECREF(__pyx_v_precision);
  __Pyx_XDECREF(__pyx_v_fmt);
  __Pyx_XDECREF(__pyx_v_encoding);
  __Pyx_XDECREF(__pyx_v_key_bytes);
  __Pyx_XDECREF(__pyx_v_ogr_schema);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":1004
 *         log.debug("Writing started")
 * 
 *     def writerecs(self, records, collection):             # <<<<<<<<<<<<<<
 *         """Writes buffered records to OGR."""
 *         cdef void *cogr_driver
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_14WritingSession_3writerecs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_5fiona_6ogrext_14WritingSession_2writerecs[] = "Writes buffered records to OGR.";
static PyObject *__pyx_pw_5fiona_6ogrext_14WritingSession_3writerecs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_records = 0;
  PyObject *__pyx_v_collection = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("writerecs (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_records,&__pyx_n_s_collection,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_records)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_collection)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("writerecs", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1004; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "writerecs") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1004; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_records = values[0];
    __pyx_v_collection = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("writerecs", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1004; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("fiona.ogrext.WritingSession.writerecs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5fiona_6ogrext_14WritingSession_2writerecs(((struct __pyx_obj_5fiona_6ogrext_WritingSession *)__pyx_v_self), __pyx_v_records, __pyx_v_collection);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":1016
 *         cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 *         if ograpi.OGR_Dr_GetName(cogr_driver) == b"GeoJSON":
 *             def validate_geometry_type(rec):             # <<<<<<<<<<<<<<
 *                 return True
 *         elif ograpi.OGR_Dr_GetName(cogr_driver) == b"ESRI Shapefile" \
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_14WritingSession_9writerecs_1validate_geometry_type(PyObject *__pyx_self, PyObject *__pyx_v_rec); /*proto*/
static PyMethodDef __pyx_mdef_5fiona_6ogrext_14WritingSession_9writerecs_1validate_geometry_type = {__Pyx_NAMESTR("validate_geometry_type"), (PyCFunction)__pyx_pw_5fiona_6ogrext_14WritingSession_9writerecs_1validate_geometry_type, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_5fiona_6ogrext_14WritingSession_9writerecs_1validate_geometry_type(PyObject *__pyx_self, PyObject *__pyx_v_rec) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("validate_geometry_type (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_14WritingSession_9writerecs_validate_geometry_type(__pyx_self, ((PyObject *)__pyx_v_rec));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_14WritingSession_9writerecs_validate_geometry_type(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_rec) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("validate_geometry_type", 0);

  /* "fiona/ogrext.pyx":1017
 *         if ograpi.OGR_Dr_GetName(cogr_driver) == b"GeoJSON":
 *             def validate_geometry_type(rec):
 *                 return True             # <<<<<<<<<<<<<<
 *         elif ograpi.OGR_Dr_GetName(cogr_driver) == b"ESRI Shapefile" \
 *                 and "Point" not in collection.schema['geometry']:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":1016
 *         cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 *         if ograpi.OGR_Dr_GetName(cogr_driver) == b"GeoJSON":
 *             def validate_geometry_type(rec):             # <<<<<<<<<<<<<<
 *                 return True
 *         elif ograpi.OGR_Dr_GetName(cogr_driver) == b"ESRI Shapefile" \
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":1022
 *             schema_geom_type = collection.schema['geometry'].lstrip(
 *                 "3D ").lstrip("Multi")
 *             def validate_geometry_type(rec):             # <<<<<<<<<<<<<<
 *                 return rec['geometry'] is None or rec['geometry']['type'].lstrip(
 *                     "Multi") == schema_geom_type
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_14WritingSession_9writerecs_3validate_geometry_type(PyObject *__pyx_self, PyObject *__pyx_v_rec); /*proto*/
static PyMethodDef __pyx_mdef_5fiona_6ogrext_14WritingSession_9writerecs_3validate_geometry_type = {__Pyx_NAMESTR("validate_geometry_type"), (PyCFunction)__pyx_pw_5fiona_6ogrext_14WritingSession_9writerecs_3validate_geometry_type, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_5fiona_6ogrext_14WritingSession_9writerecs_3validate_geometry_type(PyObject *__pyx_self, PyObject *__pyx_v_rec) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("validate_geometry_type (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_14WritingSession_9writerecs_2validate_geometry_type(__pyx_self, ((PyObject *)__pyx_v_rec));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_14WritingSession_9writerecs_2validate_geometry_type(PyObject *__pyx_self, PyObject *__pyx_v_rec) {
  struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *__pyx_cur_scope;
  struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("validate_geometry_type", 0);
  __pyx_outer_scope = (struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "fiona/ogrext.pyx":1023
 *                 "3D ").lstrip("Multi")
 *             def validate_geometry_type(rec):
 *                 return rec['geometry'] is None or rec['geometry']['type'].lstrip(             # <<<<<<<<<<<<<<
 *                     "Multi") == schema_geom_type
 *         else:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_GetItem(__pyx_v_rec, __pyx_n_s_geometry); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1023; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1023; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1023; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (!__pyx_t_2) {
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_3 = PyObject_GetItem(__pyx_v_rec, __pyx_n_s_geometry); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1023; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_type); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1023; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_lstrip); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1023; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(__pyx_t_3, __pyx_tuple__53, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1023; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "fiona/ogrext.pyx":1024
 *             def validate_geometry_type(rec):
 *                 return rec['geometry'] is None or rec['geometry']['type'].lstrip(
 *                     "Multi") == schema_geom_type             # <<<<<<<<<<<<<<
 *         else:
 *             schema_geom_type = collection.schema['geometry'].lstrip("3D ")
 */
    if (unlikely(!__pyx_cur_scope->__pyx_v_schema_geom_type)) { __Pyx_RaiseClosureNameError("schema_geom_type"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1024; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_4, __pyx_cur_scope->__pyx_v_schema_geom_type, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1024; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __pyx_t_4 = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":1022
 *             schema_geom_type = collection.schema['geometry'].lstrip(
 *                 "3D ").lstrip("Multi")
 *             def validate_geometry_type(rec):             # <<<<<<<<<<<<<<
 *                 return rec['geometry'] is None or rec['geometry']['type'].lstrip(
 *                     "Multi") == schema_geom_type
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("fiona.ogrext.WritingSession.writerecs.validate_geometry_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":1027
 *         else:
 *             schema_geom_type = collection.schema['geometry'].lstrip("3D ")
 *             def validate_geometry_type(rec):             # <<<<<<<<<<<<<<
 *                 return rec['geometry'] is None or \
 *                        rec['geometry']['type'] == schema_geom_type
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_14WritingSession_9writerecs_5validate_geometry_type(PyObject *__pyx_self, PyObject *__pyx_v_rec); /*proto*/
static PyMethodDef __pyx_mdef_5fiona_6ogrext_14WritingSession_9writerecs_5validate_geometry_type = {__Pyx_NAMESTR("validate_geometry_type"), (PyCFunction)__pyx_pw_5fiona_6ogrext_14WritingSession_9writerecs_5validate_geometry_type, METH_O, __Pyx_DOCSTR(0)};
static PyObject *__pyx_pw_5fiona_6ogrext_14WritingSession_9writerecs_5validate_geometry_type(PyObject *__pyx_self, PyObject *__pyx_v_rec) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("validate_geometry_type (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_14WritingSession_9writerecs_4validate_geometry_type(__pyx_self, ((PyObject *)__pyx_v_rec));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_14WritingSession_9writerecs_4validate_geometry_type(PyObject *__pyx_self, PyObject *__pyx_v_rec) {
  struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *__pyx_cur_scope;
  struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("validate_geometry_type", 0);
  __pyx_outer_scope = (struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "fiona/ogrext.pyx":1028
 *             schema_geom_type = collection.schema['geometry'].lstrip("3D ")
 *             def validate_geometry_type(rec):
 *                 return rec['geometry'] is None or \             # <<<<<<<<<<<<<<
 *                        rec['geometry']['type'] == schema_geom_type
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyObject_GetItem(__pyx_v_rec, __pyx_n_s_geometry); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1028; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1028; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1028; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (!__pyx_t_2) {
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "fiona/ogrext.pyx":1029
 *             def validate_geometry_type(rec):
 *                 return rec['geometry'] is None or \
 *                        rec['geometry']['type'] == schema_geom_type             # <<<<<<<<<<<<<<
 * 
 *         schema_props_keys = set(collection.schema['properties'].keys())
 */
    __pyx_t_3 = PyObject_GetItem(__pyx_v_rec, __pyx_n_s_geometry); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1029; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_type); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1029; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_v_schema_geom_type)) { __Pyx_RaiseClosureNameError("schema_geom_type"); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1029; __pyx_clineno = __LINE__; goto __pyx_L1_error;} }
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_4, __pyx_cur_scope->__pyx_v_schema_geom_type, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1029; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __pyx_t_4 = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":1027
 *         else:
 *             schema_geom_type = collection.schema['geometry'].lstrip("3D ")
 *             def validate_geometry_type(rec):             # <<<<<<<<<<<<<<
 *                 return rec['geometry'] is None or \
 *                        rec['geometry']['type'] == schema_geom_type
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("fiona.ogrext.WritingSession.writerecs.validate_geometry_type", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":1004
 *         log.debug("Writing started")
 * 
 *     def writerecs(self, records, collection):             # <<<<<<<<<<<<<<
 *         """Writes buffered records to OGR."""
 *         cdef void *cogr_driver
 */

static PyObject *__pyx_pf_5fiona_6ogrext_14WritingSession_2writerecs(struct __pyx_obj_5fiona_6ogrext_WritingSession *__pyx_v_self, PyObject *__pyx_v_records, PyObject *__pyx_v_collection) {
  struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *__pyx_cur_scope;
  void *__pyx_v_cogr_driver;
  void *__pyx_v_cogr_feature;
  void *__pyx_v_cogr_layer;
  PyObject *__pyx_v_validate_geometry_type = 0;
  PyObject *__pyx_v_schema_props_keys = NULL;
  PyObject *__pyx_v_record = NULL;
  __pyx_t_5fiona_6ograpi_OGRErr __pyx_v_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  void *__pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("writerecs", 0);
  __pyx_cur_scope = (struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *)__pyx_tp_new_5fiona_6ogrext___pyx_scope_struct_1_writerecs(__pyx_ptype_5fiona_6ogrext___pyx_scope_struct_1_writerecs, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __Pyx_GOTREF(__pyx_cur_scope);

  /* "fiona/ogrext.pyx":1009
 *         cdef void *cogr_feature
 * 
 *         cdef void *cogr_layer = self.cogr_layer             # <<<<<<<<<<<<<<
 *         if cogr_layer is NULL:
 *             raise ValueError("Null layer")
 */
  __pyx_t_1 = __pyx_v_self->__pyx_base.cogr_layer;
  __pyx_v_cogr_layer = __pyx_t_1;

  /* "fiona/ogrext.pyx":1010
 * 
 *         cdef void *cogr_layer = self.cogr_layer
 *         if cogr_layer is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null layer")
 * 
 */
  __pyx_t_2 = ((__pyx_v_cogr_layer == NULL) != 0);
  if (__pyx_t_2) {

    /* "fiona/ogrext.pyx":1011
 *         cdef void *cogr_layer = self.cogr_layer
 *         if cogr_layer is NULL:
 *             raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 * 
 *         schema_geom_type = collection.schema['geometry']
 */
    __pyx_t_3 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__54, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1011; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1011; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":1013
 *             raise ValueError("Null layer")
 * 
 *         schema_geom_type = collection.schema['geometry']             # <<<<<<<<<<<<<<
 *         cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 *         if ograpi.OGR_Dr_GetName(cogr_driver) == b"GeoJSON":
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_schema); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1013; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_geometry); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1013; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_cur_scope->__pyx_v_schema_geom_type = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":1014
 * 
 *         schema_geom_type = collection.schema['geometry']
 *         cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)             # <<<<<<<<<<<<<<
 *         if ograpi.OGR_Dr_GetName(cogr_driver) == b"GeoJSON":
 *             def validate_geometry_type(rec):
 */
  __pyx_v_cogr_driver = OGR_DS_GetDriver(__pyx_v_self->__pyx_base.cogr_ds);

  /* "fiona/ogrext.pyx":1015
 *         schema_geom_type = collection.schema['geometry']
 *         cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 *         if ograpi.OGR_Dr_GetName(cogr_driver) == b"GeoJSON":             # <<<<<<<<<<<<<<
 *             def validate_geometry_type(rec):
 *                 return True
 */
  __pyx_t_4 = __Pyx_PyBytes_FromString(OGR_Dr_GetName(__pyx_v_cogr_driver)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1015; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = (__Pyx_PyBytes_Equals(__pyx_t_4, __pyx_n_b_GeoJSON, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1015; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "fiona/ogrext.pyx":1016
 *         cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 *         if ograpi.OGR_Dr_GetName(cogr_driver) == b"GeoJSON":
 *             def validate_geometry_type(rec):             # <<<<<<<<<<<<<<
 *                 return True
 *         elif ograpi.OGR_Dr_GetName(cogr_driver) == b"ESRI Shapefile" \
 */
    __pyx_t_4 = __Pyx_CyFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_14WritingSession_9writerecs_1validate_geometry_type, 0, __pyx_n_s_writerecs_locals_validate_geomet, NULL, __pyx_n_s_fiona_ogrext, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__56)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1016; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_validate_geometry_type = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L4;
  }

  /* "fiona/ogrext.pyx":1018
 *             def validate_geometry_type(rec):
 *                 return True
 *         elif ograpi.OGR_Dr_GetName(cogr_driver) == b"ESRI Shapefile" \             # <<<<<<<<<<<<<<
 *                 and "Point" not in collection.schema['geometry']:
 *             schema_geom_type = collection.schema['geometry'].lstrip(
 */
  __pyx_t_4 = __Pyx_PyBytes_FromString(OGR_Dr_GetName(__pyx_v_cogr_driver)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1018; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = (__Pyx_PyBytes_Equals(__pyx_t_4, __pyx_kp_b_ESRI_Shapefile, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1018; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_2) {

    /* "fiona/ogrext.pyx":1019
 *                 return True
 *         elif ograpi.OGR_Dr_GetName(cogr_driver) == b"ESRI Shapefile" \
 *                 and "Point" not in collection.schema['geometry']:             # <<<<<<<<<<<<<<
 *             schema_geom_type = collection.schema['geometry'].lstrip(
 *                 "3D ").lstrip("Multi")
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_schema); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1019; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_geometry); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1019; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = (__Pyx_PySequence_Contains(__pyx_n_s_Point, __pyx_t_3, Py_NE)); if (unlikely(__pyx_t_5 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1019; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __pyx_t_5;
  } else {
    __pyx_t_6 = __pyx_t_2;
  }
  if (__pyx_t_6) {

    /* "fiona/ogrext.pyx":1020
 *         elif ograpi.OGR_Dr_GetName(cogr_driver) == b"ESRI Shapefile" \
 *                 and "Point" not in collection.schema['geometry']:
 *             schema_geom_type = collection.schema['geometry'].lstrip(             # <<<<<<<<<<<<<<
 *                 "3D ").lstrip("Multi")
 *             def validate_geometry_type(rec):
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_schema); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1020; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_geometry); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1020; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_lstrip); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1020; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(__pyx_t_3, __pyx_tuple__57, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1020; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "fiona/ogrext.pyx":1021
 *                 and "Point" not in collection.schema['geometry']:
 *             schema_geom_type = collection.schema['geometry'].lstrip(
 *                 "3D ").lstrip("Multi")             # <<<<<<<<<<<<<<
 *             def validate_geometry_type(rec):
 *                 return rec['geometry'] is None or rec['geometry']['type'].lstrip(
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_lstrip); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1021; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(__pyx_t_3, __pyx_tuple__58, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1021; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_schema_geom_type);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_schema_geom_type, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;

    /* "fiona/ogrext.pyx":1022
 *             schema_geom_type = collection.schema['geometry'].lstrip(
 *                 "3D ").lstrip("Multi")
 *             def validate_geometry_type(rec):             # <<<<<<<<<<<<<<
 *                 return rec['geometry'] is None or rec['geometry']['type'].lstrip(
 *                     "Multi") == schema_geom_type
 */
    __pyx_t_4 = __Pyx_CyFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_14WritingSession_9writerecs_3validate_geometry_type, 0, __pyx_n_s_writerecs_locals_validate_geomet, ((PyObject*)__pyx_cur_scope), __pyx_n_s_fiona_ogrext, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__60)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1022; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_v_validate_geometry_type = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L4;
  }
  /*else*/ {

    /* "fiona/ogrext.pyx":1026
 *                     "Multi") == schema_geom_type
 *         else:
 *             schema_geom_type = collection.schema['geometry'].lstrip("3D ")             # <<<<<<<<<<<<<<
 *             def validate_geometry_type(rec):
 *                 return rec['geometry'] is None or \
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_schema); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1026; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_geometry); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1026; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_lstrip); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1026; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_t_4, __pyx_tuple__61, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1026; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_schema_geom_type);
    __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_schema_geom_type, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;

    /* "fiona/ogrext.pyx":1027
 *         else:
 *             schema_geom_type = collection.schema['geometry'].lstrip("3D ")
 *             def validate_geometry_type(rec):             # <<<<<<<<<<<<<<
 *                 return rec['geometry'] is None or \
 *                        rec['geometry']['type'] == schema_geom_type
 */
    __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_14WritingSession_9writerecs_5validate_geometry_type, 0, __pyx_n_s_writerecs_locals_validate_geomet, ((PyObject*)__pyx_cur_scope), __pyx_n_s_fiona_ogrext, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__63)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1027; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_validate_geometry_type = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_L4:;

  /* "fiona/ogrext.pyx":1031
 *                        rec['geometry']['type'] == schema_geom_type
 * 
 *         schema_props_keys = set(collection.schema['properties'].keys())             # <<<<<<<<<<<<<<
 *         for record in records:
 *             log.debug("Creating feature in layer: %s" % record)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_schema); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1031; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_properties); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1031; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_keys); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1031; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_Call(__pyx_t_3, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1031; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1031; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)(&PySet_Type))), __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1031; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_schema_props_keys = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":1032
 * 
 *         schema_props_keys = set(collection.schema['properties'].keys())
 *         for record in records:             # <<<<<<<<<<<<<<
 *             log.debug("Creating feature in layer: %s" % record)
 *             # Validate against collection's schema.
 */
  if (PyList_CheckExact(__pyx_v_records) || PyTuple_CheckExact(__pyx_v_records)) {
    __pyx_t_4 = __pyx_v_records; __Pyx_INCREF(__pyx_t_4); __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_v_records); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_8 = Py_TYPE(__pyx_t_4)->tp_iternext;
  }
  for (;;) {
    if (!__pyx_t_8 && PyList_CheckExact(__pyx_t_4)) {
      if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_4)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (!__pyx_t_8 && PyTuple_CheckExact(__pyx_t_4)) {
      if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else {
      __pyx_t_3 = __pyx_t_8(__pyx_t_4);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_record, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "fiona/ogrext.pyx":1033
 *         schema_props_keys = set(collection.schema['properties'].keys())
 *         for record in records:
 *             log.debug("Creating feature in layer: %s" % record)             # <<<<<<<<<<<<<<
 *             # Validate against collection's schema.
 *             if set(record['properties'].keys()) != schema_props_keys:
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1033; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_debug); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1033; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyString_Format(__pyx_kp_s_Creating_feature_in_layer_s, __pyx_v_record); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1033; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1033; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_10);
    PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_t_9, __pyx_t_10, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1033; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "fiona/ogrext.pyx":1035
 *             log.debug("Creating feature in layer: %s" % record)
 *             # Validate against collection's schema.
 *             if set(record['properties'].keys()) != schema_props_keys:             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     "Record does not match collection schema: %r != %r" % (
 */
    __pyx_t_3 = PyObject_GetItem(__pyx_v_record, __pyx_n_s_properties); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1035; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_keys); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1035; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_t_10, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1035; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1035; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_10);
    PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)(&PySet_Type))), __pyx_t_10, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1035; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = PyObject_RichCompare(__pyx_t_3, __pyx_v_schema_props_keys, Py_NE); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1035; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1035; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (__pyx_t_6) {

      /* "fiona/ogrext.pyx":1038
 *                 raise ValueError(
 *                     "Record does not match collection schema: %r != %r" % (
 *                         record['properties'].keys(),             # <<<<<<<<<<<<<<
 *                         list(schema_props_keys) ))
 *             if not validate_geometry_type(record):
 */
      __pyx_t_10 = PyObject_GetItem(__pyx_v_record, __pyx_n_s_properties); if (unlikely(__pyx_t_10 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1038; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_n_s_keys); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1038; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = PyObject_Call(__pyx_t_3, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1038; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "fiona/ogrext.pyx":1039
 *                     "Record does not match collection schema: %r != %r" % (
 *                         record['properties'].keys(),
 *                         list(schema_props_keys) ))             # <<<<<<<<<<<<<<
 *             if not validate_geometry_type(record):
 *                 raise ValueError(
 */
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1039; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_v_schema_props_keys);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_schema_props_keys);
      __Pyx_GIVEREF(__pyx_v_schema_props_keys);
      __pyx_t_9 = PyObject_Call(((PyObject *)((PyObject*)(&PyList_Type))), __pyx_t_3, NULL); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1039; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "fiona/ogrext.pyx":1038
 *                 raise ValueError(
 *                     "Record does not match collection schema: %r != %r" % (
 *                         record['properties'].keys(),             # <<<<<<<<<<<<<<
 *                         list(schema_props_keys) ))
 *             if not validate_geometry_type(record):
 */
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1038; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_10);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_9);
      __pyx_t_10 = 0;
      __pyx_t_9 = 0;

      /* "fiona/ogrext.pyx":1037
 *             if set(record['properties'].keys()) != schema_props_keys:
 *                 raise ValueError(
 *                     "Record does not match collection schema: %r != %r" % (             # <<<<<<<<<<<<<<
 *                         record['properties'].keys(),
 *                         list(schema_props_keys) ))
 */
      __pyx_t_9 = __Pyx_PyString_Format(__pyx_kp_s_Record_does_not_match_collection, __pyx_t_3); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1037; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "fiona/ogrext.pyx":1036
 *             # Validate against collection's schema.
 *             if set(record['properties'].keys()) != schema_props_keys:
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     "Record does not match collection schema: %r != %r" % (
 *                         record['properties'].keys(),
 */
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1036; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_9 = PyObject_Call(__pyx_builtin_ValueError, __pyx_t_3, NULL); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1036; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_9, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1036; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }

    /* "fiona/ogrext.pyx":1040
 *                         record['properties'].keys(),
 *                         list(schema_props_keys) ))
 *             if not validate_geometry_type(record):             # <<<<<<<<<<<<<<
 *                 raise ValueError(
 *                     "Record's geometry type does not match "
 */
    __pyx_t_9 = PyTuple_New(1); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1040; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_INCREF(__pyx_v_record);
    PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_v_record);
    __Pyx_GIVEREF(__pyx_v_record);
    __pyx_t_3 = PyObject_Call(__pyx_v_validate_geometry_type, __pyx_t_9, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1040; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1040; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = ((!__pyx_t_6) != 0);
    if (__pyx_t_2) {

      /* "fiona/ogrext.pyx":1044
 *                     "Record's geometry type does not match "
 *                     "collection schema's geometry type: %r != %r" % (
 *                          record['geometry']['type'],             # <<<<<<<<<<<<<<
 *                          collection.schema['geometry'] ))
 * 
 */
      __pyx_t_3 = PyObject_GetItem(__pyx_v_record, __pyx_n_s_geometry); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1044; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_9 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_type); if (unlikely(__pyx_t_9 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1044; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "fiona/ogrext.pyx":1045
 *                     "collection schema's geometry type: %r != %r" % (
 *                          record['geometry']['type'],
 *                          collection.schema['geometry'] ))             # <<<<<<<<<<<<<<
 * 
 *             cogr_feature = OGRFeatureBuilder().build(record, collection)
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_schema); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1045; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_10 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_geometry); if (unlikely(__pyx_t_10 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1045; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "fiona/ogrext.pyx":1044
 *                     "Record's geometry type does not match "
 *                     "collection schema's geometry type: %r != %r" % (
 *                          record['geometry']['type'],             # <<<<<<<<<<<<<<
 *                          collection.schema['geometry'] ))
 * 
 */
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1044; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_9);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_10);
      __pyx_t_9 = 0;
      __pyx_t_10 = 0;

      /* "fiona/ogrext.pyx":1043
 *                 raise ValueError(
 *                     "Record's geometry type does not match "
 *                     "collection schema's geometry type: %r != %r" % (             # <<<<<<<<<<<<<<
 *                          record['geometry']['type'],
 *                          collection.schema['geometry'] ))
 */
      __pyx_t_10 = __Pyx_PyString_Format(__pyx_kp_s_Record_s_geometry_type_does_not, __pyx_t_3); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1043; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "fiona/ogrext.pyx":1041
 *                         list(schema_props_keys) ))
 *             if not validate_geometry_type(record):
 *                 raise ValueError(             # <<<<<<<<<<<<<<
 *                     "Record's geometry type does not match "
 *                     "collection schema's geometry type: %r != %r" % (
 */
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1041; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_10);
      __pyx_t_10 = 0;
      __pyx_t_10 = PyObject_Call(__pyx_builtin_ValueError, __pyx_t_3, NULL); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1041; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_10, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1041; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }

    /* "fiona/ogrext.pyx":1047
 *                          collection.schema['geometry'] ))
 * 
 *             cogr_feature = OGRFeatureBuilder().build(record, collection)             # <<<<<<<<<<<<<<
 *             result = ograpi.OGR_L_CreateFeature(cogr_layer, cogr_feature)
 *             if result != OGRERR_NONE:
 */
    __pyx_t_10 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5fiona_6ogrext_OGRFeatureBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1047; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_1 = ((struct __pyx_vtabstruct_5fiona_6ogrext_OGRFeatureBuilder *)((struct __pyx_obj_5fiona_6ogrext_OGRFeatureBuilder *)__pyx_t_10)->__pyx_vtab)->build(((struct __pyx_obj_5fiona_6ogrext_OGRFeatureBuilder *)__pyx_t_10), __pyx_v_record, __pyx_v_collection); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1047; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_v_cogr_feature = __pyx_t_1;

    /* "fiona/ogrext.pyx":1048
 * 
 *             cogr_feature = OGRFeatureBuilder().build(record, collection)
 *             result = ograpi.OGR_L_CreateFeature(cogr_layer, cogr_feature)             # <<<<<<<<<<<<<<
 *             if result != OGRERR_NONE:
 *                 raise RuntimeError("Failed to write record: %s" % record)
 */
    __pyx_v_result = OGR_L_CreateFeature(__pyx_v_cogr_layer, __pyx_v_cogr_feature);

    /* "fiona/ogrext.pyx":1049
 *             cogr_feature = OGRFeatureBuilder().build(record, collection)
 *             result = ograpi.OGR_L_CreateFeature(cogr_layer, cogr_feature)
 *             if result != OGRERR_NONE:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError("Failed to write record: %s" % record)
 *             _deleteOgrFeature(cogr_feature)
 */
    __pyx_t_10 = __Pyx_PyInt_From_int(__pyx_v_result); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1049; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_OGRERR_NONE); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1049; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_9 = PyObject_RichCompare(__pyx_t_10, __pyx_t_3, Py_NE); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1049; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1049; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (__pyx_t_2) {

      /* "fiona/ogrext.pyx":1050
 *             result = ograpi.OGR_L_CreateFeature(cogr_layer, cogr_feature)
 *             if result != OGRERR_NONE:
 *                 raise RuntimeError("Failed to write record: %s" % record)             # <<<<<<<<<<<<<<
 *             _deleteOgrFeature(cogr_feature)
 * 
 */
      __pyx_t_9 = __Pyx_PyString_Format(__pyx_kp_s_Failed_to_write_record_s, __pyx_v_record); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1050; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1050; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_9);
      __pyx_t_9 = 0;
      __pyx_t_9 = PyObject_Call(__pyx_builtin_RuntimeError, __pyx_t_3, NULL); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1050; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_9, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1050; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }

    /* "fiona/ogrext.pyx":1051
 *             if result != OGRERR_NONE:
 *                 raise RuntimeError("Failed to write record: %s" % record)
 *             _deleteOgrFeature(cogr_feature)             # <<<<<<<<<<<<<<
 * 
 *     def sync(self, collection):
 */
    __pyx_t_9 = __pyx_f_5fiona_6ogrext__deleteOgrFeature(__pyx_v_cogr_feature); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1051; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":1004
 *         log.debug("Writing started")
 * 
 *     def writerecs(self, records, collection):             # <<<<<<<<<<<<<<
 *         """Writes buffered records to OGR."""
 *         cdef void *cogr_driver
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("fiona.ogrext.WritingSession.writerecs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_validate_geometry_type);
  __Pyx_XDECREF(__pyx_v_schema_props_keys);
  __Pyx_XDECREF(__pyx_v_record);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":1053
 *             _deleteOgrFeature(cogr_feature)
 * 
 *     def sync(self, collection):             # <<<<<<<<<<<<<<
 *         """Syncs OGR to disk."""
 *         cdef void *cogr_ds = self.cogr_ds
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_14WritingSession_5sync(PyObject *__pyx_v_self, PyObject *__pyx_v_collection); /*proto*/
static char __pyx_doc_5fiona_6ogrext_14WritingSession_4sync[] = "Syncs OGR to disk.";
static PyObject *__pyx_pw_5fiona_6ogrext_14WritingSession_5sync(PyObject *__pyx_v_self, PyObject *__pyx_v_collection) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sync (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_14WritingSession_4sync(((struct __pyx_obj_5fiona_6ogrext_WritingSession *)__pyx_v_self), ((PyObject *)__pyx_v_collection));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_14WritingSession_4sync(struct __pyx_obj_5fiona_6ogrext_WritingSession *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_collection) {
  void *__pyx_v_cogr_ds;
  CYTHON_UNUSED void *__pyx_v_cogr_layer;
  int __pyx_v_retval;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  void *__pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sync", 0);

  /* "fiona/ogrext.pyx":1055
 *     def sync(self, collection):
 *         """Syncs OGR to disk."""
 *         cdef void *cogr_ds = self.cogr_ds             # <<<<<<<<<<<<<<
 *         cdef void *cogr_layer = self.cogr_layer
 *         if cogr_ds is NULL:
 */
  __pyx_t_1 = __pyx_v_self->__pyx_base.cogr_ds;
  __pyx_v_cogr_ds = __pyx_t_1;

  /* "fiona/ogrext.pyx":1056
 *         """Syncs OGR to disk."""
 *         cdef void *cogr_ds = self.cogr_ds
 *         cdef void *cogr_layer = self.cogr_layer             # <<<<<<<<<<<<<<
 *         if cogr_ds is NULL:
 *             raise ValueError("Null data source")
 */
  __pyx_t_1 = __pyx_v_self->__pyx_base.cogr_layer;
  __pyx_v_cogr_layer = __pyx_t_1;

  /* "fiona/ogrext.pyx":1057
 *         cdef void *cogr_ds = self.cogr_ds
 *         cdef void *cogr_layer = self.cogr_layer
 *         if cogr_ds is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null data source")
 *         log.debug("Syncing OGR to disk")
 */
  __pyx_t_2 = ((__pyx_v_cogr_ds == NULL) != 0);
  if (__pyx_t_2) {

    /* "fiona/ogrext.pyx":1058
 *         cdef void *cogr_layer = self.cogr_layer
 *         if cogr_ds is NULL:
 *             raise ValueError("Null data source")             # <<<<<<<<<<<<<<
 *         log.debug("Syncing OGR to disk")
 *         retval = ograpi.OGR_DS_SyncToDisk(cogr_ds)
 */
    __pyx_t_3 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__64, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1058; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1058; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":1059
 *         if cogr_ds is NULL:
 *             raise ValueError("Null data source")
 *         log.debug("Syncing OGR to disk")             # <<<<<<<<<<<<<<
 *         retval = ograpi.OGR_DS_SyncToDisk(cogr_ds)
 *         if retval != OGRERR_NONE:
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1059; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_debug); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1059; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_4, __pyx_tuple__65, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1059; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "fiona/ogrext.pyx":1060
 *             raise ValueError("Null data source")
 *         log.debug("Syncing OGR to disk")
 *         retval = ograpi.OGR_DS_SyncToDisk(cogr_ds)             # <<<<<<<<<<<<<<
 *         if retval != OGRERR_NONE:
 *             raise RuntimeError("Failed to sync to disk")
 */
  __pyx_v_retval = OGR_DS_SyncToDisk(__pyx_v_cogr_ds);

  /* "fiona/ogrext.pyx":1061
 *         log.debug("Syncing OGR to disk")
 *         retval = ograpi.OGR_DS_SyncToDisk(cogr_ds)
 *         if retval != OGRERR_NONE:             # <<<<<<<<<<<<<<
 *             raise RuntimeError("Failed to sync to disk")
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_retval); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1061; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_OGRERR_NONE); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1061; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_3, __pyx_t_4, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1061; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1061; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_2) {

    /* "fiona/ogrext.pyx":1062
 *         retval = ograpi.OGR_DS_SyncToDisk(cogr_ds)
 *         if retval != OGRERR_NONE:
 *             raise RuntimeError("Failed to sync to disk")             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_5 = PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__66, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1062; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1062; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":1053
 *             _deleteOgrFeature(cogr_feature)
 * 
 *     def sync(self, collection):             # <<<<<<<<<<<<<<
 *         """Syncs OGR to disk."""
 *         cdef void *cogr_ds = self.cogr_ds
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("fiona.ogrext.WritingSession.sync", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":1074
 *     cdef encoding
 * 
 *     def __init__(self, collection, bbox=None):             # <<<<<<<<<<<<<<
 *         if collection.session is None:
 *             raise ValueError("I/O operation on closed collection")
 */

/* Python wrapper */
static int __pyx_pw_5fiona_6ogrext_8Iterator_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_5fiona_6ogrext_8Iterator_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_collection = 0;
  PyObject *__pyx_v_bbox = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_collection,&__pyx_n_s_bbox,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_collection)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_bbox);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1074; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_collection = values[0];
    __pyx_v_bbox = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1074; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("fiona.ogrext.Iterator.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5fiona_6ogrext_8Iterator___init__(((struct __pyx_obj_5fiona_6ogrext_Iterator *)__pyx_v_self), __pyx_v_collection, __pyx_v_bbox);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5fiona_6ogrext_8Iterator___init__(struct __pyx_obj_5fiona_6ogrext_Iterator *__pyx_v_self, PyObject *__pyx_v_collection, PyObject *__pyx_v_bbox) {
  struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_session = 0;
  void *__pyx_v_cogr_layer;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  void *__pyx_t_4;
  double __pyx_t_5;
  double __pyx_t_6;
  double __pyx_t_7;
  double __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "fiona/ogrext.pyx":1075
 * 
 *     def __init__(self, collection, bbox=None):
 *         if collection.session is None:             # <<<<<<<<<<<<<<
 *             raise ValueError("I/O operation on closed collection")
 *         self.collection = collection
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_collection, __pyx_n_s_session); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1075; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__pyx_t_1 == Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_t_2 != 0);
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":1076
 *     def __init__(self, collection, bbox=None):
 *         if collection.session is None:
 *             raise ValueError("I/O operation on closed collection")             # <<<<<<<<<<<<<<
 *         self.collection = collection
 *         cdef Session session
 */
    __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__67, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1076; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1076; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":1077
 *         if collection.session is None:
 *             raise ValueError("I/O operation on closed collection")
 *         self.collection = collection             # <<<<<<<<<<<<<<
 *         cdef Session session
 *         session = self.collection.session
 */
  __Pyx_INCREF(__pyx_v_collection);
  __Pyx_GIVEREF(__pyx_v_collection);
  __Pyx_GOTREF(__pyx_v_self->collection);
  __Pyx_DECREF(__pyx_v_self->collection);
  __pyx_v_self->collection = __pyx_v_collection;

  /* "fiona/ogrext.pyx":1079
 *         self.collection = collection
 *         cdef Session session
 *         session = self.collection.session             # <<<<<<<<<<<<<<
 *         cdef void *cogr_layer = session.cogr_layer
 *         if cogr_layer is NULL:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->collection, __pyx_n_s_session); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1079; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5fiona_6ogrext_Session))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1079; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_session = ((struct __pyx_obj_5fiona_6ogrext_Session *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":1080
 *         cdef Session session
 *         session = self.collection.session
 *         cdef void *cogr_layer = session.cogr_layer             # <<<<<<<<<<<<<<
 *         if cogr_layer is NULL:
 *             raise ValueError("Null layer")
 */
  __pyx_t_4 = __pyx_v_session->cogr_layer;
  __pyx_v_cogr_layer = __pyx_t_4;

  /* "fiona/ogrext.pyx":1081
 *         session = self.collection.session
 *         cdef void *cogr_layer = session.cogr_layer
 *         if cogr_layer is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("Null layer")
 *         ograpi.OGR_L_ResetReading(cogr_layer)
 */
  __pyx_t_3 = ((__pyx_v_cogr_layer == NULL) != 0);
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":1082
 *         cdef void *cogr_layer = session.cogr_layer
 *         if cogr_layer is NULL:
 *             raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 *         ograpi.OGR_L_ResetReading(cogr_layer)
 *         if bbox:
 */
    __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__68, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1082; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1082; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":1083
 *         if cogr_layer is NULL:
 *             raise ValueError("Null layer")
 *         ograpi.OGR_L_ResetReading(cogr_layer)             # <<<<<<<<<<<<<<
 *         if bbox:
 *             ograpi.OGR_L_SetSpatialFilterRect(
 */
  OGR_L_ResetReading(__pyx_v_cogr_layer);

  /* "fiona/ogrext.pyx":1084
 *             raise ValueError("Null layer")
 *         ograpi.OGR_L_ResetReading(cogr_layer)
 *         if bbox:             # <<<<<<<<<<<<<<
 *             ograpi.OGR_L_SetSpatialFilterRect(
 *                 cogr_layer, bbox[0], bbox[1], bbox[2], bbox[3])
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_bbox); if (unlikely(__pyx_t_3 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1084; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_3) {

    /* "fiona/ogrext.pyx":1086
 *         if bbox:
 *             ograpi.OGR_L_SetSpatialFilterRect(
 *                 cogr_layer, bbox[0], bbox[1], bbox[2], bbox[3])             # <<<<<<<<<<<<<<
 *         self.encoding = session.get_internalencoding()
 * 
 */
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_bbox, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1086; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_5 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_5 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1086; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_bbox, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1086; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_6 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1086; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_bbox, 2, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1086; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_7 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1086; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_bbox, 3, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_1 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1086; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = __pyx_PyFloat_AsDouble(__pyx_t_1); if (unlikely((__pyx_t_8 == (double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1086; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "fiona/ogrext.pyx":1085
 *         ograpi.OGR_L_ResetReading(cogr_layer)
 *         if bbox:
 *             ograpi.OGR_L_SetSpatialFilterRect(             # <<<<<<<<<<<<<<
 *                 cogr_layer, bbox[0], bbox[1], bbox[2], bbox[3])
 *         self.encoding = session.get_internalencoding()
 */
    OGR_L_SetSpatialFilterRect(__pyx_v_cogr_layer, __pyx_t_5, __pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "fiona/ogrext.pyx":1087
 *             ograpi.OGR_L_SetSpatialFilterRect(
 *                 cogr_layer, bbox[0], bbox[1], bbox[2], bbox[3])
 *         self.encoding = session.get_internalencoding()             # <<<<<<<<<<<<<<
 * 
 *     def __iter__(self):
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_session), __pyx_n_s_get_internalencoding); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1087; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_9 = PyObject_Call(__pyx_t_1, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1087; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_GIVEREF(__pyx_t_9);
  __Pyx_GOTREF(__pyx_v_self->encoding);
  __Pyx_DECREF(__pyx_v_self->encoding);
  __pyx_v_self->encoding = __pyx_t_9;
  __pyx_t_9 = 0;

  /* "fiona/ogrext.pyx":1074
 *     cdef encoding
 * 
 *     def __init__(self, collection, bbox=None):             # <<<<<<<<<<<<<<
 *         if collection.session is None:
 *             raise ValueError("I/O operation on closed collection")
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("fiona.ogrext.Iterator.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_session);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":1089
 *         self.encoding = session.get_internalencoding()
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_8Iterator_3__iter__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_8Iterator_3__iter__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_8Iterator_2__iter__(((struct __pyx_obj_5fiona_6ogrext_Iterator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_8Iterator_2__iter__(struct __pyx_obj_5fiona_6ogrext_Iterator *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);

  /* "fiona/ogrext.pyx":1090
 * 
 *     def __iter__(self):
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     def __next__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __pyx_r = ((PyObject *)__pyx_v_self);
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":1089
 *         self.encoding = session.get_internalencoding()
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         return self
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":1092
 *         return self
 * 
 *     def __next__(self):             # <<<<<<<<<<<<<<
 *         cdef long fid
 *         cdef void * cogr_feature
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_8Iterator_5__next__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5fiona_6ogrext_8Iterator_5__next__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__next__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_8Iterator_4__next__(((struct __pyx_obj_5fiona_6ogrext_Iterator *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_8Iterator_4__next__(struct __pyx_obj_5fiona_6ogrext_Iterator *__pyx_v_self) {
  void *__pyx_v_cogr_feature;
  struct __pyx_obj_5fiona_6ogrext_Session *__pyx_v_session = 0;
  PyObject *__pyx_v_feature = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  struct __pyx_opt_args_5fiona_6ogrext_14FeatureBuilder_build __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__next__", 0);

  /* "fiona/ogrext.pyx":1096
 *         cdef void * cogr_feature
 *         cdef Session session
 *         session = self.collection.session             # <<<<<<<<<<<<<<
 *         cogr_feature = ograpi.OGR_L_GetNextFeature(session.cogr_layer)
 *         if cogr_feature == NULL:
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->collection, __pyx_n_s_session); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1096; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_5fiona_6ogrext_Session))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1096; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_session = ((struct __pyx_obj_5fiona_6ogrext_Session *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":1097
 *         cdef Session session
 *         session = self.collection.session
 *         cogr_feature = ograpi.OGR_L_GetNextFeature(session.cogr_layer)             # <<<<<<<<<<<<<<
 *         if cogr_feature == NULL:
 *             raise StopIteration
 */
  __pyx_v_cogr_feature = OGR_L_GetNextFeature(__pyx_v_session->cogr_layer);

  /* "fiona/ogrext.pyx":1098
 *         session = self.collection.session
 *         cogr_feature = ograpi.OGR_L_GetNextFeature(session.cogr_layer)
 *         if cogr_feature == NULL:             # <<<<<<<<<<<<<<
 *             raise StopIteration
 *         feature = FeatureBuilder().build(cogr_feature, self.encoding)
 */
  __pyx_t_2 = ((__pyx_v_cogr_feature == NULL) != 0);
  if (__pyx_t_2) {

    /* "fiona/ogrext.pyx":1099
 *         cogr_feature = ograpi.OGR_L_GetNextFeature(session.cogr_layer)
 *         if cogr_feature == NULL:
 *             raise StopIteration             # <<<<<<<<<<<<<<
 *         feature = FeatureBuilder().build(cogr_feature, self.encoding)
 *         _deleteOgrFeature(cogr_feature)
 */
    __Pyx_Raise(__pyx_builtin_StopIteration, 0, 0, 0);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1099; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":1100
 *         if cogr_feature == NULL:
 *             raise StopIteration
 *         feature = FeatureBuilder().build(cogr_feature, self.encoding)             # <<<<<<<<<<<<<<
 *         _deleteOgrFeature(cogr_feature)
 *         return feature
 */
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5fiona_6ogrext_FeatureBuilder)), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1100; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_v_self->encoding;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_5.__pyx_n = 1;
  __pyx_t_5.encoding = __pyx_t_3;
  __pyx_t_4 = ((struct __pyx_vtabstruct_5fiona_6ogrext_FeatureBuilder *)((struct __pyx_obj_5fiona_6ogrext_FeatureBuilder *)__pyx_t_1)->__pyx_vtab)->build(((struct __pyx_obj_5fiona_6ogrext_FeatureBuilder *)__pyx_t_1), __pyx_v_cogr_feature, &__pyx_t_5); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1100; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_feature = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":1101
 *             raise StopIteration
 *         feature = FeatureBuilder().build(cogr_feature, self.encoding)
 *         _deleteOgrFeature(cogr_feature)             # <<<<<<<<<<<<<<
 *         return feature
 * 
 */
  __pyx_t_4 = __pyx_f_5fiona_6ogrext__deleteOgrFeature(__pyx_v_cogr_feature); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1101; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":1102
 *         feature = FeatureBuilder().build(cogr_feature, self.encoding)
 *         _deleteOgrFeature(cogr_feature)
 *         return feature             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_feature);
  __pyx_r = __pyx_v_feature;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":1092
 *         return self
 * 
 *     def __next__(self):             # <<<<<<<<<<<<<<
 *         cdef long fid
 *         cdef void * cogr_feature
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("fiona.ogrext.Iterator.__next__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_session);
  __Pyx_XDECREF(__pyx_v_feature);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "fiona/ogrext.pyx":1105
 * 
 * 
 * def _listlayers(path):             # <<<<<<<<<<<<<<
 * 
 *     """Provides a list of the layers in an OGR data source.
 */

/* Python wrapper */
static PyObject *__pyx_pw_5fiona_6ogrext_10_listlayers(PyObject *__pyx_self, PyObject *__pyx_v_path); /*proto*/
static char __pyx_doc_5fiona_6ogrext_9_listlayers[] = "Provides a list of the layers in an OGR data source.\n    ";
static PyMethodDef __pyx_mdef_5fiona_6ogrext_10_listlayers = {__Pyx_NAMESTR("_listlayers"), (PyCFunction)__pyx_pw_5fiona_6ogrext_10_listlayers, METH_O, __Pyx_DOCSTR(__pyx_doc_5fiona_6ogrext_9_listlayers)};
static PyObject *__pyx_pw_5fiona_6ogrext_10_listlayers(PyObject *__pyx_self, PyObject *__pyx_v_path) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_listlayers (wrapper)", 0);
  __pyx_r = __pyx_pf_5fiona_6ogrext_9_listlayers(__pyx_self, ((PyObject *)__pyx_v_path));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5fiona_6ogrext_9_listlayers(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_path) {
  void *__pyx_v_cogr_ds;
  void *__pyx_v_cogr_layer;
  char *__pyx_v_path_c;
  char *__pyx_v_name_c;
  PyObject *__pyx_v_path_b = NULL;
  int __pyx_v_layer_count;
  PyObject *__pyx_v_layer_names = NULL;
  int __pyx_v_i;
  char *__pyx_v_name_b;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  char *__pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_listlayers", 0);

  /* "fiona/ogrext.pyx":1116
 * 
 *     # Open OGR data source.
 *     try:             # <<<<<<<<<<<<<<
 *         path_b = path.encode('utf-8')
 *     except UnicodeDecodeError:
 */
  {
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "fiona/ogrext.pyx":1117
 *     # Open OGR data source.
 *     try:
 *         path_b = path.encode('utf-8')             # <<<<<<<<<<<<<<
 *     except UnicodeDecodeError:
 *         path_b = path
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_path, __pyx_n_s_encode); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1117; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = PyObject_Call(__pyx_t_4, __pyx_tuple__69, NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1117; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_path_b = __pyx_t_5;
      __pyx_t_5 = 0;
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L10_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "fiona/ogrext.pyx":1118
 *     try:
 *         path_b = path.encode('utf-8')
 *     except UnicodeDecodeError:             # <<<<<<<<<<<<<<
 *         path_b = path
 *     path_c = path_b
 */
    __pyx_t_6 = PyErr_ExceptionMatches(__pyx_builtin_UnicodeDecodeError);
    if (__pyx_t_6) {
      __Pyx_AddTraceback("fiona.ogrext._listlayers", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1118; __pyx_clineno = __LINE__; goto __pyx_L5_except_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_GOTREF(__pyx_t_7);

      /* "fiona/ogrext.pyx":1119
 *         path_b = path.encode('utf-8')
 *     except UnicodeDecodeError:
 *         path_b = path             # <<<<<<<<<<<<<<
 *     path_c = path_b
 *     cogr_ds = ograpi.OGROpen(path_c, 0, NULL)
 */
      __Pyx_INCREF(__pyx_v_path);
      __Pyx_XDECREF_SET(__pyx_v_path_b, __pyx_v_path);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L4_exception_handled;
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L4_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L10_try_end:;
  }

  /* "fiona/ogrext.pyx":1120
 *     except UnicodeDecodeError:
 *         path_b = path
 *     path_c = path_b             # <<<<<<<<<<<<<<
 *     cogr_ds = ograpi.OGROpen(path_c, 0, NULL)
 *     if cogr_ds is NULL:
 */
  __pyx_t_8 = __Pyx_PyObject_AsString(__pyx_v_path_b); if (unlikely((!__pyx_t_8) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_path_c = __pyx_t_8;

  /* "fiona/ogrext.pyx":1121
 *         path_b = path
 *     path_c = path_b
 *     cogr_ds = ograpi.OGROpen(path_c, 0, NULL)             # <<<<<<<<<<<<<<
 *     if cogr_ds is NULL:
 *         raise ValueError("No data available at path '%s'" % path)
 */
  __pyx_v_cogr_ds = OGROpen(__pyx_v_path_c, 0, NULL);

  /* "fiona/ogrext.pyx":1122
 *     path_c = path_b
 *     cogr_ds = ograpi.OGROpen(path_c, 0, NULL)
 *     if cogr_ds is NULL:             # <<<<<<<<<<<<<<
 *         raise ValueError("No data available at path '%s'" % path)
 * 
 */
  __pyx_t_9 = ((__pyx_v_cogr_ds == NULL) != 0);
  if (__pyx_t_9) {

    /* "fiona/ogrext.pyx":1123
 *     cogr_ds = ograpi.OGROpen(path_c, 0, NULL)
 *     if cogr_ds is NULL:
 *         raise ValueError("No data available at path '%s'" % path)             # <<<<<<<<<<<<<<
 * 
 *     # Loop over the layers to get their names.
 */
    __pyx_t_7 = __Pyx_PyString_Format(__pyx_kp_s_No_data_available_at_path_s, __pyx_v_path); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_7);
    __pyx_t_7 = 0;
    __pyx_t_7 = PyObject_Call(__pyx_builtin_ValueError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_7, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "fiona/ogrext.pyx":1126
 * 
 *     # Loop over the layers to get their names.
 *     layer_count = ograpi.OGR_DS_GetLayerCount(cogr_ds)             # <<<<<<<<<<<<<<
 *     layer_names = []
 *     for i in range(layer_count):
 */
  __pyx_v_layer_count = OGR_DS_GetLayerCount(__pyx_v_cogr_ds);

  /* "fiona/ogrext.pyx":1127
 *     # Loop over the layers to get their names.
 *     layer_count = ograpi.OGR_DS_GetLayerCount(cogr_ds)
 *     layer_names = []             # <<<<<<<<<<<<<<
 *     for i in range(layer_count):
 *         cogr_layer = ograpi.OGR_DS_GetLayer(cogr_ds, i)
 */
  __pyx_t_7 = PyList_New(0); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1127; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_v_layer_names = ((PyObject*)__pyx_t_7);
  __pyx_t_7 = 0;

  /* "fiona/ogrext.pyx":1128
 *     layer_count = ograpi.OGR_DS_GetLayerCount(cogr_ds)
 *     layer_names = []
 *     for i in range(layer_count):             # <<<<<<<<<<<<<<
 *         cogr_layer = ograpi.OGR_DS_GetLayer(cogr_ds, i)
 *         name_c = ograpi.OGR_L_GetName(cogr_layer)
 */
  __pyx_t_6 = __pyx_v_layer_count;
  for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_6; __pyx_t_10+=1) {
    __pyx_v_i = __pyx_t_10;

    /* "fiona/ogrext.pyx":1129
 *     layer_names = []
 *     for i in range(layer_count):
 *         cogr_layer = ograpi.OGR_DS_GetLayer(cogr_ds, i)             # <<<<<<<<<<<<<<
 *         name_c = ograpi.OGR_L_GetName(cogr_layer)
 *         name_b = name_c
 */
    __pyx_v_cogr_layer = OGR_DS_GetLayer(__pyx_v_cogr_ds, __pyx_v_i);

    /* "fiona/ogrext.pyx":1130
 *     for i in range(layer_count):
 *         cogr_layer = ograpi.OGR_DS_GetLayer(cogr_ds, i)
 *         name_c = ograpi.OGR_L_GetName(cogr_layer)             # <<<<<<<<<<<<<<
 *         name_b = name_c
 *         layer_names.append(name_b.decode('utf-8'))
 */
    __pyx_v_name_c = OGR_L_GetName(__pyx_v_cogr_layer);

    /* "fiona/ogrext.pyx":1131
 *         cogr_layer = ograpi.OGR_DS_GetLayer(cogr_ds, i)
 *         name_c = ograpi.OGR_L_GetName(cogr_layer)
 *         name_b = name_c             # <<<<<<<<<<<<<<
 *         layer_names.append(name_b.decode('utf-8'))
 * 
 */
    __pyx_v_name_b = __pyx_v_name_c;

    /* "fiona/ogrext.pyx":1132
 *         name_c = ograpi.OGR_L_GetName(cogr_layer)
 *         name_b = name_c
 *         layer_names.append(name_b.decode('utf-8'))             # <<<<<<<<<<<<<<
 * 
 *     # Close up data source.
 */
    __pyx_t_7 = __Pyx_decode_c_string(__pyx_v_name_b, 0, strlen(__pyx_v_name_b), NULL, NULL, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_layer_names, __pyx_t_7); if (unlikely(__pyx_t_11 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }

  /* "fiona/ogrext.pyx":1135
 * 
 *     # Close up data source.
 *     if cogr_ds is not NULL:             # <<<<<<<<<<<<<<
 *         ograpi.OGR_DS_Destroy(cogr_ds)
 *     cogr_ds = NULL
 */
  __pyx_t_9 = ((__pyx_v_cogr_ds != NULL) != 0);
  if (__pyx_t_9) {

    /* "fiona/ogrext.pyx":1136
 *     # Close up data source.
 *     if cogr_ds is not NULL:
 *         ograpi.OGR_DS_Destroy(cogr_ds)             # <<<<<<<<<<<<<<
 *     cogr_ds = NULL
 * 
 */
    OGR_DS_Destroy(__pyx_v_cogr_ds);
    goto __pyx_L16;
  }
  __pyx_L16:;

  /* "fiona/ogrext.pyx":1137
 *     if cogr_ds is not NULL:
 *         ograpi.OGR_DS_Destroy(cogr_ds)
 *     cogr_ds = NULL             # <<<<<<<<<<<<<<
 * 
 *     return layer_names
 */
  __pyx_v_cogr_ds = NULL;

  /* "fiona/ogrext.pyx":1139
 *     cogr_ds = NULL
 * 
 *     return layer_names             # <<<<<<<<<<<<<<
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_layer_names);
  __pyx_r = __pyx_v_layer_names;
  goto __pyx_L0;

  /* "fiona/ogrext.pyx":1105
 * 
 * 
 * def _listlayers(path):             # <<<<<<<<<<<<<<
 * 
 *     """Provides a list of the layers in an OGR data source.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("fiona.ogrext._listlayers", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_path_b);
  __Pyx_XDECREF(__pyx_v_layer_names);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode *__pyx_freelist_5fiona_6ogrext___pyx_scope_struct___explode[8];
static int __pyx_freecount_5fiona_6ogrext___pyx_scope_struct___explode = 0;

static PyObject *__pyx_tp_new_5fiona_6ogrext___pyx_scope_struct___explode(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (likely((__pyx_freecount_5fiona_6ogrext___pyx_scope_struct___explode > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode)))) {
    o = (PyObject*)__pyx_freelist_5fiona_6ogrext___pyx_scope_struct___explode[--__pyx_freecount_5fiona_6ogrext___pyx_scope_struct___explode];
    memset(o, 0, sizeof(struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_5fiona_6ogrext___pyx_scope_struct___explode(PyObject *o) {
  struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode *p = (struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_coords);
  Py_CLEAR(p->__pyx_v_e);
  Py_CLEAR(p->__pyx_v_f);
  Py_CLEAR(p->__pyx_t_0);
  Py_CLEAR(p->__pyx_t_3);
  if ((__pyx_freecount_5fiona_6ogrext___pyx_scope_struct___explode < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode))) {
    __pyx_freelist_5fiona_6ogrext___pyx_scope_struct___explode[__pyx_freecount_5fiona_6ogrext___pyx_scope_struct___explode++] = ((struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_5fiona_6ogrext___pyx_scope_struct___explode(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode *p = (struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode *)o;
  if (p->__pyx_v_coords) {
    e = (*v)(p->__pyx_v_coords, a); if (e) return e;
  }
  if (p->__pyx_v_e) {
    e = (*v)(p->__pyx_v_e, a); if (e) return e;
  }
  if (p->__pyx_v_f) {
    e = (*v)(p->__pyx_v_f, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  if (p->__pyx_t_3) {
    e = (*v)(p->__pyx_t_3, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_5fiona_6ogrext___pyx_scope_struct___explode(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode *p = (struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode *)o;
  tmp = ((PyObject*)p->__pyx_v_coords);
  p->__pyx_v_coords = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_e);
  p->__pyx_v_e = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_v_f);
  p->__pyx_v_f = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_0);
  p->__pyx_t_0 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->__pyx_t_3);
  p->__pyx_t_3 = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_5fiona_6ogrext___pyx_scope_struct___explode = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("fiona.ogrext.__pyx_scope_struct___explode"), /*tp_name*/
  sizeof(struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct___explode), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5fiona_6ogrext___pyx_scope_struct___explode, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_5fiona_6ogrext___pyx_scope_struct___explode, /*tp_traverse*/
  __pyx_tp_clear_5fiona_6ogrext___pyx_scope_struct___explode, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5fiona_6ogrext___pyx_scope_struct___explode, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *__pyx_freelist_5fiona_6ogrext___pyx_scope_struct_1_writerecs[8];
static int __pyx_freecount_5fiona_6ogrext___pyx_scope_struct_1_writerecs = 0;

static PyObject *__pyx_tp_new_5fiona_6ogrext___pyx_scope_struct_1_writerecs(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (likely((__pyx_freecount_5fiona_6ogrext___pyx_scope_struct_1_writerecs > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs)))) {
    o = (PyObject*)__pyx_freelist_5fiona_6ogrext___pyx_scope_struct_1_writerecs[--__pyx_freecount_5fiona_6ogrext___pyx_scope_struct_1_writerecs];
    memset(o, 0, sizeof(struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_5fiona_6ogrext___pyx_scope_struct_1_writerecs(PyObject *o) {
  struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *p = (struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_schema_geom_type);
  if ((__pyx_freecount_5fiona_6ogrext___pyx_scope_struct_1_writerecs < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs))) {
    __pyx_freelist_5fiona_6ogrext___pyx_scope_struct_1_writerecs[__pyx_freecount_5fiona_6ogrext___pyx_scope_struct_1_writerecs++] = ((struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_5fiona_6ogrext___pyx_scope_struct_1_writerecs(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *p = (struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *)o;
  if (p->__pyx_v_schema_geom_type) {
    e = (*v)(p->__pyx_v_schema_geom_type, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_5fiona_6ogrext___pyx_scope_struct_1_writerecs(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *p = (struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs *)o;
  tmp = ((PyObject*)p->__pyx_v_schema_geom_type);
  p->__pyx_v_schema_geom_type = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_5fiona_6ogrext___pyx_scope_struct_1_writerecs = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("fiona.ogrext.__pyx_scope_struct_1_writerecs"), /*tp_name*/
  sizeof(struct __pyx_obj_5fiona_6ogrext___pyx_scope_struct_1_writerecs), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5fiona_6ogrext___pyx_scope_struct_1_writerecs, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_5fiona_6ogrext___pyx_scope_struct_1_writerecs, /*tp_traverse*/
  __pyx_tp_clear_5fiona_6ogrext___pyx_scope_struct_1_writerecs, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5fiona_6ogrext___pyx_scope_struct_1_writerecs, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_5fiona_6ogrext_FeatureBuilder __pyx_vtable_5fiona_6ogrext_FeatureBuilder;

static PyObject *__pyx_tp_new_5fiona_6ogrext_FeatureBuilder(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_5fiona_6ogrext_FeatureBuilder *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_5fiona_6ogrext_FeatureBuilder *)o);
  p->__pyx_vtab = __pyx_vtabptr_5fiona_6ogrext_FeatureBuilder;
  return o;
}

static void __pyx_tp_dealloc_5fiona_6ogrext_FeatureBuilder(PyObject *o) {
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  (*Py_TYPE(o)->tp_free)(o);
}

static PyTypeObject __pyx_type_5fiona_6ogrext_FeatureBuilder = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("fiona.ogrext.FeatureBuilder"), /*tp_name*/
  sizeof(struct __pyx_obj_5fiona_6ogrext_FeatureBuilder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5fiona_6ogrext_FeatureBuilder, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  __Pyx_DOCSTR("Build Fiona features from OGR feature pointers.\n\n    No OGR objects are allocated by this function and the feature\n    argument is not destroyed.\n    "), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5fiona_6ogrext_FeatureBuilder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_5fiona_6ogrext_OGRFeatureBuilder __pyx_vtable_5fiona_6ogrext_OGRFeatureBuilder;

static PyObject *__pyx_tp_new_5fiona_6ogrext_OGRFeatureBuilder(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_5fiona_6ogrext_OGRFeatureBuilder *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_5fiona_6ogrext_OGRFeatureBuilder *)o);
  p->__pyx_vtab = __pyx_vtabptr_5fiona_6ogrext_OGRFeatureBuilder;
  return o;
}

static void __pyx_tp_dealloc_5fiona_6ogrext_OGRFeatureBuilder(PyObject *o) {
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  (*Py_TYPE(o)->tp_free)(o);
}

static PyTypeObject __pyx_type_5fiona_6ogrext_OGRFeatureBuilder = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("fiona.ogrext.OGRFeatureBuilder"), /*tp_name*/
  sizeof(struct __pyx_obj_5fiona_6ogrext_OGRFeatureBuilder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5fiona_6ogrext_OGRFeatureBuilder, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  __Pyx_DOCSTR("Builds an OGR Feature from a Fiona feature mapping.\n\n    Allocates one OGR Feature which should be destroyed by the caller.\n    Borrows a layer definition from the collection.\n    "), /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5fiona_6ogrext_OGRFeatureBuilder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_5fiona_6ogrext_Session(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_5fiona_6ogrext_Session *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_5fiona_6ogrext_Session *)o);
  p->_fileencoding = Py_None; Py_INCREF(Py_None);
  p->_encoding = Py_None; Py_INCREF(Py_None);
  p->collection = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_5fiona_6ogrext_7Session_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) {
    Py_DECREF(o); o = 0;
  }
  return o;
}

static void __pyx_tp_dealloc_5fiona_6ogrext_Session(PyObject *o) {
  struct __pyx_obj_5fiona_6ogrext_Session *p = (struct __pyx_obj_5fiona_6ogrext_Session *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_5fiona_6ogrext_7Session_3__dealloc__(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->_fileencoding);
  Py_CLEAR(p->_encoding);
  Py_CLEAR(p->collection);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_5fiona_6ogrext_Session(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_5fiona_6ogrext_Session *p = (struct __pyx_obj_5fiona_6ogrext_Session *)o;
  if (p->_fileencoding) {
    e = (*v)(p->_fileencoding, a); if (e) return e;
  }
  if (p->_encoding) {
    e = (*v)(p->_encoding, a); if (e) return e;
  }
  if (p->collection) {
    e = (*v)(p->collection, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_5fiona_6ogrext_Session(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_5fiona_6ogrext_Session *p = (struct __pyx_obj_5fiona_6ogrext_Session *)o;
  tmp = ((PyObject*)p->_fileencoding);
  p->_fileencoding = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_encoding);
  p->_encoding = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->collection);
  p->collection = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_5fiona_6ogrext_Session[] = {
  {__Pyx_NAMESTR("start"), (PyCFunction)__pyx_pw_5fiona_6ogrext_7Session_5start, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("stop"), (PyCFunction)__pyx_pw_5fiona_6ogrext_7Session_7stop, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("get_fileencoding"), (PyCFunction)__pyx_pw_5fiona_6ogrext_7Session_9get_fileencoding, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("get_internalencoding"), (PyCFunction)__pyx_pw_5fiona_6ogrext_7Session_11get_internalencoding, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("get_length"), (PyCFunction)__pyx_pw_5fiona_6ogrext_7Session_13get_length, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("get_driver"), (PyCFunction)__pyx_pw_5fiona_6ogrext_7Session_15get_driver, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("get_schema"), (PyCFunction)__pyx_pw_5fiona_6ogrext_7Session_17get_schema, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("get_crs"), (PyCFunction)__pyx_pw_5fiona_6ogrext_7Session_19get_crs, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("get_extent"), (PyCFunction)__pyx_pw_5fiona_6ogrext_7Session_21get_extent, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("isactive"), (PyCFunction)__pyx_pw_5fiona_6ogrext_7Session_23isactive, METH_NOARGS, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_5fiona_6ogrext_Session = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("fiona.ogrext.Session"), /*tp_name*/
  sizeof(struct __pyx_obj_5fiona_6ogrext_Session), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5fiona_6ogrext_Session, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_5fiona_6ogrext_Session, /*tp_traverse*/
  __pyx_tp_clear_5fiona_6ogrext_Session, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_5fiona_6ogrext_Session, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5fiona_6ogrext_Session, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_5fiona_6ogrext_GeomBuilder __pyx_vtable_5fiona_6ogrext_GeomBuilder;

static PyObject *__pyx_tp_new_5fiona_6ogrext_GeomBuilder(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_5fiona_6ogrext_GeomBuilder *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)o);
  p->__pyx_vtab = __pyx_vtabptr_5fiona_6ogrext_GeomBuilder;
  p->code = Py_None; Py_INCREF(Py_None);
  p->typename = Py_None; Py_INCREF(Py_None);
  p->ndims = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_5fiona_6ogrext_GeomBuilder(PyObject *o) {
  struct __pyx_obj_5fiona_6ogrext_GeomBuilder *p = (struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->code);
  Py_CLEAR(p->typename);
  Py_CLEAR(p->ndims);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_5fiona_6ogrext_GeomBuilder(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_5fiona_6ogrext_GeomBuilder *p = (struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)o;
  if (p->code) {
    e = (*v)(p->code, a); if (e) return e;
  }
  if (p->typename) {
    e = (*v)(p->typename, a); if (e) return e;
  }
  if (p->ndims) {
    e = (*v)(p->ndims, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_5fiona_6ogrext_GeomBuilder(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_5fiona_6ogrext_GeomBuilder *p = (struct __pyx_obj_5fiona_6ogrext_GeomBuilder *)o;
  tmp = ((PyObject*)p->code);
  p->code = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->typename);
  p->typename = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->ndims);
  p->ndims = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_5fiona_6ogrext_GeomBuilder[] = {
  {__Pyx_NAMESTR("_buildPoint"), (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_1_buildPoint, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("_buildLineString"), (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_3_buildLineString, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("_buildLinearRing"), (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_5_buildLinearRing, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("_buildPolygon"), (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_7_buildPolygon, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("_buildMultiPoint"), (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_9_buildMultiPoint, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("_buildMultiLineString"), (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_11_buildMultiLineString, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("_buildMultiPolygon"), (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_13_buildMultiPolygon, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("_buildGeometryCollection"), (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_15_buildGeometryCollection, METH_NOARGS, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("build_wkb"), (PyCFunction)__pyx_pw_5fiona_6ogrext_11GeomBuilder_17build_wkb, METH_O, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_5fiona_6ogrext_GeomBuilder = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("fiona.ogrext.GeomBuilder"), /*tp_name*/
  sizeof(struct __pyx_obj_5fiona_6ogrext_GeomBuilder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5fiona_6ogrext_GeomBuilder, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("Builds Fiona (GeoJSON) geometries from an OGR geometry handle.\n    "), /*tp_doc*/
  __pyx_tp_traverse_5fiona_6ogrext_GeomBuilder, /*tp_traverse*/
  __pyx_tp_clear_5fiona_6ogrext_GeomBuilder, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_5fiona_6ogrext_GeomBuilder, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5fiona_6ogrext_GeomBuilder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_5fiona_6ogrext_OGRGeomBuilder __pyx_vtable_5fiona_6ogrext_OGRGeomBuilder;

static PyObject *__pyx_tp_new_5fiona_6ogrext_OGRGeomBuilder(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)o);
  p->__pyx_vtab = __pyx_vtabptr_5fiona_6ogrext_OGRGeomBuilder;
  p->coordinates = Py_None; Py_INCREF(Py_None);
  p->typename = Py_None; Py_INCREF(Py_None);
  p->ndims = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_5fiona_6ogrext_OGRGeomBuilder(PyObject *o) {
  struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *p = (struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->coordinates);
  Py_CLEAR(p->typename);
  Py_CLEAR(p->ndims);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_5fiona_6ogrext_OGRGeomBuilder(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *p = (struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)o;
  if (p->coordinates) {
    e = (*v)(p->coordinates, a); if (e) return e;
  }
  if (p->typename) {
    e = (*v)(p->typename, a); if (e) return e;
  }
  if (p->ndims) {
    e = (*v)(p->ndims, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_5fiona_6ogrext_OGRGeomBuilder(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *p = (struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *)o;
  tmp = ((PyObject*)p->coordinates);
  p->coordinates = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->typename);
  p->typename = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->ndims);
  p->ndims = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyTypeObject __pyx_type_5fiona_6ogrext_OGRGeomBuilder = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("fiona.ogrext.OGRGeomBuilder"), /*tp_name*/
  sizeof(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5fiona_6ogrext_OGRGeomBuilder, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("Builds OGR geometries from Fiona geometries.\n    "), /*tp_doc*/
  __pyx_tp_traverse_5fiona_6ogrext_OGRGeomBuilder, /*tp_traverse*/
  __pyx_tp_clear_5fiona_6ogrext_OGRGeomBuilder, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5fiona_6ogrext_OGRGeomBuilder, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_5fiona_6ogrext_Iterator(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_5fiona_6ogrext_Iterator *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_5fiona_6ogrext_Iterator *)o);
  p->collection = Py_None; Py_INCREF(Py_None);
  p->encoding = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_5fiona_6ogrext_Iterator(PyObject *o) {
  struct __pyx_obj_5fiona_6ogrext_Iterator *p = (struct __pyx_obj_5fiona_6ogrext_Iterator *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->collection);
  Py_CLEAR(p->encoding);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_5fiona_6ogrext_Iterator(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_5fiona_6ogrext_Iterator *p = (struct __pyx_obj_5fiona_6ogrext_Iterator *)o;
  if (p->collection) {
    e = (*v)(p->collection, a); if (e) return e;
  }
  if (p->encoding) {
    e = (*v)(p->encoding, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_5fiona_6ogrext_Iterator(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_5fiona_6ogrext_Iterator *p = (struct __pyx_obj_5fiona_6ogrext_Iterator *)o;
  tmp = ((PyObject*)p->collection);
  p->collection = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->encoding);
  p->encoding = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_5fiona_6ogrext_Iterator[] = {
  {__Pyx_NAMESTR("__next__"), (PyCFunction)__pyx_pw_5fiona_6ogrext_8Iterator_5__next__, METH_NOARGS|METH_COEXIST, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_5fiona_6ogrext_Iterator = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("fiona.ogrext.Iterator"), /*tp_name*/
  sizeof(struct __pyx_obj_5fiona_6ogrext_Iterator), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5fiona_6ogrext_Iterator, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("Provides iterated access to feature data.\n    "), /*tp_doc*/
  __pyx_tp_traverse_5fiona_6ogrext_Iterator, /*tp_traverse*/
  __pyx_tp_clear_5fiona_6ogrext_Iterator, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_5fiona_6ogrext_8Iterator_3__iter__, /*tp_iter*/
  __pyx_pw_5fiona_6ogrext_8Iterator_5__next__, /*tp_iternext*/
  __pyx_methods_5fiona_6ogrext_Iterator, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_5fiona_6ogrext_8Iterator_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5fiona_6ogrext_Iterator, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_5fiona_6ogrext_WritingSession(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_5fiona_6ogrext_WritingSession *p;
  PyObject *o = __pyx_tp_new_5fiona_6ogrext_Session(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_5fiona_6ogrext_WritingSession *)o);
  p->_schema_mapping = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_5fiona_6ogrext_WritingSession(PyObject *o) {
  struct __pyx_obj_5fiona_6ogrext_WritingSession *p = (struct __pyx_obj_5fiona_6ogrext_WritingSession *)o;
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_schema_mapping);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_5fiona_6ogrext_Session(o);
}

static int __pyx_tp_traverse_5fiona_6ogrext_WritingSession(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_5fiona_6ogrext_WritingSession *p = (struct __pyx_obj_5fiona_6ogrext_WritingSession *)o;
  e = __pyx_tp_traverse_5fiona_6ogrext_Session(o, v, a); if (e) return e;
  if (p->_schema_mapping) {
    e = (*v)(p->_schema_mapping, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_5fiona_6ogrext_WritingSession(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_5fiona_6ogrext_WritingSession *p = (struct __pyx_obj_5fiona_6ogrext_WritingSession *)o;
  __pyx_tp_clear_5fiona_6ogrext_Session(o);
  tmp = ((PyObject*)p->_schema_mapping);
  p->_schema_mapping = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_5fiona_6ogrext_WritingSession[] = {
  {__Pyx_NAMESTR("start"), (PyCFunction)__pyx_pw_5fiona_6ogrext_14WritingSession_1start, METH_O, __Pyx_DOCSTR(0)},
  {__Pyx_NAMESTR("writerecs"), (PyCFunction)__pyx_pw_5fiona_6ogrext_14WritingSession_3writerecs, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_5fiona_6ogrext_14WritingSession_2writerecs)},
  {__Pyx_NAMESTR("sync"), (PyCFunction)__pyx_pw_5fiona_6ogrext_14WritingSession_5sync, METH_O, __Pyx_DOCSTR(__pyx_doc_5fiona_6ogrext_14WritingSession_4sync)},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_5fiona_6ogrext_WritingSession = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("fiona.ogrext.WritingSession"), /*tp_name*/
  sizeof(struct __pyx_obj_5fiona_6ogrext_WritingSession), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5fiona_6ogrext_WritingSession, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_5fiona_6ogrext_WritingSession, /*tp_traverse*/
  __pyx_tp_clear_5fiona_6ogrext_WritingSession, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_5fiona_6ogrext_WritingSession, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5fiona_6ogrext_WritingSession, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
  #if PY_VERSION_HEX < 0x03020000
    { PyObject_HEAD_INIT(NULL) NULL, 0, NULL },
  #else
    PyModuleDef_HEAD_INIT,
  #endif
    __Pyx_NAMESTR("ogrext"),
    0, /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_s_3D, __pyx_k_3D, sizeof(__pyx_k_3D), 0, 0, 1, 0},
  {&__pyx_kp_s_3D_GeometryCollection, __pyx_k_3D_GeometryCollection, sizeof(__pyx_k_3D_GeometryCollection), 0, 0, 1, 0},
  {&__pyx_kp_s_3D_LineString, __pyx_k_3D_LineString, sizeof(__pyx_k_3D_LineString), 0, 0, 1, 0},
  {&__pyx_kp_s_3D_MultiLineString, __pyx_k_3D_MultiLineString, sizeof(__pyx_k_3D_MultiLineString), 0, 0, 1, 0},
  {&__pyx_kp_s_3D_MultiPoint, __pyx_k_3D_MultiPoint, sizeof(__pyx_k_3D_MultiPoint), 0, 0, 1, 0},
  {&__pyx_kp_s_3D_MultiPolygon, __pyx_k_3D_MultiPolygon, sizeof(__pyx_k_3D_MultiPolygon), 0, 0, 1, 0},
  {&__pyx_kp_s_3D_Point, __pyx_k_3D_Point, sizeof(__pyx_k_3D_Point), 0, 0, 1, 0},
  {&__pyx_kp_s_3D_Polygon, __pyx_k_3D_Polygon, sizeof(__pyx_k_3D_Polygon), 0, 0, 1, 0},
  {&__pyx_kp_s_Added_line_s, __pyx_k_Added_line_s, sizeof(__pyx_k_Added_line_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Added_part_s, __pyx_k_Added_part_s, sizeof(__pyx_k_Added_part_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Added_point_s, __pyx_k_Added_point_s, sizeof(__pyx_k_Added_point_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Added_polygon_s, __pyx_k_Added_polygon_s, sizeof(__pyx_k_Added_polygon_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Added_ring_s, __pyx_k_Added_ring_s, sizeof(__pyx_k_Added_ring_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Adding_line_s, __pyx_k_Adding_line_s, sizeof(__pyx_k_Adding_line_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Adding_part_s, __pyx_k_Adding_part_s, sizeof(__pyx_k_Adding_part_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Adding_point_s, __pyx_k_Adding_point_s, sizeof(__pyx_k_Adding_point_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Adding_polygon_s, __pyx_k_Adding_polygon_s, sizeof(__pyx_k_Adding_polygon_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Adding_ring_s, __pyx_k_Adding_ring_s, sizeof(__pyx_k_Adding_ring_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Adding_values_f_f, __pyx_k_Adding_values_f_f, sizeof(__pyx_k_Adding_values_f_f), 0, 0, 1, 0},
  {&__pyx_kp_s_Built_line, __pyx_k_Built_line, sizeof(__pyx_k_Built_line), 0, 0, 1, 0},
  {&__pyx_kp_s_Built_part, __pyx_k_Built_part, sizeof(__pyx_k_Built_part), 0, 0, 1, 0},
  {&__pyx_kp_s_Built_polygon, __pyx_k_Built_polygon, sizeof(__pyx_k_Built_polygon), 0, 0, 1, 0},
  {&__pyx_kp_s_Built_ring, __pyx_k_Built_ring, sizeof(__pyx_k_Built_ring), 0, 0, 1, 0},
  {&__pyx_n_s_CRSError, __pyx_k_CRSError, sizeof(__pyx_k_CRSError), 0, 0, 1, 1},
  {&__pyx_kp_s_Closing_ring, __pyx_k_Closing_ring, sizeof(__pyx_k_Closing_ring), 0, 0, 1, 0},
  {&__pyx_kp_s_Created_fields, __pyx_k_Created_fields, sizeof(__pyx_k_Created_fields), 0, 0, 1, 0},
  {&__pyx_kp_s_Created_layer, __pyx_k_Created_layer, sizeof(__pyx_k_Created_layer), 0, 0, 1, 0},
  {&__pyx_kp_s_Creating_feature_in_layer_s, __pyx_k_Creating_feature_in_layer_s, sizeof(__pyx_k_Creating_feature_in_layer_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Creating_field_s_s, __pyx_k_Creating_field_s_s, sizeof(__pyx_k_Creating_field_s_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Deleted_pre_existing_data_at_s, __pyx_k_Deleted_pre_existing_data_at_s, sizeof(__pyx_k_Deleted_pre_existing_data_at_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Deleted_pre_existing_layer_at_s, __pyx_k_Deleted_pre_existing_layer_at_s, sizeof(__pyx_k_Deleted_pre_existing_layer_at_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Determines_the_number_of_dimensi, __pyx_k_Determines_the_number_of_dimensi, sizeof(__pyx_k_Determines_the_number_of_dimensi), 0, 0, 1, 0},
  {&__pyx_n_s_DimensionsHandler, __pyx_k_DimensionsHandler, sizeof(__pyx_k_DimensionsHandler), 0, 0, 1, 1},
  {&__pyx_n_s_DimensionsHandler_getNumDims, __pyx_k_DimensionsHandler_getNumDims, sizeof(__pyx_k_DimensionsHandler_getNumDims), 0, 0, 1, 1},
  {&__pyx_n_s_DimensionsHandler_getNumDimsGeom, __pyx_k_DimensionsHandler_getNumDimsGeom, sizeof(__pyx_k_DimensionsHandler_getNumDimsGeom), 0, 0, 1, 1},
  {&__pyx_n_s_DimensionsHandler_getNumDimsLine, __pyx_k_DimensionsHandler_getNumDimsLine, sizeof(__pyx_k_DimensionsHandler_getNumDimsLine), 0, 0, 1, 1},
  {&__pyx_n_s_DimensionsHandler_getNumDimsLine_2, __pyx_k_DimensionsHandler_getNumDimsLine_2, sizeof(__pyx_k_DimensionsHandler_getNumDimsLine_2), 0, 0, 1, 1},
  {&__pyx_n_s_DimensionsHandler_getNumDimsMult, __pyx_k_DimensionsHandler_getNumDimsMult, sizeof(__pyx_k_DimensionsHandler_getNumDimsMult), 0, 0, 1, 1},
  {&__pyx_n_s_DimensionsHandler_getNumDimsMult_2, __pyx_k_DimensionsHandler_getNumDimsMult_2, sizeof(__pyx_k_DimensionsHandler_getNumDimsMult_2), 0, 0, 1, 1},
  {&__pyx_n_s_DimensionsHandler_getNumDimsMult_3, __pyx_k_DimensionsHandler_getNumDimsMult_3, sizeof(__pyx_k_DimensionsHandler_getNumDimsMult_3), 0, 0, 1, 1},
  {&__pyx_n_s_DimensionsHandler_getNumDimsPoin, __pyx_k_DimensionsHandler_getNumDimsPoin, sizeof(__pyx_k_DimensionsHandler_getNumDimsPoin), 0, 0, 1, 1},
  {&__pyx_n_s_DimensionsHandler_getNumDimsPoly, __pyx_k_DimensionsHandler_getNumDimsPoly, sizeof(__pyx_k_DimensionsHandler_getNumDimsPoly), 0, 0, 1, 1},
  {&__pyx_n_s_DriverError, __pyx_k_DriverError, sizeof(__pyx_k_DriverError), 0, 0, 1, 1},
  {&__pyx_kp_b_ESRI_Shapefile, __pyx_k_ESRI_Shapefile, sizeof(__pyx_k_ESRI_Shapefile), 0, 0, 0, 0},
  {&__pyx_kp_s_ESRI_Shapefile, __pyx_k_ESRI_Shapefile, sizeof(__pyx_k_ESRI_Shapefile), 0, 0, 1, 0},
  {&__pyx_n_s_FIELD_TYPES, __pyx_k_FIELD_TYPES, sizeof(__pyx_k_FIELD_TYPES), 0, 0, 1, 1},
  {&__pyx_n_s_FIELD_TYPES_MAP, __pyx_k_FIELD_TYPES_MAP, sizeof(__pyx_k_FIELD_TYPES_MAP), 0, 0, 1, 1},
  {&__pyx_kp_s_Failed_to_decode_s_using_s_codec, __pyx_k_Failed_to_decode_s_using_s_codec, sizeof(__pyx_k_Failed_to_decode_s_using_s_codec), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_encode_s_using_s_codec, __pyx_k_Failed_to_encode_s_using_s_codec, sizeof(__pyx_k_Failed_to_encode_s_using_s_codec), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_get_layer_s, __pyx_k_Failed_to_get_layer_s, sizeof(__pyx_k_Failed_to_get_layer_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_open_s, __pyx_k_Failed_to_open_s, sizeof(__pyx_k_Failed_to_open_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_sync_to_disk, __pyx_k_Failed_to_sync_to_disk, sizeof(__pyx_k_Failed_to_sync_to_disk), 0, 0, 1, 0},
  {&__pyx_kp_s_Failed_to_write_record_s, __pyx_k_Failed_to_write_record_s, sizeof(__pyx_k_Failed_to_write_record_s), 0, 0, 1, 0},
  {&__pyx_n_s_Feature, __pyx_k_Feature, sizeof(__pyx_k_Feature), 0, 0, 1, 1},
  {&__pyx_n_s_Fiona, __pyx_k_Fiona, sizeof(__pyx_k_Fiona), 0, 0, 1, 1},
  {&__pyx_n_s_FionaDateTimeType, __pyx_k_FionaDateTimeType, sizeof(__pyx_k_FionaDateTimeType), 0, 0, 1, 1},
  {&__pyx_n_s_FionaDateType, __pyx_k_FionaDateType, sizeof(__pyx_k_FionaDateType), 0, 0, 1, 1},
  {&__pyx_n_s_FionaTimeType, __pyx_k_FionaTimeType, sizeof(__pyx_k_FionaTimeType), 0, 0, 1, 1},
  {&__pyx_n_s_GEOMETRY_TYPES, __pyx_k_GEOMETRY_TYPES, sizeof(__pyx_k_GEOMETRY_TYPES), 0, 0, 1, 1},
  {&__pyx_n_b_GeoJSON, __pyx_k_GeoJSON, sizeof(__pyx_k_GeoJSON), 0, 0, 0, 1},
  {&__pyx_n_s_GeometryCollection, __pyx_k_GeometryCollection, sizeof(__pyx_k_GeometryCollection), 0, 0, 1, 1},
  {&__pyx_kp_s_Geometry_s, __pyx_k_Geometry_s, sizeof(__pyx_k_Geometry_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Got_coordinate_system, __pyx_k_Got_coordinate_system, sizeof(__pyx_k_Got_coordinate_system), 0, 0, 1, 0},
  {&__pyx_n_s_Handler, __pyx_k_Handler, sizeof(__pyx_k_Handler), 0, 0, 1, 1},
  {&__pyx_kp_s_ISO_8859_1, __pyx_k_ISO_8859_1, sizeof(__pyx_k_ISO_8859_1), 0, 0, 1, 0},
  {&__pyx_kp_s_I_O_operation_on_closed_collecti, __pyx_k_I_O_operation_on_closed_collecti, sizeof(__pyx_k_I_O_operation_on_closed_collecti), 0, 0, 1, 0},
  {&__pyx_kp_s_Invalid_field_name_ref_s, __pyx_k_Invalid_field_name_ref_s, sizeof(__pyx_k_Invalid_field_name_ref_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Invalid_field_type_s, __pyx_k_Invalid_field_type_s, sizeof(__pyx_k_Invalid_field_type_s), 0, 0, 1, 0},
  {&__pyx_n_s_KeyError, __pyx_k_KeyError, sizeof(__pyx_k_KeyError), 0, 0, 1, 1},
  {&__pyx_n_s_LineString, __pyx_k_LineString, sizeof(__pyx_k_LineString), 0, 0, 1, 1},
  {&__pyx_n_s_LinearRing, __pyx_k_LinearRing, sizeof(__pyx_k_LinearRing), 0, 0, 1, 1},
  {&__pyx_kp_s_Looking_up_s_in_s, __pyx_k_Looking_up_s_in_s, sizeof(__pyx_k_Looking_up_s_in_s), 0, 0, 1, 0},
  {&__pyx_n_s_Multi, __pyx_k_Multi, sizeof(__pyx_k_Multi), 0, 0, 1, 1},
  {&__pyx_n_s_MultiLineString, __pyx_k_MultiLineString, sizeof(__pyx_k_MultiLineString), 0, 0, 1, 1},
  {&__pyx_n_s_MultiPoint, __pyx_k_MultiPoint, sizeof(__pyx_k_MultiPoint), 0, 0, 1, 1},
  {&__pyx_n_s_MultiPolygon, __pyx_k_MultiPolygon, sizeof(__pyx_k_MultiPolygon), 0, 0, 1, 1},
  {&__pyx_kp_s_No_data_available_at_path_s, __pyx_k_No_data_available_at_path_s, sizeof(__pyx_k_No_data_available_at_path_s), 0, 0, 1, 0},
  {&__pyx_kp_s_No_such_file_or_directory_s, __pyx_k_No_such_file_or_directory_s, sizeof(__pyx_k_No_such_file_or_directory_s), 0, 0, 1, 0},
  {&__pyx_n_s_None, __pyx_k_None, sizeof(__pyx_k_None), 0, 0, 1, 1},
  {&__pyx_n_s_NullHandler, __pyx_k_NullHandler, sizeof(__pyx_k_NullHandler), 0, 0, 1, 1},
  {&__pyx_n_s_NullHandler_emit, __pyx_k_NullHandler_emit, sizeof(__pyx_k_NullHandler_emit), 0, 0, 1, 1},
  {&__pyx_kp_s_Null_data_source, __pyx_k_Null_data_source, sizeof(__pyx_k_Null_data_source), 0, 0, 1, 0},
  {&__pyx_kp_s_Null_driver, __pyx_k_Null_driver, sizeof(__pyx_k_Null_driver), 0, 0, 1, 0},
  {&__pyx_kp_s_Null_feature, __pyx_k_Null_feature, sizeof(__pyx_k_Null_feature), 0, 0, 1, 0},
  {&__pyx_kp_s_Null_feature_definition, __pyx_k_Null_feature_definition, sizeof(__pyx_k_Null_feature_definition), 0, 0, 1, 0},
  {&__pyx_kp_s_Null_field_definition, __pyx_k_Null_field_definition, sizeof(__pyx_k_Null_field_definition), 0, 0, 1, 0},
  {&__pyx_kp_s_Null_field_name_reference, __pyx_k_Null_field_name_reference, sizeof(__pyx_k_Null_field_name_reference), 0, 0, 1, 0},
  {&__pyx_kp_s_Null_geom, __pyx_k_Null_geom, sizeof(__pyx_k_Null_geom), 0, 0, 1, 0},
  {&__pyx_kp_s_Null_geometry, __pyx_k_Null_geometry, sizeof(__pyx_k_Null_geometry), 0, 0, 1, 0},
  {&__pyx_kp_s_Null_layer, __pyx_k_Null_layer, sizeof(__pyx_k_Null_layer), 0, 0, 1, 0},
  {&__pyx_kp_s_Null_layer_2, __pyx_k_Null_layer_2, sizeof(__pyx_k_Null_layer_2), 0, 0, 1, 0},
  {&__pyx_kp_s_Null_projection, __pyx_k_Null_projection, sizeof(__pyx_k_Null_projection), 0, 0, 1, 0},
  {&__pyx_kp_s_Null_spatial_reference, __pyx_k_Null_spatial_reference, sizeof(__pyx_k_Null_spatial_reference), 0, 0, 1, 0},
  {&__pyx_n_s_OGRERR_CORRUPT_DATA, __pyx_k_OGRERR_CORRUPT_DATA, sizeof(__pyx_k_OGRERR_CORRUPT_DATA), 0, 0, 1, 1},
  {&__pyx_n_s_OGRERR_FAILURE, __pyx_k_OGRERR_FAILURE, sizeof(__pyx_k_OGRERR_FAILURE), 0, 0, 1, 1},
  {&__pyx_n_s_OGRERR_INVALID_HANDLE, __pyx_k_OGRERR_INVALID_HANDLE, sizeof(__pyx_k_OGRERR_INVALID_HANDLE), 0, 0, 1, 1},
  {&__pyx_n_s_OGRERR_NONE, __pyx_k_OGRERR_NONE, sizeof(__pyx_k_OGRERR_NONE), 0, 0, 1, 1},
  {&__pyx_n_s_OGRERR_NOT_ENOUGH_DATA, __pyx_k_OGRERR_NOT_ENOUGH_DATA, sizeof(__pyx_k_OGRERR_NOT_ENOUGH_DATA), 0, 0, 1, 1},
  {&__pyx_n_s_OGRERR_NOT_ENOUGH_MEMORY, __pyx_k_OGRERR_NOT_ENOUGH_MEMORY, sizeof(__pyx_k_OGRERR_NOT_ENOUGH_MEMORY), 0, 0, 1, 1},
  {&__pyx_n_s_OGRERR_UNSUPPORTED_GEOMETRY_TYPE, __pyx_k_OGRERR_UNSUPPORTED_GEOMETRY_TYPE, sizeof(__pyx_k_OGRERR_UNSUPPORTED_GEOMETRY_TYPE), 0, 0, 1, 1},
  {&__pyx_n_s_OGRERR_UNSUPPORTED_OPERATION, __pyx_k_OGRERR_UNSUPPORTED_OPERATION, sizeof(__pyx_k_OGRERR_UNSUPPORTED_OPERATION), 0, 0, 1, 1},
  {&__pyx_n_s_OGRERR_UNSUPPORTED_SRS, __pyx_k_OGRERR_UNSUPPORTED_SRS, sizeof(__pyx_k_OGRERR_UNSUPPORTED_SRS), 0, 0, 1, 1},
  {&__pyx_n_s_OGR_DETECTED_ENCODING, __pyx_k_OGR_DETECTED_ENCODING, sizeof(__pyx_k_OGR_DETECTED_ENCODING), 0, 0, 1, 1},
  {&__pyx_n_s_OSError, __pyx_k_OSError, sizeof(__pyx_k_OSError), 0, 0, 1, 1},
  {&__pyx_n_s_OrderedDict, __pyx_k_OrderedDict, sizeof(__pyx_k_OrderedDict), 0, 0, 1, 1},
  {&__pyx_kp_s_Params_s, __pyx_k_Params_s, sizeof(__pyx_k_Params_s), 0, 0, 1, 0},
  {&__pyx_n_s_Point, __pyx_k_Point, sizeof(__pyx_k_Point), 0, 0, 1, 1},
  {&__pyx_n_s_Polygon, __pyx_k_Polygon, sizeof(__pyx_k_Polygon), 0, 0, 1, 1},
  {&__pyx_kp_s_Projection_not_found_cogr_crs_wa, __pyx_k_Projection_not_found_cogr_crs_wa, sizeof(__pyx_k_Projection_not_found_cogr_crs_wa), 0, 0, 1, 0},
  {&__pyx_kp_s_Record_does_not_match_collection, __pyx_k_Record_does_not_match_collection, sizeof(__pyx_k_Record_does_not_match_collection), 0, 0, 1, 0},
  {&__pyx_kp_s_Record_s_geometry_type_does_not, __pyx_k_Record_s_geometry_type_does_not, sizeof(__pyx_k_Record_s_geometry_type_does_not), 0, 0, 1, 0},
  {&__pyx_n_s_RuntimeError, __pyx_k_RuntimeError, sizeof(__pyx_k_RuntimeError), 0, 0, 1, 1},
  {&__pyx_n_s_SchemaError, __pyx_k_SchemaError, sizeof(__pyx_k_SchemaError), 0, 0, 1, 1},
  {&__pyx_kp_s_Set_field_s_s, __pyx_k_Set_field_s_s, sizeof(__pyx_k_Set_field_s_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Skipping_field_s_invalid_type_s, __pyx_k_Skipping_field_s_invalid_type_s, sizeof(__pyx_k_Skipping_field_s_invalid_type_s), 0, 0, 1, 0},
  {&__pyx_n_s_StopIteration, __pyx_k_StopIteration, sizeof(__pyx_k_StopIteration), 0, 0, 1, 1},
  {&__pyx_kp_s_Syncing_OGR_to_disk, __pyx_k_Syncing_OGR_to_disk, sizeof(__pyx_k_Syncing_OGR_to_disk), 0, 0, 1, 0},
  {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
  {&__pyx_kp_s_Unexpected_proj_parameter_s, __pyx_k_Unexpected_proj_parameter_s, sizeof(__pyx_k_Unexpected_proj_parameter_s), 0, 0, 1, 0},
  {&__pyx_n_s_UnicodeDecodeError, __pyx_k_UnicodeDecodeError, sizeof(__pyx_k_UnicodeDecodeError), 0, 0, 1, 1},
  {&__pyx_n_s_Unknown, __pyx_k_Unknown, sizeof(__pyx_k_Unknown), 0, 0, 1, 1},
  {&__pyx_kp_s_Unsupported_geometry_type_s, __pyx_k_Unsupported_geometry_type_s, sizeof(__pyx_k_Unsupported_geometry_type_s), 0, 0, 1, 0},
  {&__pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_k_Users_seang_code_Fiona_src_fion, sizeof(__pyx_k_Users_seang_code_Fiona_src_fion), 0, 0, 1, 0},
  {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {&__pyx_kp_s_Writing_started, __pyx_k_Writing_started, sizeof(__pyx_k_Writing_started), 0, 0, 1, 0},
  {&__pyx_kp_s__20, __pyx_k__20, sizeof(__pyx_k__20), 0, 0, 1, 0},
  {&__pyx_kp_s__29, __pyx_k__29, sizeof(__pyx_k__29), 0, 0, 1, 0},
  {&__pyx_kp_s__31, __pyx_k__31, sizeof(__pyx_k__31), 0, 0, 1, 0},
  {&__pyx_kp_s__40, __pyx_k__40, sizeof(__pyx_k__40), 0, 0, 1, 0},
  {&__pyx_kp_s__46, __pyx_k__46, sizeof(__pyx_k__46), 0, 0, 1, 0},
  {&__pyx_kp_s__48, __pyx_k__48, sizeof(__pyx_k__48), 0, 0, 1, 0},
  {&__pyx_n_s_a, __pyx_k_a, sizeof(__pyx_k_a), 0, 0, 1, 1},
  {&__pyx_n_s_addHandler, __pyx_k_addHandler, sizeof(__pyx_k_addHandler), 0, 0, 1, 1},
  {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
  {&__pyx_n_s_bbox, __pyx_k_bbox, sizeof(__pyx_k_bbox), 0, 0, 1, 1},
  {&__pyx_n_s_bounds, __pyx_k_bounds, sizeof(__pyx_k_bounds), 0, 0, 1, 1},
  {&__pyx_n_s_build, __pyx_k_build, sizeof(__pyx_k_build), 0, 0, 1, 1},
  {&__pyx_n_s_buildGeometryCollection, __pyx_k_buildGeometryCollection, sizeof(__pyx_k_buildGeometryCollection), 0, 0, 1, 1},
  {&__pyx_n_s_buildLineString, __pyx_k_buildLineString, sizeof(__pyx_k_buildLineString), 0, 0, 1, 1},
  {&__pyx_n_s_buildLinearRing, __pyx_k_buildLinearRing, sizeof(__pyx_k_buildLinearRing), 0, 0, 1, 1},
  {&__pyx_n_s_buildMultiLineString, __pyx_k_buildMultiLineString, sizeof(__pyx_k_buildMultiLineString), 0, 0, 1, 1},
  {&__pyx_n_s_buildMultiPoint, __pyx_k_buildMultiPoint, sizeof(__pyx_k_buildMultiPoint), 0, 0, 1, 1},
  {&__pyx_n_s_buildMultiPolygon, __pyx_k_buildMultiPolygon, sizeof(__pyx_k_buildMultiPolygon), 0, 0, 1, 1},
  {&__pyx_n_s_buildPoint, __pyx_k_buildPoint, sizeof(__pyx_k_buildPoint), 0, 0, 1, 1},
  {&__pyx_n_s_buildPolygon, __pyx_k_buildPolygon, sizeof(__pyx_k_buildPolygon), 0, 0, 1, 1},
  {&__pyx_n_s_build_wkb, __pyx_k_build_wkb, sizeof(__pyx_k_build_wkb), 0, 0, 1, 1},
  {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
  {&__pyx_n_s_cogr_ds, __pyx_k_cogr_ds, sizeof(__pyx_k_cogr_ds), 0, 0, 1, 1},
  {&__pyx_n_s_cogr_feature, __pyx_k_cogr_feature, sizeof(__pyx_k_cogr_feature), 0, 0, 1, 1},
  {&__pyx_n_s_cogr_geometry, __pyx_k_cogr_geometry, sizeof(__pyx_k_cogr_geometry), 0, 0, 1, 1},
  {&__pyx_n_s_cogr_layer, __pyx_k_cogr_layer, sizeof(__pyx_k_cogr_layer), 0, 0, 1, 1},
  {&__pyx_n_s_collection, __pyx_k_collection, sizeof(__pyx_k_collection), 0, 0, 1, 1},
  {&__pyx_n_s_coordinates, __pyx_k_coordinates, sizeof(__pyx_k_coordinates), 0, 0, 1, 1},
  {&__pyx_n_s_coords, __pyx_k_coords, sizeof(__pyx_k_coords), 0, 0, 1, 1},
  {&__pyx_n_s_crs, __pyx_k_crs, sizeof(__pyx_k_crs), 0, 0, 1, 1},
  {&__pyx_kp_s_d, __pyx_k_d, sizeof(__pyx_k_d), 0, 0, 1, 0},
  {&__pyx_kp_s_d_2, __pyx_k_d_2, sizeof(__pyx_k_d_2), 0, 0, 1, 0},
  {&__pyx_n_s_date, __pyx_k_date, sizeof(__pyx_k_date), 0, 0, 1, 1},
  {&__pyx_n_s_datetime, __pyx_k_datetime, sizeof(__pyx_k_datetime), 0, 0, 1, 1},
  {&__pyx_n_s_debug, __pyx_k_debug, sizeof(__pyx_k_debug), 0, 0, 1, 1},
  {&__pyx_n_s_decode, __pyx_k_decode, sizeof(__pyx_k_decode), 0, 0, 1, 1},
  {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
  {&__pyx_n_s_driver, __pyx_k_driver, sizeof(__pyx_k_driver), 0, 0, 1, 1},
  {&__pyx_n_s_e, __pyx_k_e, sizeof(__pyx_k_e), 0, 0, 1, 1},
  {&__pyx_n_s_emit, __pyx_k_emit, sizeof(__pyx_k_emit), 0, 0, 1, 1},
  {&__pyx_n_s_encode, __pyx_k_encode, sizeof(__pyx_k_encode), 0, 0, 1, 1},
  {&__pyx_n_s_encoding, __pyx_k_encoding, sizeof(__pyx_k_encoding), 0, 0, 1, 1},
  {&__pyx_n_s_exists, __pyx_k_exists, sizeof(__pyx_k_exists), 0, 0, 1, 1},
  {&__pyx_n_s_explode, __pyx_k_explode, sizeof(__pyx_k_explode), 0, 0, 1, 1},
  {&__pyx_n_s_f, __pyx_k_f, sizeof(__pyx_k_f), 0, 0, 1, 1},
  {&__pyx_n_s_feature, __pyx_k_feature, sizeof(__pyx_k_feature), 0, 0, 1, 1},
  {&__pyx_n_s_featureRT, __pyx_k_featureRT, sizeof(__pyx_k_featureRT), 0, 0, 1, 1},
  {&__pyx_n_s_fiona_errors, __pyx_k_fiona_errors, sizeof(__pyx_k_fiona_errors), 0, 0, 1, 1},
  {&__pyx_n_s_fiona_odict, __pyx_k_fiona_odict, sizeof(__pyx_k_fiona_odict), 0, 0, 1, 1},
  {&__pyx_n_s_fiona_ogrext, __pyx_k_fiona_ogrext, sizeof(__pyx_k_fiona_ogrext), 0, 0, 1, 1},
  {&__pyx_n_s_fiona_rfc3339, __pyx_k_fiona_rfc3339, sizeof(__pyx_k_fiona_rfc3339), 0, 0, 1, 1},
  {&__pyx_n_s_first, __pyx_k_first, sizeof(__pyx_k_first), 0, 0, 1, 1},
  {&__pyx_n_s_float, __pyx_k_float, sizeof(__pyx_k_float), 0, 0, 1, 1},
  {&__pyx_n_s_geom_type, __pyx_k_geom_type, sizeof(__pyx_k_geom_type), 0, 0, 1, 1},
  {&__pyx_n_s_geometries, __pyx_k_geometries, sizeof(__pyx_k_geometries), 0, 0, 1, 1},
  {&__pyx_n_s_geometry, __pyx_k_geometry, sizeof(__pyx_k_geometry), 0, 0, 1, 1},
  {&__pyx_n_s_geometryRT, __pyx_k_geometryRT, sizeof(__pyx_k_geometryRT), 0, 0, 1, 1},
  {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
  {&__pyx_n_s_getLogger, __pyx_k_getLogger, sizeof(__pyx_k_getLogger), 0, 0, 1, 1},
  {&__pyx_n_s_getNumDims, __pyx_k_getNumDims, sizeof(__pyx_k_getNumDims), 0, 0, 1, 1},
  {&__pyx_n_s_getNumDimsGeometryCollection, __pyx_k_getNumDimsGeometryCollection, sizeof(__pyx_k_getNumDimsGeometryCollection), 0, 0, 1, 1},
  {&__pyx_n_s_getNumDimsLineString, __pyx_k_getNumDimsLineString, sizeof(__pyx_k_getNumDimsLineString), 0, 0, 1, 1},
  {&__pyx_n_s_getNumDimsLinearRing, __pyx_k_getNumDimsLinearRing, sizeof(__pyx_k_getNumDimsLinearRing), 0, 0, 1, 1},
  {&__pyx_n_s_getNumDimsMultiLineString, __pyx_k_getNumDimsMultiLineString, sizeof(__pyx_k_getNumDimsMultiLineString), 0, 0, 1, 1},
  {&__pyx_n_s_getNumDimsMultiPoint, __pyx_k_getNumDimsMultiPoint, sizeof(__pyx_k_getNumDimsMultiPoint), 0, 0, 1, 1},
  {&__pyx_n_s_getNumDimsMultiPolygon, __pyx_k_getNumDimsMultiPolygon, sizeof(__pyx_k_getNumDimsMultiPolygon), 0, 0, 1, 1},
  {&__pyx_n_s_getNumDimsPoint, __pyx_k_getNumDimsPoint, sizeof(__pyx_k_getNumDimsPoint), 0, 0, 1, 1},
  {&__pyx_n_s_getNumDimsPolygon, __pyx_k_getNumDimsPolygon, sizeof(__pyx_k_getNumDimsPolygon), 0, 0, 1, 1},
  {&__pyx_n_s_get_driver, __pyx_k_get_driver, sizeof(__pyx_k_get_driver), 0, 0, 1, 1},
  {&__pyx_n_s_get_fileencoding, __pyx_k_get_fileencoding, sizeof(__pyx_k_get_fileencoding), 0, 0, 1, 1},
  {&__pyx_n_s_get_internalencoding, __pyx_k_get_internalencoding, sizeof(__pyx_k_get_internalencoding), 0, 0, 1, 1},
  {&__pyx_n_s_get_schema, __pyx_k_get_schema, sizeof(__pyx_k_get_schema), 0, 0, 1, 1},
  {&__pyx_n_s_getpreferredencoding, __pyx_k_getpreferredencoding, sizeof(__pyx_k_getpreferredencoding), 0, 0, 1, 1},
  {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
  {&__pyx_n_s_id, __pyx_k_id, sizeof(__pyx_k_id), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
  {&__pyx_n_s_int, __pyx_k_int, sizeof(__pyx_k_int), 0, 0, 1, 1},
  {&__pyx_n_s_integer_types, __pyx_k_integer_types, sizeof(__pyx_k_integer_types), 0, 0, 1, 1},
  {&__pyx_n_s_isoformat, __pyx_k_isoformat, sizeof(__pyx_k_isoformat), 0, 0, 1, 1},
  {&__pyx_n_s_items, __pyx_k_items, sizeof(__pyx_k_items), 0, 0, 1, 1},
  {&__pyx_n_s_join, __pyx_k_join, sizeof(__pyx_k_join), 0, 0, 1, 1},
  {&__pyx_n_s_keys, __pyx_k_keys, sizeof(__pyx_k_keys), 0, 0, 1, 1},
  {&__pyx_n_s_layer_count, __pyx_k_layer_count, sizeof(__pyx_k_layer_count), 0, 0, 1, 1},
  {&__pyx_n_s_layer_names, __pyx_k_layer_names, sizeof(__pyx_k_layer_names), 0, 0, 1, 1},
  {&__pyx_n_s_listlayers, __pyx_k_listlayers, sizeof(__pyx_k_listlayers), 0, 0, 1, 1},
  {&__pyx_n_s_locale, __pyx_k_locale, sizeof(__pyx_k_locale), 0, 0, 1, 1},
  {&__pyx_n_s_log, __pyx_k_log, sizeof(__pyx_k_log), 0, 0, 1, 1},
  {&__pyx_n_s_logging, __pyx_k_logging, sizeof(__pyx_k_logging), 0, 0, 1, 1},
  {&__pyx_n_s_long, __pyx_k_long, sizeof(__pyx_k_long), 0, 0, 1, 1},
  {&__pyx_n_s_lstrip, __pyx_k_lstrip, sizeof(__pyx_k_lstrip), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_map, __pyx_k_map, sizeof(__pyx_k_map), 0, 0, 1, 1},
  {&__pyx_n_s_max, __pyx_k_max, sizeof(__pyx_k_max), 0, 0, 1, 1},
  {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
  {&__pyx_n_s_min, __pyx_k_min, sizeof(__pyx_k_min), 0, 0, 1, 1},
  {&__pyx_n_s_mode, __pyx_k_mode, sizeof(__pyx_k_mode), 0, 0, 1, 1},
  {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_name_b, __pyx_k_name_b, sizeof(__pyx_k_name_b), 0, 0, 1, 1},
  {&__pyx_n_s_name_c, __pyx_k_name_c, sizeof(__pyx_k_name_c), 0, 0, 1, 1},
  {&__pyx_n_s_no_defs, __pyx_k_no_defs, sizeof(__pyx_k_no_defs), 0, 0, 1, 1},
  {&__pyx_n_s_object, __pyx_k_object, sizeof(__pyx_k_object), 0, 0, 1, 1},
  {&__pyx_kp_s_ogr_detected_encoding, __pyx_k_ogr_detected_encoding, sizeof(__pyx_k_ogr_detected_encoding), 0, 0, 1, 0},
  {&__pyx_n_s_os, __pyx_k_os, sizeof(__pyx_k_os), 0, 0, 1, 1},
  {&__pyx_n_s_parse_date, __pyx_k_parse_date, sizeof(__pyx_k_parse_date), 0, 0, 1, 1},
  {&__pyx_n_s_parse_datetime, __pyx_k_parse_datetime, sizeof(__pyx_k_parse_datetime), 0, 0, 1, 1},
  {&__pyx_n_s_parse_time, __pyx_k_parse_time, sizeof(__pyx_k_parse_time), 0, 0, 1, 1},
  {&__pyx_n_s_path, __pyx_k_path, sizeof(__pyx_k_path), 0, 0, 1, 1},
  {&__pyx_n_s_path_b, __pyx_k_path_b, sizeof(__pyx_k_path_b), 0, 0, 1, 1},
  {&__pyx_n_s_path_c, __pyx_k_path_c, sizeof(__pyx_k_path_c), 0, 0, 1, 1},
  {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
  {&__pyx_n_s_properties, __pyx_k_properties, sizeof(__pyx_k_properties), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_rec, __pyx_k_rec, sizeof(__pyx_k_rec), 0, 0, 1, 1},
  {&__pyx_n_s_record, __pyx_k_record, sizeof(__pyx_k_record), 0, 0, 1, 1},
  {&__pyx_n_s_records, __pyx_k_records, sizeof(__pyx_k_records), 0, 0, 1, 1},
  {&__pyx_n_s_result, __pyx_k_result, sizeof(__pyx_k_result), 0, 0, 1, 1},
  {&__pyx_kp_s_s, __pyx_k_s, sizeof(__pyx_k_s), 0, 0, 1, 0},
  {&__pyx_kp_s_s_None_fieldtype_r_r, __pyx_k_s_None_fieldtype_r_r, sizeof(__pyx_k_s_None_fieldtype_r_r), 0, 0, 1, 0},
  {&__pyx_kp_s_s_s, __pyx_k_s_s, sizeof(__pyx_k_s_s), 0, 0, 1, 0},
  {&__pyx_n_s_schema, __pyx_k_schema, sizeof(__pyx_k_schema), 0, 0, 1, 1},
  {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
  {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
  {&__pyx_n_s_session, __pyx_k_session, sizeof(__pyx_k_session), 0, 0, 1, 1},
  {&__pyx_n_s_six, __pyx_k_six, sizeof(__pyx_k_six), 0, 0, 1, 1},
  {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
  {&__pyx_n_s_stop, __pyx_k_stop, sizeof(__pyx_k_stop), 0, 0, 1, 1},
  {&__pyx_n_s_str, __pyx_k_str, sizeof(__pyx_k_str), 0, 0, 1, 1},
  {&__pyx_n_s_string_types, __pyx_k_string_types, sizeof(__pyx_k_string_types), 0, 0, 1, 1},
  {&__pyx_n_s_strip, __pyx_k_strip, sizeof(__pyx_k_strip), 0, 0, 1, 1},
  {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_text_type, __pyx_k_text_type, sizeof(__pyx_k_text_type), 0, 0, 1, 1},
  {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
  {&__pyx_n_s_time, __pyx_k_time, sizeof(__pyx_k_time), 0, 0, 1, 1},
  {&__pyx_n_s_type, __pyx_k_type, sizeof(__pyx_k_type), 0, 0, 1, 1},
  {&__pyx_n_s_upper, __pyx_k_upper, sizeof(__pyx_k_upper), 0, 0, 1, 1},
  {&__pyx_kp_s_utf_8, __pyx_k_utf_8, sizeof(__pyx_k_utf_8), 0, 0, 1, 0},
  {&__pyx_n_s_validate_geometry_type, __pyx_k_validate_geometry_type, sizeof(__pyx_k_validate_geometry_type), 0, 0, 1, 1},
  {&__pyx_n_s_w, __pyx_k_w, sizeof(__pyx_k_w), 0, 0, 1, 1},
  {&__pyx_n_s_warn, __pyx_k_warn, sizeof(__pyx_k_warn), 0, 0, 1, 1},
  {&__pyx_n_s_writerecs_locals_validate_geomet, __pyx_k_writerecs_locals_validate_geomet, sizeof(__pyx_k_writerecs_locals_validate_geomet), 0, 0, 1, 1},
  {&__pyx_n_s_x, __pyx_k_x, sizeof(__pyx_k_x), 0, 0, 1, 1},
  {&__pyx_n_s_y, __pyx_k_y, sizeof(__pyx_k_y), 0, 0, 1, 1},
  {&__pyx_n_s_zip, __pyx_k_zip, sizeof(__pyx_k_zip), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_object = __Pyx_GetBuiltinName(__pyx_n_s_object); if (!__pyx_builtin_object) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 159; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_zip = __Pyx_GetBuiltinName(__pyx_n_s_zip); if (!__pyx_builtin_zip) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 409; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_min = __Pyx_GetBuiltinName(__pyx_n_s_min); if (!__pyx_builtin_min) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_max = __Pyx_GetBuiltinName(__pyx_n_s_max); if (!__pyx_builtin_max) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 410; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_KeyError = __Pyx_GetBuiltinName(__pyx_n_s_KeyError); if (!__pyx_builtin_KeyError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 411; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 411; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_UnicodeDecodeError = __Pyx_GetBuiltinName(__pyx_n_s_UnicodeDecodeError); if (!__pyx_builtin_UnicodeDecodeError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 466; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_RuntimeError = __Pyx_GetBuiltinName(__pyx_n_s_RuntimeError); if (!__pyx_builtin_RuntimeError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 825; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_OSError = __Pyx_GetBuiltinName(__pyx_n_s_OSError); if (!__pyx_builtin_OSError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 843; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_map = __Pyx_GetBuiltinName(__pyx_n_s_map); if (!__pyx_builtin_map) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 976; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_StopIteration = __Pyx_GetBuiltinName(__pyx_n_s_StopIteration); if (!__pyx_builtin_StopIteration) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1099; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "fiona/ogrext.pyx":156
 *         cdef int i
 *         if geom is NULL:
 *             raise ValueError("Null geom")             # <<<<<<<<<<<<<<
 *         npoints = ograpi.OGR_G_GetPointCount(geom)
 *         coords = []
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_kp_s_Null_geom); if (unlikely(!__pyx_tuple_)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 156; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "fiona/ogrext.pyx":179
 *         cdef void *part
 *         if geom is NULL:
 *             raise ValueError("Null geom")             # <<<<<<<<<<<<<<
 *         parts = []
 *         for j in range(ograpi.OGR_G_GetGeometryCount(geom)):
 */
  __pyx_tuple__2 = PyTuple_Pack(1, __pyx_kp_s_Null_geom); if (unlikely(!__pyx_tuple__2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 179; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);

  /* "fiona/ogrext.pyx":209
 *         # The only method anyone needs to call
 *         if geom is NULL:
 *             raise ValueError("Null geom")             # <<<<<<<<<<<<<<
 * 
 *         cdef unsigned int etype = ograpi.OGR_G_GetGeometryType(geom)
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_kp_s_Null_geom); if (unlikely(!__pyx_tuple__3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 209; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "fiona/ogrext.pyx":273
 *                 log.debug("Adding values %f, %f", x, y)
 *                 ograpi.OGR_G_AddPoint_2D(cogr_geometry, x, y)
 *         log.debug("Closing ring")             # <<<<<<<<<<<<<<
 *         ograpi.OGR_G_CloseRings(cogr_geometry)
 *         return cogr_geometry
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_kp_s_Closing_ring); if (unlikely(!__pyx_tuple__4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 273; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "fiona/ogrext.pyx":287
 *             cogr_ring = OGRGeomBuilder().build(
 *                 {'type': 'LinearRing', 'coordinates': ring} )
 *             log.debug("Built ring")             # <<<<<<<<<<<<<<
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_ring)
 *             log.debug("Added ring %s", ring)
 */
  __pyx_tuple__5 = PyTuple_Pack(1, __pyx_kp_s_Built_ring); if (unlikely(!__pyx_tuple__5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 287; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "fiona/ogrext.pyx":319
 *             cogr_part = OGRGeomBuilder().build(
 *                 {'type': 'LineString', 'coordinates': line} )
 *             log.debug("Built line")             # <<<<<<<<<<<<<<
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 *             log.debug("Added line %s", line)
 */
  __pyx_tuple__6 = PyTuple_Pack(1, __pyx_kp_s_Built_line); if (unlikely(!__pyx_tuple__6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 319; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);

  /* "fiona/ogrext.pyx":333
 *             cogr_part = OGRGeomBuilder().build(
 *                 {'type': 'Polygon', 'coordinates': part} )
 *             log.debug("Built polygon")             # <<<<<<<<<<<<<<
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 *             log.debug("Added polygon %s", part)
 */
  __pyx_tuple__7 = PyTuple_Pack(1, __pyx_kp_s_Built_polygon); if (unlikely(!__pyx_tuple__7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "fiona/ogrext.pyx":346
 *             log.debug("Adding part %s", part)
 *             cogr_part = OGRGeomBuilder().build(part)
 *             log.debug("Built part")             # <<<<<<<<<<<<<<
 *             ograpi.OGR_G_AddGeometryDirectly(cogr_geometry, cogr_part)
 *             log.debug("Added part %s", part)
 */
  __pyx_tuple__8 = PyTuple_Pack(1, __pyx_kp_s_Built_part); if (unlikely(!__pyx_tuple__8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 346; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "fiona/ogrext.pyx":354
 *         handler = DimensionsHandler()
 *         self.typename = geometry['type']
 *         self.coordinates = geometry.get('coordinates')             # <<<<<<<<<<<<<<
 *         if self.coordinates:
 *             self.ndims = handler.getNumDims(self.typename, self.coordinates)
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_n_s_coordinates); if (unlikely(!__pyx_tuple__9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "fiona/ogrext.pyx":372
 *             return self._buildMultiPolygon()
 *         elif self.typename == 'GeometryCollection':
 *             self.coordinates = geometry.get('geometries')             # <<<<<<<<<<<<<<
 *             self.ndims = handler.getNumDims(self.typename, self.coordinates)
 *             return self._buildGeometryCollection()
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_n_s_geometries); if (unlikely(!__pyx_tuple__10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 372; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "fiona/ogrext.pyx":441
 *             fdefn = ograpi.OGR_F_GetFieldDefnRef(feature, i)
 *             if fdefn is NULL:
 *                 raise ValueError("Null feature definition")             # <<<<<<<<<<<<<<
 *             key_c = ograpi.OGR_Fld_GetNameRef(fdefn)
 *             if key_c == NULL:
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_s_Null_feature_definition); if (unlikely(!__pyx_tuple__11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "fiona/ogrext.pyx":444
 *             key_c = ograpi.OGR_Fld_GetNameRef(fdefn)
 *             if key_c == NULL:
 *                 raise ValueError("Null field name reference")             # <<<<<<<<<<<<<<
 *             key_b = key_c
 *             key = key_b.decode('utf-8')
 */
  __pyx_tuple__12 = PyTuple_Pack(1, __pyx_kp_s_Null_field_name_reference); if (unlikely(!__pyx_tuple__12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 444; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "fiona/ogrext.pyx":511
 *         cdef void *cogr_layer = session.cogr_layer
 *         if cogr_layer is NULL:
 *             raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 *         cdef void *cogr_featuredefn = ograpi.OGR_L_GetLayerDefn(cogr_layer)
 *         if cogr_featuredefn is NULL:
 */
  __pyx_tuple__13 = PyTuple_Pack(1, __pyx_kp_s_Null_layer); if (unlikely(!__pyx_tuple__13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 511; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);

  /* "fiona/ogrext.pyx":514
 *         cdef void *cogr_featuredefn = ograpi.OGR_L_GetLayerDefn(cogr_layer)
 *         if cogr_featuredefn is NULL:
 *             raise ValueError("Null feature definition")             # <<<<<<<<<<<<<<
 *         cdef void *cogr_feature = ograpi.OGR_F_Create(cogr_featuredefn)
 *         if cogr_feature is NULL:
 */
  __pyx_tuple__14 = PyTuple_Pack(1, __pyx_kp_s_Null_feature_definition); if (unlikely(!__pyx_tuple__14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 514; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "fiona/ogrext.pyx":517
 *         cdef void *cogr_feature = ograpi.OGR_F_Create(cogr_featuredefn)
 *         if cogr_feature is NULL:
 *             raise ValueError("Null feature")             # <<<<<<<<<<<<<<
 * 
 *         if feature['geometry'] is not None:
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_kp_s_Null_feature); if (unlikely(!__pyx_tuple__15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 517; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "fiona/ogrext.pyx":581
 *     cdef void *cogr_geometry = ograpi.OGR_F_GetGeometryRef(cogr_feature)
 *     if cogr_geometry is NULL:
 *         raise ValueError("Null geometry")             # <<<<<<<<<<<<<<
 *     log.debug("Geometry: %s" % ograpi.OGR_G_ExportToJson(cogr_geometry))
 *     encoding = collection.encoding or 'utf-8'
 */
  __pyx_tuple__16 = PyTuple_Pack(1, __pyx_kp_s_Null_geometry); if (unlikely(!__pyx_tuple__16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 581; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "fiona/ogrext.pyx":613
 * 
 *         try:
 *             path_b = collection.path.encode('utf-8')             # <<<<<<<<<<<<<<
 *         except UnicodeDecodeError:
 *             # Presume already a UTF-8 encoded string
 */
  __pyx_tuple__17 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__17)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 613; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "fiona/ogrext.pyx":625
 * 
 *         if isinstance(collection.name, string_types):
 *             name_b = collection.name.encode('utf-8')             # <<<<<<<<<<<<<<
 *             name_c = name_b
 *             self.cogr_layer = ograpi.OGR_DS_GetLayerByName(
 */
  __pyx_tuple__18 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__18)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 625; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__18);
  __Pyx_GIVEREF(__pyx_tuple__18);

  /* "fiona/ogrext.pyx":634
 *             name_c = ograpi.OGR_L_GetName(self.cogr_layer)
 *             name_b = name_c
 *             collection.name = name_b.decode('utf-8')             # <<<<<<<<<<<<<<
 * 
 *         if self.cogr_layer is NULL:
 */
  __pyx_tuple__19 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__19)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 634; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);

  /* "fiona/ogrext.pyx":673
 *     def get_length(self):
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 *         return ograpi.OGR_L_GetFeatureCount(self.cogr_layer, 0)
 * 
 */
  __pyx_tuple__21 = PyTuple_Pack(1, __pyx_kp_s_Null_layer); if (unlikely(!__pyx_tuple__21)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 673; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);

  /* "fiona/ogrext.pyx":679
 *         cdef void *cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 *         if cogr_driver is NULL:
 *             raise ValueError("Null driver")             # <<<<<<<<<<<<<<
 *         cdef char *name = ograpi.OGR_Dr_GetName(cogr_driver)
 *         driver_name = name
 */
  __pyx_tuple__22 = PyTuple_Pack(1, __pyx_kp_s_Null_driver); if (unlikely(!__pyx_tuple__22)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 679; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);

  /* "fiona/ogrext.pyx":693
 * 
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 * 
 *         cogr_featuredefn = ograpi.OGR_L_GetLayerDefn(self.cogr_layer)
 */
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_kp_s_Null_layer); if (unlikely(!__pyx_tuple__23)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 693; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "fiona/ogrext.pyx":697
 *         cogr_featuredefn = ograpi.OGR_L_GetLayerDefn(self.cogr_layer)
 *         if cogr_featuredefn is NULL:
 *             raise ValueError("Null feature definition")             # <<<<<<<<<<<<<<
 *         n = ograpi.OGR_FD_GetFieldCount(cogr_featuredefn)
 *         for i from 0 <= i < n:
 */
  __pyx_tuple__24 = PyTuple_Pack(1, __pyx_kp_s_Null_feature_definition); if (unlikely(!__pyx_tuple__24)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 697; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);

  /* "fiona/ogrext.pyx":702
 *             cogr_fielddefn = ograpi.OGR_FD_GetFieldDefn(cogr_featuredefn, i)
 *             if cogr_fielddefn is NULL:
 *                 raise ValueError("Null field definition")             # <<<<<<<<<<<<<<
 *             key_c = ograpi.OGR_Fld_GetNameRef(cogr_fielddefn)
 *             key_b = key_c
 */
  __pyx_tuple__25 = PyTuple_Pack(1, __pyx_kp_s_Null_field_definition); if (unlikely(!__pyx_tuple__25)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 702; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);

  /* "fiona/ogrext.pyx":749
 *         cdef char *proj_c = NULL
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 *         cdef void *cogr_crs = ograpi.OGR_L_GetSpatialRef(self.cogr_layer)
 *         log.debug("Got coordinate system")
 */
  __pyx_tuple__26 = PyTuple_Pack(1, __pyx_kp_s_Null_layer); if (unlikely(!__pyx_tuple__26)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 749; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);

  /* "fiona/ogrext.pyx":751
 *             raise ValueError("Null layer")
 *         cdef void *cogr_crs = ograpi.OGR_L_GetSpatialRef(self.cogr_layer)
 *         log.debug("Got coordinate system")             # <<<<<<<<<<<<<<
 *         crs = {}
 *         if cogr_crs is not NULL:
 */
  __pyx_tuple__27 = PyTuple_Pack(1, __pyx_kp_s_Got_coordinate_system); if (unlikely(!__pyx_tuple__27)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 751; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);

  /* "fiona/ogrext.pyx":756
 *             ograpi.OSRExportToProj4(cogr_crs, &proj_c)
 *             if proj_c is NULL:
 *                 raise ValueError("Null projection")             # <<<<<<<<<<<<<<
 *             proj_b = proj_c
 *             log.debug("Params: %s", proj_b)
 */
  __pyx_tuple__28 = PyTuple_Pack(1, __pyx_kp_s_Null_projection); if (unlikely(!__pyx_tuple__28)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 756; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__28);
  __Pyx_GIVEREF(__pyx_tuple__28);

  /* "fiona/ogrext.pyx":762
 *             value = value.strip()
 *             for param in value.split():
 *                 kv = param.split("=")             # <<<<<<<<<<<<<<
 *                 if len(kv) == 2:
 *                     k, v = kv
 */
  __pyx_tuple__30 = PyTuple_Pack(1, __pyx_kp_s__29); if (unlikely(!__pyx_tuple__30)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 762; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);

  /* "fiona/ogrext.pyx":776
 *                 else:
 *                     raise ValueError("Unexpected proj parameter %s" % param)
 *                 k = k.lstrip("+")             # <<<<<<<<<<<<<<
 *                 crs[k] = v
 *             ograpi.CPLFree(proj_c)
 */
  __pyx_tuple__32 = PyTuple_Pack(1, __pyx_kp_s__31); if (unlikely(!__pyx_tuple__32)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 776; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);

  /* "fiona/ogrext.pyx":780
 *             ograpi.CPLFree(proj_c)
 *         else:
 *             log.debug("Projection not found (cogr_crs was NULL)")             # <<<<<<<<<<<<<<
 *         return crs
 * 
 */
  __pyx_tuple__33 = PyTuple_Pack(1, __pyx_kp_s_Projection_not_found_cogr_crs_wa); if (unlikely(!__pyx_tuple__33)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 780; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);

  /* "fiona/ogrext.pyx":785
 *     def get_extent(self):
 *         if self.cogr_layer is NULL:
 *             raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 *         cdef ograpi.OGREnvelope extent
 *         result = ograpi.OGR_L_GetExtent(self.cogr_layer, &extent, 1)
 */
  __pyx_tuple__34 = PyTuple_Pack(1, __pyx_kp_s_Null_layer); if (unlikely(!__pyx_tuple__34)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 785; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__34);
  __Pyx_GIVEREF(__pyx_tuple__34);

  /* "fiona/ogrext.pyx":819
 *             if os.path.exists(path):
 *                 try:
 *                     path_b = path.encode('utf-8')             # <<<<<<<<<<<<<<
 *                 except UnicodeDecodeError:
 *                     path_b = path
 */
  __pyx_tuple__35 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__35)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 819; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);

  /* "fiona/ogrext.pyx":828
 *                 cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 *                 if cogr_driver is NULL:
 *                     raise ValueError("Null driver")             # <<<<<<<<<<<<<<
 * 
 *                 if isinstance(collection.name, string_types):
 */
  __pyx_tuple__36 = PyTuple_Pack(1, __pyx_kp_s_Null_driver); if (unlikely(!__pyx_tuple__36)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__36);
  __Pyx_GIVEREF(__pyx_tuple__36);

  /* "fiona/ogrext.pyx":854
 *         elif collection.mode == 'w':
 *             try:
 *                 path_b = path.encode('utf-8')             # <<<<<<<<<<<<<<
 *             except UnicodeDecodeError:
 *                 path_b = path
 */
  __pyx_tuple__37 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__37)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 854; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);

  /* "fiona/ogrext.pyx":863
 *             cogr_driver = ograpi.OGRGetDriverByName(driver_c)
 *             if cogr_driver is NULL:
 *                 raise ValueError("Null driver")             # <<<<<<<<<<<<<<
 * 
 *             if not os.path.exists(path):
 */
  __pyx_tuple__38 = PyTuple_Pack(1, __pyx_kp_s_Null_driver); if (unlikely(!__pyx_tuple__38)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__38);
  __Pyx_GIVEREF(__pyx_tuple__38);

  /* "fiona/ogrext.pyx":896
 *                 cogr_srs = ograpi.OSRNewSpatialReference(NULL)
 *                 if cogr_srs is NULL:
 *                     raise ValueError("Null spatial reference")             # <<<<<<<<<<<<<<
 *                 params = []
 *                 for k, v in collection.crs.items():
 */
  __pyx_tuple__39 = PyTuple_Pack(1, __pyx_kp_s_Null_spatial_reference); if (unlikely(!__pyx_tuple__39)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 896; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);

  /* "fiona/ogrext.pyx":930
 *                 name_c = ograpi.OGR_L_GetName(cogr_layer)
 *                 name_b = name_c
 *                 layer_names.append(name_b.decode('utf-8'))             # <<<<<<<<<<<<<<
 * 
 *             idx = -1
 */
  __pyx_tuple__41 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__41)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 930; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);

  /* "fiona/ogrext.pyx":944
 * 
 *             # Create the named layer in the datasource.
 *             name_b = collection.name.encode('utf-8')             # <<<<<<<<<<<<<<
 *             name_c = name_b
 *             self.cogr_layer = ograpi.OGR_DS_CreateLayer(
 */
  __pyx_tuple__42 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__42)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__42);
  __Pyx_GIVEREF(__pyx_tuple__42);

  /* "fiona/ogrext.pyx":951
 *                 cogr_srs,
 *                 <unsigned int>[k for k,v in GEOMETRY_TYPES.items() if
 *                     v == collection.schema.get('geometry', 'Unknown')][0],             # <<<<<<<<<<<<<<
 *                 options
 *                 )
 */
  __pyx_tuple__43 = PyTuple_Pack(2, __pyx_n_s_geometry, __pyx_n_s_Unknown); if (unlikely(!__pyx_tuple__43)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);

  /* "fiona/ogrext.pyx":958
 * 
 *             if self.cogr_layer is NULL:
 *                 raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 *             log.debug("Created layer")
 * 
 */
  __pyx_tuple__44 = PyTuple_Pack(1, __pyx_kp_s_Null_layer); if (unlikely(!__pyx_tuple__44)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__44);
  __Pyx_GIVEREF(__pyx_tuple__44);

  /* "fiona/ogrext.pyx":959
 *             if self.cogr_layer is NULL:
 *                 raise ValueError("Null layer")
 *             log.debug("Created layer")             # <<<<<<<<<<<<<<
 * 
 *             # Next, make a layer definition from the given schema properties,
 */
  __pyx_tuple__45 = PyTuple_Pack(1, __pyx_kp_s_Created_layer); if (unlikely(!__pyx_tuple__45)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 959; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);

  /* "fiona/ogrext.pyx":974
 *                 width = precision = None
 *                 if ':' in value:
 *                     value, fmt = value.split(':')             # <<<<<<<<<<<<<<
 *                     if '.' in fmt:
 *                         width, precision = map(int, fmt.split('.'))
 */
  __pyx_tuple__47 = PyTuple_Pack(1, __pyx_kp_s__46); if (unlikely(!__pyx_tuple__47)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 974; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__47);
  __Pyx_GIVEREF(__pyx_tuple__47);

  /* "fiona/ogrext.pyx":976
 *                     value, fmt = value.split(':')
 *                     if '.' in fmt:
 *                         width, precision = map(int, fmt.split('.'))             # <<<<<<<<<<<<<<
 *                     else:
 *                         width = int(fmt)
 */
  __pyx_tuple__49 = PyTuple_Pack(1, __pyx_kp_s__48); if (unlikely(!__pyx_tuple__49)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 976; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__49);
  __Pyx_GIVEREF(__pyx_tuple__49);

  /* "fiona/ogrext.pyx":986
 *                     FIELD_TYPES.index(value) )
 *                 if cogr_fielddefn is NULL:
 *                     raise ValueError("Null field definition")             # <<<<<<<<<<<<<<
 *                 if width:
 *                     ograpi.OGR_Fld_SetWidth(cogr_fielddefn, width)
 */
  __pyx_tuple__50 = PyTuple_Pack(1, __pyx_kp_s_Null_field_definition); if (unlikely(!__pyx_tuple__50)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 986; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);

  /* "fiona/ogrext.pyx":993
 *                 ograpi.OGR_L_CreateField(self.cogr_layer, cogr_fielddefn, 1)
 *                 ograpi.OGR_Fld_Destroy(cogr_fielddefn)
 *             log.debug("Created fields")             # <<<<<<<<<<<<<<
 * 
 *         # Mapping of the Python collection schema to the munged
 */
  __pyx_tuple__51 = PyTuple_Pack(1, __pyx_kp_s_Created_fields); if (unlikely(!__pyx_tuple__51)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 993; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__51);
  __Pyx_GIVEREF(__pyx_tuple__51);

  /* "fiona/ogrext.pyx":1002
 *             ogr_schema['properties'].keys() ))
 * 
 *         log.debug("Writing started")             # <<<<<<<<<<<<<<
 * 
 *     def writerecs(self, records, collection):
 */
  __pyx_tuple__52 = PyTuple_Pack(1, __pyx_kp_s_Writing_started); if (unlikely(!__pyx_tuple__52)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1002; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);

  /* "fiona/ogrext.pyx":1023
 *                 "3D ").lstrip("Multi")
 *             def validate_geometry_type(rec):
 *                 return rec['geometry'] is None or rec['geometry']['type'].lstrip(             # <<<<<<<<<<<<<<
 *                     "Multi") == schema_geom_type
 *         else:
 */
  __pyx_tuple__53 = PyTuple_Pack(1, __pyx_n_s_Multi); if (unlikely(!__pyx_tuple__53)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1023; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__53);
  __Pyx_GIVEREF(__pyx_tuple__53);

  /* "fiona/ogrext.pyx":1011
 *         cdef void *cogr_layer = self.cogr_layer
 *         if cogr_layer is NULL:
 *             raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 * 
 *         schema_geom_type = collection.schema['geometry']
 */
  __pyx_tuple__54 = PyTuple_Pack(1, __pyx_kp_s_Null_layer); if (unlikely(!__pyx_tuple__54)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1011; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__54);
  __Pyx_GIVEREF(__pyx_tuple__54);

  /* "fiona/ogrext.pyx":1016
 *         cogr_driver = ograpi.OGR_DS_GetDriver(self.cogr_ds)
 *         if ograpi.OGR_Dr_GetName(cogr_driver) == b"GeoJSON":
 *             def validate_geometry_type(rec):             # <<<<<<<<<<<<<<
 *                 return True
 *         elif ograpi.OGR_Dr_GetName(cogr_driver) == b"ESRI Shapefile" \
 */
  __pyx_tuple__55 = PyTuple_Pack(1, __pyx_n_s_rec); if (unlikely(!__pyx_tuple__55)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1016; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__55);
  __Pyx_GIVEREF(__pyx_tuple__55);
  __pyx_codeobj__56 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__55, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_validate_geometry_type, 1016, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__56)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1016; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":1020
 *         elif ograpi.OGR_Dr_GetName(cogr_driver) == b"ESRI Shapefile" \
 *                 and "Point" not in collection.schema['geometry']:
 *             schema_geom_type = collection.schema['geometry'].lstrip(             # <<<<<<<<<<<<<<
 *                 "3D ").lstrip("Multi")
 *             def validate_geometry_type(rec):
 */
  __pyx_tuple__57 = PyTuple_Pack(1, __pyx_kp_s_3D); if (unlikely(!__pyx_tuple__57)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1020; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__57);
  __Pyx_GIVEREF(__pyx_tuple__57);

  /* "fiona/ogrext.pyx":1021
 *                 and "Point" not in collection.schema['geometry']:
 *             schema_geom_type = collection.schema['geometry'].lstrip(
 *                 "3D ").lstrip("Multi")             # <<<<<<<<<<<<<<
 *             def validate_geometry_type(rec):
 *                 return rec['geometry'] is None or rec['geometry']['type'].lstrip(
 */
  __pyx_tuple__58 = PyTuple_Pack(1, __pyx_n_s_Multi); if (unlikely(!__pyx_tuple__58)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1021; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__58);
  __Pyx_GIVEREF(__pyx_tuple__58);

  /* "fiona/ogrext.pyx":1022
 *             schema_geom_type = collection.schema['geometry'].lstrip(
 *                 "3D ").lstrip("Multi")
 *             def validate_geometry_type(rec):             # <<<<<<<<<<<<<<
 *                 return rec['geometry'] is None or rec['geometry']['type'].lstrip(
 *                     "Multi") == schema_geom_type
 */
  __pyx_tuple__59 = PyTuple_Pack(1, __pyx_n_s_rec); if (unlikely(!__pyx_tuple__59)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1022; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);
  __pyx_codeobj__60 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__59, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_validate_geometry_type, 1022, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__60)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1022; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":1026
 *                     "Multi") == schema_geom_type
 *         else:
 *             schema_geom_type = collection.schema['geometry'].lstrip("3D ")             # <<<<<<<<<<<<<<
 *             def validate_geometry_type(rec):
 *                 return rec['geometry'] is None or \
 */
  __pyx_tuple__61 = PyTuple_Pack(1, __pyx_kp_s_3D); if (unlikely(!__pyx_tuple__61)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1026; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__61);
  __Pyx_GIVEREF(__pyx_tuple__61);

  /* "fiona/ogrext.pyx":1027
 *         else:
 *             schema_geom_type = collection.schema['geometry'].lstrip("3D ")
 *             def validate_geometry_type(rec):             # <<<<<<<<<<<<<<
 *                 return rec['geometry'] is None or \
 *                        rec['geometry']['type'] == schema_geom_type
 */
  __pyx_tuple__62 = PyTuple_Pack(1, __pyx_n_s_rec); if (unlikely(!__pyx_tuple__62)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1027; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__62);
  __Pyx_GIVEREF(__pyx_tuple__62);
  __pyx_codeobj__63 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__62, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_validate_geometry_type, 1027, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__63)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1027; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":1058
 *         cdef void *cogr_layer = self.cogr_layer
 *         if cogr_ds is NULL:
 *             raise ValueError("Null data source")             # <<<<<<<<<<<<<<
 *         log.debug("Syncing OGR to disk")
 *         retval = ograpi.OGR_DS_SyncToDisk(cogr_ds)
 */
  __pyx_tuple__64 = PyTuple_Pack(1, __pyx_kp_s_Null_data_source); if (unlikely(!__pyx_tuple__64)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1058; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__64);
  __Pyx_GIVEREF(__pyx_tuple__64);

  /* "fiona/ogrext.pyx":1059
 *         if cogr_ds is NULL:
 *             raise ValueError("Null data source")
 *         log.debug("Syncing OGR to disk")             # <<<<<<<<<<<<<<
 *         retval = ograpi.OGR_DS_SyncToDisk(cogr_ds)
 *         if retval != OGRERR_NONE:
 */
  __pyx_tuple__65 = PyTuple_Pack(1, __pyx_kp_s_Syncing_OGR_to_disk); if (unlikely(!__pyx_tuple__65)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1059; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__65);
  __Pyx_GIVEREF(__pyx_tuple__65);

  /* "fiona/ogrext.pyx":1062
 *         retval = ograpi.OGR_DS_SyncToDisk(cogr_ds)
 *         if retval != OGRERR_NONE:
 *             raise RuntimeError("Failed to sync to disk")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__66 = PyTuple_Pack(1, __pyx_kp_s_Failed_to_sync_to_disk); if (unlikely(!__pyx_tuple__66)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1062; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__66);
  __Pyx_GIVEREF(__pyx_tuple__66);

  /* "fiona/ogrext.pyx":1076
 *     def __init__(self, collection, bbox=None):
 *         if collection.session is None:
 *             raise ValueError("I/O operation on closed collection")             # <<<<<<<<<<<<<<
 *         self.collection = collection
 *         cdef Session session
 */
  __pyx_tuple__67 = PyTuple_Pack(1, __pyx_kp_s_I_O_operation_on_closed_collecti); if (unlikely(!__pyx_tuple__67)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1076; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__67);
  __Pyx_GIVEREF(__pyx_tuple__67);

  /* "fiona/ogrext.pyx":1082
 *         cdef void *cogr_layer = session.cogr_layer
 *         if cogr_layer is NULL:
 *             raise ValueError("Null layer")             # <<<<<<<<<<<<<<
 *         ograpi.OGR_L_ResetReading(cogr_layer)
 *         if bbox:
 */
  __pyx_tuple__68 = PyTuple_Pack(1, __pyx_kp_s_Null_layer); if (unlikely(!__pyx_tuple__68)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1082; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__68);
  __Pyx_GIVEREF(__pyx_tuple__68);

  /* "fiona/ogrext.pyx":1117
 *     # Open OGR data source.
 *     try:
 *         path_b = path.encode('utf-8')             # <<<<<<<<<<<<<<
 *     except UnicodeDecodeError:
 *         path_b = path
 */
  __pyx_tuple__69 = PyTuple_Pack(1, __pyx_kp_s_utf_8); if (unlikely(!__pyx_tuple__69)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__69);
  __Pyx_GIVEREF(__pyx_tuple__69);

  /* "fiona/ogrext.pyx":18
 * 
 * 
 * log = logging.getLogger("Fiona")             # <<<<<<<<<<<<<<
 * class NullHandler(logging.Handler):
 *     def emit(self, record):
 */
  __pyx_tuple__70 = PyTuple_Pack(1, __pyx_n_s_Fiona); if (unlikely(!__pyx_tuple__70)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__70);
  __Pyx_GIVEREF(__pyx_tuple__70);

  /* "fiona/ogrext.pyx":20
 * log = logging.getLogger("Fiona")
 * class NullHandler(logging.Handler):
 *     def emit(self, record):             # <<<<<<<<<<<<<<
 *         pass
 * log.addHandler(NullHandler())
 */
  __pyx_tuple__71 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_record); if (unlikely(!__pyx_tuple__71)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);
  __pyx_codeobj__72 = (PyObject*)__Pyx_PyCode_New(2, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__71, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_emit, 20, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__72)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":114
 *     coordinates = None
 * 
 *     def getNumDimsPoint(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates)
 * 
 */
  __pyx_tuple__73 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__73)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__73);
  __Pyx_GIVEREF(__pyx_tuple__73);
  __pyx_codeobj__74 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__73, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_getNumDimsPoint, 114, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__74)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":117
 *         return len(self.coordinates)
 * 
 *     def getNumDimsLineString(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0])
 * 
 */
  __pyx_tuple__75 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__75)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__75);
  __Pyx_GIVEREF(__pyx_tuple__75);
  __pyx_codeobj__76 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__75, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_getNumDimsLineString, 117, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__76)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":120
 *         return len(self.coordinates[0])
 * 
 *     def getNumDimsLinearRing(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0])
 * 
 */
  __pyx_tuple__77 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__77)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__77);
  __Pyx_GIVEREF(__pyx_tuple__77);
  __pyx_codeobj__78 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__77, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_getNumDimsLinearRing, 120, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__78)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":123
 *         return len(self.coordinates[0])
 * 
 *     def getNumDimsPolygon(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0][0])
 * 
 */
  __pyx_tuple__79 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__79)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__79);
  __Pyx_GIVEREF(__pyx_tuple__79);
  __pyx_codeobj__80 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__79, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_getNumDimsPolygon, 123, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__80)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":126
 *         return len(self.coordinates[0][0])
 * 
 *     def getNumDimsMultiPoint(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0])
 * 
 */
  __pyx_tuple__81 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__81)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__81);
  __Pyx_GIVEREF(__pyx_tuple__81);
  __pyx_codeobj__82 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__81, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_getNumDimsMultiPoint, 126, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__82)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":129
 *         return len(self.coordinates[0])
 * 
 *     def getNumDimsMultiLineString(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0][0])
 * 
 */
  __pyx_tuple__83 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__83)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__83);
  __Pyx_GIVEREF(__pyx_tuple__83);
  __pyx_codeobj__84 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__83, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_getNumDimsMultiLineString, 129, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__84)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":132
 *         return len(self.coordinates[0][0])
 * 
 *     def getNumDimsMultiPolygon(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0][0][0])
 * 
 */
  __pyx_tuple__85 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__85)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__85);
  __Pyx_GIVEREF(__pyx_tuple__85);
  __pyx_codeobj__86 = (PyObject*)__Pyx_PyCode_New(1, 0, 1, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__85, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_getNumDimsMultiPolygon, 132, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__86)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":135
 *         return len(self.coordinates[0][0][0])
 * 
 *     def getNumDimsGeometryCollection(self):             # <<<<<<<<<<<<<<
 *         first = self.coordinates[0]
 *         return self.getNumDims(first['type'], first['coordinates'])
 */
  __pyx_tuple__87 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_first); if (unlikely(!__pyx_tuple__87)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__87);
  __Pyx_GIVEREF(__pyx_tuple__87);
  __pyx_codeobj__88 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__87, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_getNumDimsGeometryCollection, 135, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__88)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":139
 *         return self.getNumDims(first['type'], first['coordinates'])
 * 
 *     def getNumDims(self, geom_type, coordinates):             # <<<<<<<<<<<<<<
 *         self.coordinates = coordinates
 *         return getattr(self, 'getNumDims' + geom_type)()
 */
  __pyx_tuple__89 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_geom_type, __pyx_n_s_coordinates); if (unlikely(!__pyx_tuple__89)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__89);
  __Pyx_GIVEREF(__pyx_tuple__89);
  __pyx_codeobj__90 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__89, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_getNumDims, 139, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__90)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":384
 * 
 * 
 * def geometryRT(geometry):             # <<<<<<<<<<<<<<
 *     # For testing purposes only, leaks the JSON data
 *     cdef void *cogr_geometry = OGRGeomBuilder().build(geometry)
 */
  __pyx_tuple__91 = PyTuple_Pack(3, __pyx_n_s_geometry, __pyx_n_s_cogr_geometry, __pyx_n_s_result); if (unlikely(!__pyx_tuple__91)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 384; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__91);
  __Pyx_GIVEREF(__pyx_tuple__91);
  __pyx_codeobj__92 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__91, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_geometryRT, 384, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__92)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 384; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":393
 * 
 * 
 * def _explode(coords):             # <<<<<<<<<<<<<<
 *     """Explode a GeoJSON geometry's coordinates object and yield
 *     coordinate tuples. As long as the input is conforming, the type of
 */
  __pyx_tuple__93 = PyTuple_Pack(3, __pyx_n_s_coords, __pyx_n_s_e, __pyx_n_s_f); if (unlikely(!__pyx_tuple__93)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__93);
  __Pyx_GIVEREF(__pyx_tuple__93);
  __pyx_codeobj__94 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__93, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_explode, 393, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__94)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":406
 * 
 * 
 * def _bounds(geometry):             # <<<<<<<<<<<<<<
 *     """Bounding box of a GeoJSON geometry"""
 *     try:
 */
  __pyx_tuple__95 = PyTuple_Pack(3, __pyx_n_s_geometry, __pyx_n_s_x, __pyx_n_s_y); if (unlikely(!__pyx_tuple__95)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 406; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__95);
  __Pyx_GIVEREF(__pyx_tuple__95);
  __pyx_codeobj__96 = (PyObject*)__Pyx_PyCode_New(1, 0, 3, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__95, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_bounds, 406, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__96)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 406; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":576
 * 
 * 
 * def featureRT(feature, collection):             # <<<<<<<<<<<<<<
 *     # For testing purposes only, leaks the JSON data
 *     cdef void *cogr_feature = OGRFeatureBuilder().build(feature, collection)
 */
  __pyx_tuple__97 = PyTuple_Pack(6, __pyx_n_s_feature, __pyx_n_s_collection, __pyx_n_s_cogr_feature, __pyx_n_s_cogr_geometry, __pyx_n_s_encoding, __pyx_n_s_result); if (unlikely(!__pyx_tuple__97)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 576; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__97);
  __Pyx_GIVEREF(__pyx_tuple__97);
  __pyx_codeobj__98 = (PyObject*)__Pyx_PyCode_New(2, 0, 6, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__97, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_featureRT, 576, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__98)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 576; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":1105
 * 
 * 
 * def _listlayers(path):             # <<<<<<<<<<<<<<
 * 
 *     """Provides a list of the layers in an OGR data source.
 */
  __pyx_tuple__99 = PyTuple_Pack(10, __pyx_n_s_path, __pyx_n_s_cogr_ds, __pyx_n_s_cogr_layer, __pyx_n_s_path_c, __pyx_n_s_name_c, __pyx_n_s_path_b, __pyx_n_s_layer_count, __pyx_n_s_layer_names, __pyx_n_s_i, __pyx_n_s_name_b); if (unlikely(!__pyx_tuple__99)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__99);
  __Pyx_GIVEREF(__pyx_tuple__99);
  __pyx_codeobj__100 = (PyObject*)__Pyx_PyCode_New(1, 0, 10, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__99, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_Users_seang_code_Fiona_src_fion, __pyx_n_s_listlayers, 1105, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__100)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_4 = PyInt_FromLong(4); if (unlikely(!__pyx_int_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_5 = PyInt_FromLong(5); if (unlikely(!__pyx_int_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_6 = PyInt_FromLong(6); if (unlikely(!__pyx_int_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_7 = PyInt_FromLong(7); if (unlikely(!__pyx_int_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_8 = PyInt_FromLong(8); if (unlikely(!__pyx_int_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_11 = PyInt_FromLong(11); if (unlikely(!__pyx_int_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_15 = PyInt_FromLong(15); if (unlikely(!__pyx_int_15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_24 = PyInt_FromLong(24); if (unlikely(!__pyx_int_24)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_80 = PyInt_FromLong(80); if (unlikely(!__pyx_int_80)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_100 = PyInt_FromLong(100); if (unlikely(!__pyx_int_100)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_101 = PyInt_FromLong(101); if (unlikely(!__pyx_int_101)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_2147483648 = PyInt_FromString((char *)"2147483648", 0, 0); if (unlikely(!__pyx_int_2147483648)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_2147483649 = PyInt_FromString((char *)"2147483649", 0, 0); if (unlikely(!__pyx_int_2147483649)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_2147483650 = PyInt_FromString((char *)"2147483650", 0, 0); if (unlikely(!__pyx_int_2147483650)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_2147483651 = PyInt_FromString((char *)"2147483651", 0, 0); if (unlikely(!__pyx_int_2147483651)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_2147483652 = PyInt_FromString((char *)"2147483652", 0, 0); if (unlikely(!__pyx_int_2147483652)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_2147483653 = PyInt_FromString((char *)"2147483653", 0, 0); if (unlikely(!__pyx_int_2147483653)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_2147483654 = PyInt_FromString((char *)"2147483654", 0, 0); if (unlikely(!__pyx_int_2147483654)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_2147483655 = PyInt_FromString((char *)"2147483655", 0, 0); if (unlikely(!__pyx_int_2147483655)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC initogrext(void); /*proto*/
PyMODINIT_FUNC initogrext(void)
#else
PyMODINIT_FUNC PyInit_ogrext(void); /*proto*/
PyMODINIT_FUNC PyInit_ogrext(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit_ogrext(void)", 0);
  if ( __Pyx_check_binary_version() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #ifdef __Pyx_CyFunction_USED
  if (__Pyx_CyFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4(__Pyx_NAMESTR("ogrext"), __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_NAMESTR(__Pyx_BUILTIN_MODULE_NAME)); if (unlikely(!__pyx_b)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (__Pyx_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  /*--- Initialize various global constants etc. ---*/
  if (unlikely(__Pyx_InitGlobals() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  if (__pyx_module_is_main_fiona__ogrext) {
    if (__Pyx_SetAttrString(__pyx_m, "__name__", __pyx_n_s_main) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!PyDict_GetItemString(modules, "fiona.ogrext")) {
      if (unlikely(PyDict_SetItemString(modules, "fiona.ogrext", __pyx_m) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (unlikely(__Pyx_InitCachedBuiltins() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Constants init code ---*/
  if (unlikely(__Pyx_InitCachedConstants() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Global init code ---*/
  /*--- Variable export code ---*/
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  if (PyType_Ready(&__pyx_type_5fiona_6ogrext___pyx_scope_struct___explode) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_5fiona_6ogrext___pyx_scope_struct___explode.tp_print = 0;
  __pyx_ptype_5fiona_6ogrext___pyx_scope_struct___explode = &__pyx_type_5fiona_6ogrext___pyx_scope_struct___explode;
  if (PyType_Ready(&__pyx_type_5fiona_6ogrext___pyx_scope_struct_1_writerecs) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1004; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_5fiona_6ogrext___pyx_scope_struct_1_writerecs.tp_print = 0;
  __pyx_ptype_5fiona_6ogrext___pyx_scope_struct_1_writerecs = &__pyx_type_5fiona_6ogrext___pyx_scope_struct_1_writerecs;
  __pyx_vtabptr_5fiona_6ogrext_FeatureBuilder = &__pyx_vtable_5fiona_6ogrext_FeatureBuilder;
  __pyx_vtable_5fiona_6ogrext_FeatureBuilder.build = (PyObject *(*)(struct __pyx_obj_5fiona_6ogrext_FeatureBuilder *, void *, struct __pyx_opt_args_5fiona_6ogrext_14FeatureBuilder_build *__pyx_optional_args))__pyx_f_5fiona_6ogrext_14FeatureBuilder_build;
  if (PyType_Ready(&__pyx_type_5fiona_6ogrext_FeatureBuilder) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 417; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_5fiona_6ogrext_FeatureBuilder.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_5fiona_6ogrext_FeatureBuilder.tp_dict, __pyx_vtabptr_5fiona_6ogrext_FeatureBuilder) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 417; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "FeatureBuilder", (PyObject *)&__pyx_type_5fiona_6ogrext_FeatureBuilder) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 417; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5fiona_6ogrext_FeatureBuilder = &__pyx_type_5fiona_6ogrext_FeatureBuilder;
  __pyx_vtabptr_5fiona_6ogrext_OGRFeatureBuilder = &__pyx_vtable_5fiona_6ogrext_OGRFeatureBuilder;
  __pyx_vtable_5fiona_6ogrext_OGRFeatureBuilder.build = (void *(*)(struct __pyx_obj_5fiona_6ogrext_OGRFeatureBuilder *, PyObject *, PyObject *))__pyx_f_5fiona_6ogrext_17OGRFeatureBuilder_build;
  if (PyType_Ready(&__pyx_type_5fiona_6ogrext_OGRFeatureBuilder) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 496; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_5fiona_6ogrext_OGRFeatureBuilder.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_5fiona_6ogrext_OGRFeatureBuilder.tp_dict, __pyx_vtabptr_5fiona_6ogrext_OGRFeatureBuilder) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 496; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "OGRFeatureBuilder", (PyObject *)&__pyx_type_5fiona_6ogrext_OGRFeatureBuilder) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 496; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5fiona_6ogrext_OGRFeatureBuilder = &__pyx_type_5fiona_6ogrext_OGRFeatureBuilder;
  if (PyType_Ready(&__pyx_type_5fiona_6ogrext_Session) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 591; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_5fiona_6ogrext_Session.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "Session", (PyObject *)&__pyx_type_5fiona_6ogrext_Session) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 591; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5fiona_6ogrext_Session = &__pyx_type_5fiona_6ogrext_Session;
  __pyx_vtabptr_5fiona_6ogrext_GeomBuilder = &__pyx_vtable_5fiona_6ogrext_GeomBuilder;
  __pyx_vtable_5fiona_6ogrext_GeomBuilder._buildCoords = (PyObject *(*)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, void *))__pyx_f_5fiona_6ogrext_11GeomBuilder__buildCoords;
  __pyx_vtable_5fiona_6ogrext_GeomBuilder._buildPoint = (PyObject *(*)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch))__pyx_f_5fiona_6ogrext_11GeomBuilder__buildPoint;
  __pyx_vtable_5fiona_6ogrext_GeomBuilder._buildLineString = (PyObject *(*)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch))__pyx_f_5fiona_6ogrext_11GeomBuilder__buildLineString;
  __pyx_vtable_5fiona_6ogrext_GeomBuilder._buildLinearRing = (PyObject *(*)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch))__pyx_f_5fiona_6ogrext_11GeomBuilder__buildLinearRing;
  __pyx_vtable_5fiona_6ogrext_GeomBuilder._buildParts = (PyObject *(*)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, void *))__pyx_f_5fiona_6ogrext_11GeomBuilder__buildParts;
  __pyx_vtable_5fiona_6ogrext_GeomBuilder._buildPolygon = (PyObject *(*)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch))__pyx_f_5fiona_6ogrext_11GeomBuilder__buildPolygon;
  __pyx_vtable_5fiona_6ogrext_GeomBuilder._buildMultiPoint = (PyObject *(*)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch))__pyx_f_5fiona_6ogrext_11GeomBuilder__buildMultiPoint;
  __pyx_vtable_5fiona_6ogrext_GeomBuilder._buildMultiLineString = (PyObject *(*)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch))__pyx_f_5fiona_6ogrext_11GeomBuilder__buildMultiLineString;
  __pyx_vtable_5fiona_6ogrext_GeomBuilder._buildMultiPolygon = (PyObject *(*)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch))__pyx_f_5fiona_6ogrext_11GeomBuilder__buildMultiPolygon;
  __pyx_vtable_5fiona_6ogrext_GeomBuilder._buildGeometryCollection = (PyObject *(*)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, int __pyx_skip_dispatch))__pyx_f_5fiona_6ogrext_11GeomBuilder__buildGeometryCollection;
  __pyx_vtable_5fiona_6ogrext_GeomBuilder.build = (PyObject *(*)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, void *))__pyx_f_5fiona_6ogrext_11GeomBuilder_build;
  __pyx_vtable_5fiona_6ogrext_GeomBuilder.build_wkb = (PyObject *(*)(struct __pyx_obj_5fiona_6ogrext_GeomBuilder *, PyObject *, int __pyx_skip_dispatch))__pyx_f_5fiona_6ogrext_11GeomBuilder_build_wkb;
  if (PyType_Ready(&__pyx_type_5fiona_6ogrext_GeomBuilder) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_5fiona_6ogrext_GeomBuilder.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_5fiona_6ogrext_GeomBuilder.tp_dict, __pyx_vtabptr_5fiona_6ogrext_GeomBuilder) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "GeomBuilder", (PyObject *)&__pyx_type_5fiona_6ogrext_GeomBuilder) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5fiona_6ogrext_GeomBuilder = &__pyx_type_5fiona_6ogrext_GeomBuilder;
  __pyx_vtabptr_5fiona_6ogrext_OGRGeomBuilder = &__pyx_vtable_5fiona_6ogrext_OGRGeomBuilder;
  __pyx_vtable_5fiona_6ogrext_OGRGeomBuilder._buildPoint = (void *(*)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *))__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildPoint;
  __pyx_vtable_5fiona_6ogrext_OGRGeomBuilder._buildLineString = (void *(*)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *))__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildLineString;
  __pyx_vtable_5fiona_6ogrext_OGRGeomBuilder._buildLinearRing = (void *(*)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *))__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildLinearRing;
  __pyx_vtable_5fiona_6ogrext_OGRGeomBuilder._buildPolygon = (void *(*)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *))__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildPolygon;
  __pyx_vtable_5fiona_6ogrext_OGRGeomBuilder._buildMultiPoint = (void *(*)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *))__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildMultiPoint;
  __pyx_vtable_5fiona_6ogrext_OGRGeomBuilder._buildMultiLineString = (void *(*)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *))__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildMultiLineString;
  __pyx_vtable_5fiona_6ogrext_OGRGeomBuilder._buildMultiPolygon = (void *(*)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *))__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildMultiPolygon;
  __pyx_vtable_5fiona_6ogrext_OGRGeomBuilder._buildGeometryCollection = (void *(*)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *))__pyx_f_5fiona_6ogrext_14OGRGeomBuilder__buildGeometryCollection;
  __pyx_vtable_5fiona_6ogrext_OGRGeomBuilder.build = (void *(*)(struct __pyx_obj_5fiona_6ogrext_OGRGeomBuilder *, PyObject *))__pyx_f_5fiona_6ogrext_14OGRGeomBuilder_build;
  if (PyType_Ready(&__pyx_type_5fiona_6ogrext_OGRGeomBuilder) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 227; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_5fiona_6ogrext_OGRGeomBuilder.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_5fiona_6ogrext_OGRGeomBuilder.tp_dict, __pyx_vtabptr_5fiona_6ogrext_OGRGeomBuilder) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 227; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "OGRGeomBuilder", (PyObject *)&__pyx_type_5fiona_6ogrext_OGRGeomBuilder) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 227; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5fiona_6ogrext_OGRGeomBuilder = &__pyx_type_5fiona_6ogrext_OGRGeomBuilder;
  if (PyType_Ready(&__pyx_type_5fiona_6ogrext_Iterator) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1065; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_5fiona_6ogrext_Iterator.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "Iterator", (PyObject *)&__pyx_type_5fiona_6ogrext_Iterator) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1065; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5fiona_6ogrext_Iterator = &__pyx_type_5fiona_6ogrext_Iterator;
  __pyx_type_5fiona_6ogrext_WritingSession.tp_base = __pyx_ptype_5fiona_6ogrext_Session;
  if (PyType_Ready(&__pyx_type_5fiona_6ogrext_WritingSession) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 797; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_5fiona_6ogrext_WritingSession.tp_print = 0;
  if (__Pyx_SetAttrString(__pyx_m, "WritingSession", (PyObject *)&__pyx_type_5fiona_6ogrext_WritingSession) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 797; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5fiona_6ogrext_WritingSession = &__pyx_type_5fiona_6ogrext_WritingSession;
  /*--- Type import code ---*/
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/

  /* "fiona/ogrext.pyx":3
 * # These are extension functions and classes using the OGR C API.
 * 
 * import datetime             # <<<<<<<<<<<<<<
 * import locale
 * import logging
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_datetime, 0, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 3; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_datetime, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 3; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":4
 * 
 * import datetime
 * import locale             # <<<<<<<<<<<<<<
 * import logging
 * import os
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_locale, 0, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 4; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_locale, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 4; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":5
 * import datetime
 * import locale
 * import logging             # <<<<<<<<<<<<<<
 * import os
 * import sys
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_logging, 0, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 5; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_logging, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 5; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":6
 * import locale
 * import logging
 * import os             # <<<<<<<<<<<<<<
 * import sys
 * 
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_os, 0, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_os, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 6; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":7
 * import logging
 * import os
 * import sys             # <<<<<<<<<<<<<<
 * 
 * from six import integer_types, string_types, text_type
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_sys, 0, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 7; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_sys, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 7; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":9
 * import sys
 * 
 * from six import integer_types, string_types, text_type             # <<<<<<<<<<<<<<
 * 
 * from fiona cimport ograpi
 */
  __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_integer_types);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_integer_types);
  __Pyx_GIVEREF(__pyx_n_s_integer_types);
  __Pyx_INCREF(__pyx_n_s_string_types);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_string_types);
  __Pyx_GIVEREF(__pyx_n_s_string_types);
  __Pyx_INCREF(__pyx_n_s_text_type);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_s_text_type);
  __Pyx_GIVEREF(__pyx_n_s_text_type);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_six, __pyx_t_1, -1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_integer_types); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_integer_types, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_string_types); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_string_types, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_text_type); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_text_type, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":12
 * 
 * from fiona cimport ograpi
 * from fiona.errors import DriverError, SchemaError, CRSError             # <<<<<<<<<<<<<<
 * from fiona.odict import OrderedDict
 * from fiona.rfc3339 import parse_date, parse_datetime, parse_time
 */
  __pyx_t_2 = PyList_New(3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_DriverError);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_DriverError);
  __Pyx_GIVEREF(__pyx_n_s_DriverError);
  __Pyx_INCREF(__pyx_n_s_SchemaError);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_SchemaError);
  __Pyx_GIVEREF(__pyx_n_s_SchemaError);
  __Pyx_INCREF(__pyx_n_s_CRSError);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_CRSError);
  __Pyx_GIVEREF(__pyx_n_s_CRSError);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_fiona_errors, __pyx_t_2, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_DriverError); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DriverError, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_SchemaError); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SchemaError, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_CRSError); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_CRSError, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 12; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":13
 * from fiona cimport ograpi
 * from fiona.errors import DriverError, SchemaError, CRSError
 * from fiona.odict import OrderedDict             # <<<<<<<<<<<<<<
 * from fiona.rfc3339 import parse_date, parse_datetime, parse_time
 * from fiona.rfc3339 import FionaDateType, FionaDateTimeType, FionaTimeType
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 13; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_OrderedDict);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_OrderedDict);
  __Pyx_GIVEREF(__pyx_n_s_OrderedDict);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_fiona_odict, __pyx_t_1, -1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 13; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_OrderedDict); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 13; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OrderedDict, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 13; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":14
 * from fiona.errors import DriverError, SchemaError, CRSError
 * from fiona.odict import OrderedDict
 * from fiona.rfc3339 import parse_date, parse_datetime, parse_time             # <<<<<<<<<<<<<<
 * from fiona.rfc3339 import FionaDateType, FionaDateTimeType, FionaTimeType
 * 
 */
  __pyx_t_2 = PyList_New(3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_parse_date);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_parse_date);
  __Pyx_GIVEREF(__pyx_n_s_parse_date);
  __Pyx_INCREF(__pyx_n_s_parse_datetime);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_parse_datetime);
  __Pyx_GIVEREF(__pyx_n_s_parse_datetime);
  __Pyx_INCREF(__pyx_n_s_parse_time);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_parse_time);
  __Pyx_GIVEREF(__pyx_n_s_parse_time);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_fiona_rfc3339, __pyx_t_2, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_parse_date); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_parse_date, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_parse_datetime); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_parse_datetime, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_parse_time); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_parse_time, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 14; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "fiona/ogrext.pyx":15
 * from fiona.odict import OrderedDict
 * from fiona.rfc3339 import parse_date, parse_datetime, parse_time
 * from fiona.rfc3339 import FionaDateType, FionaDateTimeType, FionaTimeType             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_FionaDateType);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_FionaDateType);
  __Pyx_GIVEREF(__pyx_n_s_FionaDateType);
  __Pyx_INCREF(__pyx_n_s_FionaDateTimeType);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_FionaDateTimeType);
  __Pyx_GIVEREF(__pyx_n_s_FionaDateTimeType);
  __Pyx_INCREF(__pyx_n_s_FionaTimeType);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_s_FionaTimeType);
  __Pyx_GIVEREF(__pyx_n_s_FionaTimeType);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_fiona_rfc3339, __pyx_t_1, -1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_FionaDateType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FionaDateType, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_FionaDateTimeType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FionaDateTimeType, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_FionaTimeType); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FionaTimeType, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 15; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":18
 * 
 * 
 * log = logging.getLogger("Fiona")             # <<<<<<<<<<<<<<
 * class NullHandler(logging.Handler):
 *     def emit(self, record):
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_logging); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_getLogger); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, __pyx_tuple__70, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_log, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 18; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":19
 * 
 * log = logging.getLogger("Fiona")
 * class NullHandler(logging.Handler):             # <<<<<<<<<<<<<<
 *     def emit(self, record):
 *         pass
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_logging); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 19; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_Handler); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 19; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 19; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_CalculateMetaclass(NULL, __pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 19; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_Py3MetaclassPrepare(__pyx_t_1, __pyx_t_2, __pyx_n_s_NullHandler, __pyx_n_s_NullHandler, (PyObject *) NULL, __pyx_n_s_fiona_ogrext, (PyObject *) NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 19; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);

  /* "fiona/ogrext.pyx":20
 * log = logging.getLogger("Fiona")
 * class NullHandler(logging.Handler):
 *     def emit(self, record):             # <<<<<<<<<<<<<<
 *         pass
 * log.addHandler(NullHandler())
 */
  __pyx_t_4 = __Pyx_CyFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_11NullHandler_1emit, 0, __pyx_n_s_NullHandler_emit, NULL, __pyx_n_s_fiona_ogrext, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__72)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  if (PyObject_SetItem(__pyx_t_3, __pyx_n_s_emit, __pyx_t_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 20; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":19
 * 
 * log = logging.getLogger("Fiona")
 * class NullHandler(logging.Handler):             # <<<<<<<<<<<<<<
 *     def emit(self, record):
 *         pass
 */
  __pyx_t_4 = __Pyx_Py3ClassCreate(__pyx_t_1, __pyx_n_s_NullHandler, __pyx_t_2, __pyx_t_3, NULL, 0, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 19; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_NullHandler, __pyx_t_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 19; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":22
 *     def emit(self, record):
 *         pass
 * log.addHandler(NullHandler())             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_log); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 22; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_addHandler); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 22; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_NullHandler); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 22; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_Call(__pyx_t_2, __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 22; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 22; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_1, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 22; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "fiona/ogrext.pyx":26
 * 
 * # Mapping of OGR integer geometry types to GeoJSON type names.
 * GEOMETRY_TYPES = {             # <<<<<<<<<<<<<<
 *     0: 'Unknown',
 *     1: 'Point',
 */
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_0, __pyx_n_s_Unknown) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_1, __pyx_n_s_Point) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_2, __pyx_n_s_LineString) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_3, __pyx_n_s_Polygon) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_4, __pyx_n_s_MultiPoint) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_5, __pyx_n_s_MultiLineString) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_6, __pyx_n_s_MultiPolygon) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_7, __pyx_n_s_GeometryCollection) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_100, __pyx_n_s_None) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_101, __pyx_n_s_LinearRing) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_2147483649, __pyx_kp_s_3D_Point) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_2147483650, __pyx_kp_s_3D_LineString) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_2147483651, __pyx_kp_s_3D_Polygon) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_2147483652, __pyx_kp_s_3D_MultiPoint) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_2147483653, __pyx_kp_s_3D_MultiLineString) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_2147483654, __pyx_kp_s_3D_MultiPolygon) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_t_3, __pyx_int_2147483655, __pyx_kp_s_3D_GeometryCollection) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_GEOMETRY_TYPES, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 26; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "fiona/ogrext.pyx":50
 * # arrays in a future version.
 * 
 * FIELD_TYPES = [             # <<<<<<<<<<<<<<
 *     'int',          # OFTInteger, Simple 32bit integer
 *     None,           # OFTIntegerList, List of 32bit integers
 */
  __pyx_t_3 = PyList_New(12); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_int);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_int);
  __Pyx_GIVEREF(__pyx_n_s_int);
  __Pyx_INCREF(Py_None);
  PyList_SET_ITEM(__pyx_t_3, 1, Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_INCREF(__pyx_n_s_float);
  PyList_SET_ITEM(__pyx_t_3, 2, __pyx_n_s_float);
  __Pyx_GIVEREF(__pyx_n_s_float);
  __Pyx_INCREF(Py_None);
  PyList_SET_ITEM(__pyx_t_3, 3, Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_INCREF(__pyx_n_s_str);
  PyList_SET_ITEM(__pyx_t_3, 4, __pyx_n_s_str);
  __Pyx_GIVEREF(__pyx_n_s_str);
  __Pyx_INCREF(Py_None);
  PyList_SET_ITEM(__pyx_t_3, 5, Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_INCREF(Py_None);
  PyList_SET_ITEM(__pyx_t_3, 6, Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_INCREF(Py_None);
  PyList_SET_ITEM(__pyx_t_3, 7, Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_INCREF(Py_None);
  PyList_SET_ITEM(__pyx_t_3, 8, Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_INCREF(__pyx_n_s_date);
  PyList_SET_ITEM(__pyx_t_3, 9, __pyx_n_s_date);
  __Pyx_GIVEREF(__pyx_n_s_date);
  __Pyx_INCREF(__pyx_n_s_time);
  PyList_SET_ITEM(__pyx_t_3, 10, __pyx_n_s_time);
  __Pyx_GIVEREF(__pyx_n_s_time);
  __Pyx_INCREF(__pyx_n_s_datetime);
  PyList_SET_ITEM(__pyx_t_3, 11, __pyx_n_s_datetime);
  __Pyx_GIVEREF(__pyx_n_s_datetime);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FIELD_TYPES, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 50; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "fiona/ogrext.pyx":66
 * 
 * # Mapping of Fiona field type names to Python types.
 * FIELD_TYPES_MAP = {             # <<<<<<<<<<<<<<
 *     'int':      int,
 *     'float':    float,
 */
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);

  /* "fiona/ogrext.pyx":67
 * # Mapping of Fiona field type names to Python types.
 * FIELD_TYPES_MAP = {
 *     'int':      int,             # <<<<<<<<<<<<<<
 *     'float':    float,
 *     'str':      text_type,
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_int, ((PyObject *)((PyObject*)(&PyInt_Type)))) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":68
 * FIELD_TYPES_MAP = {
 *     'int':      int,
 *     'float':    float,             # <<<<<<<<<<<<<<
 *     'str':      text_type,
 *     'date':     FionaDateType,
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_float, ((PyObject *)((PyObject*)(&PyFloat_Type)))) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":69
 *     'int':      int,
 *     'float':    float,
 *     'str':      text_type,             # <<<<<<<<<<<<<<
 *     'date':     FionaDateType,
 *     'time':     FionaTimeType,
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_text_type); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 69; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_str, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":70
 *     'float':    float,
 *     'str':      text_type,
 *     'date':     FionaDateType,             # <<<<<<<<<<<<<<
 *     'time':     FionaTimeType,
 *     'datetime': FionaDateTimeType
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_FionaDateType); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 70; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_date, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":71
 *     'str':      text_type,
 *     'date':     FionaDateType,
 *     'time':     FionaTimeType,             # <<<<<<<<<<<<<<
 *     'datetime': FionaDateTimeType
 *     }
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_FionaTimeType); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 71; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_time, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "fiona/ogrext.pyx":73
 *     'time':     FionaTimeType,
 *     'datetime': FionaDateTimeType
 *     }             # <<<<<<<<<<<<<<
 * 
 * # OGR integer error types.
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_FionaDateTimeType); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 73; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_datetime, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_FIELD_TYPES_MAP, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 66; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "fiona/ogrext.pyx":77
 * # OGR integer error types.
 * 
 * OGRERR_NONE = 0             # <<<<<<<<<<<<<<
 * OGRERR_NOT_ENOUGH_DATA = 1    # not enough data to deserialize *[inserted by cython to avoid comment closer]/
 * OGRERR_NOT_ENOUGH_MEMORY = 2
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OGRERR_NONE, __pyx_int_0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 77; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":78
 * 
 * OGRERR_NONE = 0
 * OGRERR_NOT_ENOUGH_DATA = 1    # not enough data to deserialize *[inserted by cython to avoid comment closer]/             # <<<<<<<<<<<<<<
 * OGRERR_NOT_ENOUGH_MEMORY = 2
 * OGRERR_UNSUPPORTED_GEOMETRY_TYPE = 3
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OGRERR_NOT_ENOUGH_DATA, __pyx_int_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 78; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":79
 * OGRERR_NONE = 0
 * OGRERR_NOT_ENOUGH_DATA = 1    # not enough data to deserialize *[inserted by cython to avoid comment closer]/
 * OGRERR_NOT_ENOUGH_MEMORY = 2             # <<<<<<<<<<<<<<
 * OGRERR_UNSUPPORTED_GEOMETRY_TYPE = 3
 * OGRERR_UNSUPPORTED_OPERATION = 4
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OGRERR_NOT_ENOUGH_MEMORY, __pyx_int_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 79; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":80
 * OGRERR_NOT_ENOUGH_DATA = 1    # not enough data to deserialize *[inserted by cython to avoid comment closer]/
 * OGRERR_NOT_ENOUGH_MEMORY = 2
 * OGRERR_UNSUPPORTED_GEOMETRY_TYPE = 3             # <<<<<<<<<<<<<<
 * OGRERR_UNSUPPORTED_OPERATION = 4
 * OGRERR_CORRUPT_DATA = 5
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OGRERR_UNSUPPORTED_GEOMETRY_TYPE, __pyx_int_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 80; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":81
 * OGRERR_NOT_ENOUGH_MEMORY = 2
 * OGRERR_UNSUPPORTED_GEOMETRY_TYPE = 3
 * OGRERR_UNSUPPORTED_OPERATION = 4             # <<<<<<<<<<<<<<
 * OGRERR_CORRUPT_DATA = 5
 * OGRERR_FAILURE = 6
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OGRERR_UNSUPPORTED_OPERATION, __pyx_int_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 81; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":82
 * OGRERR_UNSUPPORTED_GEOMETRY_TYPE = 3
 * OGRERR_UNSUPPORTED_OPERATION = 4
 * OGRERR_CORRUPT_DATA = 5             # <<<<<<<<<<<<<<
 * OGRERR_FAILURE = 6
 * OGRERR_UNSUPPORTED_SRS = 7
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OGRERR_CORRUPT_DATA, __pyx_int_5) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 82; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":83
 * OGRERR_UNSUPPORTED_OPERATION = 4
 * OGRERR_CORRUPT_DATA = 5
 * OGRERR_FAILURE = 6             # <<<<<<<<<<<<<<
 * OGRERR_UNSUPPORTED_SRS = 7
 * OGRERR_INVALID_HANDLE = 8
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OGRERR_FAILURE, __pyx_int_6) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":84
 * OGRERR_CORRUPT_DATA = 5
 * OGRERR_FAILURE = 6
 * OGRERR_UNSUPPORTED_SRS = 7             # <<<<<<<<<<<<<<
 * OGRERR_INVALID_HANDLE = 8
 * 
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OGRERR_UNSUPPORTED_SRS, __pyx_int_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 84; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":85
 * OGRERR_FAILURE = 6
 * OGRERR_UNSUPPORTED_SRS = 7
 * OGRERR_INVALID_HANDLE = 8             # <<<<<<<<<<<<<<
 * 
 * # Recent versions of OGR can sometimes detect file encoding, but don't
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OGRERR_INVALID_HANDLE, __pyx_int_8) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 85; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":89
 * # Recent versions of OGR can sometimes detect file encoding, but don't
 * # provide access yet to the detected encoding. Hence this variable.
 * OGR_DETECTED_ENCODING = '-ogr-detected-encoding'             # <<<<<<<<<<<<<<
 * 
 * # Geometry related functions and classes follow.
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_OGR_DETECTED_ENCODING, __pyx_kp_s_ogr_detected_encoding) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 89; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":109
 * 
 * 
 * class DimensionsHandler(object):             # <<<<<<<<<<<<<<
 *     """Determines the number of dimensions of a Fiona geometry.
 *     """
 */
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_builtin_object);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_builtin_object);
  __Pyx_GIVEREF(__pyx_builtin_object);
  __pyx_t_2 = __Pyx_CalculateMetaclass(NULL, __pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = __Pyx_Py3MetaclassPrepare(__pyx_t_2, __pyx_t_3, __pyx_n_s_DimensionsHandler, __pyx_n_s_DimensionsHandler, (PyObject *) NULL, __pyx_n_s_fiona_ogrext, __pyx_kp_s_Determines_the_number_of_dimensi); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);

  /* "fiona/ogrext.pyx":112
 *     """Determines the number of dimensions of a Fiona geometry.
 *     """
 *     coordinates = None             # <<<<<<<<<<<<<<
 * 
 *     def getNumDimsPoint(self):
 */
  if (PyObject_SetItem(__pyx_t_1, __pyx_n_s_coordinates, Py_None) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "fiona/ogrext.pyx":114
 *     coordinates = None
 * 
 *     def getNumDimsPoint(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates)
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_17DimensionsHandler_1getNumDimsPoint, 0, __pyx_n_s_DimensionsHandler_getNumDimsPoin, NULL, __pyx_n_s_fiona_ogrext, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__74)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  if (PyObject_SetItem(__pyx_t_1, __pyx_n_s_getNumDimsPoint, __pyx_t_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":117
 *         return len(self.coordinates)
 * 
 *     def getNumDimsLineString(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0])
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_17DimensionsHandler_3getNumDimsLineString, 0, __pyx_n_s_DimensionsHandler_getNumDimsLine, NULL, __pyx_n_s_fiona_ogrext, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__76)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  if (PyObject_SetItem(__pyx_t_1, __pyx_n_s_getNumDimsLineString, __pyx_t_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":120
 *         return len(self.coordinates[0])
 * 
 *     def getNumDimsLinearRing(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0])
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_17DimensionsHandler_5getNumDimsLinearRing, 0, __pyx_n_s_DimensionsHandler_getNumDimsLine_2, NULL, __pyx_n_s_fiona_ogrext, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__78)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  if (PyObject_SetItem(__pyx_t_1, __pyx_n_s_getNumDimsLinearRing, __pyx_t_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 120; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":123
 *         return len(self.coordinates[0])
 * 
 *     def getNumDimsPolygon(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0][0])
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_17DimensionsHandler_7getNumDimsPolygon, 0, __pyx_n_s_DimensionsHandler_getNumDimsPoly, NULL, __pyx_n_s_fiona_ogrext, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__80)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  if (PyObject_SetItem(__pyx_t_1, __pyx_n_s_getNumDimsPolygon, __pyx_t_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 123; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":126
 *         return len(self.coordinates[0][0])
 * 
 *     def getNumDimsMultiPoint(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0])
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_17DimensionsHandler_9getNumDimsMultiPoint, 0, __pyx_n_s_DimensionsHandler_getNumDimsMult, NULL, __pyx_n_s_fiona_ogrext, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__82)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  if (PyObject_SetItem(__pyx_t_1, __pyx_n_s_getNumDimsMultiPoint, __pyx_t_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 126; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":129
 *         return len(self.coordinates[0])
 * 
 *     def getNumDimsMultiLineString(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0][0])
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_17DimensionsHandler_11getNumDimsMultiLineString, 0, __pyx_n_s_DimensionsHandler_getNumDimsMult_2, NULL, __pyx_n_s_fiona_ogrext, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__84)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  if (PyObject_SetItem(__pyx_t_1, __pyx_n_s_getNumDimsMultiLineString, __pyx_t_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":132
 *         return len(self.coordinates[0][0])
 * 
 *     def getNumDimsMultiPolygon(self):             # <<<<<<<<<<<<<<
 *         return len(self.coordinates[0][0][0])
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_17DimensionsHandler_13getNumDimsMultiPolygon, 0, __pyx_n_s_DimensionsHandler_getNumDimsMult_3, NULL, __pyx_n_s_fiona_ogrext, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__86)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  if (PyObject_SetItem(__pyx_t_1, __pyx_n_s_getNumDimsMultiPolygon, __pyx_t_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":135
 *         return len(self.coordinates[0][0][0])
 * 
 *     def getNumDimsGeometryCollection(self):             # <<<<<<<<<<<<<<
 *         first = self.coordinates[0]
 *         return self.getNumDims(first['type'], first['coordinates'])
 */
  __pyx_t_4 = __Pyx_CyFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_17DimensionsHandler_15getNumDimsGeometryCollection, 0, __pyx_n_s_DimensionsHandler_getNumDimsGeom, NULL, __pyx_n_s_fiona_ogrext, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__88)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  if (PyObject_SetItem(__pyx_t_1, __pyx_n_s_getNumDimsGeometryCollection, __pyx_t_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":139
 *         return self.getNumDims(first['type'], first['coordinates'])
 * 
 *     def getNumDims(self, geom_type, coordinates):             # <<<<<<<<<<<<<<
 *         self.coordinates = coordinates
 *         return getattr(self, 'getNumDims' + geom_type)()
 */
  __pyx_t_4 = __Pyx_CyFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_17DimensionsHandler_17getNumDims, 0, __pyx_n_s_DimensionsHandler_getNumDims, NULL, __pyx_n_s_fiona_ogrext, PyModule_GetDict(__pyx_m), ((PyObject *)__pyx_codeobj__90)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  if (PyObject_SetItem(__pyx_t_1, __pyx_n_s_getNumDims, __pyx_t_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 139; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "fiona/ogrext.pyx":109
 * 
 * 
 * class DimensionsHandler(object):             # <<<<<<<<<<<<<<
 *     """Determines the number of dimensions of a Fiona geometry.
 *     """
 */
  __pyx_t_4 = __Pyx_Py3ClassCreate(__pyx_t_2, __pyx_n_s_DimensionsHandler, __pyx_t_3, __pyx_t_1, NULL, 0, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_DimensionsHandler, __pyx_t_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 109; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "fiona/ogrext.pyx":384
 * 
 * 
 * def geometryRT(geometry):             # <<<<<<<<<<<<<<
 *     # For testing purposes only, leaks the JSON data
 *     cdef void *cogr_geometry = OGRGeomBuilder().build(geometry)
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_1geometryRT, NULL, __pyx_n_s_fiona_ogrext); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 384; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_geometryRT, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 384; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "fiona/ogrext.pyx":393
 * 
 * 
 * def _explode(coords):             # <<<<<<<<<<<<<<
 *     """Explode a GeoJSON geometry's coordinates object and yield
 *     coordinate tuples. As long as the input is conforming, the type of
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_3_explode, NULL, __pyx_n_s_fiona_ogrext); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_explode, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 393; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "fiona/ogrext.pyx":406
 * 
 * 
 * def _bounds(geometry):             # <<<<<<<<<<<<<<
 *     """Bounding box of a GeoJSON geometry"""
 *     try:
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_6_bounds, NULL, __pyx_n_s_fiona_ogrext); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 406; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_bounds, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 406; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "fiona/ogrext.pyx":576
 * 
 * 
 * def featureRT(feature, collection):             # <<<<<<<<<<<<<<
 *     # For testing purposes only, leaks the JSON data
 *     cdef void *cogr_feature = OGRFeatureBuilder().build(feature, collection)
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_8featureRT, NULL, __pyx_n_s_fiona_ogrext); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 576; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_featureRT, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 576; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "fiona/ogrext.pyx":1105
 * 
 * 
 * def _listlayers(path):             # <<<<<<<<<<<<<<
 * 
 *     """Provides a list of the layers in an OGR data source.
 */
  __pyx_t_3 = PyCFunction_NewEx(&__pyx_mdef_5fiona_6ogrext_10_listlayers, NULL, __pyx_n_s_fiona_ogrext); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_listlayers, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "fiona/ogrext.pyx":1
 * # These are extension functions and classes using the OGR C API.             # <<<<<<<<<<<<<<
 * 
 * import datetime
 */
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  if (__pyx_m) {
    __Pyx_AddTraceback("init fiona.ogrext", __pyx_clineno, __pyx_lineno, __pyx_filename);
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init fiona.ogrext");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* Runtime support code */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif /* CYTHON_REFNANNY */

static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

static CYTHON_INLINE int __Pyx_GetItemInt_ByteArray_Fast(PyObject* string, Py_ssize_t i,
                                                         int wraparound, int boundscheck) {
    Py_ssize_t length;
    if (wraparound | boundscheck) {
        length = PyByteArray_GET_SIZE(string);
        if (wraparound & unlikely(i < 0)) i += length;
        if ((!boundscheck) || likely((0 <= i) & (i < length))) {
            return (unsigned char) (PyByteArray_AS_STRING(string)[i]);
        } else {
            PyErr_SetString(PyExc_IndexError, "bytearray index out of range");
            return -1;
        }
    } else {
        return (unsigned char) (PyByteArray_AS_STRING(string)[i]);
    }
}

static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (wraparound & unlikely(i < 0)) i += PyList_GET_SIZE(o);
    if ((!boundscheck) || likely((0 <= i) & (i < PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (wraparound & unlikely(i < 0)) i += PyTuple_GET_SIZE(o);
    if ((!boundscheck) || likely((0 <= i) & (i < PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely((n >= 0) & (n < PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely((n >= 0) & (n < PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (PyErr_ExceptionMatches(PyExc_OverflowError))
                        PyErr_Clear();
                    else
                        return NULL;
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_COMPILING_IN_CPYTHON
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_Restore(type, value, tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(type, value, tb);
#endif
}

#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    #if PY_VERSION_HEX < 0x02050000
    if (PyClass_Check(type)) {
    #else
    if (PyType_Check(type)) {
    #endif
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        #if PY_VERSION_HEX < 0x02050000
        if (PyInstance_Check(type)) {
            type = (PyObject*) ((PyInstanceObject*)type)->in_class;
            Py_INCREF(type);
        } else {
            type = 0;
            PyErr_SetString(PyExc_TypeError,
                "raise: exception must be an old-style class or instance");
            goto raise_error;
        }
        #else
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
        #endif
    }
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else /* Python 3+ */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                if (PyObject_IsSubclass(instance_class, type)) {
                    type = instance_class;
                } else {
                    instance_class = NULL;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
#if PY_VERSION_HEX >= 0x03030000
    if (cause) {
#else
    if (cause && cause != Py_None) {
#endif
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
        PyThreadState *tstate = PyThreadState_GET();
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON
    result = PyDict_GetItem(__pyx_d, name);
    if (result) {
        Py_INCREF(result);
    } else {
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(exc_type == PyExc_StopIteration) || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        #if CYTHON_PEP393_ENABLED
        if (unlikely(PyUnicode_READY(s1) < 0) || unlikely(PyUnicode_READY(s2) < 0))
            return -1;
        #endif
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, length * kind);
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

static CYTHON_INLINE void __Pyx_ExceptionSave(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
#else
    PyErr_GetExcInfo(type, value, tb);
#endif
}
static void __Pyx_ExceptionReset(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(type, value, tb);
#endif
}

static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_COMPILING_IN_CPYTHON
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_COMPILING_IN_CPYTHON
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors)) {
    Py_ssize_t length;
    if (unlikely((start < 0) | (stop < 0))) {
        length = strlen(cstring);
        if (start < 0) {
            start += length;
            if (start < 0)
                start = 0;
        }
        if (stop < 0)
            stop += length;
    }
    length = stop - start;
    if (unlikely(length <= 0))
        return PyUnicode_FromUnicode(NULL, 0);
    cstring += start;
    if (decode_func) {
        return decode_func(cstring, length, errors);
    } else {
        return PyUnicode_Decode(cstring, length, encoding, errors);
    }
}

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(PyObject_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CPYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
}

static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

static double __Pyx__PyObject_AsDouble(PyObject* obj) {
    PyObject* float_value;
#if CYTHON_COMPILING_IN_PYPY
    float_value = PyNumber_Float(obj);
#else
    PyNumberMethods *nb = Py_TYPE(obj)->tp_as_number;
    if (likely(nb) && likely(nb->nb_float)) {
        float_value = nb->nb_float(obj);
        if (likely(float_value) && unlikely(!PyFloat_Check(float_value))) {
            PyErr_Format(PyExc_TypeError,
                "__float__ returned non-float (type %.200s)",
                Py_TYPE(float_value)->tp_name);
            Py_DECREF(float_value);
            goto bad;
        }
    } else if (PyUnicode_CheckExact(obj) || PyBytes_CheckExact(obj)) {
#if PY_MAJOR_VERSION >= 3
        float_value = PyFloat_FromString(obj);
#else
        float_value = PyFloat_FromString(obj, 0);
#endif
    } else {
        PyObject* args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        PyTuple_SET_ITEM(args, 0, obj);
        float_value = PyObject_Call((PyObject*)&PyFloat_Type, args, 0);
        PyTuple_SET_ITEM(args, 0, 0);
        Py_DECREF(args);
    }
#endif
    if (likely(float_value)) {
        double value = PyFloat_AS_DOUBLE(float_value);
        Py_DECREF(float_value);
        return value;
    }
bad:
    return (double)-1;
}

#if !CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values) {
    return PyObject_CallMethodObjArgs(sep, __pyx_n_s_join, values, NULL)
}
#endif

static CYTHON_INLINE void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL)
        value = Py_None; /* Mark as deleted */
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    Py_DECREF(res);
    return 0;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
#ifndef PY_WRITE_RESTRICTED /* < Py2.5 */
#define PY_WRITE_RESTRICTED WRITE_RESTRICTED
#endif
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(__pyx_CyFunctionObject, func.m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromString(m->func.m_ml->ml_name);
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {__Pyx_NAMESTR("__reduce__"), (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
static PyObject *__Pyx_CyFunction_New(PyTypeObject *type, PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    __pyx_CyFunctionObject *op = PyObject_GC_New(__pyx_CyFunctionObject, type);
    if (op == NULL)
        return NULL;
    op->flags = flags;
    op->func_weakreflist = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    PyObject_GC_Track(op);
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyMem_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    if (m->func_weakreflist != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return PyMethod_New(func,
                            type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
    return PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
#if CYTHON_COMPILING_IN_PYPY
static PyObject * __Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    Py_ssize_t size;
    switch (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST)) {
    case METH_VARARGS:
        if (likely(kw == NULL) || PyDict_Size(kw) == 0)
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL) || PyDict_Size(kw) == 0) {
            size = PyTuple_GET_SIZE(arg);
            if (size == 0)
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%zd given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL) || PyDict_Size(kw) == 0) {
            size = PyTuple_GET_SIZE(arg);
            if (size == 1)
                return (*meth)(self, PyTuple_GET_ITEM(arg, 0));
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%zd given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
#else
static PyObject * __Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
	return PyCFunction_Call(func, arg, kw);
}
#endif
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __Pyx_NAMESTR("cython_function_or_method"), /*tp_name*/
    sizeof(__pyx_CyFunctionObject),   /*tp_basicsize*/
    0,                                  /*tp_itemsize*/
    (destructor) __Pyx_CyFunction_dealloc, /*tp_dealloc*/
    0,                                  /*tp_print*/
    0,                                  /*tp_getattr*/
    0,                                  /*tp_setattr*/
#if PY_MAJOR_VERSION < 3
    0,                                  /*tp_compare*/
#else
    0,                                  /*reserved*/
#endif
    (reprfunc) __Pyx_CyFunction_repr,   /*tp_repr*/
    0,                                  /*tp_as_number*/
    0,                                  /*tp_as_sequence*/
    0,                                  /*tp_as_mapping*/
    0,                                  /*tp_hash*/
    __Pyx_CyFunction_Call,              /*tp_call*/
    0,                                  /*tp_str*/
    0,                                  /*tp_getattro*/
    0,                                  /*tp_setattro*/
    0,                                  /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC, /* tp_flags*/
    0,                                  /*tp_doc*/
    (traverseproc) __Pyx_CyFunction_traverse,   /*tp_traverse*/
    (inquiry) __Pyx_CyFunction_clear,   /*tp_clear*/
    0,                                  /*tp_richcompare*/
    offsetof(__pyx_CyFunctionObject, func_weakreflist), /* tp_weaklistoffse */
    0,                                  /*tp_iter*/
    0,                                  /*tp_iternext*/
    __pyx_CyFunction_methods,           /*tp_methods*/
    __pyx_CyFunction_members,           /*tp_members*/
    __pyx_CyFunction_getsets,           /*tp_getset*/
    0,                                  /*tp_base*/
    0,                                  /*tp_dict*/
    __Pyx_CyFunction_descr_get,         /*tp_descr_get*/
    0,                                  /*tp_descr_set*/
    offsetof(__pyx_CyFunctionObject, func_dict),/*tp_dictoffset*/
    0,                                  /*tp_init*/
    0,                                  /*tp_alloc*/
    0,                                  /*tp_new*/
    0,                                  /*tp_free*/
    0,                                  /*tp_is_gc*/
    0,                                  /*tp_bases*/
    0,                                  /*tp_mro*/
    0,                                  /*tp_cache*/
    0,                                  /*tp_subclasses*/
    0,                                  /*tp_weaklist*/
    0,                                  /*tp_del*/
#if PY_VERSION_HEX >= 0x02060000
    0,                                  /*tp_version_tag*/
#endif
#if PY_VERSION_HEX >= 0x030400a1
    0,                                  /*tp_finalize*/
#endif
};
static int __Pyx_CyFunction_init(void) {
#if !CYTHON_COMPILING_IN_PYPY
    __pyx_CyFunctionType_type.tp_call = PyCFunction_Call;
#endif
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (__pyx_CyFunctionType == NULL) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyMem_Malloc(size);
    if (!m->defaults)
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3&&PY_MINOR_VERSION==0)
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases = PyTuple_GET_SIZE(bases);
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStr(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs = PyTuple_Pack(2, name, bases);
            if (unlikely(!pargs)) {
                Py_DECREF(prep);
                return NULL;
            }
            ns = PyObject_Call(prep, pargs, mkw);
            Py_DECREF(prep);
            Py_DECREF(pargs);
        } else {
            if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError)))
                return NULL;
            PyErr_Clear();
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result, *margs;
    PyObject *owned_metaclass = NULL;
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    margs = PyTuple_Pack(3, name, bases, dict);
    if (unlikely(!margs)) {
        result = NULL;
    } else {
        result = PyObject_Call(metaclass, margs, mkw);
        Py_DECREF(margs);
    }
    Py_XDECREF(owned_metaclass);
    return result;
}

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_VERSION_HEX < 0x03030000
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    #if PY_VERSION_HEX >= 0x02050000
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                #if PY_VERSION_HEX < 0x03030000
                PyObject *py_level = PyInt_FromLong(1);
                if (!py_level)
                    goto bad;
                module = PyObject_CallFunctionObjArgs(py_import,
                    name, global_dict, empty_dict, list, py_level, NULL);
                Py_DECREF(py_level);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                #endif
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0; /* try absolute import on failure */
        }
        #endif
        if (!module) {
            #if PY_VERSION_HEX < 0x03030000
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
    #else
    if (level>0) {
        PyErr_SetString(PyExc_RuntimeError, "Relative import is not supported for Python <=2.4.");
        goto bad;
    }
    module = PyObject_CallFunctionObjArgs(py_import,
        name, global_dict, empty_dict, list, NULL);
    #endif
bad:
    #if PY_VERSION_HEX < 0x03030000
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(long) <= sizeof(unsigned long long)) {
            return PyLong_FromUnsignedLongLong((unsigned long long) value);
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(long long)) {
            return PyLong_FromLongLong((long long) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(int) <= sizeof(unsigned long long)) {
            return PyLong_FromUnsignedLongLong((unsigned long long) value);
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(long long)) {
            return PyLong_FromLongLong((long long) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func)             \
    {                                                                     \
        func_type value = func(x);                                        \
        if (sizeof(target_type) < sizeof(func_type)) {                    \
            if (unlikely(value != (func_type) (target_type) value)) {     \
                func_type zero = 0;                                       \
                PyErr_SetString(PyExc_OverflowError,                      \
                    (is_unsigned && unlikely(value < zero)) ?             \
                    "can't convert negative value to " #target_type :     \
                    "value too large to convert to " #target_type);       \
                return (target_type) -1;                                  \
            }                                                             \
        }                                                                 \
        return (target_type) value;                                       \
    }

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
 #endif
#endif
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG)
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to int");
                return (int) -1;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(int)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (int) ((PyLongObject*)x)->ob_digit[0];
                }
            }
 #endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to int");
                return (int) -1;
            }
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT(int, unsigned long, PyLong_AsUnsignedLong)
            } else if (sizeof(int) <= sizeof(unsigned long long)) {
                __PYX_VERIFY_RETURN_INT(int, unsigned long long, PyLong_AsUnsignedLongLong)
            }
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(int)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(int) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(int) ((PyLongObject*)x)->ob_digit[0];
                }
            }
 #endif
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT(int, long, PyLong_AsLong)
            } else if (sizeof(int) <= sizeof(long long)) {
                __PYX_VERIFY_RETURN_INT(int, long long, PyLong_AsLongLong)
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_int(unsigned int value) {
    const unsigned int neg_one = (unsigned int) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(unsigned int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(unsigned int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(unsigned int) <= sizeof(unsigned long long)) {
            return PyLong_FromUnsignedLongLong((unsigned long long) value);
        }
    } else {
        if (sizeof(unsigned int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(unsigned int) <= sizeof(long long)) {
            return PyLong_FromLongLong((long long) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(unsigned int),
                                     little, !is_unsigned);
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
 #endif
#endif
static CYTHON_INLINE unsigned int __Pyx_PyInt_As_unsigned_int(PyObject *x) {
    const unsigned int neg_one = (unsigned int) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(unsigned int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(unsigned int, long, PyInt_AS_LONG)
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned int");
                return (unsigned int) -1;
            }
            return (unsigned int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(unsigned int)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (unsigned int) ((PyLongObject*)x)->ob_digit[0];
                }
            }
 #endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned int");
                return (unsigned int) -1;
            }
            if (sizeof(unsigned int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT(unsigned int, unsigned long, PyLong_AsUnsignedLong)
            } else if (sizeof(unsigned int) <= sizeof(unsigned long long)) {
                __PYX_VERIFY_RETURN_INT(unsigned int, unsigned long long, PyLong_AsUnsignedLongLong)
            }
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(unsigned int)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(unsigned int) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(unsigned int) ((PyLongObject*)x)->ob_digit[0];
                }
            }
 #endif
#endif
            if (sizeof(unsigned int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT(unsigned int, long, PyLong_AsLong)
            } else if (sizeof(unsigned int) <= sizeof(long long)) {
                __PYX_VERIFY_RETURN_INT(unsigned int, long long, PyLong_AsLongLong)
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            unsigned int val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (unsigned int) -1;
        }
    } else {
        unsigned int val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned int) -1;
        val = __Pyx_PyInt_As_unsigned_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
 #endif
#endif
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) -1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG)
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to long");
                return (long) -1;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return (long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
 #endif
#endif
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to long");
                return (long) -1;
            }
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT(long, unsigned long, PyLong_AsUnsignedLong)
            } else if (sizeof(long) <= sizeof(unsigned long long)) {
                __PYX_VERIFY_RETURN_INT(long, unsigned long long, PyLong_AsUnsignedLongLong)
            }
        } else {
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
            if (sizeof(digit) <= sizeof(long)) {
                switch (Py_SIZE(x)) {
                    case  0: return 0;
                    case  1: return +(long) ((PyLongObject*)x)->ob_digit[0];
                    case -1: return -(long) ((PyLongObject*)x)->ob_digit[0];
                }
            }
 #endif
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT(long, long, PyLong_AsLong)
            } else if (sizeof(long) <= sizeof(long long)) {
                __PYX_VERIFY_RETURN_INT(long, long long, PyLong_AsLongLong)
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
#else
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
#endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}

static PyObject *__Pyx_Generator_Next(PyObject *self);
static PyObject *__Pyx_Generator_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Generator_Close(PyObject *self);
static PyObject *__Pyx_Generator_Throw(PyObject *gen, PyObject *args);
static PyTypeObject *__pyx_GeneratorType = 0;
#define __Pyx_Generator_CheckExact(obj) (Py_TYPE(obj) == __pyx_GeneratorType)
#define __Pyx_Generator_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
#if 1 || PY_VERSION_HEX < 0x030300B0
static int __Pyx_PyGen_FetchStopIterationValue(PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (unlikely(et != PyExc_StopIteration) &&
            unlikely(!PyErr_GivenExceptionMatches(et, PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (likely(!ev) || !PyObject_IsInstance(ev, PyExc_StopIteration)) {
            if (!ev) {
                Py_INCREF(Py_None);
                ev = Py_None;
            }
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = ev;
            return 0;
        }
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_IsInstance(ev, PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = PyObject_GetAttr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PyObject_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
#endif
static CYTHON_INLINE
void __Pyx_Generator_ExceptionClear(__pyx_GeneratorObject *self) {
    PyObject *exc_type = self->exc_type;
    PyObject *exc_value = self->exc_value;
    PyObject *exc_traceback = self->exc_traceback;
    self->exc_type = NULL;
    self->exc_value = NULL;
    self->exc_traceback = NULL;
    Py_XDECREF(exc_type);
    Py_XDECREF(exc_value);
    Py_XDECREF(exc_traceback);
}
static CYTHON_INLINE
int __Pyx_Generator_CheckRunning(__pyx_GeneratorObject *gen) {
    if (unlikely(gen->is_running)) {
        PyErr_SetString(PyExc_ValueError,
                        "generator already executing");
        return 1;
    }
    return 0;
}
static CYTHON_INLINE
PyObject *__Pyx_Generator_SendEx(__pyx_GeneratorObject *self, PyObject *value) {
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            PyErr_SetString(PyExc_TypeError,
                            "can't send non-None value to a "
                            "just-started generator");
            return NULL;
        }
    }
    if (unlikely(self->resume_label == -1)) {
        PyErr_SetNone(PyExc_StopIteration);
        return NULL;
    }
    if (value) {
#if CYTHON_COMPILING_IN_PYPY
#else
        /* Generators always return to their most recent caller, not
         * necessarily their creator. */
        if (self->exc_traceback) {
            PyThreadState *tstate = PyThreadState_GET();
            PyTracebackObject *tb = (PyTracebackObject *) self->exc_traceback;
            PyFrameObject *f = tb->tb_frame;
            Py_XINCREF(tstate->frame);
            assert(f->f_back == NULL);
            f->f_back = tstate->frame;
        }
#endif
        __Pyx_ExceptionSwap(&self->exc_type, &self->exc_value,
                            &self->exc_traceback);
    } else {
        __Pyx_Generator_ExceptionClear(self);
    }
    self->is_running = 1;
    retval = self->body((PyObject *) self, value);
    self->is_running = 0;
    if (retval) {
        __Pyx_ExceptionSwap(&self->exc_type, &self->exc_value,
                            &self->exc_traceback);
#if CYTHON_COMPILING_IN_PYPY
#else
        /* Don't keep the reference to f_back any longer than necessary.  It
         * may keep a chain of frames alive or it could create a reference
         * cycle. */
        if (self->exc_traceback) {
            PyTracebackObject *tb = (PyTracebackObject *) self->exc_traceback;
            PyFrameObject *f = tb->tb_frame;
            Py_CLEAR(f->f_back);
        }
#endif
    } else {
        __Pyx_Generator_ExceptionClear(self);
    }
    return retval;
}
static CYTHON_INLINE
PyObject *__Pyx_Generator_FinishDelegation(__pyx_GeneratorObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Generator_Undelegate(gen);
    __Pyx_PyGen_FetchStopIterationValue(&val);
    ret = __Pyx_Generator_SendEx(gen, val);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(__Pyx_Generator_CheckRunning(gen)))
        return NULL;
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        ret = Py_TYPE(yf)->tp_iternext(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Generator_FinishDelegation(gen);
    }
    return __Pyx_Generator_SendEx(gen, Py_None);
}
static PyObject *__Pyx_Generator_Send(PyObject *self, PyObject *value) {
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(__Pyx_Generator_CheckRunning(gen)))
        return NULL;
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Send(yf, value);
        } else {
            if (value == Py_None)
                ret = PyIter_Next(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Generator_FinishDelegation(gen);
    }
    return __Pyx_Generator_SendEx(gen, value);
}
static int __Pyx_Generator_CloseIter(__pyx_GeneratorObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Generator_Close(yf);
        if (!retval)
            return -1;
    } else {
        PyObject *meth;
        gen->is_running = 1;
        meth = PyObject_GetAttr(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                PyErr_WriteUnraisable(yf);
            }
            PyErr_Clear();
        } else {
            retval = PyObject_CallFunction(meth, NULL);
            Py_DECREF(meth);
            if (!retval)
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Close(PyObject *self) {
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(__Pyx_Generator_CheckRunning(gen)))
        return NULL;
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Generator_CloseIter(gen, yf);
        __Pyx_Generator_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
#if PY_VERSION_HEX < 0x02050000
        PyErr_SetNone(PyExc_StopIteration);
#else
        PyErr_SetNone(PyExc_GeneratorExit);
#endif
    retval = __Pyx_Generator_SendEx(gen, NULL);
    if (retval) {
        Py_DECREF(retval);
        PyErr_SetString(PyExc_RuntimeError,
                        "generator ignored GeneratorExit");
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (!raised_exception
        || raised_exception == PyExc_StopIteration
#if PY_VERSION_HEX >= 0x02050000
        || raised_exception == PyExc_GeneratorExit
        || PyErr_GivenExceptionMatches(raised_exception, PyExc_GeneratorExit)
#endif
        || PyErr_GivenExceptionMatches(raised_exception, PyExc_StopIteration))
    {
        if (raised_exception) PyErr_Clear();      /* ignore these errors */
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx_Generator_Throw(PyObject *self, PyObject *args) {
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject *) self;
    PyObject *typ;
    PyObject *tb = NULL;
    PyObject *val = NULL;
    PyObject *yf = gen->yieldfrom;
    if (!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb))
        return NULL;
    if (unlikely(__Pyx_Generator_CheckRunning(gen)))
        return NULL;
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
#if PY_VERSION_HEX >= 0x02050000
        if (PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit)) {
            int err = __Pyx_Generator_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Generator_Undelegate(gen);
            if (err < 0)
                return __Pyx_Generator_SendEx(gen, NULL);
            goto throw_here;
        }
#endif
        gen->is_running = 1;
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Throw(yf, args);
        } else {
            PyObject *meth = PyObject_GetAttr(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                    gen->is_running = 0;
                    return NULL;
                }
                PyErr_Clear();
                __Pyx_Generator_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            ret = PyObject_CallObject(meth, args);
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Generator_FinishDelegation(gen);
        }
        return ret;
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Generator_SendEx(gen, NULL);
}
static int __Pyx_Generator_traverse(PyObject *self, visitproc visit, void *arg) {
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject *) self;
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    Py_VISIT(gen->exc_type);
    Py_VISIT(gen->exc_value);
    Py_VISIT(gen->exc_traceback);
    return 0;
}
static int __Pyx_Generator_clear(PyObject *self) {
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    Py_CLEAR(gen->exc_type);
    Py_CLEAR(gen->exc_value);
    Py_CLEAR(gen->exc_traceback);
    return 0;
}
static void __Pyx_Generator_dealloc(PyObject *self) {
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label > 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1
        if (PyObject_CallFinalizerFromDealloc(self))
#else
        Py_TYPE(gen)->tp_del(self);
        if (self->ob_refcnt > 0)
#endif
            return;                     /* resurrected.  :( */
        PyObject_GC_UnTrack(self);
    }
    __Pyx_Generator_clear(self);
    PyObject_GC_Del(gen);
}
static void __Pyx_Generator_del(PyObject *self) {
    PyObject *res;
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_GeneratorObject *gen = (__pyx_GeneratorObject *) self;
    if (gen->resume_label <= 0)
        return ;
#if PY_VERSION_HEX < 0x030400a1
    assert(self->ob_refcnt == 0);
    self->ob_refcnt = 1;
#endif
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
    res = __Pyx_Generator_Close(self);
    if (res == NULL)
        PyErr_WriteUnraisable(self);
    else
        Py_DECREF(res);
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if PY_VERSION_HEX < 0x030400a1
    /* Undo the temporary resurrection; can't use DECREF here, it would
     * cause a recursive call.
     */
    assert(self->ob_refcnt > 0);
    if (--self->ob_refcnt == 0)
        return; /* this is the normal path out */
    /* close() resurrected it!  Make it look like the original Py_DECREF
     * never happened.
     */
    {
        Py_ssize_t refcnt = self->ob_refcnt;
        _Py_NewReference(self);
        self->ob_refcnt = refcnt;
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(self->ob_type) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    /* If Py_REF_DEBUG, _Py_NewReference bumped _Py_RefTotal, so
     * we need to undo that. */
    _Py_DEC_REFTOTAL;
#endif
    /* If Py_TRACE_REFS, _Py_NewReference re-added self to the object
     * chain, so no more to do there.
     * If COUNT_ALLOCS, the original decref bumped tp_frees, and
     * _Py_NewReference bumped tp_allocs:  both of those need to be
     * undone.
     */
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running",
#if PY_VERSION_HEX >= 0x02060000
     T_BOOL,
#else
     T_BYTE,
#endif
     offsetof(__pyx_GeneratorObject, is_running),
     READONLY,
     NULL},
    {0, 0, 0, 0, 0}
};
static PyMethodDef __pyx_Generator_methods[] = {
    {__Pyx_NAMESTR("send"), (PyCFunction) __Pyx_Generator_Send, METH_O, 0},
    {__Pyx_NAMESTR("throw"), (PyCFunction) __Pyx_Generator_Throw, METH_VARARGS, 0},
    {__Pyx_NAMESTR("close"), (PyCFunction) __Pyx_Generator_Close, METH_NOARGS, 0},
    {0, 0, 0, 0}
};
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __Pyx_NAMESTR("generator"),         /*tp_name*/
    sizeof(__pyx_GeneratorObject),      /*tp_basicsize*/
    0,                                  /*tp_itemsize*/
    (destructor) __Pyx_Generator_dealloc,/*tp_dealloc*/
    0,                                  /*tp_print*/
    0,                                  /*tp_getattr*/
    0,                                  /*tp_setattr*/
#if PY_MAJOR_VERSION < 3
    0,                                  /*tp_compare*/
#else
    0,                                  /*reserved*/
#endif
    0,                                   /*tp_repr*/
    0,                                  /*tp_as_number*/
    0,                                  /*tp_as_sequence*/
    0,                                  /*tp_as_mapping*/
    0,                                  /*tp_hash*/
    0,                                  /*tp_call*/
    0,                                  /*tp_str*/
    0,                                  /*tp_getattro*/
    0,                                  /*tp_setattro*/
    0,                                  /*tp_as_buffer*/
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE, /* tp_flags*/
    0,                                  /*tp_doc*/
    (traverseproc) __Pyx_Generator_traverse,   /*tp_traverse*/
    0,                                  /*tp_clear*/
    0,                                  /*tp_richcompare*/
    offsetof(__pyx_GeneratorObject, gi_weakreflist), /* tp_weaklistoffse */
    0,                                  /*tp_iter*/
    (iternextfunc) __Pyx_Generator_Next, /*tp_iternext*/
    __pyx_Generator_methods,            /*tp_methods*/
    __pyx_Generator_memberlist,         /*tp_members*/
    0,                                  /*tp_getset*/
    0,                                  /*tp_base*/
    0,                                  /*tp_dict*/
    0,                                  /*tp_descr_get*/
    0,                                  /*tp_descr_set*/
    0,                                  /*tp_dictoffset*/
    0,                                  /*tp_init*/
    0,                                  /*tp_alloc*/
    0,                                  /*tp_new*/
    0,                                  /*tp_free*/
    0,                                  /*tp_is_gc*/
    0,                                  /*tp_bases*/
    0,                                  /*tp_mro*/
    0,                                  /*tp_cache*/
    0,                                  /*tp_subclasses*/
    0,                                  /*tp_weaklist*/
#if PY_VERSION_HEX >= 0x030400a1
    0,                                  /*tp_del*/
#else
    __Pyx_Generator_del,                /*tp_del*/
#endif
#if PY_VERSION_HEX >= 0x02060000
    0,                                  /*tp_version_tag*/
#endif
#if PY_VERSION_HEX >= 0x030400a1
    __Pyx_Generator_del,                /*tp_finalize*/
#endif
};
static __pyx_GeneratorObject *__Pyx_Generator_New(__pyx_generator_body_t body,
                                                  PyObject *closure) {
    __pyx_GeneratorObject *gen =
        PyObject_GC_New(__pyx_GeneratorObject, &__pyx_GeneratorType_type);
    if (gen == NULL)
        return NULL;
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    gen->exc_type = NULL;
    gen->exc_value = NULL;
    gen->exc_traceback = NULL;
    gen->gi_weakreflist = NULL;
    PyObject_GC_Track(gen);
    return gen;
}
static int __pyx_Generator_init(void) {
    __pyx_GeneratorType_type.tp_getattro = PyObject_GenericGetAttr;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
    if (__pyx_GeneratorType == NULL) {
        return -1;
    }
    return 0;
}

static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        #if PY_VERSION_HEX < 0x02050000
        return PyErr_Warn(NULL, message);
        #else
        return PyErr_WarnEx(NULL, message, 1);
        #endif
    }
    return 0;
}

static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = (start + end) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,            /*int argcount,*/
        0,            /*int kwonlyargcount,*/
        0,            /*int nlocals,*/
        0,            /*int stacksize,*/
        0,            /*int flags,*/
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,      /*int firstlineno,*/
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_globals = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_globals = PyModule_GetDict(__pyx_m);
    if (!py_globals) goto bad;
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        py_globals,          /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    py_frame->f_lineno = py_line;
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else  /* Python 3+ has unicode identifiers */
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, strlen(c_str));
}
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
#if PY_VERSION_HEX < 0x03030000
        char* defenc_c;
        PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
        if (!defenc) return NULL;
        defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        {
            char* end = defenc_c + PyBytes_GET_SIZE(defenc);
            char* c;
            for (c = defenc_c; c < end; c++) {
                if ((unsigned char) (*c) >= 128) {
                    PyUnicode_AsASCIIString(o);
                    return NULL;
                }
            }
        }
#endif /*__PYX_DEFAULT_STRING_ENCODING_IS_ASCII*/
        *length = PyBytes_GET_SIZE(defenc);
        return defenc_c;
#else /* PY_VERSION_HEX < 0x03030000 */
        if (PyUnicode_READY(o) == -1) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        if (PyUnicode_IS_ASCII(o)) {
            *length = PyUnicode_GET_DATA_SIZE(o);
            return PyUnicode_AsUTF8(o);
        } else {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
#else /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII */
        return PyUnicode_AsUTF8AndSize(o, length);
#endif /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII */
#endif /* PY_VERSION_HEX < 0x03030000 */
    } else
#endif /* __PYX_DEFAULT_STRING_ENCODING_IS_ASCII  || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT */
#if PY_VERSION_HEX >= 0x02060000
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x) {
  PyNumberMethods *m;
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return Py_INCREF(x), x;
  m = Py_TYPE(x)->tp_as_number;
#if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
#else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
#endif
  if (res) {
#if PY_MAJOR_VERSION < 3
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%.4s__ returned non-%.4s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
 #if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
 #endif
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b)))
      return PyInt_AS_LONG(b);
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
     #if CYTHON_USE_PYLONG_INTERNALS
       switch (Py_SIZE(b)) {
       case -1: return -(sdigit)((PyLongObject*)b)->ob_digit[0];
       case  0: return 0;
       case  1: return ((PyLongObject*)b)->ob_digit[0];
       }
     #endif
    #endif
  #if PY_VERSION_HEX < 0x02060000
    return PyInt_AsSsize_t(b);
  #else
    return PyLong_AsSsize_t(b);
  #endif
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
#if PY_VERSION_HEX < 0x02050000
   if (ival <= LONG_MAX)
       return PyInt_FromLong((long)ival);
   else {
       unsigned char *bytes = (unsigned char *) &ival;
       int one = 1; int little = (int)*(unsigned char*)&one;
       return _PyLong_FromByteArray(bytes, sizeof(size_t), little, 0);
   }
#else
   return PyInt_FromSize_t(ival);
#endif
}


#endif /* Py_PYTHON_H */
